--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersAnimalCareSeasons by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021

-- FillType indices

--[[
	1 :: UNKNOWN, 2 :: WHEAT, 3 :: BARLEY, 4 :: OAT, 5 :: CANOLA, 6 :: SUNFLOWER, 7 :: SOYBEAN, 8 :: MAIZE
	9 :: POTATO, 10 :: SUGARBEET, 11 :: COTTON, 12 :: SUGARCANE, 13 :: SEEDS, 14 :: EGG, 15 :: WOOL, 16 :: MILK
	17 :: FUEL, 18 :: WATER, 19 :: FORAGE, 20 :: FORAGE_MIXING, 21 :: CHAFF, 22 :: TREESAPLINGS, 23 :: WOODCHIPS
	24 :: SILAGE, 25 :: OILSEEDRADISH, 26 :: POPLAR, 27 :: GRASS, 28 :: GRASS_WINDROW, 29 :: DRYGRASS,
	30 :: DRYGRASS_WINDROW, 31 :: STRAW, 32 :: DIESEL, 33 :: DEF, 34 :: AIR, 35 :: ROUNDBALE, 36 :: ROUNDBALE_GRASS
	37 :: ROUNDBALE_DRYGRASS, 38 :: ROUNDBALE_WHEAT, 39 :: ROUNDBALE_BARLEY, 40 :: SQUAREBALE, 41 :: SQUAREBALE_WHEAT
	42 :: SQUAREBALE_BARLEY, 43 :: FERTILIZER, 44 :: LIQUIDFERTILIZER, 45 :: MANURE, 46 :: LIQUIDMANURE
	47 :: DIGESTATE, 48 :: PIGFOOD, 49 :: TARP, 50 :: LIME, 51 :: HERBICIDE, 52 :: WEED, 53 :: HORSE_TYPE_BEIGE
	54 :: HORSE_TYPE_BLACK, 55 :: HORSE_TYPE_BROWN, 56 :: HORSE_TYPE_BROWN_WHITE, 57 :: HORSE_TYPE_DARK_BROWN
	58 :: HORSE_TYPE_GREY, 59 :: HORSE_TYPE_LIGHT_BROWN, 60 :: HORSE_TYPE_RED_BROWN, 61 :: COW_TYPE_BROWN
	62 :: COW_TYPE_BROWN_WHITE, 63 :: COW_TYPE_BLACK, 64 :: COW_TYPE_BLACK_WHITE, 65 :: COW_TYPE_BRAHMAN_BROWN
	66 :: COW_TYPE_BRAHMAN_WHITE, 67 :: COW_TYPE_BRAHMAN_LIGHT_BROWN, 68 :: COW_TYPE_BRAHMAN_GREY
	69 :: SHEEP_TYPE_WHITE, 70 :: SHEEP_TYPE_BROWN, 71 :: SHEEP_TYPE_BLACK_WHITE, 72 :: SHEEP_TYPE_BLACK
	73 :: PIG_TYPE_RED, 74 :: PIG_TYPE_WHITE, 75 :: PIG_TYPE_BLACK_WHITE, 76 :: PIG_TYPE_BLACK
	77 :: CHICKEN_TYPE_BLACK, 78 :: CHICKEN_TYPE_WHITE, 79 :: CHICKEN_TYPE_BROWN, 80 :: CHICKEN_TYPE_ROOSTER
	
	local pigNames = {"PIG_TYPE_RED", "PIG_TYPE_WHITE", "PIG_TYPE_BLACK_WHITE", "PIG_TYPE_BLACK"};
	local cow1Names = {"COW_TYPE_BROWN", "COW_TYPE_BROWN_WHITE", "COW_TYPE_BLACK", "COW_TYPE_BLACK_WHITE"};
	local cow2Names = {"COW_TYPE_BRAHMAN_BROWN", "COW_TYPE_BRAHMAN_WHITE", "COW_TYPE_BRAHMAN_LIGHT_BROWN", "COW_TYPE_BRAHMAN_GREY"};
	local sheepNames = {"SHEEP_TYPE_WHITE", "SHEEP_TYPE_BROWN", "SHEEP_TYPE_BLACK_WHITE", "SHEEP_TYPE_BLACK"};
	local chickenNames = {"CHICKEN_TYPE_BLACK", "CHICKEN_TYPE_WHITE", "CHICKEN_TYPE_BROWN", "CHICKEN_TYPE_ROOSTER"};
	local horses1Names = {"HORSE_TYPE_GREY","HORSE_TYPE_BROWN_WHITE","HORSE_TYPE_BEIGE","HORSE_TYPE_RED_BROWN"};
	local horses2Names = {"HORSE_TYPE_BROWN","HORSE_TYPE_BLACK","HORSE_TYPE_DARK_BROWN","HORSE_TYPE_LIGHT_BROWN"};
	
--]]

RealNumbersAnimalCareSeasons = {};

function RealNumbersAnimalCareSeasons:loadMap(name)


	print("\nFS19_RealLifeNumbers: RealNumbersAnimalCareSeasons active\n")

	RNS.notRunYetRealNumbersAnimalCareSeasons = true;
	RNS.upStartRealNumbersAnimalCareSeasons = true;

end;


function RealNumbersAnimalCareSeasons:keyEvent(unicode, sym, modifier, isDown)

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_x) then
		print("\nlAlt-rx pressed: RealNumbersAnimalCareSeasons\n");
		myAnimalPigs = g_seasons.animals.animalManager.typeToAnimal["PIG"]
		print_r(myAnimalPigs)
	end;
end;

function RealNumbersAnimalCareSeasons:update(dt)
	local textWidth = 50; 	-- text width in log file
	local iFillType = 0;
	local minute = g_currentMission.environment.currentMinute;
	local currency = "€";	-- or  "$" or "£"
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then 
        currency = "€";
	elseif gameMoneyUnit == 2 then 
        currency = "$";
	elseif gameMoneyUnit == 3 then 
        currency = "£";
	end;



	local runMinute = minute % 10; -- remainder
	if runMinute ~= 2 then RNS.notRunYetRealNumbersAnimalCareSeasons = true; end;
	if runMinute == 2 or RNS.upStartRealNumbersAnimalCareSeasons then
		if RNS.notRunYetRealNumbersAnimalCareSeasons then

--			print("RealNumbersAnimalCareSeasons:update"); -- comment out when not debugging

			if g_seasons ~= nil then

-- PIGS
				myAnimalPigs = g_seasons.animals.animalManager.typeToAnimal["PIG"];
--				print_r(myAnimalPigs)


				local pigNames = {"PIG_TYPE_RED", "PIG_TYPE_WHITE", "PIG_TYPE_BLACK_WHITE", "PIG_TYPE_BLACK"};

--				for k = 1,4 do
				for i,animalSubTypes in pairs(myAnimalPigs.subTypes) do
					local k = 0;
					animalName = string.upper(animalSubTypes.fillTypeDesc.name);
					if animalName == pigNames[1] 	then k = 1; end;
					if animalName == pigNames[2] 	then k = 2; end;
					if animalName == pigNames[3] 	then k = 3; end;
					if animalName == pigNames[4] 	then k = 4; end;


					
					local myType 			= myAnimalPigs.type;
					local class 			= myAnimalPigs.class;
					
					local subTypeId 		= animalSubTypes.subTypeId;
					local subTypeFillType 	= animalSubTypes.fillType;
					local subTypeName 		= animalSubTypes.subTypeName;
					local subTypeType 		= animalSubTypes.type;
					
--					print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

--					iFillType = RNS.pigs.fillType[k];
--					animalSubTypes = g_animalManager:getAnimalByFillType(iFillType);

					if k > 0 then
										
-- input
						animalSubTypes.seasons.straw = 285 * RNS.pigs.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
						animalSubTypes.seasons.water = RNS.pigs.waterPerDayPerKg[k];
						animalSubTypes.seasons.food = RNS.pigs.foodPerDayPerKg[k]/RN.commodityDensity.PIGFOOD;
-- weight
						animalSubTypes.seasons.buyWeight = RNS.pigs.buyWeight[k];
						animalSubTypes.seasons.bornWeight = RNS.pigs.bornWeight[k];
-- output
						animalSubTypes.seasons.milk = RNS.pigs.milkPerDay[k];
						animalSubTypes.seasons.manure = RNS.pigs.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
						animalSubTypes.seasons.liquidManure =	RNS.pigs.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
						animalSubTypes.seasons.foodSpillage = RNS.pigs.foodSpillage[k];
-- breeding
						animalSubTypes.seasons.fertileAge = RNS.pigs.fertileAge[k];
						animalSubTypes.seasons.averageLitterSize = RNS.pigs.averageLitterSize[k];
						animalSubTypes.seasons.variationLitterSize = RNS.pigs.variationLitterSize[k];
						animalSubTypes.seasons.birthRate = RNS.pigs.birthRate[k];
						animalSubTypes.seasons.femalePercentage = RNS.pigs.femalePercentage[k];

						animalSubTypes.breeding.fertileAge = RNS.pigs.fertileAge[k];
						animalSubTypes.breeding.averageLitterSize = RNS.pigs.averageLitterSize[k];
						animalSubTypes.breeding.variationLitterSize = RNS.pigs.variationLitterSize[k];
						animalSubTypes.breeding.birthRate = RNS.pigs.birthRate[k];
						animalSubTypes.breeding.femalePercentage = RNS.pigs.femalePercentage[k];

-- store
						animalSubTypes.storeInfo.buyPrice = RNS.pigs.buyPriceMultiplier[k] * RNS.pigs.buyWeight[k] * RNS.pigs.pricePerKg[k];
						animalSubTypes.storeInfo.baseSellPrice = RNS.pigs.baseSellPrice[k];
						animalSubTypes.storeInfo.pricePerKg = RNS.pigs.pricePerKg[k];
						animalSubTypes.storeInfo.priceDropAge = RNS.pigs.priceDropAge[k];
						animalSubTypes.storeInfo.transportPrice = math.min(RNS.pigs.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
						animalSubTypes.storeInfo.buyAge = RNS.pigs.buyAge[k]/365;
						animalSubTypes.storeInfo.buyIsFemale = RNS.pigs.buyIsFemale[k];
						animalSubTypes.storeInfo.buyWeight = RNS.pigs.buyWeight[k];

						animalSubTypes.seasons.buyPrice = RNS.pigs.buyPriceMultiplier[k];
						animalSubTypes.seasons.baseSellPrice = RNS.pigs.baseSellPrice[k];
						animalSubTypes.seasons.pricePerKg = RNS.pigs.pricePerKg[k];
						animalSubTypes.seasons.priceDropAge = RNS.pigs.priceDropAge[k];
						animalSubTypes.seasons.transportPrice = math.min(RNS.pigs.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
						animalSubTypes.seasons.buyAge = RNS.pigs.buyAge[k];
						animalSubTypes.seasons.buyIsFemale = RNS.pigs.buyIsFemale[k];

						if RNS.upStartRealNumbersAnimalCareSeasons then
							print(" ");
							myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
							myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
							myPrintString(subTypeName.." FS name",animalName,textWidth," ");
							myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");
							myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
							myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
							myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
							myPrint(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
							myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
							myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
							myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
							myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);							
						end;
					end;
				end;


-- PIGLETS
				if RN.hasAnimal["PIGLET"] then 
					myAnimalPiglets = g_seasons.animals.animalManager.typeToAnimal["PIG"];
	--				print_r(myAnimalPiglets)

					if g_seasons.animals.animalManager.typeToAnimal["PIG"] ~= nil then
					
						local pig2Names = {"PIGLET_TYPE_RED", "PIGLET_TYPE_WHITE", "PIGLET_TYPE_BLACK_WHITE", "PIGLET_TYPE_BLACK"};

		--				for k = 1,4 do
						for i,animalSubTypes in pairs(myAnimalPiglets.subTypes) do
							local k = 0;
							animalName = string.upper(animalSubTypes.fillTypeDesc.name);
							if animalName == pig2Names[1] 	then k = 1; end;
							if animalName == pig2Names[2] 	then k = 2; end;
							if animalName == pig2Names[3] 	then k = 3; end;
							if animalName == pig2Names[4] 	then k = 4; end;
							
							local myType 			= myAnimalPiglets.type;
							local class 			= myAnimalPiglets.class;
							
							local subTypeId 		= animalSubTypes.subTypeId;
							local subTypeFillType 	= animalSubTypes.fillType;
							local subTypeName 		= animalSubTypes.subTypeName;
							local subTypeType 		= animalSubTypes.type;

	--						print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

							if k > 0 then
		-- input
								animalSubTypes.seasons.straw = 285 * RNS.piglets.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
								animalSubTypes.seasons.water = RNS.piglets.waterPerDayPerKg[k];
								animalSubTypes.seasons.food = RNS.piglets.foodPerDayPerKg[k]/RN.commodityDensity.PIGFOOD;
		-- weight
								animalSubTypes.seasons.buyWeight = RNS.piglets.buyWeight[k];
								animalSubTypes.seasons.bornWeight = RNS.piglets.bornWeight[k];
		-- output
								animalSubTypes.seasons.milk = RNS.piglets.milkPerDay[k];
								animalSubTypes.seasons.manure = RNS.piglets.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
								animalSubTypes.seasons.liquidManure =	RNS.piglets.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
								animalSubTypes.seasons.foodSpillage = RNS.piglets.foodSpillage[k];
		-- breeding
								animalSubTypes.seasons.fertileAge = RNS.piglets.fertileAge[k];
								animalSubTypes.seasons.averageLitterSize = RNS.piglets.averageLitterSize[k];
								animalSubTypes.seasons.variationLitterSize = RNS.piglets.variationLitterSize[k];
								animalSubTypes.seasons.birthRate = RNS.piglets.birthRate[k];
								animalSubTypes.seasons.femalePercentage = RNS.piglets.femalePercentage[k];

								animalSubTypes.breeding.fertileAge = RNS.piglets.fertileAge[k];
								animalSubTypes.breeding.averageLitterSize = RNS.piglets.averageLitterSize[k];
								animalSubTypes.breeding.variationLitterSize = RNS.piglets.variationLitterSize[k];
								animalSubTypes.breeding.birthRate = RNS.piglets.birthRate[k];
								animalSubTypes.breeding.femalePercentage = RNS.piglets.femalePercentage[k];

		-- store
								animalSubTypes.storeInfo.buyPrice = RNS.piglets.buyPriceMultiplier[k] * RNS.piglets.buyWeight[k] * RNS.piglets.pricePerKg[k];
								animalSubTypes.storeInfo.baseSellPrice = RNS.piglets.baseSellPrice[k];
								animalSubTypes.storeInfo.pricePerKg = RNS.piglets.pricePerKg[k];
								animalSubTypes.storeInfo.priceDropAge = RNS.piglets.priceDropAge[k];
								animalSubTypes.storeInfo.transportPrice = math.min(RNS.piglets.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
								animalSubTypes.storeInfo.buyAge = RNS.piglets.buyAge[k]/365;
								animalSubTypes.storeInfo.buyIsFemale = RNS.piglets.buyIsFemale[k];
								animalSubTypes.storeInfo.buyWeight = RNS.piglets.buyWeight[k];

								animalSubTypes.seasons.buyPrice = RNS.piglets.buyPriceMultiplier[k];
								animalSubTypes.seasons.baseSellPrice = RNS.piglets.baseSellPrice[k];
								animalSubTypes.seasons.pricePerKg = RNS.piglets.pricePerKg[k];
								animalSubTypes.seasons.priceDropAge = RNS.piglets.priceDropAge[k];
								animalSubTypes.seasons.transportPrice = math.min(RNS.piglets.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
								animalSubTypes.seasons.buyAge = RNS.piglets.buyAge[k];
								animalSubTypes.seasons.buyIsFemale = RNS.piglets.buyIsFemale[k];

								if RNS.upStartRealNumbersAnimalCareSeasons then
									print(" ");
									myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
									myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
									myPrintString(subTypeName.." FS name",animalName,textWidth," ");
									myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");
									myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
									myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
									myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
									myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
									myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
									myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
									myPrint(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
									myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
									myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
									myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
									myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);							
								end;
							end;
						end;
					end;
				end;

-- COWS

				local cows1Names = {"COW_TYPE_BROWN", "COW_TYPE_BROWN_WHITE", "COW_TYPE_BLACK", "COW_TYPE_BLACK_WHITE"};

				myAnimalCows1 = g_seasons.animals.animalManager.typeToAnimal["COW"];
--				print_r(myAnimalCows1)

--				for k = 1,4 do
				for i,animalSubTypes in pairs(myAnimalCows1.subTypes) do
					local k = 0;
					animalName = string.upper(animalSubTypes.fillTypeDesc.name);
					if animalName == cows1Names[1] 	then k = 1; end;
					if animalName == cows1Names[2] 	then k = 2; end;
					if animalName == cows1Names[3] 	then k = 3; end;
					if animalName == cows1Names[4] 	then k = 4; end;
			
					local myType 			= myAnimalCows1.type;
					local class 			= myAnimalCows1.class;
					
					local subTypeId 		= animalSubTypes.subTypeId;
					local subTypeFillType 	= animalSubTypes.fillType;
					local subTypeName 		= animalSubTypes.subTypeName;
					local subTypeType 		= animalSubTypes.type;

--					print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

--					iFillType = RNS.cows1.fillType[k];
--					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);

					if k > 0 then
					
						RN.hasAnimal["COW"] 	= true;
					
-- input
						animalSubTypes.seasons.straw = 285 * RNS.cows1.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
						animalSubTypes.seasons.water = RNS.cows1.waterPerDayPerKg[k];
						animalSubTypes.seasons.food = RNS.cows1.foodTroughFraction[k] * RNS.cows1.foodPerDayPerKg[k]/RN.commodityDensity.COWFOOD;
-- weight
						animalSubTypes.seasons.buyWeight = RNS.cows1.buyWeight[k];
						animalSubTypes.seasons.bornWeight = RNS.cows1.bornWeight[k];
-- output
						animalSubTypes.seasons.milk = RNS.cows1.milkPerDay[k];
						animalSubTypes.seasons.manure = RNS.cows1.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
						animalSubTypes.seasons.liquidManure =	RNS.cows1.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
						animalSubTypes.seasons.foodSpillage = RNS.cows1.foodSpillage[k];
-- breeding
						animalSubTypes.seasons.fertileAge = RNS.cows1.fertileAge[k];
						animalSubTypes.seasons.averageLitterSize = RNS.cows1.averageLitterSize[k];
						animalSubTypes.seasons.variationLitterSize = RNS.cows1.variationLitterSize[k];
						animalSubTypes.seasons.birthRate = RNS.cows1.birthRate[k];
						animalSubTypes.seasons.femalePercentage = RNS.cows1.femalePercentage[k];

						animalSubTypes.breeding.fertileAge = RNS.cows1.fertileAge[k];
						animalSubTypes.breeding.averageLitterSize = RNS.cows1.averageLitterSize[k];
						animalSubTypes.breeding.variationLitterSize = RNS.cows1.variationLitterSize[k];
						animalSubTypes.breeding.birthRate = RNS.cows1.birthRate[k];
						animalSubTypes.breeding.femalePercentage = RNS.cows1.femalePercentage[k];
-- store
						animalSubTypes.storeInfo.buyPrice = RNS.cows1.buyPriceMultiplier[k] * RNS.cows1.buyWeight[k] * RNS.cows1.pricePerKg[k];
						animalSubTypes.storeInfo.baseSellPrice = RNS.cows1.baseSellPrice[k];
						animalSubTypes.storeInfo.pricePerKg = RNS.cows1.pricePerKg[k];
						animalSubTypes.storeInfo.priceDropAge = RNS.cows1.priceDropAge[k];
						animalSubTypes.storeInfo.transportPrice = math.min(RNS.cows1.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
						animalSubTypes.storeInfo.buyAge = RNS.cows1.buyAge[k]/365;
						animalSubTypes.storeInfo.buyIsFemale = RNS.cows1.buyIsFemale[k];
						animalSubTypes.storeInfo.buyWeight = RNS.cows1.buyWeight[k];

						animalSubTypes.seasons.buyPrice = RNS.cows1.buyPriceMultiplier[k];
						animalSubTypes.seasons.baseSellPrice = RNS.cows1.baseSellPrice[k];
						animalSubTypes.seasons.pricePerKg = RNS.cows1.pricePerKg[k];
						animalSubTypes.seasons.priceDropAge = RNS.cows1.priceDropAge[k];
						animalSubTypes.seasons.transportPrice = math.min(RNS.cows1.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
						animalSubTypes.seasons.buyAge = RNS.cows1.buyAge[k];
						animalSubTypes.seasons.buyIsFemale = RNS.cows1.buyIsFemale[k];

						if RNS.upStartRealNumbersAnimalCareSeasons then
							print(" ");
							myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
							myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
							myPrintString(subTypeName.." FS name",animalName,textWidth," ");
							myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
							myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
							myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." milkPerDay",animalSubTypes.seasons.milk,textWidth,"L/day ");
							myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
							myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
							myPrint(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
							myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
							myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
							myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
							myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);							
						end;
					end;
				end;

				local cows2Names = {"COW_TYPE_BRAHMAN_BROWN", "COW_TYPE_BRAHMAN_WHITE", "COW_TYPE_BRAHMAN_LIGHT_BROWN", "COW_TYPE_BRAHMAN_GREY"};

				myAnimalCows2 = g_seasons.animals.animalManager.typeToAnimal["COW"];
--				print_r(myAnimalCows2)

--				for k = 1,4 do
				for i,animalSubTypes in pairs(myAnimalCows2.subTypes) do
					local k = 0;
					animalName = string.upper(animalSubTypes.fillTypeDesc.name);
					if animalName == cows2Names[1] 	then k = 1; end;
					if animalName == cows2Names[2] 	then k = 2; end;
					if animalName == cows2Names[3] 	then k = 3; end;
					if animalName == cows2Names[4] 	then k = 4; end;
					
					local myType 			= myAnimalCows2.type;
					local class 			= myAnimalCows2.class;
					
					local subTypeId 		= animalSubTypes.subTypeId;
					local subTypeFillType 	= animalSubTypes.fillType;
					local subTypeName 		= animalSubTypes.subTypeName;
					local subTypeType 		= animalSubTypes.type;

--					print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);


--					iFillType = RNS.cows1.fillType[k];
--					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);


					if k > 0 then
					
						RN.hasAnimal["COW"] 	= true;
					
-- input
						animalSubTypes.seasons.straw = 285 * RNS.cows2.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
						animalSubTypes.seasons.water = RNS.cows2.waterPerDayPerKg[k];
						animalSubTypes.seasons.food = RNS.cows2.foodTroughFraction[k] * RNS.cows2.foodPerDayPerKg[k]/RN.commodityDensity.COWFOOD;
-- weight
						animalSubTypes.seasons.buyWeight = RNS.cows2.buyWeight[k];
						animalSubTypes.seasons.bornWeight = RNS.cows2.bornWeight[k];
-- output
						animalSubTypes.seasons.milk = RNS.cows2.milkPerDay[k];
						animalSubTypes.seasons.manure = RNS.cows2.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
						animalSubTypes.seasons.liquidManure =	RNS.cows2.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
						animalSubTypes.seasons.foodSpillage = RNS.cows2.foodSpillage[k];
-- breeding
						animalSubTypes.seasons.fertileAge = RNS.cows2.fertileAge[k];
						animalSubTypes.seasons.averageLitterSize = RNS.cows2.averageLitterSize[k];
						animalSubTypes.seasons.variationLitterSize = RNS.cows2.variationLitterSize[k];
						animalSubTypes.seasons.birthRate = RNS.cows2.birthRate[k];
						animalSubTypes.seasons.femalePercentage = RNS.cows2.femalePercentage[k];

						animalSubTypes.breeding.fertileAge = RNS.cows2.fertileAge[k];
						animalSubTypes.breeding.averageLitterSize = RNS.cows2.averageLitterSize[k];
						animalSubTypes.breeding.variationLitterSize = RNS.cows2.variationLitterSize[k];
						animalSubTypes.breeding.birthRate = RNS.cows2.birthRate[k];
						animalSubTypes.breeding.femalePercentage = RNS.cows2.femalePercentage[k];
-- store
						animalSubTypes.storeInfo.buyPrice = RNS.cows2.buyPriceMultiplier[k] * RNS.cows2.buyWeight[k] * RNS.cows2.pricePerKg[k];
						animalSubTypes.storeInfo.baseSellPrice = RNS.cows2.baseSellPrice[k];
						animalSubTypes.storeInfo.pricePerKg = RNS.cows2.pricePerKg[k];
						animalSubTypes.storeInfo.priceDropAge = RNS.cows2.priceDropAge[k];
						animalSubTypes.storeInfo.transportPrice = math.min(RNS.cows2.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
						animalSubTypes.storeInfo.buyAge = RNS.cows2.buyAge[k]/365;
						animalSubTypes.storeInfo.buyIsFemale = RNS.cows2.buyIsFemale[k];
						animalSubTypes.storeInfo.buyWeight = RNS.cows2.buyWeight[k];

						animalSubTypes.seasons.buyPrice = RNS.cows2.buyPriceMultiplier[k];
						animalSubTypes.seasons.baseSellPrice = RNS.cows2.baseSellPrice[k];
						animalSubTypes.seasons.pricePerKg = RNS.cows2.pricePerKg[k];
						animalSubTypes.seasons.priceDropAge = RNS.cows2.priceDropAge[k];
						animalSubTypes.seasons.transportPrice = math.min(RNS.cows2.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
						animalSubTypes.seasons.buyAge = RNS.cows2.buyAge[k];
						animalSubTypes.seasons.buyIsFemale = RNS.cows2.buyIsFemale[k];

						if RNS.upStartRealNumbersAnimalCareSeasons then
							print(" ");
							myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
							myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
							myPrintString(subTypeName.." FS name",animalName,textWidth," ");
							myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
							myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
							myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." milkPerDay",animalSubTypes.seasons.milk,textWidth,"L/day ");
							myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
							myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
							myPrint(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
							myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
							myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
							myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
							myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);
						end;
					end;
				end;

-- CALF 

				local calfNames = {"CALF_TYPE_BLACKWHITE", "CALF_TYPE_BLACK", "CALF_TYPE_BROWN"};

				if g_seasons.animals.animalManager.typeToAnimal["CALF"] ~= nil then
					myAnimalCalf = g_seasons.animals.animalManager.typeToAnimal["CALF"];
	--				print_r(myAnimalCalf)

	--				for k = 1,4 do
					for i,animalSubTypes in pairs(myAnimalCalf.subTypes) do
						local k = 0;
						animalName = string.upper(animalSubTypes.fillTypeDesc.name);
						if animalName == calfNames[1] 	then k = 1; end;
						if animalName == calfNames[2] 	then k = 2; end;
						if animalName == calfNames[3] 	then k = 3; end;
						
						local myType 			= myAnimalCalf.type;
						local class 			= myAnimalCalf.class;
						
						local subTypeId 		= animalSubTypes.subTypeId;
						local subTypeFillType 	= animalSubTypes.fillType;
						local subTypeName 		= animalSubTypes.subTypeName;
						local subTypeType 		= animalSubTypes.type;

--						print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

	--					iFillType = RNS.cows1.fillType[k];
	--					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);

						if k > 0 then
						
							RN.hasAnimal["CALF"] 	= true;
						
	-- input
							animalSubTypes.seasons.straw = 285 * RNS.calf.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
							animalSubTypes.seasons.water = RNS.calf.waterPerDayPerKg[k];
--							animalSubTypes.seasons.food = animalSubTypes.seasons.food;
							animalSubTypes.seasons.food = RNS.calf.foodTroughFraction[k] * RNS.calf.foodPerDayPerKg[k]/RN.commodityDensity.MILK;
	-- weight
							animalSubTypes.seasons.buyWeight = RNS.calf.buyWeight[k];
							animalSubTypes.seasons.bornWeight = RNS.calf.bornWeight[k];
	-- output
							animalSubTypes.seasons.milk = RNS.calf.milkPerDay[k];
							animalSubTypes.seasons.manure = RNS.calf.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
							animalSubTypes.seasons.liquidManure =	RNS.calf.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
							animalSubTypes.seasons.foodSpillage = RNS.calf.foodSpillage[k];
	-- breeding
							animalSubTypes.seasons.fertileAge = RNS.calf.fertileAge[k];
							animalSubTypes.seasons.averageLitterSize = RNS.calf.averageLitterSize[k];
							animalSubTypes.seasons.variationLitterSize = RNS.calf.variationLitterSize[k];
							animalSubTypes.seasons.birthRate = RNS.calf.birthRate[k];
							animalSubTypes.seasons.femalePercentage = RNS.calf.femalePercentage[k];

							animalSubTypes.breeding.fertileAge = RNS.calf.fertileAge[k];
							animalSubTypes.breeding.averageLitterSize = RNS.calf.averageLitterSize[k];
							animalSubTypes.breeding.variationLitterSize = RNS.calf.variationLitterSize[k];
							animalSubTypes.breeding.birthRate = RNS.calf.birthRate[k];
							animalSubTypes.breeding.femalePercentage = RNS.calf.femalePercentage[k];
	-- store
							animalSubTypes.storeInfo.buyPrice = RNS.calf.buyPriceMultiplier[k] * RNS.calf.buyWeight[k] * RNS.calf.pricePerKg[k];
							animalSubTypes.storeInfo.baseSellPrice = RNS.calf.baseSellPrice[k];
							animalSubTypes.storeInfo.pricePerKg = RNS.calf.pricePerKg[k];
							animalSubTypes.storeInfo.priceDropAge = RNS.calf.priceDropAge[k];
							animalSubTypes.storeInfo.transportPrice = math.min(RNS.calf.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
							animalSubTypes.storeInfo.buyAge = RNS.calf.buyAge[k]/365;
							animalSubTypes.storeInfo.buyIsFemale = RNS.calf.buyIsFemale[k];
							animalSubTypes.storeInfo.buyWeight = RNS.calf.buyWeight[k];

							animalSubTypes.seasons.buyPrice = RNS.calf.buyPriceMultiplier[k];
							animalSubTypes.seasons.baseSellPrice = RNS.calf.baseSellPrice[k];
							animalSubTypes.seasons.pricePerKg = RNS.calf.pricePerKg[k];
							animalSubTypes.seasons.priceDropAge = RNS.calf.priceDropAge[k];
							animalSubTypes.seasons.transportPrice = math.min(RNS.calf.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
							animalSubTypes.seasons.buyAge = RNS.calf.buyAge[k];
							animalSubTypes.seasons.buyIsFemale = RNS.calf.buyIsFemale[k];

							if RNS.upStartRealNumbersAnimalCareSeasons then
								print(" ");
								myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
								myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
								myPrintString(subTypeName.." FS name",animalName,textWidth," ");
								myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
								myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
								myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
--								myPrintFloat(subTypeName.." milkPerDay",animalSubTypes.seasons.milk,textWidth,"L/day ");
								myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
								myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
--								myPrint(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
--								myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
--								myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
								myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
								myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);							
							end;
						end;
					end;
				end;


-- SHEEP				
				local sheepNames = {"SHEEP_TYPE_WHITE", "SHEEP_TYPE_BROWN", "SHEEP_TYPE_BLACK_WHITE", "SHEEP_TYPE_BLACK"};
				
				myAnimalSheep = g_seasons.animals.animalManager.typeToAnimal["SHEEP"];
--				print_r(myAnimalSheep)

--				for k = 1,4 do
				for i,animalSubTypes in pairs(myAnimalSheep.subTypes) do
					local k = 0;
					animalName = string.upper(animalSubTypes.fillTypeDesc.name);
					if animalName == sheepNames[1] 	then k = 1; end;
					if animalName == sheepNames[2] 	then k = 2; end;
					if animalName == sheepNames[3] 	then k = 3; end;
					if animalName == sheepNames[4] 	then k = 4; end;
					
					local myType 			= myAnimalSheep.type;
					local class 			= myAnimalSheep.class;
					
					local subTypeId 		= animalSubTypes.subTypeId;
					local subTypeFillType 	= animalSubTypes.fillType;
					local subTypeName 		= animalSubTypes.subTypeName;
					local subTypeType 		= animalSubTypes.type;

--					print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

--					iFillType = RNS.sheep.fillType[k];
--					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);

					if k > 0 then
						
						RN.hasAnimal["SHEEP"] 	= true;

-- input
						animalSubTypes.seasons.straw = 285 * RNS.sheep.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
						animalSubTypes.seasons.water = RNS.sheep.waterPerDayPerKg[k];
						animalSubTypes.seasons.food = RNS.sheep.foodTroughFraction[k] * RNS.sheep.foodPerDayPerKg[k]/RN.commodityDensity.ROUNDBALE_GRASS;
-- weight
						animalSubTypes.seasons.buyWeight = RNS.sheep.buyWeight[k];
						animalSubTypes.seasons.bornWeight = RNS.sheep.bornWeight[k];
-- output
						animalSubTypes.seasons.milk = RNS.sheep.milkPerDay[k];
						animalSubTypes.seasons.manure = RNS.sheep.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
						animalSubTypes.seasons.liquidManure =	RNS.sheep.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
						animalSubTypes.seasons.foodSpillage = RNS.sheep.foodSpillage[k];
						animalSubTypes.seasons.pallets = RNS.sheep.woolKgPerYear[k]/RN.commodityDensity.WOOL; -- L wool per year
-- breeding
						animalSubTypes.seasons.fertileAge = RNS.sheep.fertileAge[k];
						animalSubTypes.seasons.averageLitterSize = RNS.sheep.averageLitterSize[k];
						animalSubTypes.seasons.variationLitterSize = RNS.sheep.variationLitterSize[k];
						animalSubTypes.seasons.birthRate = RNS.sheep.birthRate[k];
						animalSubTypes.seasons.femalePercentage = RNS.sheep.femalePercentage[k];

						animalSubTypes.breeding.fertileAge = RNS.sheep.fertileAge[k];
						animalSubTypes.breeding.averageLitterSize = RNS.sheep.averageLitterSize[k];
						animalSubTypes.breeding.variationLitterSize = RNS.sheep.variationLitterSize[k];
						animalSubTypes.breeding.birthRate = RNS.sheep.birthRate[k];
						animalSubTypes.breeding.femalePercentage = RNS.sheep.femalePercentage[k];

-- store
						animalSubTypes.storeInfo.buyPrice = RNS.sheep.buyPriceMultiplier[k] * RNS.sheep.buyWeight[k] * RNS.sheep.pricePerKg[k];
						animalSubTypes.storeInfo.baseSellPrice = RNS.sheep.baseSellPrice[k];
						animalSubTypes.storeInfo.pricePerKg = RNS.sheep.pricePerKg[k];
						animalSubTypes.storeInfo.priceDropAge = RNS.sheep.priceDropAge[k];
						animalSubTypes.storeInfo.transportPrice = math.min(RNS.sheep.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
						animalSubTypes.storeInfo.buyAge = RNS.sheep.buyAge[k]/365;
						animalSubTypes.storeInfo.buyIsFemale = RNS.sheep.buyIsFemale[k];
						animalSubTypes.storeInfo.buyWeight = RNS.sheep.buyWeight[k];

						animalSubTypes.seasons.buyPrice = RNS.sheep.buyPriceMultiplier[k];
						animalSubTypes.seasons.baseSellPrice = RNS.sheep.baseSellPrice[k];
						animalSubTypes.seasons.pricePerKg = RNS.sheep.pricePerKg[k];
						animalSubTypes.seasons.priceDropAge = RNS.sheep.priceDropAge[k];
						animalSubTypes.seasons.transportPrice = math.min(RNS.sheep.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
						animalSubTypes.seasons.buyAge = RNS.sheep.buyAge[k];
						animalSubTypes.seasons.buyIsFemale = RNS.sheep.buyIsFemale[k];

						if RNS.upStartRealNumbersAnimalCareSeasons then
							print(" ");
							myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
							myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
							myPrintString(subTypeName.." FS name",animalName,textWidth," ");
							myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
							myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
							myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." milkPerDay",animalSubTypes.seasons.milk,textWidth,"L/day ");
							myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
							myPrintFloat(subTypeName.." Liter wool per year",animalSubTypes.seasons.pallets,textWidth,"L/year ");
							myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
							myPrintFloat(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
							myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
							myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
							myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
							myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);
						end;
					end;
				end;


-- GOATS				
				local goatNames = {"GOAT_TYPE_BROWN", "GOAT_TYPE_WHITE", "GOAT_TYPE_BLACK"};

				if g_seasons.animals.animalManager.typeToAnimal["GOAT"] ~= nil then
					myAnimalGoats = g_seasons.animals.animalManager.typeToAnimal["GOAT"];
	--				print_r(myAnimalGoats)

	--				for k = 1,4 do
					for i,animalSubTypes in pairs(myAnimalGoats.subTypes) do
						local k = 0;
						animalName = string.upper(animalSubTypes.fillTypeDesc.name);
						if animalName == goatNames[1] 	then k = 1; end;
						if animalName == goatNames[2] 	then k = 2; end;
						if animalName == goatNames[3] 	then k = 3; end;
						
						local myType 			= myAnimalGoats.type;
						local class 			= myAnimalGoats.class;
						
						local subTypeId 		= animalSubTypes.subTypeId;
						local subTypeFillType 	= animalSubTypes.fillType;
						local subTypeName 		= animalSubTypes.subTypeName;
						local subTypeType 		= animalSubTypes.type;

--						print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

	--					iFillType = RNS.GOATS.fillType[k];
	--					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);

						if k > 0 then
						
							RN.hasAnimal["GOAT"] 	= true;

	-- input
							animalSubTypes.seasons.straw = 285 * RNS.goats.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
							animalSubTypes.seasons.water = RNS.goats.waterPerDayPerKg[k];
							animalSubTypes.seasons.food = RNS.goats.foodTroughFraction[k] * RNS.goats.foodPerDayPerKg[k]/RN.commodityDensity.ROUNDBALE_GRASS;
	-- weight
							animalSubTypes.seasons.buyWeight = RNS.goats.buyWeight[k];
							animalSubTypes.seasons.bornWeight = RNS.goats.bornWeight[k];
	-- output
							animalSubTypes.seasons.milk = RNS.goats.milkPerDay[k];
							animalSubTypes.seasons.manure = RNS.goats.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
							animalSubTypes.seasons.liquidManure =	RNS.goats.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
							animalSubTypes.seasons.foodSpillage = RNS.goats.foodSpillage[k];
							animalSubTypes.seasons.pallets = RNS.goats.woolKgPerYear[k]/RN.commodityDensity.WOOL; -- L wool per year
	-- breeding
							animalSubTypes.seasons.fertileAge = RNS.goats.fertileAge[k];
							animalSubTypes.seasons.averageLitterSize = RNS.goats.averageLitterSize[k];
							animalSubTypes.seasons.variationLitterSize = RNS.goats.variationLitterSize[k];
							animalSubTypes.seasons.birthRate = RNS.goats.birthRate[k];
							animalSubTypes.seasons.femalePercentage = RNS.goats.femalePercentage[k];

							animalSubTypes.breeding.fertileAge = RNS.goats.fertileAge[k];
							animalSubTypes.breeding.averageLitterSize = RNS.goats.averageLitterSize[k];
							animalSubTypes.breeding.variationLitterSize = RNS.goats.variationLitterSize[k];
							animalSubTypes.breeding.birthRate = RNS.goats.birthRate[k];
							animalSubTypes.breeding.femalePercentage = RNS.goats.femalePercentage[k];

	-- store
							animalSubTypes.storeInfo.buyPrice = RNS.goats.buyPriceMultiplier[k] * RNS.goats.buyWeight[k] * RNS.goats.pricePerKg[k];
							animalSubTypes.storeInfo.baseSellPrice = RNS.goats.baseSellPrice[k];
							animalSubTypes.storeInfo.pricePerKg = RNS.goats.pricePerKg[k];
							animalSubTypes.storeInfo.priceDropAge = RNS.goats.priceDropAge[k];
							animalSubTypes.storeInfo.transportPrice = math.min(RNS.goats.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
							animalSubTypes.storeInfo.buyAge = RNS.goats.buyAge[k]/365;
							animalSubTypes.storeInfo.buyIsFemale = RNS.goats.buyIsFemale[k];
							animalSubTypes.storeInfo.buyWeight = RNS.goats.buyWeight[k];

							animalSubTypes.seasons.buyPrice = RNS.goats.buyPriceMultiplier[k];
							animalSubTypes.seasons.baseSellPrice = RNS.goats.baseSellPrice[k];
							animalSubTypes.seasons.pricePerKg = RNS.goats.pricePerKg[k];
							animalSubTypes.seasons.priceDropAge = RNS.goats.priceDropAge[k];
							animalSubTypes.seasons.transportPrice = math.min(RNS.goats.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
							animalSubTypes.seasons.buyAge = RNS.goats.buyAge[k];
							animalSubTypes.seasons.buyIsFemale = RNS.goats.buyIsFemale[k];

							if RNS.upStartRealNumbersAnimalCareSeasons then
								print(" ");
								myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
								myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
								myPrintString(subTypeName.." FS name",animalName,textWidth," ");
								myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
								myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
								myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." milkPerDay",animalSubTypes.seasons.milk,textWidth,"L/day ");
								myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
								myPrintFloat(subTypeName.." Liter wool per year",animalSubTypes.seasons.pallets,textWidth,"L/year ");
								myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
								myPrintFloat(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
								myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
								myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
								myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
								myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);
							end;
						end;
					end;
				end;


-- GOATS registered as sheep
				
				local goatNames = {"GOAT_TYPE_BROWN", "GOAT_TYPE_WHITE", "GOAT_TYPE_BLACK"};

				if g_seasons.animals.animalManager.typeToAnimal["SHEEP"] ~= nil then
					myAnimalGoats = g_seasons.animals.animalManager.typeToAnimal["SHEEP"];
	--				print_r(myAnimalGoats)

	--				for k = 1,4 do
					for i,animalSubTypes in pairs(myAnimalGoats.subTypes) do
						local k = 0;
						animalName = string.upper(animalSubTypes.fillTypeDesc.name);
						if animalName == goatNames[1] 	then k = 1; end;
						if animalName == goatNames[2] 	then k = 2; end;
						if animalName == goatNames[3] 	then k = 3; end;
						
						local myType 			= myAnimalGoats.type;
						local class 			= myAnimalGoats.class;
						
						local subTypeId 		= animalSubTypes.subTypeId;
						local subTypeFillType 	= animalSubTypes.fillType;
						local subTypeName 		= animalSubTypes.subTypeName;
						local subTypeType 		= animalSubTypes.type;

--						print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

	--					iFillType = RNS.GOATS.fillType[k];
	--					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);

						if k > 0 then
							RN.hasAnimal["GOAT"] = true;

	-- input
							animalSubTypes.seasons.straw = 285 * RNS.goats.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
							animalSubTypes.seasons.water = RNS.goats.waterPerDayPerKg[k];
							animalSubTypes.seasons.food = RNS.goats.foodTroughFraction[k] * RNS.goats.foodPerDayPerKg[k]/RN.commodityDensity.ROUNDBALE_GRASS;
	-- weight
							animalSubTypes.seasons.buyWeight = RNS.goats.buyWeight[k];
							animalSubTypes.seasons.bornWeight = RNS.goats.bornWeight[k];
	-- output
							animalSubTypes.seasons.milk = RNS.goats.milkPerDay[k];
							animalSubTypes.seasons.manure = RNS.goats.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
							animalSubTypes.seasons.liquidManure =	RNS.goats.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
							animalSubTypes.seasons.foodSpillage = RNS.goats.foodSpillage[k];
							animalSubTypes.seasons.pallets = RNS.goats.woolKgPerYear[k]/RN.commodityDensity.WOOL; -- L wool per year
	-- breeding
							animalSubTypes.seasons.fertileAge = RNS.goats.fertileAge[k];
							animalSubTypes.seasons.averageLitterSize = RNS.goats.averageLitterSize[k];
							animalSubTypes.seasons.variationLitterSize = RNS.goats.variationLitterSize[k];
							animalSubTypes.seasons.birthRate = RNS.goats.birthRate[k];
							animalSubTypes.seasons.femalePercentage = RNS.goats.femalePercentage[k];

							animalSubTypes.breeding.fertileAge = RNS.goats.fertileAge[k];
							animalSubTypes.breeding.averageLitterSize = RNS.goats.averageLitterSize[k];
							animalSubTypes.breeding.variationLitterSize = RNS.goats.variationLitterSize[k];
							animalSubTypes.breeding.birthRate = RNS.goats.birthRate[k];
							animalSubTypes.breeding.femalePercentage = RNS.goats.femalePercentage[k];

	-- store
							animalSubTypes.storeInfo.buyPrice = RNS.goats.buyPriceMultiplier[k] * RNS.goats.buyWeight[k] * RNS.goats.pricePerKg[k];
							animalSubTypes.storeInfo.baseSellPrice = RNS.goats.baseSellPrice[k];
							animalSubTypes.storeInfo.pricePerKg = RNS.goats.pricePerKg[k];
							animalSubTypes.storeInfo.priceDropAge = RNS.goats.priceDropAge[k];
							animalSubTypes.storeInfo.transportPrice = math.min(RNS.goats.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
							animalSubTypes.storeInfo.buyAge = RNS.goats.buyAge[k]/365;
							animalSubTypes.storeInfo.buyIsFemale = RNS.goats.buyIsFemale[k];
							animalSubTypes.storeInfo.buyWeight = RNS.goats.buyWeight[k];

							animalSubTypes.seasons.buyPrice = RNS.goats.buyPriceMultiplier[k];
							animalSubTypes.seasons.baseSellPrice = RNS.goats.baseSellPrice[k];
							animalSubTypes.seasons.pricePerKg = RNS.goats.pricePerKg[k];
							animalSubTypes.seasons.priceDropAge = RNS.goats.priceDropAge[k];
							animalSubTypes.seasons.transportPrice = math.min(RNS.goats.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
							animalSubTypes.seasons.buyAge = RNS.goats.buyAge[k];
							animalSubTypes.seasons.buyIsFemale = RNS.goats.buyIsFemale[k];

							if RNS.upStartRealNumbersAnimalCareSeasons then
								print(" ");
								myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
								myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
								myPrintString(subTypeName.." FS name",animalName,textWidth," ");
								myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
								myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
								myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." milkPerDay",animalSubTypes.seasons.milk,textWidth,"L/day ");
								myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
								myPrintFloat(subTypeName.." Liter wool per year",animalSubTypes.seasons.pallets,textWidth,"L/year ");
								myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
								myPrintFloat(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
								myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
								myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
								myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
								myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);
							end;
						end;
					end;
				end;


-- CHICKEN
				local chickenNames = {"CHICKEN_TYPE_BLACK", "CHICKEN_TYPE_WHITE", "CHICKEN_TYPE_BROWN", "CHICKEN_TYPE_ROOSTER"};
				
				myAnimalChicken = g_seasons.animals.animalManager.typeToAnimal["CHICKEN"];
--				print_r(myAnimalChicken)

				for i,animalSubTypes in pairs(myAnimalChicken.subTypes) do
					local k = 0;
					animalName = string.upper(animalSubTypes.fillTypeDesc.name);
					if animalName == chickenNames[1] 	then k = 1; end;
					if animalName == chickenNames[2] 	then k = 2; end;
					if animalName == chickenNames[3] 	then k = 3; end;
					if animalName == chickenNames[4] 	then k = 4; end;
					
					local myType 			= myAnimalChicken.type;
					local class 			= myAnimalChicken.class;
					
					local subTypeId 		= animalSubTypes.subTypeId;
					local subTypeFillType 	= animalSubTypes.fillType;
					local subTypeName 		= animalSubTypes.subTypeName;
					local subTypeType 		= animalSubTypes.type;

--					print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

--					iFillType = RNS.chicken.fillType[k];
--					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);

					if k > 0 then	
						
						RN.hasAnimal["CHICKEN"] 	= true;

-- input
						animalSubTypes.seasons.straw = 285 * RNS.chicken.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
						animalSubTypes.seasons.water = RNS.chicken.waterPerDayPerKg[k];
						animalSubTypes.seasons.food = RNS.chicken.foodPerDayPerKg[k]/RN.commodityDensity.CHICKENFOOD;
-- weight
						animalSubTypes.seasons.buyWeight = RNS.chicken.buyWeight[k];
						animalSubTypes.seasons.bornWeight = RNS.chicken.bornWeight[k];
-- output
						animalSubTypes.seasons.milk = RNS.chicken.milkPerDay[k];
						animalSubTypes.seasons.manure = RNS.chicken.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
						animalSubTypes.seasons.liquidManure =	RNS.chicken.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
						animalSubTypes.seasons.foodSpillage = RNS.chicken.foodSpillage[k];
						animalSubTypes.seasons.pallets = RNS.chicken.eggsPerYear[k] * 0.06/RN.commodityDensity.EGG; -- L egg per year per hen, 1 egg = 60 g
-- breeding
						animalSubTypes.seasons.fertileAge = RNS.chicken.fertileAge[k];
						animalSubTypes.seasons.averageLitterSize = RNS.chicken.averageLitterSize[k];
						animalSubTypes.seasons.variationLitterSize = RNS.chicken.variationLitterSize[k];
						animalSubTypes.seasons.birthRate = RNS.chicken.birthRate[k];
						animalSubTypes.seasons.femalePercentage = RNS.chicken.femalePercentage[k];

						animalSubTypes.breeding.fertileAge = RNS.chicken.fertileAge[k];
						animalSubTypes.breeding.averageLitterSize = RNS.chicken.averageLitterSize[k];
						animalSubTypes.breeding.variationLitterSize = RNS.chicken.variationLitterSize[k];
						animalSubTypes.breeding.birthRate = RNS.chicken.birthRate[k];
						animalSubTypes.breeding.femalePercentage = RNS.chicken.femalePercentage[k];

-- store
						animalSubTypes.storeInfo.buyPrice = RNS.chicken.buyPriceMultiplier[k] * RNS.chicken.buyWeight[k] * RNS.chicken.pricePerKg[k];
						animalSubTypes.storeInfo.baseSellPrice = RNS.chicken.baseSellPrice[k];
						animalSubTypes.storeInfo.pricePerKg = RNS.chicken.pricePerKg[k];
						animalSubTypes.storeInfo.priceDropAge = RNS.chicken.priceDropAge[k];
						animalSubTypes.storeInfo.transportPrice = math.min(RNS.chicken.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
						animalSubTypes.storeInfo.buyAge = RNS.chicken.buyAge[k]/365;
						animalSubTypes.storeInfo.buyIsFemale = RNS.chicken.buyIsFemale[k];
						animalSubTypes.storeInfo.buyWeight = RNS.chicken.buyWeight[k];

						animalSubTypes.seasons.buyPrice = RNS.chicken.buyPriceMultiplier[k];
						animalSubTypes.seasons.baseSellPrice = RNS.chicken.baseSellPrice[k];
						animalSubTypes.seasons.pricePerKg = RNS.chicken.pricePerKg[k];
						animalSubTypes.seasons.priceDropAge = RNS.chicken.priceDropAge[k];
						animalSubTypes.seasons.transportPrice = math.min(RNS.chicken.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
						animalSubTypes.seasons.buyAge = RNS.chicken.buyAge[k];
						animalSubTypes.seasons.buyIsFemale = RNS.chicken.buyIsFemale[k];

						if RNS.upStartRealNumbersAnimalCareSeasons then
							print(" ");
							myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
							myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
							myPrintString(subTypeName.." FS name",animalName,textWidth," ");
							myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
							myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
							myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
							myPrintFloat(subTypeName.." Liter eggs per year",animalSubTypes.seasons.pallets,textWidth,"L/year ");
							myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
							myPrint(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
							myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
							myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
							myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
							myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);
						end;
					end;
				end;

-- DUCKS
				local duckNames = {"DUCK_TYPE_WHITE", "DUCK_TYPE_BROWN", "DUCK_TYPE_BLACK"};

				if g_seasons.animals.animalManager.typeToAnimal["DUCK"] ~= nil then
					myAnimalDuck = g_seasons.animals.animalManager.typeToAnimal["DUCK"];
	--				print_r(myAnimalDuck)

					for i,animalSubTypes in pairs(myAnimalDuck.subTypes) do
						local k = 0;
						animalName = string.upper(animalSubTypes.fillTypeDesc.name);
						if animalName == duckNames[1] 	then k = 1; end;
						if animalName == duckNames[2] 	then k = 2; end;
						if animalName == duckNames[3] 	then k = 3; end;
						
						local myType 			= myAnimalDuck.type;
						local class 			= myAnimalDuck.class;
						
						local subTypeId 		= animalSubTypes.subTypeId;
						local subTypeFillType 	= animalSubTypes.fillType;
						local subTypeName 		= animalSubTypes.subTypeName;
						local subTypeType 		= animalSubTypes.type;

--						print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

						if k > 0 then	

	-- input
							animalSubTypes.seasons.straw = 285 * RNS.ducks.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
							animalSubTypes.seasons.water = RNS.ducks.waterPerDayPerKg[k];
							animalSubTypes.seasons.food = RNS.ducks.foodPerDayPerKg[k]/RN.commodityDensity.CHICKENFOOD;
	-- weight
							animalSubTypes.seasons.buyWeight = RNS.ducks.buyWeight[k];
							animalSubTypes.seasons.bornWeight = RNS.ducks.bornWeight[k];
	-- output
							animalSubTypes.seasons.milk = RNS.ducks.milkPerDay[k];
							animalSubTypes.seasons.manure = RNS.ducks.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
							animalSubTypes.seasons.liquidManure =	RNS.ducks.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
							animalSubTypes.seasons.foodSpillage = RNS.ducks.foodSpillage[k];
							animalSubTypes.seasons.pallets = RNS.ducks.eggsPerYear[k] * 0.06/RN.commodityDensity.EGG; -- L egg per year per hen, 1 egg = 60 g
	-- breeding
							animalSubTypes.seasons.fertileAge = RNS.ducks.fertileAge[k];
							animalSubTypes.seasons.averageLitterSize = RNS.ducks.averageLitterSize[k];
							animalSubTypes.seasons.variationLitterSize = RNS.ducks.variationLitterSize[k];
							animalSubTypes.seasons.birthRate = RNS.ducks.birthRate[k];
							animalSubTypes.seasons.femalePercentage = RNS.ducks.femalePercentage[k];

							animalSubTypes.breeding.fertileAge = RNS.ducks.fertileAge[k];
							animalSubTypes.breeding.averageLitterSize = RNS.ducks.averageLitterSize[k];
							animalSubTypes.breeding.variationLitterSize = RNS.ducks.variationLitterSize[k];
							animalSubTypes.breeding.birthRate = RNS.ducks.birthRate[k];
							animalSubTypes.breeding.femalePercentage = RNS.ducks.femalePercentage[k];

	-- store
							animalSubTypes.storeInfo.buyPrice = RNS.ducks.buyPriceMultiplier[k] * RNS.ducks.buyWeight[k] * RNS.ducks.pricePerKg[k];
							animalSubTypes.storeInfo.baseSellPrice = RNS.ducks.baseSellPrice[k];
							animalSubTypes.storeInfo.pricePerKg = RNS.ducks.pricePerKg[k];
							animalSubTypes.storeInfo.priceDropAge = RNS.ducks.priceDropAge[k];
							animalSubTypes.storeInfo.transportPrice = math.min(RNS.ducks.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
							animalSubTypes.storeInfo.buyAge = RNS.ducks.buyAge[k]/365;
							animalSubTypes.storeInfo.buyIsFemale = RNS.ducks.buyIsFemale[k];
							animalSubTypes.storeInfo.buyWeight = RNS.ducks.buyWeight[k];

							animalSubTypes.seasons.buyPrice = RNS.ducks.buyPriceMultiplier[k];
							animalSubTypes.seasons.baseSellPrice = RNS.ducks.baseSellPrice[k];
							animalSubTypes.seasons.pricePerKg = RNS.ducks.pricePerKg[k];
							animalSubTypes.seasons.priceDropAge = RNS.ducks.priceDropAge[k];
							animalSubTypes.seasons.transportPrice = math.min(RNS.ducks.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
							animalSubTypes.seasons.buyAge = RNS.ducks.buyAge[k];
							animalSubTypes.seasons.buyIsFemale = RNS.ducks.buyIsFemale[k];

							if RNS.upStartRealNumbersAnimalCareSeasons then
								print(" ");
								myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
								myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
								myPrintString(subTypeName.." FS name",animalName,textWidth," ");
								myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
								myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
								myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
								myPrintFloat(subTypeName.." Liter eggs per year",animalSubTypes.seasons.pallets,textWidth,"L/year ");
								myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
								myPrint(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
								myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
								myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
								myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
								myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);
							end;
						end;
					end;
				end;
				

-- DUCKS registered as CHICKEN

				local duckNames = {"DUCK_TYPE_WHITE", "DUCK_TYPE_BROWN", "DUCK_TYPE_BLACK"};

				if g_seasons.animals.animalManager.typeToAnimal["CHICKEN"] ~= nil then
					myAnimalDuck = g_seasons.animals.animalManager.typeToAnimal["CHICKEN"];
	--				print_r(myAnimalDuck)


	--				for k = 1,4 do
					for i,animalSubTypes in pairs(myAnimalDuck.subTypes) do
						local k = 0;
						animalName = string.upper(animalSubTypes.fillTypeDesc.name);
						if animalName == duckNames[1] 	then k = 1; end;
						if animalName == duckNames[2] 	then k = 2; end;
						if animalName == duckNames[3] 	then k = 3; end;
						
						local myType 			= myAnimalDuck.type;
						local class 			= myAnimalDuck.class;
						
						local subTypeId 		= animalSubTypes.subTypeId;
						local subTypeFillType 	= animalSubTypes.fillType;
						local subTypeName 		= animalSubTypes.subTypeName;
						local subTypeType 		= animalSubTypes.type;

--						print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

						if k > 0 then	

	-- input
							animalSubTypes.seasons.straw = 285 * RNS.ducks.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
							animalSubTypes.seasons.water = RNS.ducks.waterPerDayPerKg[k];
							animalSubTypes.seasons.food = RNS.ducks.foodPerDayPerKg[k]/RN.commodityDensity.CHICKENFOOD;
	-- weight
							animalSubTypes.seasons.buyWeight = RNS.ducks.buyWeight[k];
							animalSubTypes.seasons.bornWeight = RNS.ducks.bornWeight[k];
	-- output
							animalSubTypes.seasons.milk = RNS.ducks.milkPerDay[k];
							animalSubTypes.seasons.manure = RNS.ducks.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
							animalSubTypes.seasons.liquidManure =	RNS.ducks.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
							animalSubTypes.seasons.foodSpillage = RNS.ducks.foodSpillage[k];
							animalSubTypes.seasons.pallets = RNS.ducks.eggsPerYear[k] * 0.06/RN.commodityDensity.EGG; -- L egg per year per hen, 1 egg = 60 g
	-- breeding
							animalSubTypes.seasons.fertileAge = RNS.ducks.fertileAge[k];
							animalSubTypes.seasons.averageLitterSize = RNS.ducks.averageLitterSize[k];
							animalSubTypes.seasons.variationLitterSize = RNS.ducks.variationLitterSize[k];
							animalSubTypes.seasons.birthRate = RNS.ducks.birthRate[k];
							animalSubTypes.seasons.femalePercentage = RNS.ducks.femalePercentage[k];

							animalSubTypes.breeding.fertileAge = RNS.ducks.fertileAge[k];
							animalSubTypes.breeding.averageLitterSize = RNS.ducks.averageLitterSize[k];
							animalSubTypes.breeding.variationLitterSize = RNS.ducks.variationLitterSize[k];
							animalSubTypes.breeding.birthRate = RNS.ducks.birthRate[k];
							animalSubTypes.breeding.femalePercentage = RNS.ducks.femalePercentage[k];

	-- store
							animalSubTypes.storeInfo.buyPrice = RNS.ducks.buyPriceMultiplier[k] * RNS.ducks.buyWeight[k] * RNS.ducks.pricePerKg[k];
							animalSubTypes.storeInfo.baseSellPrice = RNS.ducks.baseSellPrice[k];
							animalSubTypes.storeInfo.pricePerKg = RNS.ducks.pricePerKg[k];
							animalSubTypes.storeInfo.priceDropAge = RNS.ducks.priceDropAge[k];
							animalSubTypes.storeInfo.transportPrice = math.min(RNS.ducks.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
							animalSubTypes.storeInfo.buyAge = RNS.ducks.buyAge[k]/365;
							animalSubTypes.storeInfo.buyIsFemale = RNS.ducks.buyIsFemale[k];
							animalSubTypes.storeInfo.buyWeight = RNS.ducks.buyWeight[k];

							animalSubTypes.seasons.buyPrice = RNS.ducks.buyPriceMultiplier[k];
							animalSubTypes.seasons.baseSellPrice = RNS.ducks.baseSellPrice[k];
							animalSubTypes.seasons.pricePerKg = RNS.ducks.pricePerKg[k];
							animalSubTypes.seasons.priceDropAge = RNS.ducks.priceDropAge[k];
							animalSubTypes.seasons.transportPrice = math.min(RNS.ducks.transportPrice[k], 0.01 * animalSubTypes.storeInfo.buyPrice);
							animalSubTypes.seasons.buyAge = RNS.ducks.buyAge[k];
							animalSubTypes.seasons.buyIsFemale = RNS.ducks.buyIsFemale[k];

							if RNS.upStartRealNumbersAnimalCareSeasons then
								print(" ");
								myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
								myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
								myPrintString(subTypeName.." FS name",animalName,textWidth," ");
								myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
								myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
								myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
								myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");							
								myPrintFloat(subTypeName.." Liter eggs per year",animalSubTypes.seasons.pallets,textWidth,"L/year ");
								myPrintFloat(subTypeName.." fertileAge",animalSubTypes.breeding.fertileAge,textWidth,"year ");							
								myPrint(subTypeName.." averageLitterSize",animalSubTypes.breeding.averageLitterSize,textWidth," ");							
								myPrint(subTypeName.." variationLitterSize",animalSubTypes.breeding.variationLitterSize,textWidth," ");							
								myPrintFloat(subTypeName.." femalePercentage",animalSubTypes.breeding.femalePercentage,textWidth," ");							
								myPrintFloat(subTypeName.." pricePerKg",animalSubTypes.storeInfo.pricePerKg,textWidth,currency.."/kg");							
								myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);
							end;
						end;
					end;
				end;
				


-- HORSES

--				for k = 1,4 do
				
				local horses1Names = {"HORSE_TYPE_GREY","HORSE_TYPE_BROWN_WHITE","HORSE_TYPE_BEIGE","HORSE_TYPE_RED_BROWN"};

				myAnimalHorses1 = g_seasons.animals.animalManager.typeToAnimal["HORSE"];
--				print_r(myAnimalHorses1)


				for i,animalSubTypes in pairs(myAnimalHorses1.subTypes) do
					local k = 0;
					animalName = string.upper(animalSubTypes.fillTypeDesc.name);
					if animalName == horses1Names[1] 	then k = 1; end;
					if animalName == horses1Names[2] 	then k = 2; end;
					if animalName == horses1Names[3] 	then k = 3; end;
					if animalName == horses1Names[4] 	then k = 4; end;
					
					local myType 			= myAnimalHorses1.type;
					local class 			= myAnimalHorses1.class;
					
					local subTypeId 		= animalSubTypes.subTypeId;
					local subTypeFillType 	= animalSubTypes.fillType;
					local subTypeName 		= animalSubTypes.subTypeName;
					local subTypeType 		= animalSubTypes.type;

--					print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

--					iFillType = RNS.horses1.fillType[k];
--					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);

					if k > 0 then	
					
						RN.hasAnimal["HORSE"] 	= true;

-- input
						animalSubTypes.seasons.straw = 285 * RNS.horses1.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
						animalSubTypes.seasons.water = RNS.horses1.waterPerDayPerKg[k];
						animalSubTypes.seasons.food = RNS.horses1.foodPerDayPerKg[k];
-- weight
						animalSubTypes.seasons.buyWeight = RNS.horses1.buyWeight[k];
						animalSubTypes.seasons.bornWeight = RNS.horses1.bornWeight[k];
-- output
						animalSubTypes.seasons.milk = RNS.horses1.milkPerDay[k];
						animalSubTypes.seasons.manure = RNS.horses1.manurePerDayPerKg[k];
						animalSubTypes.seasons.liquidManure =	RNS.horses1.liquidManure[k];
						animalSubTypes.seasons.foodSpillage = RNS.horses1.foodSpillage[k];
-- store
						animalSubTypes.storeInfo.buyPrice = RNS.horses1.buyPriceMultiplier[k] * RNS.horses1.buyWeight[k] * RNS.horses1.pricePerKg[k];
						animalSubTypes.storeInfo.baseSellPrice = RNS.horses1.baseSellPrice[k];
						animalSubTypes.storeInfo.pricePerKg = RNS.horses1.pricePerKg[k];
						animalSubTypes.storeInfo.priceDropAge = RNS.horses1.priceDropAge[k];
						animalSubTypes.storeInfo.transportPrice = RNS.horses1.transportPrice[k];
						animalSubTypes.storeInfo.buyAge = RNS.horses1.buyAge[k]/365;
						animalSubTypes.storeInfo.buyIsFemale = RNS.horses1.buyIsFemale[k];
						animalSubTypes.storeInfo.buyWeight = RNS.horses1.buyWeight[k];

						animalSubTypes.seasons.buyPrice = RNS.horses1.buyPriceMultiplier[k];
						animalSubTypes.seasons.baseSellPrice = RNS.horses1.baseSellPrice[k];
						animalSubTypes.seasons.pricePerKg = RNS.horses1.pricePerKg[k];
						animalSubTypes.seasons.priceDropAge = RNS.horses1.priceDropAge[k];
						animalSubTypes.seasons.transportPrice = RNS.horses1.transportPrice[k];
						animalSubTypes.seasons.buyAge = RNS.horses1.buyAge[k];
						animalSubTypes.seasons.buyIsFemale = RNS.horses1.buyIsFemale[k];
						animalSubTypes.seasons.liveryIncome  = RNS.horses1.liveryIncome[k];
						animalSubTypes.seasons.trainingDifficulty = RNS.horses1.trainingDifficulty[k];

						if RNS.upStartRealNumbersAnimalCareSeasons then
							print(" ");
							myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
							myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
							myPrintString(subTypeName.." FS name",animalName,textWidth," ");
							myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
							myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
							myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");																								
							myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);
							myPrint(subTypeName.." liveryIncome",animalSubTypes.seasons.liveryIncome,textWidth,currency);
						end;
					end;
				end;
				
--				for k = 1,4 do
				
				local horses2Names = {"HORSE_TYPE_BROWN","HORSE_TYPE_BLACK","HORSE_TYPE_DARK_BROWN","HORSE_TYPE_LIGHT_BROWN"};

				myAnimalHorses2 = g_seasons.animals.animalManager.typeToAnimal["HORSE"];
--				print_r(myAnimalHorses2)


				for i,animalSubTypes in pairs(myAnimalHorses2.subTypes) do
					local k = 0;
					animalName = string.upper(animalSubTypes.fillTypeDesc.name);
					if animalName == horses2Names[1] 	then k = 1; end;
					if animalName == horses2Names[2] 	then k = 2; end;
					if animalName == horses2Names[3] 	then k = 3; end;
					if animalName == horses2Names[4] 	then k = 4; end;
					
					local myType 			= myAnimalHorses2.type;
					local class 			= myAnimalHorses2.class;
					
					local subTypeId 		= animalSubTypes.subTypeId;
					local subTypeFillType 	= animalSubTypes.fillType;
					local subTypeName 		= animalSubTypes.subTypeName;
					local subTypeType 		= animalSubTypes.type;

--					print("k = "..k.." : "..animalName.." subTypeId = "..subTypeId.." subTypeName = "..subTypeName);

--					iFillType = RNS.horses2.fillType[k];
--					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);

					if k > 0 then	
						
						RN.hasAnimal["HORSE"] 	= true;

-- input
						animalSubTypes.seasons.straw = 285 * RNS.horses2.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
						animalSubTypes.seasons.water = RNS.horses2.waterPerDayPerKg[k];
						animalSubTypes.seasons.food = RNS.horses2.foodPerDayPerKg[k];
-- weight
						animalSubTypes.seasons.buyWeight = RNS.horses2.buyWeight[k];
						animalSubTypes.seasons.bornWeight = RNS.horses2.bornWeight[k];
-- output
						animalSubTypes.seasons.milk = RNS.horses2.milkPerDay[k];
						animalSubTypes.seasons.manure = RNS.horses2.manurePerDayPerKg[k];
						animalSubTypes.seasons.liquidManure =	RNS.horses2.liquidManure[k];
						animalSubTypes.seasons.foodSpillage = RNS.horses2.foodSpillage[k];
-- store
						animalSubTypes.storeInfo.buyPrice = RNS.horses2.buyPriceMultiplier[k] * RNS.horses2.buyWeight[k] * RNS.horses2.pricePerKg[k];
						animalSubTypes.storeInfo.baseSellPrice = RNS.horses2.baseSellPrice[k];
						animalSubTypes.storeInfo.pricePerKg = RNS.horses2.pricePerKg[k];
						animalSubTypes.storeInfo.priceDropAge = RNS.horses2.priceDropAge[k];
						animalSubTypes.storeInfo.transportPrice = RNS.horses2.transportPrice[k];
						animalSubTypes.storeInfo.buyAge = RNS.horses2.buyAge[k]/365;
						animalSubTypes.storeInfo.buyIsFemale = RNS.horses2.buyIsFemale[k];
						animalSubTypes.storeInfo.buyWeight = RNS.horses2.buyWeight[k];

						animalSubTypes.seasons.buyPrice = RNS.horses2.buyPriceMultiplier[k];
						animalSubTypes.seasons.baseSellPrice = RNS.horses2.baseSellPrice[k];
						animalSubTypes.seasons.pricePerKg = RNS.horses2.pricePerKg[k];
						animalSubTypes.seasons.priceDropAge = RNS.horses2.priceDropAge[k];
						animalSubTypes.seasons.transportPrice = RNS.horses2.transportPrice[k];
						animalSubTypes.seasons.buyAge = RNS.horses2.buyAge[k];
						animalSubTypes.seasons.buyIsFemale = RNS.horses2.buyIsFemale[k];
						animalSubTypes.seasons.liveryIncome  = RNS.horses2.liveryIncome[k];
						animalSubTypes.seasons.trainingDifficulty = RNS.horses2.trainingDifficulty[k];

						if RNS.upStartRealNumbersAnimalCareSeasons then
							print(" ");
							myPrint(subTypeName.." SubType Id",subTypeId,textWidth," ");
							myPrint(subTypeName.." FillType Id",subTypeFillType,textWidth," ");
							myPrintString(subTypeName.." FS name",animalName,textWidth," ");
							myPrintString(subTypeName.." SubType name",subTypeName,textWidth," ");						
							myPrint(subTypeName.." strawPerYear",animalSubTypes.seasons.straw,textWidth,"L/year ");
							myPrintFloat(subTypeName.." waterPerDayPerKg",animalSubTypes.seasons.water,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." foodPerDayPerKg",animalSubTypes.seasons.food,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." manurePerDayPerKg",animalSubTypes.seasons.manure,textWidth,"L/day/kg BW ");
							myPrintFloat(subTypeName.." liquidManurePerDayPerKg",animalSubTypes.seasons.liquidManure,textWidth,"L/day/kg BW ");																								
							myPrintFloat(subTypeName.." transportPrice",animalSubTypes.storeInfo.transportPrice,textWidth,currency);
							myPrint(subTypeName.." liveryIncome",animalSubTypes.seasons.liveryIncome,textWidth,currency);
						end;
					end;
				end;
				print(" ");
				RNS.notRunYetRealNumbersAnimalCareSeasons = false;
				RNS.upStartRealNumbersAnimalCareSeasons = false;
			end;
		end;
	end;

end;
function RealNumbersAnimalCareSeasons:draw()
end;
function RealNumbersAnimalCareSeasons:deleteMap()
end;
function RealNumbersAnimalCareSeasons:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersAnimalCareSeasons);
