--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersAnnualFeedPrediction by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021


-- FillType indices

--[[
	1 :: UNKNOWN, 2 :: WHEAT, 3 :: BARLEY, 4 :: OAT, 5 :: CANOLA, 6 :: SUNFLOWER, 7 :: SOYBEAN, 8 :: MAIZE
	9 :: POTATO, 10 :: SUGARBEET, 11 :: COTTON, 12 :: SUGARCANE, 13 :: SEEDS, 14 :: EGG, 15 :: WOOL, 16 :: MILK
	17 :: FUEL, 18 :: WATER, 19 :: FORAGE, 20 :: FORAGE_MIXING, 21 :: CHAFF, 22 :: TREESAPLINGS, 23 :: WOODCHIPS
	24 :: SILAGE, 25 :: OILSEEDRADISH, 26 :: POPLAR, 27 :: GRASS, 28 :: GRASS_WINDROW, 29 :: DRYGRASS,
	30 :: DRYGRASS_WINDROW, 31 :: STRAW, 32 :: DIESEL, 33 :: DEF, 34 :: AIR, 35 :: ROUNDBALE, 36 :: ROUNDBALE_GRASS
	37 :: ROUNDBALE_DRYGRASS, 38 :: ROUNDBALE_WHEAT, 39 :: ROUNDBALE_BARLEY, 40 :: SQUAREBALE, 41 :: SQUAREBALE_WHEAT
	42 :: SQUAREBALE_BARLEY, 43 :: FERTILIZER, 44 :: LIQUIDFERTILIZER, 45 :: MANURE, 46 :: LIQUIDMANURE
	47 :: DIGESTATE, 48 :: PIGFOOD, 49 :: TARP, 50 :: LIME, 51 :: HERBICIDE, 52 :: WEED, 53 :: HORSE_TYPE_BEIGE
	54 :: HORSE_TYPE_BLACK, 55 :: HORSE_TYPE_BROWN, 56 :: HORSE_TYPE_BROWN_WHITE, 57 :: HORSE_TYPE_DARK_BROWN
	58 :: HORSE_TYPE_GREY, 59 :: HORSE_TYPE_LIGHT_BROWN, 60 :: HORSE_TYPE_RED_BROWN, 61 :: COW_TYPE_BROWN
	62 :: COW_TYPE_BROWN_WHITE, 63 :: COW_TYPE_BLACK, 64 :: COW_TYPE_BLACK_WHITE, 65 :: COW_TYPE_BRAHMAN_BROWN
	66 :: COW_TYPE_BRAHMAN_WHITE, 67 :: COW_TYPE_BRAHMAN_LIGHT_BROWN, 68 :: COW_TYPE_BRAHMAN_GREY
	69 :: SHEEP_TYPE_WHITE, 70 :: SHEEP_TYPE_BROWN, 71 :: SHEEP_TYPE_BLACK_WHITE, 72 :: SHEEP_TYPE_BLACK
	73 :: PIG_TYPE_RED, 74 :: PIG_TYPE_WHITE, 75 :: PIG_TYPE_BLACK_WHITE, 76 :: PIG_TYPE_BLACK
	77 :: CHICKEN_TYPE_BLACK, 78 :: CHICKEN_TYPE_WHITE, 79 :: CHICKEN_TYPE_BROWN, 80 :: CHICKEN_TYPE_ROOSTER
--]]

RealNumbersAnnualFeedPrediction = {};

function myPrintFeed(text, number1, number2, number3, number4, textWidth, unit)
	print(string.format("%s =  %10.0f %10.0f %10.0f %10.0f %s", text..string.rep(" ",textWidth-string.len(text)),number1, number2, number3, number4,"    "..unit));
end;
function myPrintFloatFeed(text, number1, number2, number3, number4, textWidth, unit)
	print(string.format("%s =  %10.4f %10.4f %10.4f %10.4f %s", text..string.rep(" ",textWidth-string.len(text)),number1, number2, number3, number4,"    "..unit));
end;
function myPrintFeedNames(text1, text2, text3, text4, textWidth,textWidth1)
	print(string.format("%s %10s %10s %10s %10s", string.rep(" ",textWidth+3),
												string.rep(" ",textWidth1-string.len(text1))..text1,
												string.rep(" ",textWidth1-string.len(text2))..text2,
												string.rep(" ",textWidth1-string.len(text3))..text3,
												string.rep(" ",textWidth1-string.len(text4))..text4));
end;
function myPrintFeed3(text, number1, number2, number3, textWidth, unit)
	print(string.format("%s =  %10.0f %10.0f %10.0f %s", text..string.rep(" ",textWidth-string.len(text)),number1, number2, number3,"    "..unit));
end;
function myPrintFloatFeed3(text, number1, number2, number3, textWidth, unit)
	print(string.format("%s =  %10.4f %10.4f %10.4f %s", text..string.rep(" ",textWidth-string.len(text)),number1, number2, number3,"    "..unit));
end;
function myPrintFeedNames3(text1, text2, text3, textWidth,textWidth1)
	print(string.format("%s %10s %10s %10s", string.rep(" ",textWidth+3),
												string.rep(" ",textWidth1-string.len(text1))..text1,
												string.rep(" ",textWidth1-string.len(text2))..text2,
												string.rep(" ",textWidth1-string.len(text3))..text3));
end;

function RealNumbersAnnualFeedPrediction:loadMap(name)
	local textWidth = 40; 					-- text width in log file
	local textWidth1 = 10; 					-- text width in log file
	RN.totalFeedHectares	= {};
	RN.numberOfFoodGroups	= {};

--[[
RN.cropBonusYieldLitersPerHa[fruitName]
RN.windrowYieldLitersPerHa[fruitName]
RN.numberRoundBalesPerHa[fruitName]
RN.numberSquareBalesPerHa[fruitName]
RN.cropPricePerLiter[fruitName]
--]]

	RN.hasAnimal				= {};
	RN.hasAnimal["COW"] 		= false;
	RN.hasAnimal["CALF"] 		= false;
	RN.hasAnimal["PIG"] 		= false;
	RN.hasAnimal["PIG2"] 		= false;
	RN.hasAnimal["PIGLET"] 		= false;
	RN.hasAnimal["SHEEP"] 		= false;
	RN.hasAnimal["GOAT"] 		= false;
	RN.hasAnimal["SHEEPGOAT"] 	= false;
	RN.hasAnimal["CHICKEN"] 	= false;
	RN.hasAnimal["DUCK"] 		= false;
	RN.hasAnimal["CHICKENDUCK"] = false;
	RN.hasAnimal["HORSE"] 		= false;

	print("\nFS19_RealLifeNumbers: RealNumbersAnnualFeedPrediction active\n")

	myAnimalPigs = g_seasons.animals.animalManager.typeToAnimal["PIG"];

	if myAnimalPigs ~= nil then
		local pigNames = {"PIG_TYPE_RED", "PIG_TYPE_WHITE", "PIG_TYPE_BLACK_WHITE", "PIG_TYPE_BLACK"};

		for i,animalSubTypes in pairs(myAnimalPigs.subTypes) do
			local k = 0;
			animalName = string.upper(animalSubTypes.fillTypeDesc.name);
			if animalName == pigNames[1] 	then RN.hasAnimal["PIG"] = true; end;
			if animalName == pigNames[2] 	then RN.hasAnimal["PIG"] = true; end;
			if animalName == pigNames[3] 	then RN.hasAnimal["PIG"] = true; end;
			if animalName == pigNames[4] 	then RN.hasAnimal["PIG"] = true; end;

			local subTypeName 		= animalSubTypes.subTypeName;
			local subTypeType 		= animalSubTypes.type;

			if string.find(string.upper(subTypeName),"PIGLET") ~= nil then RN.hasAnimal["PIGLET"] = true; end;
		end;
	end;


	myAnimalCows1 = g_seasons.animals.animalManager.typeToAnimal["COW"];

	if myAnimalCows1 ~= nil then
		local cows1Names = {"COW_TYPE_BROWN", "COW_TYPE_BROWN_WHITE", "COW_TYPE_BLACK", "COW_TYPE_BLACK_WHITE"};

		for i,animalSubTypes in pairs(myAnimalCows1.subTypes) do
			local k = 0;
			animalName = string.upper(animalSubTypes.fillTypeDesc.name);
			if animalName == cows1Names[1] 	then RN.hasAnimal["COW"] = true; end;
			if animalName == cows1Names[2] 	then RN.hasAnimal["COW"] = true; end;
			if animalName == cows1Names[3] 	then RN.hasAnimal["COW"] = true; end;
			if animalName == cows1Names[4] 	then RN.hasAnimal["COW"] = true; end;

			local subTypeName 		= animalSubTypes.subTypeName;
			local subTypeType 		= animalSubTypes.type;
			if string.find(string.upper(subTypeName),"CALF") ~= nil then RN.hasAnimal["CALF"] = true; end;
		end;
	end;


	myAnimalCows2 = g_seasons.animals.animalManager.typeToAnimal["COW"];

	if myAnimalCows2 ~= nil then
		local cows2Names = {"COW_TYPE_BRAHMAN_BROWN", "COW_TYPE_BRAHMAN_WHITE", "COW_TYPE_BRAHMAN_LIGHT_BROWN", "COW_TYPE_BRAHMAN_GREY"};

		for i,animalSubTypes in pairs(myAnimalCows2.subTypes) do
			local k = 0;
			animalName = string.upper(animalSubTypes.fillTypeDesc.name);
			if animalName == cows2Names[1] 	then RN.hasAnimal["COW"] = true; end;
			if animalName == cows2Names[2] 	then RN.hasAnimal["COW"] = true; end;
			if animalName == cows2Names[3] 	then RN.hasAnimal["COW"] = true; end;
			if animalName == cows2Names[4] 	then RN.hasAnimal["COW"] = true; end;

			local subTypeName 		= animalSubTypes.subTypeName;
			local subTypeType 		= animalSubTypes.type;
			if string.find(string.upper(subTypeName),"CALF") ~= nil then RN.hasAnimal["CALF"] = true; end;
		end;
	end;


	myAnimalCalf = g_seasons.animals.animalManager.typeToAnimal["CALF"];
	if myAnimalCalf ~= nil then
		local calfNames = {"CALF_TYPE_BLACKWHITE", "CALF_TYPE_BLACK", "CALF_TYPE_BROWN"};

		for i,animalSubTypes in pairs(myAnimalCalf.subTypes) do
			local k = 0;
			animalName = string.upper(animalSubTypes.fillTypeDesc.name);
			if animalName == calfNames[1] 	then RN.hasAnimal["CALF"] = true; end;
			if animalName == calfNames[2] 	then RN.hasAnimal["CALF"] = true; end;
			if animalName == calfNames[3] 	then RN.hasAnimal["CALF"] = true; end;

			local subTypeName 		= animalSubTypes.subTypeName;
			local subTypeType 		= animalSubTypes.type;
			if string.find(string.upper(subTypeName),"CALF") ~= nil then RN.hasAnimal["CALF"] = true; end;
		end;
	end;


	myAnimalSheep = g_seasons.animals.animalManager.typeToAnimal["SHEEP"];
	if myAnimalSheep ~= nil then
		local sheepNames = {"SHEEP_TYPE_WHITE", "SHEEP_TYPE_BROWN", "SHEEP_TYPE_BLACK_WHITE", "SHEEP_TYPE_BLACK"};

		for i,animalSubTypes in pairs(myAnimalSheep.subTypes) do
			local k = 0;
			animalName = string.upper(animalSubTypes.fillTypeDesc.name);
			if animalName == sheepNames[1] 	then RN.hasAnimal["SHEEP"] = true; end;
			if animalName == sheepNames[2] 	then RN.hasAnimal["SHEEP"] = true; end;
			if animalName == sheepNames[3] 	then RN.hasAnimal["SHEEP"] = true; end;
			if animalName == sheepNames[4] 	then RN.hasAnimal["SHEEP"] = true; end;

			local subTypeName 		= animalSubTypes.subTypeName;
			local subTypeType 		= animalSubTypes.type;
			if string.find(string.upper(subTypeName),"SHEEP") ~= nil then RN.hasAnimal["SHEEP"] = true; end;
			if string.find(string.upper(subTypeName),"GOAT") ~= nil then RN.hasAnimal["SHEEPGOAT"] = true; end;
		end;
	end;




	myAnimalGoats = g_seasons.animals.animalManager.typeToAnimal["GOAT"];
	if myAnimalGoats ~= nil then
		local goatNames = {"GOAT_TYPE_BROWN", "GOAT_TYPE_WHITE", "GOAT_TYPE_BLACK"};

		for i,animalSubTypes in pairs(myAnimalGoats.subTypes) do
			local k = 0;
			animalName = string.upper(animalSubTypes.fillTypeDesc.name);
			if animalName == goatNames[1] 	then RN.hasAnimal["GOAT"] = true; end;
			if animalName == goatNames[2] 	then RN.hasAnimal["GOAT"] = true; end;
			if animalName == goatNames[3] 	then RN.hasAnimal["GOAT"] = true; end;

			local subTypeName 		= animalSubTypes.subTypeName;
			local subTypeType 		= animalSubTypes.type;
			if string.find(string.upper(subTypeName),"GOAT") ~= nil then RN.hasAnimal["GOAT"] = true; end;
		end;
	end;


	myAnimalChicken = g_seasons.animals.animalManager.typeToAnimal["CHICKEN"];
	if myAnimalChicken ~= nil then
		local chickenNames = {"CHICKEN_TYPE_BLACK", "CHICKEN_TYPE_WHITE", "CHICKEN_TYPE_BROWN", "CHICKEN_TYPE_ROOSTER"};

		for i,animalSubTypes in pairs(myAnimalChicken.subTypes) do
			local k = 0;
			animalName = string.upper(animalSubTypes.fillTypeDesc.name);
			if animalName == chickenNames[1] 	then RN.hasAnimal["CHICKEN"] = true; end;
			if animalName == chickenNames[2] 	then RN.hasAnimal["CHICKEN"] = true; end;
			if animalName == chickenNames[3] 	then RN.hasAnimal["CHICKEN"] = true; end;
			if animalName == chickenNames[4] 	then RN.hasAnimal["CHICKEN"] = true; end;

			local subTypeName 		= animalSubTypes.subTypeName;
			local subTypeType 		= animalSubTypes.type;
			if string.find(string.upper(subTypeName),"CHICKEN") ~= nil then RN.hasAnimal["CHICKEN"] = true; end;
			if string.find(string.upper(subTypeName),"DUCK") ~= nil then RN.hasAnimal["CHICKENDUCK"] = true; end;
		end;
	end;


	myAnimalDuck = g_seasons.animals.animalManager.typeToAnimal["DUCK"];
	if myAnimalDuck ~= nil then
		local duckNames = {"DUCK_TYPE_WHITE", "DUCK_TYPE_BROWN", "DUCK_TYPE_BLACK"};

		for i,animalSubTypes in pairs(myAnimalDuck.subTypes) do
			local k = 0;
			animalName = string.upper(animalSubTypes.fillTypeDesc.name);
			if animalName == duckNames[1] 	then RN.hasAnimal["DUCK"] = true; end;
			if animalName == duckNames[2] 	then RN.hasAnimal["DUCK"] = true; end;
			if animalName == duckNames[3] 	then RN.hasAnimal["DUCK"] = true; end;

			local subTypeName 		= animalSubTypes.subTypeName;
			local subTypeType 		= animalSubTypes.type;
			if string.find(string.upper(subTypeName),"DUCK") ~= nil then RN.hasAnimal["DUCK"] = true; end;
		end;
	end;


	myAnimalHorses1 = g_seasons.animals.animalManager.typeToAnimal["HORSE"];
	if myAnimalHorses1 ~= nil then
		local horses1Names = {"HORSE_TYPE_GREY","HORSE_TYPE_BROWN_WHITE","HORSE_TYPE_BEIGE","HORSE_TYPE_RED_BROWN"};


		for i,animalSubTypes in pairs(myAnimalHorses1.subTypes) do
			local k = 0;
			animalName = string.upper(animalSubTypes.fillTypeDesc.name);
			if animalName == horses1Names[1] 	then RN.hasAnimal["HORSE"] = true; end;
			if animalName == horses1Names[2] 	then RN.hasAnimal["HORSE"] = true; end;
			if animalName == horses1Names[3] 	then RN.hasAnimal["HORSE"] = true; end;
			if animalName == horses1Names[4] 	then RN.hasAnimal["HORSE"] = true; end;

			local subTypeName 		= animalSubTypes.subTypeName;
			local subTypeType 		= animalSubTypes.type;
		end;
	end;

	myAnimalHorses2 = g_seasons.animals.animalManager.typeToAnimal["HORSE"];
	if myAnimalHorses2 ~= nil then
		local horses2Names = {"HORSE_TYPE_BROWN","HORSE_TYPE_BLACK","HORSE_TYPE_DARK_BROWN","HORSE_TYPE_LIGHT_BROWN"};


		for i,animalSubTypes in pairs(myAnimalHorses2.subTypes) do
			local k = 0;
			animalName = string.upper(animalSubTypes.fillTypeDesc.name);
			if animalName == horses2Names[1] 	then RN.hasAnimal["HORSE"] = true; end;
			if animalName == horses2Names[2] 	then RN.hasAnimal["HORSE"] = true; end;
			if animalName == horses2Names[3] 	then RN.hasAnimal["HORSE"] = true; end;
			if animalName == horses2Names[4] 	then RN.hasAnimal["HORSE"] = true; end;

			local subTypeName 		= animalSubTypes.subTypeName;
			local subTypeType 		= animalSubTypes.type;
		end;
	end;

	print(" ");
	print("This maps has the following animal types:\n");
	if RN.hasAnimal["PIG"] then print("Pigs"); end;
	if RN.hasAnimal["COW"] then print("Cows"); end;
	if RN.hasAnimal["SHEEP"] then print("Sheep"); end;
	if RN.hasAnimal["HORSE"] then print("Horses "); end;
	if RN.hasAnimal["CHICKEN"] then print("Chicken"); end;
	if RN.hasAnimal["CALF"] then print("Calves"); end;
	if RN.hasAnimal["PIGLET"] then print("Piglets"); end;
	if RN.hasAnimal["GOAT"] then print("Goats "); end;
	if RN.hasAnimal["DUCK"] then print("Ducks"); end;
	if RN.hasAnimal["SHEEPGOAT"] then print("Goats in sheep pen "); end;
	if RN.hasAnimal["CHICKENDUCK"] then print("Ducks in Chicken pen"); end;


	print(" ");
	print("PIGS");
	print(" ");
	RN.numberOfFoodGroups["PIGS"] = #g_animalFoodManager.foodGroups.PIG.content;
	print("Number of feed categories     : "..RN.numberOfFoodGroups["PIGS"]);
	print(" ");
	for k,foodGroups in pairs(g_animalFoodManager.foodGroups.PIG.content) do
		print("Feed category                 : "..foodGroups.title);
		print("Production weight     		: "..foodGroups.productionWeight);
		print("Eat weight            		: "..foodGroups.eatWeight);
		for l,iFillType in pairs(foodGroups.fillTypes) do
			local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
			print("Feed content          		: "..fillName);
			RN.totalFeedHectares[fillName] = 0;
		end;
		print(" ");
	end;

	print(" ");
	print("PIGFOOD");
	print(" ");

	for k,foodMixtures in pairs(g_animalFoodManager.foodMixtures) do
		for l,ingredients in pairs(foodMixtures.ingredients) do
			print(" ");
			print("Mix component "..l.." weight     	: "..ingredients.weight);
			print(" ");
			for m,iFillType in pairs(ingredients.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Ingredient "..l.."               	: "..fillName);
			end;
		end;
	end;
	print(" ");

	if g_seasons.animals.animalManager.typeToAnimal["PIG2"] ~= nil then
		print(" ");

		print(" ");
		print("PIG2");
		print(" ");
		RN.numberOfFoodGroups["PIG2"] = #g_animalFoodManager.foodGroups.PIG2.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["PIG2"]);
		print(" ");

		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.PIG2.content) do
			print("Feed category                 : "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;
	end;

	print(" ");
	print("COWS");
	print(" ");
	RN.numberOfFoodGroups["COWS"] = #g_animalFoodManager.foodGroups.COW.content;
	print("Number of feed categories     : "..RN.numberOfFoodGroups["COWS"]);
	print(" ");
	for k,foodGroups in pairs(g_animalFoodManager.foodGroups.COW.content) do
		print("Feed category                 : "..foodGroups.title);
		print("Production weight     		: "..foodGroups.productionWeight);
		print("Eat weight            		: "..foodGroups.eatWeight);
		for l,iFillType in pairs(foodGroups.fillTypes) do
			local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
			print("Feed content          		: "..fillName);
			RN.totalFeedHectares[fillName] = 0;
		end;
		print(" ");
	end;

	if g_seasons.animals.animalManager.typeToAnimal["CALF"] ~= nil then
		print(" ");

		print(" ");
		print("CALF");
		print(" ");
		RN.numberOfFoodGroups["CALF"] = #g_animalFoodManager.foodGroups.CALF.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["CALF"]);
		print(" ");

		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.CALF.content) do
			print("Feed category                 : "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;
	end;

	print(" ");
	print("SHEEP");
	print(" ");
	RN.numberOfFoodGroups["SHEEP"] = #g_animalFoodManager.foodGroups.SHEEP.content;
	print("Number of feed categories     : "..RN.numberOfFoodGroups["SHEEP"]);
	print(" ");

	for k,foodGroups in pairs(g_animalFoodManager.foodGroups.SHEEP.content) do
		print("Feed category                 : "..foodGroups.title);
		print("Production weight     		: "..foodGroups.productionWeight);
		print("Eat weight            		: "..foodGroups.eatWeight);
		for l,iFillType in pairs(foodGroups.fillTypes) do
			local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
			print("Feed content          		: "..fillName);
			RN.totalFeedHectares[fillName] = 0;
		end;
		print(" ");
	end;

	if g_seasons.animals.animalManager.typeToAnimal["GOAT"] ~= nil then
		print(" ");

		print(" ");
		print("GOAT");
		print(" ");
		RN.numberOfFoodGroups["GOATS"] = #g_animalFoodManager.foodGroups.GOAT.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["GOATS"]);
		print(" ");

		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.GOAT.content) do
			print("Feed category                 : "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;
	end;

	if g_seasons.animals.animalManager.typeToAnimal["SHEEPGOAT"] ~= nil then
		print(" ");

		print(" ");
		print("GOAT");
		print(" ");
		RN.numberOfFoodGroups["GOATS"] = #g_animalFoodManager.foodGroups.SHEEPGOAT.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["GOATS"]);
		print(" ");

		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.SHEEPGOAT.content) do
			print("Feed category                 : "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;
	end;

	print(" ");
	print("CHICKEN");
	print(" ");
	RN.numberOfFoodGroups["CHICKEN"] = #g_animalFoodManager.foodGroups.CHICKEN.content;
	print("Number of feed categories     : "..RN.numberOfFoodGroups["CHICKEN"]);
	print(" ");

	for k,foodGroups in pairs(g_animalFoodManager.foodGroups.CHICKEN.content) do
		print("Feed category               	: "..foodGroups.title);
		print("Production weight     		: "..foodGroups.productionWeight);
		print("Eat weight            		: "..foodGroups.eatWeight);
		for l,iFillType in pairs(foodGroups.fillTypes) do
			local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
			print("Feed content          		: "..fillName);
			RN.totalFeedHectares[fillName] = 0;
		end;
		print(" ");
	end;

	if g_seasons.animals.animalManager.typeToAnimal["DUCK"] ~= nil then
		print(" ");

		print(" ");
		print("DUCK");
		print(" ");
		RN.numberOfFoodGroups["DUCKS"] = #g_animalFoodManager.foodGroups.DUCK.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["DUCKS"]);
		print(" ");

		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.DUCK.content) do
			print("Feed category                 : "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;
	end;

	print(" ");
	print("HORSES");
	print(" ");
	RN.numberOfFoodGroups["HORSES"] = #g_animalFoodManager.foodGroups.HORSE.content;
	print("Number of feed categories     : "..RN.numberOfFoodGroups["HORSES"]);
	print(" ");

	for k,foodGroups in pairs(g_animalFoodManager.foodGroups.HORSE.content) do
		print("Feed category                 : "..foodGroups.title);
		print("Production weight     		: "..foodGroups.productionWeight);
		print("Eat weight            		: "..foodGroups.eatWeight);
		for l,iFillType in pairs(foodGroups.fillTypes) do
			local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
			print("Feed content          		: "..fillName);
			RN.totalFeedHectares[fillName] = 0;
		end;
		print(" ");
	end;

	if g_seasons.animals.animalManager.typeToAnimal["DOG"] ~= nil then
		print(" ");

		print(" ");
		print("DOG");
		print(" ");
		RN.numberOfFoodGroups["DOGS"] = #g_animalFoodManager.foodGroups.DOG.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["DOGS"]);
		print(" ");

		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.DOG.content) do
			print("Feed category                 : "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;
	end;

	RNS.cows1.color              = {   "BROWN",       "BROWN_WHITE",         "BLACK",       "BLACK_WHITE"    };
	RNS.cows1.type               = {  "Limousin",       "Ayrshire",          "Saler",         "Holstein"     };
	RNS.cows1.matureWeight		 = {    1000,              540,               1000,                680       };  -- kg
	RNS.cows1.weightDay          = {     365,              365,                365,                365       };  -- Age (in days) of known weight
	RNS.cows1.weightM            = {     566,              480,                516,                495       };  -- kg
	RNS.cows1.weightF            = {     420,              300,                396,                309       };  -- kg
	RNS.cows1.linGrowthPct		 = {      85,               85,                 85,                 85       };  -- %
	RNS.cows1.monthsToLevelOut   = {      24,               24,                 24,                 24       };  -- months to growth levels out
	RNS.cows1.slaughterAge       = {     365,              365,                365,                365       };  -- age of slaughter in days
	RNS.cows1.numberMature       = {      10,                0,                  0,                 80       };  -- number of mature animals
	RNS.cows1.strawPercentage    = {      25,               25,                 25,                 25       };  -- percentage of feed from straw
	RNS.cows1.hayPercentage      = {      50,               50,                 50,                 50       };  -- percentage of feed from hay
	RNS.cows1.silagePercentage   = {      25,               25,                 25,                 25       };  -- perentage of feed from silage
	RNS.cows1.roundBaleVolume    = {    1500,             1500,               1500,               1500       };  -- Liters
	RNS.cows1.squareBaleVolume   = {    2600,             2600,               2600,               2600       };  -- Liters

	RNS.cows1.numberOfspr = {};
	RNS.cows1.males = {};
	RNS.cows1.females = {};
	RNS.cows1.linPeakWeight = {};
	RNS.cows1.daysToLevel = {};
	RNS.cows1.gainPerDayM = {};
	RNS.cows1.gainPerDayF = {};
	RNS.cows1.slaugtherWeightM = {};
	RNS.cows1.slaugtherWeightF = {};
	RNS.cows1.averageWeightM = {};
	RNS.cows1.averageWeightF = {};
	RNS.cows1.matureWater = {};
	RNS.cows1.offsprWaterM = {};
	RNS.cows1.offsprWaterF = {};
	RNS.cows1.breedWater = {};
	RNS.cows1.matureFeed = {};
	RNS.cows1.offsprFeedM = {};
 	RNS.cows1.offsprFeedF = {};
	RNS.cows1.breedFeed = {};
	RNS.cows1.troughFeed = {};
    RNS.cows1.mixDensity = {};
	RNS.cows1.mixVolume = {};
	RNS.cows1.troughStraw = {};
	RNS.cows1.troughHay = {};
	RNS.cows1.troughSilage = {};
	RNS.cows1.bedStraw = {};
	RNS.cows1.straw = {};
	RNS.cows1.strawRoundBales = {};
	RNS.cows1.strawSquareBales = {};
	RNS.cows1.hayRoundBales = {};
	RNS.cows1.haySquareBales = {};
	RNS.cows1.silageRoundBales = {};
    RNS.cows1.silageSquareBales = {};

	RNS.cows1.matureManure = {};
	RNS.cows1.offsprManureM = {};
	RNS.cows1.offsprManureF = {};
	RNS.cows1.famManure = {};
	RNS.cows1.breedManure = {};

	RNS.cows1.matureSlurry = {};
	RNS.cows1.offsprSlurryF = {};
	RNS.cows1.offsprSlurryM = {};
	RNS.cows1.famSlurry = {};
	RNS.cows1.breedSlurry = {};

	RNS.cows1.wheatHa = {};
	RNS.cows1.hayHa = {};
	RNS.cows1.silageHa = {};

	RNS.cows1.feedName 			= {};
	RNS.cows1.feedVolume		= {};
	RNS.cows1.feedRoundBales	= {};
	RNS.cows1.feedSquareBales	= {};
	RNS.cows1.hectares			= {};

	for k = 1,4 do
		RNS.cows1.feedVolume[k]        	= {};
		RNS.cows1.feedRoundBales[k]		= {};
		RNS.cows1.feedSquareBales[k]	= {};
		RNS.cows1.hectares[k]			= {};

		RNS.cows1.numberOfspr[k]       	= RNS.cows1.numberMature[k] * RNS.cows1.averageLitterSize[k];
		RNS.cows1.males[k]             	= (1 - RNS.cows1.femalePercentage[k]) * RNS.cows1.numberOfspr[k];
		RNS.cows1.females[k]            = RNS.cows1.femalePercentage[k] * RNS.cows1.numberOfspr[k];
		RNS.cows1.gainPerDayM[k]       	= (RNS.cows1.weightM[k] - RNS.cows1.bornWeight[k])/RNS.cows1.weightDay[k];
		RNS.cows1.gainPerDayF[k]       	= (RNS.cows1.weightF[k] - RNS.cows1.bornWeight[k])/RNS.cows1.weightDay[k];
		RNS.cows1.slaugtherWeightM[k]  	= RNS.cows1.bornWeight[k] + RNS.cows1.gainPerDayM[k] * RNS.cows1.slaughterAge[k];
		RNS.cows1.slaugtherWeightF[k]  	= RNS.cows1.bornWeight[k] + RNS.cows1.gainPerDayF[k] * RNS.cows1.slaughterAge[k];
		RNS.cows1.averageWeightM[k]    	= 0.5 * (RNS.cows1.slaugtherWeightM[k] + RNS.cows1.bornWeight[k]);
		RNS.cows1.averageWeightF[k]    	= 0.5 * (RNS.cows1.slaugtherWeightF[k] + RNS.cows1.bornWeight[k]);

		RNS.cows1.matureWater[k]       	= 365 * RNS.cows1.numberMature[k] * RNS.cows1.matureWeight[k] * RNS.cows1.waterPerDayPerKg[k];
		RNS.cows1.offsprWaterM[k]      	= RNS.cows1.males[k]   * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightM[k] * RNS.cows1.waterPerDayPerKg[k];
		RNS.cows1.offsprWaterF[k]      	= RNS.cows1.females[k] * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightF[k] * RNS.cows1.waterPerDayPerKg[k];
		RNS.cows1.breedWater[k]        	= RNS.cows1.matureWater[k] + RNS.cows1.offsprWaterM[k] + RNS.cows1.offsprWaterF[k];

		RNS.cows1.matureManure[k]      	= 365 * RNS.cows1.matureWeight[k] * RNS.cows1.manurePerDayPerKg[k];		-- Manure per mature animal per year
		RNS.cows1.offsprManureM[k]     	= RNS.cows1.males[k]   * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightM[k] * RNS.cows1.manurePerDayPerKg[k];
		RNS.cows1.offsprManureF[k]     	= RNS.cows1.females[k] * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightF[k] * RNS.cows1.manurePerDayPerKg[k];
		RNS.cows1.breedManure[k]       	= RNS.cows1.matureManure[k] + RNS.cows1.offsprManureM[k] + RNS.cows1.offsprManureF[k];

		RNS.cows1.matureSlurry[k]      	= 365 * RNS.cows1.matureWeight[k] * RNS.cows1.liquidManure[k];		-- Slurry per mature animal per year
		RNS.cows1.offsprSlurryM[k]     	= RNS.cows1.males[k]   * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightM[k] * RNS.cows1.liquidManure[k];
		RNS.cows1.offsprSlurryF[k]     	= RNS.cows1.females[k] * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightF[k] * RNS.cows1.liquidManure[k];
		RNS.cows1.breedSlurry[k]       	= RNS.cows1.matureSlurry[k] + RNS.cows1.offsprSlurryM[k] + RNS.cows1.offsprSlurryF[k];

		RNS.cows1.matureFeed[k]        	= 365 * RNS.cows1.numberMature[k] * RNS.cows1.matureWeight[k] * RNS.cows1.foodPerDayPerKg[k];
		RNS.cows1.offsprFeedM[k]       	= RNS.cows1.males[k]   * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightM[k] * RNS.cows1.foodPerDayPerKg[k];
		RNS.cows1.offsprFeedF[k]       	= RNS.cows1.females[k] * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightF[k] * RNS.cows1.foodPerDayPerKg[k];
		RNS.cows1.breedFeed[k]         	= RNS.cows1.matureFeed[k] + RNS.cows1.offsprFeedM[k] + RNS.cows1.offsprFeedF[k];
		RNS.cows1.troughFeed[k]        	= RNS.cows1.foodTroughFraction[k] * RNS.cows1.breedFeed[k];

		RNS.cows1.bedStraw[k]          	= 365 * RNS.cows1.numberMature[k] * RNS.cows1.strawPerDay[k] / RN.commodityDensity.SQUAREBALE_WHEAT;	-- for mature cows
		RNS.cows1.bedStraw[k]          	= RNS.cows1.bedStraw[k] + RNS.cows1.slaughterAge[k] * RNS.cows1.numberMature[k] * RNS.cows1.averageLitterSize[k] * RNS.cows1.strawPerDay[k] / RN.commodityDensity.SQUAREBALE_WHEAT;
		RNS.cows1.straw[k]             	= RNS.cows1.bedStraw[k];
		RNS.cows1.strawRoundBales[k]   	= RNS.cows1.straw[k] / RNS.cows1.roundBaleVolume[k];
		RNS.cows1.strawSquareBales[k]  	= RNS.cows1.straw[k] / RNS.cows1.squareBaleVolume[k];

		RNS.cows1.mixDensity[k]	= 0;

		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.COW.content) do
			local meanDensity = 0;
			local mixNumbers = 0;
			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--					print(fillName);
					if RN.commodityDensity[fillName] ~= nil then
						meanDensity = meanDensity + RN.commodityDensity[fillName];
					elseif RN.cropDensity[fillName] ~= nil then
						meanDensity = meanDensity + RN.cropDensity[fillName];
					else
						print(fillName.."   density not defined");
						meanDensity = 0.3;		-- number used in case of error
					end;
					mixNumbers = mixNumbers + 1;
				end;
			end;
			meanDensity = meanDensity/mixNumbers;		-- mean mass density within each feed group
			if foodGroups.eatWeight < 1 then
				RNS.cows1.mixDensity[k] = RNS.cows1.mixDensity[k] + meanDensity * foodGroups.eatWeight; -- mass density of of complete feed mix
			else
				RNS.cows1.mixDensity[k] = RNS.cows1.mixDensity[k] + meanDensity * (1/RN.numberOfFoodGroups["COWS"]); -- mass density of of complete feed mix
			end;
		end;

		RNS.cows1.mixVolume[k]         = RNS.cows1.troughFeed[k]/RNS.cows1.mixDensity[k];

		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.COW.content) do

			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--					print(fillName);
					RNS.cows1.feedName[fillName] = fillName;
					RNS.cows1.feedVolume[k][fillName] =  foodGroups.eatWeight * RNS.cows1.mixVolume[k];
					if RN.roundBaleVolume[fillName] ~= nill then
						RNS.cows1.feedRoundBales[k][fillName] = RNS.cows1.feedVolume[k][fillName]/RN.roundBaleVolume[fillName];
					else
						RNS.cows1.feedRoundBales[k][fillName] = 0;
					end;
					if RN.squareBaleVolume[fillName] ~= nill then
						RNS.cows1.feedSquareBales[k][fillName] = RNS.cows1.feedVolume[k][fillName]/RN.squareBaleVolume[fillName];
					else
						RNS.cows1.feedSquareBales[k][fillName] = 0;
					end;
					if RN.netYield[fillName] ~= nill then
						RNS.cows1.hectares[k][fillName] = RNS.cows1.feedVolume[k][fillName]/RN.netYield[fillName];
					else
						RNS.cows1.hectares[k][fillName] = 0;
					end;
					RN.totalFeedHectares[fillName] = RN.totalFeedHectares[fillName] + RNS.cows1.hectares[k][fillName];
				end;
			end;
		end;
	end;


	print(" ");
	print("COWS");
	print(" ");
--	print("                                            "..RNS.cows1.type[1].." "..RNS.cows1.type[2].." "..RNS.cows1.type[3].." "..RNS.cows1.type[4]);

	myPrintFeedNames(RNS.cows1.type[1], RNS.cows1.type[2], RNS.cows1.type[3], RNS.cows1.type[4], textWidth,textWidth1);

	myPrintFeed("Number of mature animals",RNS.cows1.numberMature[1],RNS.cows1.numberMature[2],RNS.cows1.numberMature[3],RNS.cows1.numberMature[4],textWidth, " ");
	myPrintFeed("Number of offsprings, males",RNS.cows1.males[1],RNS.cows1.males[2],RNS.cows1.males[3],RNS.cows1.males[4],textWidth, " ");
	myPrintFeed("Number of offsprings, females",RNS.cows1.females[1],RNS.cows1.females[2],RNS.cows1.females[3],RNS.cows1.females[4],textWidth, " ");
	myPrintFeed("Average weight males", RNS.cows1.averageWeightM[1],RNS.cows1.averageWeightM[2],RNS.cows1.averageWeightM[3],RNS.cows1.averageWeightM[4],textWidth, " kg");
	myPrintFeed("Average weight females", RNS.cows1.averageWeightF[1],RNS.cows1.averageWeightF[2],RNS.cows1.averageWeightF[3],RNS.cows1.averageWeightF[4],textWidth, " kg");
	myPrintFloatFeed("Average weight gain, males", RNS.cows1.gainPerDayM[1],RNS.cows1.gainPerDayM[2],RNS.cows1.gainPerDayM[3],RNS.cows1.gainPerDayM[4],textWidth, " kg/day");
	myPrintFloatFeed("Average weight gain, females", RNS.cows1.gainPerDayF[1],RNS.cows1.gainPerDayF[2],RNS.cows1.gainPerDayF[3],RNS.cows1.gainPerDayF[4],textWidth, " kg/day");
	myPrintFeed("Slaughter age", RNS.cows1.slaughterAge[1],RNS.cows1.slaughterAge[2],RNS.cows1.slaughterAge[3],RNS.cows1.slaughterAge[4],textWidth, " days");
	myPrintFeed("Slaughter weight, male", RNS.cows1.slaugtherWeightM[1],RNS.cows1.slaugtherWeightM[2],RNS.cows1.slaugtherWeightM[3],RNS.cows1.slaugtherWeightM[4],textWidth, " kg");
	myPrintFeed("Slaughter weight, female", RNS.cows1.slaugtherWeightF[1],RNS.cows1.slaugtherWeightF[2],RNS.cows1.slaugtherWeightF[3],RNS.cows1.slaugtherWeightF[4],textWidth, " kg");
	myPrintFeed("Herd manure per year", RNS.cows1.breedManure[1],RNS.cows1.breedManure[2],RNS.cows1.breedManure[3],RNS.cows1.breedManure[4],textWidth, " L/year");
	myPrintFeed("Herd slurry per year", RNS.cows1.breedSlurry[1],RNS.cows1.breedSlurry[2],RNS.cows1.breedSlurry[3],RNS.cows1.breedSlurry[4],textWidth, " L/year");
	myPrintFeed("Herd bedding straw", RNS.cows1.bedStraw[1],RNS.cows1.bedStraw[2],RNS.cows1.bedStraw[3],RNS.cows1.bedStraw[4],textWidth, " L/year");
	myPrintFeed("Round straw bales", RNS.cows1.strawRoundBales[1],RNS.cows1.strawRoundBales[2],RNS.cows1.strawRoundBales[3],RNS.cows1.strawRoundBales[4],textWidth, " Bales/year");
	myPrintFeed("Square straw bales", RNS.cows1.strawSquareBales[1],RNS.cows1.strawSquareBales[2],RNS.cows1.strawSquareBales[3],RNS.cows1.strawSquareBales[4],textWidth, " Bales/year");
	myPrintFeed("Water per year", RNS.cows1.breedWater[1],RNS.cows1.breedWater[2],RNS.cows1.breedWater[3],RNS.cows1.breedWater[4],textWidth," L/year");
	myPrintFeed("Herd feed intake", RNS.cows1.breedFeed[1],RNS.cows1.breedFeed[2],RNS.cows1.breedFeed[3],RNS.cows1.breedFeed[4],textWidth, " kg/year");
	myPrintFeed("Herd trough feed", RNS.cows1.troughFeed[1],RNS.cows1.troughFeed[2],RNS.cows1.troughFeed[3],RNS.cows1.troughFeed[4],textWidth, " kg/year");
	myPrintFloatFeed("Feedmix density", RNS.cows1.mixDensity[1],RNS.cows1.mixDensity[2],RNS.cows1.mixDensity[3],RNS.cows1.mixDensity[4],textWidth, " kg/L");
	myPrintFeed("Herd Feedmix volume", RNS.cows1.mixVolume[1],RNS.cows1.mixVolume[2],RNS.cows1.mixVolume[3],RNS.cows1.mixVolume[4],textWidth, " L/year");


	for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.COW.content) do

		for l,iFillType in pairs(foodGroups.fillTypes) do
			if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print(" ");
				print(fillName);
				myPrintFloat("Volume fraction = ",foodGroups.eatWeight,textWidth, " ");
				myPrintFeed("Herd trough ", RNS.cows1.feedVolume[1][fillName],RNS.cows1.feedVolume[2][fillName],RNS.cows1.feedVolume[3][fillName],RNS.cows1.feedVolume[4][fillName],textWidth, " L/year");
				if RNS.cows1.feedRoundBales[1][fillName] > 0 then
					myPrintFeed("Round bales ", RNS.cows1.feedRoundBales[1][fillName],RNS.cows1.feedRoundBales[2][fillName],RNS.cows1.feedRoundBales[3][fillName],RNS.cows1.feedRoundBales[4][fillName],textWidth, " ");
					myPrintFeed("Square bales ", RNS.cows1.feedSquareBales[1][fillName],RNS.cows1.feedSquareBales[2][fillName],RNS.cows1.feedSquareBales[3][fillName],RNS.cows1.feedSquareBales[4][fillName],textWidth, " ");
				end;
				myPrintFloatFeed("Hectares ", RNS.cows1.hectares[1][fillName],RNS.cows1.hectares[2][fillName],RNS.cows1.hectares[3][fillName],RNS.cows1.hectares[4][fillName],textWidth, " Ha");
			else
				print(fillName.." is not defined on this map");
			end;
		end;
	end;


	print(" ");



	RNS.cows2.color              = {"BRAHMAN_BROWN", "BRAHMAN_WHITE", "BRAHMAN_LIGHT_BROWN","BRAHMAN_GREY"   };
	RNS.cows2.type               = {"Brahman (brown)","Brahman (white)","Brahman (light brown)","Brahman (grey)"};
	RNS.cows2.matureWeight		 = {     900,              900,                900,                900       };  -- kg
	RNS.cows2.weightDay          = {     365,              365,                365,                365       };  -- Age (in days) of known weight
	RNS.cows2.weightM            = {     566,              480,                516,                495       };  -- kg
	RNS.cows2.weightF            = {     420,              300,                396,                309       };  -- kg
	RNS.cows2.linGrowthPct		 = {      85,               85,                 85,                 85       };  -- %
	RNS.cows2.monthsToLevelOut   = {      24,               24,                 24,                 24       };  -- months to growth levels out
	RNS.cows2.slaughterAge       = {     365,              365,                365,                365       };  -- age of slaughter in days
	RNS.cows2.numberMature       = {       0,                0,                  0,                  0       };  -- number of mature animals
	RNS.cows2.strawPercentage    = {      25,               25,                 25,                 25       };  -- percentage of feed from straw
	RNS.cows2.hayPercentage      = {      50,               50,                 50,                 50       };  -- percentage of feed from hay
	RNS.cows2.silagePercentage   = {      25,               25,                 25,                 25       };  -- perentage of feed from silage
	RNS.cows2.roundBaleVolume    = {    1500,             1500,               1500,               1500       };  -- Liters
	RNS.cows2.squareBaleVolume   = {    2600,             2600,               2600,               2600       };  -- Liters


	RNS.cows2.numberOfspr = {};
	RNS.cows2.males = {};
	RNS.cows2.females = {};
	RNS.cows2.linPeakWeight = {};
	RNS.cows2.daysToLevel = {};
	RNS.cows2.gainPerDayM = {};
	RNS.cows2.gainPerDayF = {};
	RNS.cows2.slaugtherWeightM = {};
	RNS.cows2.slaugtherWeightF = {};
	RNS.cows2.averageWeightM = {};
	RNS.cows2.averageWeightF = {};
	RNS.cows2.matureWater = {};
	RNS.cows2.offsprWaterM = {};
	RNS.cows2.offsprWaterF = {};
	RNS.cows2.breedWater = {};
	RNS.cows2.matureFeed = {};
	RNS.cows2.offsprFeedM = {};
 	RNS.cows2.offsprFeedF = {};
	RNS.cows2.breedFeed = {};
	RNS.cows2.troughFeed = {};
    RNS.cows2.mixDensity = {};
	RNS.cows2.mixVolume = {};
	RNS.cows2.troughStraw = {};
	RNS.cows2.troughHay = {};
	RNS.cows2.troughSilage = {};
	RNS.cows2.bedStraw = {};
	RNS.cows2.straw = {};
	RNS.cows2.strawRoundBales = {};
	RNS.cows2.strawSquareBales = {};
	RNS.cows2.hayRoundBales = {};
	RNS.cows2.haySquareBales = {};
	RNS.cows2.silageRoundBales = {};
    RNS.cows2.silageSquareBales = {};

	RNS.cows2.matureManure = {};
	RNS.cows2.offsprManureM = {};
	RNS.cows2.offsprManureF = {};
	RNS.cows2.famManure = {};
	RNS.cows2.breedManure = {};

	RNS.cows2.matureSlurry = {};
	RNS.cows2.offsprSlurryM = {};
	RNS.cows2.offsprSlurryF = {};
	RNS.cows2.famSlurry = {};
	RNS.cows2.breedSlurry = {};

	RNS.cows2.wheatHa = {};
	RNS.cows2.hayHa = {};
	RNS.cows2.silageHa = {};

	RNS.cows2.feedName 			= {};
	RNS.cows2.feedVolume		= {};
	RNS.cows2.feedRoundBales	= {};
	RNS.cows2.feedSquareBales	= {};
	RNS.cows2.hectares			= {};

	for k = 1,4 do
		RNS.cows2.feedVolume[k]        	= {};
		RNS.cows2.feedRoundBales[k]		= {};
		RNS.cows2.feedSquareBales[k]	= {};
		RNS.cows2.hectares[k]			= {};

		RNS.cows2.numberOfspr[k]       	= RNS.cows2.numberMature[k] * RNS.cows2.averageLitterSize[k];
		RNS.cows2.males[k]             	= (1 - RNS.cows2.femalePercentage[k]) * RNS.cows2.numberOfspr[k];
		RNS.cows2.females[k]            = RNS.cows2.femalePercentage[k] * RNS.cows2.numberOfspr[k];
		RNS.cows2.gainPerDayM[k]       	= (RNS.cows2.weightM[k] - RNS.cows2.bornWeight[k])/RNS.cows2.weightDay[k];
		RNS.cows2.gainPerDayF[k]       	= (RNS.cows2.weightF[k] - RNS.cows2.bornWeight[k])/RNS.cows2.weightDay[k];
		RNS.cows2.slaugtherWeightM[k]  	= RNS.cows2.bornWeight[k] + RNS.cows2.gainPerDayM[k] * RNS.cows2.slaughterAge[k];
		RNS.cows2.slaugtherWeightF[k]  	= RNS.cows2.bornWeight[k] + RNS.cows2.gainPerDayF[k] * RNS.cows2.slaughterAge[k];
		RNS.cows2.averageWeightM[k]    	= 0.5 * (RNS.cows2.slaugtherWeightM[k] + RNS.cows2.bornWeight[k]);
		RNS.cows2.averageWeightF[k]    	= 0.5 * (RNS.cows2.slaugtherWeightF[k] + RNS.cows2.bornWeight[k]);

		RNS.cows2.matureWater[k]       	= 365 * RNS.cows2.numberMature[k] * RNS.cows2.matureWeight[k] * RNS.cows2.waterPerDayPerKg[k];
		RNS.cows2.offsprWaterM[k]      	= RNS.cows2.males[k]   * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightM[k] * RNS.cows2.waterPerDayPerKg[k];
		RNS.cows2.offsprWaterF[k]      	= RNS.cows2.females[k] * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightF[k] * RNS.cows2.waterPerDayPerKg[k];
		RNS.cows2.breedWater[k]        	= RNS.cows2.matureWater[k] + RNS.cows2.offsprWaterM[k] + RNS.cows2.offsprWaterF[k];

		RNS.cows2.matureManure[k]      	= 365 * RNS.cows2.matureWeight[k] * RNS.cows2.manurePerDayPerKg[k];		-- Manure per mature animal per year
		RNS.cows2.offsprManureM[k]     	= RNS.cows2.males[k]   * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightM[k] * RNS.cows2.manurePerDayPerKg[k];
		RNS.cows2.offsprManureF[k]     	= RNS.cows2.females[k] * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightF[k] * RNS.cows2.manurePerDayPerKg[k];
		RNS.cows2.breedManure[k]       	= RNS.cows2.matureManure[k] + RNS.cows2.offsprManureM[k] + RNS.cows2.offsprManureF[k];

		RNS.cows2.matureSlurry[k]      	= 365 * RNS.cows2.matureWeight[k] * RNS.cows2.liquidManure[k];		-- Slurry per mature animal per year
		RNS.cows2.offsprSlurryM[k]     	= RNS.cows2.males[k]   * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightM[k] * RNS.cows2.liquidManure[k];
		RNS.cows2.offsprSlurryF[k]     	= RNS.cows2.females[k] * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightF[k] * RNS.cows2.liquidManure[k];
		RNS.cows2.breedSlurry[k]       	= RNS.cows2.matureSlurry[k] + RNS.cows2.offsprSlurryM[k] + RNS.cows2.offsprSlurryF[k];

		RNS.cows2.matureFeed[k]        	= 365 * RNS.cows2.numberMature[k] * RNS.cows2.matureWeight[k] * RNS.cows2.foodPerDayPerKg[k];
		RNS.cows2.offsprFeedM[k]       	= RNS.cows2.males[k]   * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightM[k] * RNS.cows2.foodPerDayPerKg[k];
		RNS.cows2.offsprFeedF[k]       	= RNS.cows2.females[k] * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightF[k] * RNS.cows2.foodPerDayPerKg[k];
		RNS.cows2.breedFeed[k]         	= RNS.cows2.matureFeed[k] + RNS.cows2.offsprFeedM[k] + RNS.cows2.offsprFeedF[k];
		RNS.cows2.troughFeed[k]        	= RNS.cows2.foodTroughFraction[k] * RNS.cows2.breedFeed[k];

		RNS.cows2.bedStraw[k]          	= 365 * RNS.cows2.numberMature[k] * RNS.cows2.strawPerDay[k] / RN.commodityDensity.SQUAREBALE_WHEAT;	-- for mature cows
		RNS.cows2.bedStraw[k]          	= RNS.cows2.bedStraw[k] + RNS.cows2.slaughterAge[k] * RNS.cows2.numberMature[k] * RNS.cows2.averageLitterSize[k] * RNS.cows2.strawPerDay[k] / RN.commodityDensity.SQUAREBALE_WHEAT;
		RNS.cows2.straw[k]             	= RNS.cows2.bedStraw[k];
		RNS.cows2.strawRoundBales[k]   	= RNS.cows2.straw[k] / RNS.cows2.roundBaleVolume[k];
		RNS.cows2.strawSquareBales[k]  	= RNS.cows2.straw[k] / RNS.cows2.squareBaleVolume[k];

		RNS.cows2.mixDensity[k]	= 0;

		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.COW.content) do
			local meanDensity = 0;
			local mixNumbers = 0;
			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--					print(fillName);
					if RN.commodityDensity[fillName] ~= nil then
						meanDensity = meanDensity + RN.commodityDensity[fillName];
					elseif RN.cropDensity[fillName] ~= nil then
						meanDensity = meanDensity + RN.cropDensity[fillName];
					else
						print(fillName.."   density not defined");
						meanDensity = 0.3;		-- number used in case of error
					end;
					mixNumbers = mixNumbers + 1;
				end;
			end;
			meanDensity = meanDensity/mixNumbers;		-- mean mass density within each feed group
			if foodGroups.eatWeight < 1 then
				RNS.cows2.mixDensity[k] = RNS.cows2.mixDensity[k] + meanDensity * foodGroups.eatWeight; -- mass density of of complete feed mix
			else
				RNS.cows2.mixDensity[k] = RNS.cows2.mixDensity[k] + meanDensity * (1/RN.numberOfFoodGroups["COWS"]); -- mass density of of complete feed mix
			end;
		end;

		RNS.cows2.mixVolume[k]         = RNS.cows2.troughFeed[k]/RNS.cows2.mixDensity[k];

		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.COW.content) do

			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--					print(fillName);
					RNS.cows2.feedName[fillName] = fillName;
					RNS.cows2.feedVolume[k][fillName] =  foodGroups.eatWeight * RNS.cows2.mixVolume[k];
					if RN.roundBaleVolume[fillName] ~= nill then
						RNS.cows2.feedRoundBales[k][fillName] = RNS.cows2.feedVolume[k][fillName]/RN.roundBaleVolume[fillName];
					else
						RNS.cows2.feedRoundBales[k][fillName] = 0;
					end;
					if RN.squareBaleVolume[fillName] ~= nill then
						RNS.cows2.feedSquareBales[k][fillName] = RNS.cows2.feedVolume[k][fillName]/RN.squareBaleVolume[fillName];
					else
						RNS.cows2.feedSquareBales[k][fillName] = 0;
					end;
					if RN.netYield[fillName] ~= nill then
						RNS.cows2.hectares[k][fillName] = RNS.cows2.feedVolume[k][fillName]/RN.netYield[fillName];
					else
						RNS.cows2.hectares[k][fillName] = 0;
					end;
					RN.totalFeedHectares[fillName] = RN.totalFeedHectares[fillName] + RNS.cows2.hectares[k][fillName];
				end;
			end;
		end;
	end;


	print(" ");
	print("COWS");
	print(" ");
--	print("                                            "..RNS.cows2.type[1].." "..RNS.cows2.type[2].." "..RNS.cows2.type[3].." "..RNS.cows2.type[4]);

	myPrintFeedNames(RNS.cows2.type[1], RNS.cows2.type[2], RNS.cows2.type[3], RNS.cows2.type[4], textWidth,textWidth1);

	myPrintFeed("Number of mature animals",RNS.cows2.numberMature[1],RNS.cows2.numberMature[2],RNS.cows2.numberMature[3],RNS.cows2.numberMature[4],textWidth, " ");
	myPrintFeed("Number of offsprings, males",RNS.cows2.males[1],RNS.cows2.males[2],RNS.cows2.males[3],RNS.cows2.males[4],textWidth, " ");
	myPrintFeed("Number of offsprings, females",RNS.cows2.females[1],RNS.cows2.females[2],RNS.cows2.females[3],RNS.cows2.females[4],textWidth, " ");
	myPrintFeed("Average weight males", RNS.cows2.averageWeightM[1],RNS.cows2.averageWeightM[2],RNS.cows2.averageWeightM[3],RNS.cows2.averageWeightM[4],textWidth, " kg");
	myPrintFeed("Average weight females", RNS.cows2.averageWeightF[1],RNS.cows2.averageWeightF[2],RNS.cows2.averageWeightF[3],RNS.cows2.averageWeightF[4],textWidth, " kg");
	myPrintFloatFeed("Average weight gain, males", RNS.cows2.gainPerDayM[1],RNS.cows2.gainPerDayM[2],RNS.cows2.gainPerDayM[3],RNS.cows2.gainPerDayM[4],textWidth, " kg/day");
	myPrintFloatFeed("Average weight gain, females", RNS.cows2.gainPerDayF[1],RNS.cows2.gainPerDayF[2],RNS.cows2.gainPerDayF[3],RNS.cows2.gainPerDayF[4],textWidth, " kg/day");
	myPrintFeed("Slaughter age", RNS.cows2.slaughterAge[1],RNS.cows2.slaughterAge[2],RNS.cows2.slaughterAge[3],RNS.cows2.slaughterAge[4],textWidth, " days");
	myPrintFeed("Slaughter weight, male", RNS.cows2.slaugtherWeightM[1],RNS.cows2.slaugtherWeightM[2],RNS.cows2.slaugtherWeightM[3],RNS.cows2.slaugtherWeightM[4],textWidth, " kg");
	myPrintFeed("Slaughter weight, female", RNS.cows2.slaugtherWeightF[1],RNS.cows2.slaugtherWeightF[2],RNS.cows2.slaugtherWeightF[3],RNS.cows2.slaugtherWeightF[4],textWidth, " kg");
	myPrintFeed("Herd manure per year", RNS.cows2.breedManure[1],RNS.cows2.breedManure[2],RNS.cows2.breedManure[3],RNS.cows2.breedManure[4],textWidth, " L/year");
	myPrintFeed("Herd slurry per year", RNS.cows2.breedSlurry[1],RNS.cows2.breedSlurry[2],RNS.cows2.breedSlurry[3],RNS.cows2.breedSlurry[4],textWidth, " L/year");
	myPrintFeed("Herd bedding straw", RNS.cows2.bedStraw[1],RNS.cows2.bedStraw[2],RNS.cows2.bedStraw[3],RNS.cows2.bedStraw[4],textWidth, " L/year");
	myPrintFeed("Round straw bales", RNS.cows2.strawRoundBales[1],RNS.cows2.strawRoundBales[2],RNS.cows2.strawRoundBales[3],RNS.cows2.strawRoundBales[4],textWidth, " Bales/year");
	myPrintFeed("Square straw bales", RNS.cows2.strawSquareBales[1],RNS.cows2.strawSquareBales[2],RNS.cows2.strawSquareBales[3],RNS.cows2.strawSquareBales[4],textWidth, " Bales/year");
	myPrintFeed("Water per year", RNS.cows2.breedWater[1],RNS.cows2.breedWater[2],RNS.cows2.breedWater[3],RNS.cows2.breedWater[4],textWidth," L/year");
	myPrintFeed("Herd feed intake", RNS.cows2.breedFeed[1],RNS.cows2.breedFeed[2],RNS.cows2.breedFeed[3],RNS.cows2.breedFeed[4],textWidth, " kg/year");
	myPrintFeed("Herd trough feed", RNS.cows2.troughFeed[1],RNS.cows2.troughFeed[2],RNS.cows2.troughFeed[3],RNS.cows2.troughFeed[4],textWidth, " kg/year");
	myPrintFloatFeed("Feedmix density", RNS.cows2.mixDensity[1],RNS.cows2.mixDensity[2],RNS.cows2.mixDensity[3],RNS.cows2.mixDensity[4],textWidth, " kg/L");
	myPrintFeed("Herd Feedmix volume", RNS.cows2.mixVolume[1],RNS.cows2.mixVolume[2],RNS.cows2.mixVolume[3],RNS.cows2.mixVolume[4],textWidth, " L/year");


	for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.COW.content) do

		for l,iFillType in pairs(foodGroups.fillTypes) do
			if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print(" ");
				print(fillName);
				myPrintFloat("Volume fraction = ",foodGroups.eatWeight,textWidth, " ");
				myPrintFeed("Herd trough ", RNS.cows2.feedVolume[1][fillName],RNS.cows2.feedVolume[2][fillName],RNS.cows2.feedVolume[3][fillName],RNS.cows2.feedVolume[4][fillName],textWidth, " L/year");
				if RNS.cows2.feedRoundBales[1][fillName] > 0 then
					myPrintFeed("Round bales ", RNS.cows2.feedRoundBales[1][fillName],RNS.cows2.feedRoundBales[2][fillName],RNS.cows2.feedRoundBales[3][fillName],RNS.cows2.feedRoundBales[4][fillName],textWidth, " ");
					myPrintFeed("Square bales ", RNS.cows2.feedSquareBales[1][fillName],RNS.cows2.feedSquareBales[2][fillName],RNS.cows2.feedSquareBales[3][fillName],RNS.cows2.feedSquareBales[4][fillName],textWidth, " ");
				end;
				myPrintFloatFeed("Hectares ", RNS.cows2.hectares[1][fillName],RNS.cows2.hectares[2][fillName],RNS.cows2.hectares[3][fillName],RNS.cows2.hectares[4][fillName],textWidth, " Ha");
			else
				print(fillName.." is not defined on this map");
			end;
		end;
	end;

--	if g_seasons.animals.animalManager.typeToAnimal["CALF"] ~= nil then

	if RN.hasAnimal["CALF"] then

		RNS.calf.color              = { "BLACK_WHITE",    "TYPE_BLACK",      "TYPE_BROWN"    };
		RNS.calf.type               = {  "calfBlackWhite",  "calfBlack",     "calfBrown"     };
		RNS.calf.matureWeight		= {    1000,             1000,               1000        };  -- kg
		RNS.calf.weightDay          = {     365,              365,                365        };  -- Age (in days) of known weight
		RNS.calf.weightM            = {     566,              540,                516        };  -- kg
		RNS.calf.weightF            = {     420,              410,                396        };  -- kg
		RNS.calf.linGrowthPct		= {      85,               85,                 85        };  -- %
		RNS.calf.monthsToLevelOut   = {      24,               24,                 24        };  -- months to growth levels out
		RNS.calf.weaningAge         = {      30,               30,                 30        };  -- age of weaning in days
		RNS.calf.numberMales       	= {       0,                0,                  0        };  -- number of mature animals
		RNS.calf.strawPercentage    = {      25,               25,                 25        };  -- percentage of feed from straw
		RNS.calf.hayPercentage      = {      50,               50,                 50        };  -- percentage of feed from hay
		RNS.calf.silagePercentage   = {      25,               25,                 25        };  -- perentage of feed from silage
		RNS.calf.roundBaleVolume    = {    1500,             1500,               1500        };  -- Liters
		RNS.calf.squareBaleVolume   = {    2600,             2600,               2600        };  -- Liters



		RNS.calf.numberOfspr = {};
		RNS.calf.males = {};
		RNS.calf.females = {};
		RNS.calf.linPeakWeight = {};
		RNS.calf.daysToLevel = {};
		RNS.calf.gainPerDayM = {};
		RNS.calf.gainPerDayF = {};
		RNS.calf.weaningWeightM = {};
		RNS.calf.weaningWeightF = {};
		RNS.calf.averageWeightM = {};
		RNS.calf.averageWeightF = {};
		RNS.calf.matureWater = {};
		RNS.calf.offsprWaterM = {};
		RNS.calf.offsprWaterF = {};
		RNS.calf.breedWater = {};
		RNS.calf.matureFeed = {};
		RNS.calf.offsprFeedM = {};
		RNS.calf.offsprFeedF = {};
		RNS.calf.breedFeed = {};
		RNS.calf.troughFeed = {};
		RNS.calf.mixDensity = {};
		RNS.calf.mixVolume = {};
		RNS.calf.troughStraw = {};
		RNS.calf.troughHay = {};
		RNS.calf.troughSilage = {};
		RNS.calf.bedStraw = {};
		RNS.calf.straw = {};
		RNS.calf.strawRoundBales = {};
		RNS.calf.strawSquareBales = {};
		RNS.calf.hayRoundBales = {};
		RNS.calf.haySquareBales = {};
		RNS.calf.silageRoundBales = {};
		RNS.calf.silageSquareBales = {};

		RNS.calf.matureManure = {};
		RNS.calf.offsprManureM = {};
		RNS.calf.offsprManureF = {};
		RNS.calf.famManure = {};
		RNS.calf.breedManure = {};

		RNS.calf.matureSlurry = {};
		RNS.calf.offsprSlurryF = {};
		RNS.calf.offsprSlurryM = {};
		RNS.calf.famSlurry = {};
		RNS.calf.breedSlurry = {};

		RNS.calf.feedName 			= {};
		RNS.calf.feedVolume		= {};
		RNS.calf.feedRoundBales	= {};
		RNS.calf.feedSquareBales	= {};
		RNS.calf.hectares			= {};

		for k = 1,3 do
			RNS.calf.feedVolume[k]        	= {};
			RNS.calf.feedRoundBales[k]		= {};
			RNS.calf.feedSquareBales[k]		= {};
			RNS.calf.hectares[k]			= {};

			RNS.calf.males[k]             	= RNS.calf.numberMales[k];
			RNS.calf.gainPerDayM[k]       	= (RNS.calf.weightM[k] - RNS.calf.bornWeight[k])/RNS.calf.weightDay[k];
			RNS.calf.weaningWeightM[k]  	= RNS.calf.bornWeight[k] + RNS.calf.gainPerDayM[k] * RNS.calf.weaningAge[k];
			RNS.calf.averageWeightM[k]    	= 0.5 * (RNS.calf.weaningWeightM[k] + RNS.calf.bornWeight[k]);

			RNS.calf.offsprWaterM[k]      	= RNS.calf.males[k]   * RNS.calf.weaningAge[k] * RNS.calf.averageWeightM[k] * RNS.calf.waterPerDayPerKg[k];
			RNS.calf.breedWater[k]        	= RNS.calf.offsprWaterM[k]

			RNS.calf.offsprManureM[k]     	= RNS.calf.males[k]   * RNS.calf.weaningAge[k] * RNS.calf.averageWeightM[k] * RNS.calf.manurePerDayPerKg[k];
			RNS.calf.breedManure[k]       	= RNS.calf.offsprManureM[k]

			RNS.calf.offsprSlurryM[k]     	= RNS.calf.males[k]   * RNS.calf.weaningAge[k] * RNS.calf.averageWeightM[k] * RNS.calf.liquidManure[k];
			RNS.calf.breedSlurry[k]       	= RNS.calf.offsprSlurryM[k]

			RNS.calf.offsprFeedM[k]       	= RNS.calf.males[k]   * RNS.calf.weaningAge[k] * RNS.calf.averageWeightM[k] * RNS.calf.foodPerDayPerKg[k];
			RNS.calf.breedFeed[k]         	= RNS.calf.offsprFeedM[k];
			RNS.calf.troughFeed[k]        	= RNS.calf.foodTroughFraction[k] * RNS.calf.breedFeed[k];

			RNS.calf.bedStraw[k]          	= RNS.calf.males[k]   * RNS.calf.weaningAge[k] * RNS.calf.strawPerDay[k] / RN.commodityDensity.SQUAREBALE_WHEAT;
			RNS.calf.strawRoundBales[k]   	= RNS.calf.bedStraw[k] / RNS.calf.roundBaleVolume[k];
			RNS.calf.strawSquareBales[k]  	= RNS.calf.bedStraw[k] / RNS.calf.squareBaleVolume[k];

			RNS.calf.mixDensity[k]	= 0;

			for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.CALF.content) do
				local meanDensity = 0;
				local mixNumbers = 0;
				for l,iFillType in pairs(foodGroups.fillTypes) do
					if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
						local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
	--					print(fillName);
						if RN.commodityDensity[fillName] ~= nil then
							meanDensity = meanDensity + RN.commodityDensity[fillName];
						elseif RN.cropDensity[fillName] ~= nil then
							meanDensity = meanDensity + RN.cropDensity[fillName];
						else
							print(fillName.."   density not defined");
							meanDensity = 0.3;		-- number used in case of error
						end;
						mixNumbers = mixNumbers + 1;
					end;
				end;
				meanDensity = meanDensity/mixNumbers;		-- mean mass density within each feed group
				if foodGroups.eatWeight < 1 then
					RNS.calf.mixDensity[k] = RNS.calf.mixDensity[k] + meanDensity * foodGroups.eatWeight; -- mass density of of complete feed mix
				else
					RNS.calf.mixDensity[k] = RNS.calf.mixDensity[k] + meanDensity * (1/RN.numberOfFoodGroups["CALF"]); -- mass density of of complete feed mix
				end;
			end;

			RNS.calf.mixVolume[k]         = RNS.calf.troughFeed[k]/RNS.calf.mixDensity[k];

			for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.CALF.content) do

				for l,iFillType in pairs(foodGroups.fillTypes) do
					if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
						local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
	--					print(fillName);
						RNS.calf.feedName[fillName] = fillName;
						RNS.calf.feedVolume[k][fillName] =  foodGroups.eatWeight * RNS.calf.mixVolume[k];
						if RN.roundBaleVolume[fillName] ~= nill then
							RNS.calf.feedRoundBales[k][fillName] = RNS.calf.feedVolume[k][fillName]/RN.roundBaleVolume[fillName];
						else
							RNS.calf.feedRoundBales[k][fillName] = 0;
						end;
						if RN.squareBaleVolume[fillName] ~= nill then
							RNS.calf.feedSquareBales[k][fillName] = RNS.calf.feedVolume[k][fillName]/RN.squareBaleVolume[fillName];
						else
							RNS.calf.feedSquareBales[k][fillName] = 0;
						end;
						if RN.netYield[fillName] ~= nill then
							RNS.calf.hectares[k][fillName] = RNS.calf.feedVolume[k][fillName]/RN.netYield[fillName];
						else
							RNS.calf.hectares[k][fillName] = 0;
						end;
						RN.totalFeedHectares[fillName] = RN.totalFeedHectares[fillName] + RNS.calf.hectares[k][fillName];
					end;
				end;
			end;
		end;


		print(" ");
		print("CALVES");
		print(" ");

		myPrintFeedNames3(RNS.calf.type[1], RNS.calf.type[2], RNS.calf.type[3], textWidth,textWidth1);
		myPrintFeed3("Number of calves, males",RNS.calf.males[1],RNS.calf.males[2],RNS.calf.males[3],textWidth, " ");
		myPrintFloatFeed3("Average weight gain, males", RNS.calf.gainPerDayM[1],RNS.calf.gainPerDayM[2],RNS.calf.gainPerDayM[3],textWidth, " kg/day");
		myPrintFeed3("Weaning age", RNS.calf.weaningAge[1],RNS.calf.weaningAge[2],RNS.calf.weaningAge[3],textWidth, " days");
		myPrintFeed3("Weaning weight, male", RNS.calf.weaningWeightM[1],RNS.calf.weaningWeightM[2],RNS.calf.weaningWeightM[3],textWidth, " kg");
		myPrintFeed3("Average weight males", RNS.calf.averageWeightM[1],RNS.calf.averageWeightM[2],RNS.calf.averageWeightM[3],textWidth, " kg");
		myPrintFeed3("Herd manure per weaning", RNS.calf.breedManure[1],RNS.calf.breedManure[2],RNS.calf.breedManure[3],textWidth, " L/weaning");
		myPrintFeed3("Herd slurry per year", RNS.calf.breedSlurry[1],RNS.calf.breedSlurry[2],RNS.calf.breedSlurry[3],textWidth, " L/weaning");
		myPrintFeed3("Herd bedding straw", RNS.calf.bedStraw[1],RNS.calf.bedStraw[2],RNS.calf.bedStraw[3],textWidth, " L/year");
		myPrintFeed3("Round straw bales", RNS.calf.strawRoundBales[1],RNS.calf.strawRoundBales[2],RNS.calf.strawRoundBales[3],textWidth, " Bales/weaning");
		myPrintFeed3("Square straw bales", RNS.calf.strawSquareBales[1],RNS.calf.strawSquareBales[2],RNS.calf.strawSquareBales[3],textWidth, " Bales/weaning");
		myPrintFeed3("Water per weaning", RNS.calf.breedWater[1],RNS.calf.breedWater[2],RNS.calf.breedWater[3],textWidth," L/weaning");
		myPrintFeed3("Herd feed intake", RNS.calf.breedFeed[1],RNS.calf.breedFeed[2],RNS.calf.breedFeed[3],textWidth, " kg/weaning");
		myPrintFeed3("Herd trough feed", RNS.calf.troughFeed[1],RNS.calf.troughFeed[2],RNS.calf.troughFeed[3],textWidth, " kg/weaning");
		myPrintFloatFeed3("Feedmix density", RNS.calf.mixDensity[1],RNS.calf.mixDensity[2],RNS.calf.mixDensity[3],textWidth, " kg/L");
		myPrintFeed3("Herd Feedmix volume", RNS.calf.mixVolume[1],RNS.calf.mixVolume[2],RNS.calf.mixVolume[3],textWidth, " L/weaning");


		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.CALF.content) do

			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
					print(" ");
					print(fillName);
					myPrintFloat("Volume fraction = ",foodGroups.eatWeight,textWidth, " ");
					myPrintFeed3("Herd trough ", RNS.calf.feedVolume[1][fillName],RNS.calf.feedVolume[2][fillName],RNS.calf.feedVolume[3][fillName],textWidth, " L/weaning");
				else
					print(fillName.." is not defined on this map");
				end;
			end;
		end;
	end;


-- https://iamcountryside.com/pigs/10-pig-breeds/

	RNS.pigs.color               = {     "RED",         "WHITE",          "BLACK_WHITE",         "BLACK"     };
	RNS.pigs.type                = { "Yorkshire","Gloucestershire Old Spot","Spotted",         "Berkshire"   };
	RNS.pigs.matureWeight		 = {     250,              250,                250,                250       };  -- kg
	RNS.pigs.weightDay           = {     120,              120,                120,                120       };  -- Age (in days) of known weight
	RNS.pigs.weight              = {     122,              122,                122,                122       };  -- kg
	RNS.pigs.slaughterAge      	 = {     120,              120,                120,                120       };  -- age of slaughter in days
	RNS.pigs.numberMature        = {      12,                0,                  0,                  0       };  -- number of mature animals
	RNS.pigs.strawPerDayPerKg	 = {   0.005,            0.005,              0.005,              0.005       };  -- kg straw per day per kg bodyweight
	RNS.pigs.cerealPercentage    = {      25,               25,                 25,                 25       };  -- percentage of feed from straw
	RNS.pigs.cornPercentage      = {      50,               50,                 50,                 50       };  -- percentage of feed from hay
	RNS.pigs.proteinPercentage   = {      25,               25,                 25,                 25       };  -- perentage of feed from silage
	RNS.pigs.roundBaleVolume     = {    1500,             1500,               1500,               1500       };  -- Liters
	RNS.pigs.squareBaleVolume    = {    2600,             2600,               2600,               2600       };  -- Liters

	RNS.pigs.numberOfspr = {};
	RNS.pigs.gainPerDay = {};
	RNS.pigs.slaugtherWeight = {};
	RNS.pigs.averageWeight = {};
	RNS.pigs.matureWater = {};
	RNS.pigs.offsprWater = {};
	RNS.pigs.famWater = {};
	RNS.pigs.breedWater = {};
	RNS.pigs.matureFeed = {};
	RNS.pigs.offsprFeed = {};
	RNS.pigs.famFeed = {};
	RNS.pigs.breedFeed = {};
	RNS.pigs.troughFeed = {};
    RNS.pigs.mixDensity = {};
	RNS.pigs.mixVolume = {};
	RNS.pigs.troughCorn = {};
	RNS.pigs.troughCereal = {};
	RNS.pigs.troughProtein = {};
	RNS.pigs.bedStraw = {};
	RNS.pigs.straw = {};
	RNS.pigs.strawRoundBales = {};
	RNS.pigs.strawSquareBales = {};

	RNS.pigs.matureManure = {};
	RNS.pigs.offsprManure = {};
	RNS.pigs.famManure = {};
	RNS.pigs.breedManure = {};

	RNS.pigs.matureSlurry = {};
	RNS.pigs.offsprSlurry = {};
	RNS.pigs.famSlurry = {};
	RNS.pigs.breedSlurry = {};

	RNS.pigs.wheatHa = {};
	RNS.pigs.cornHa = {};
	RNS.pigs.soybeanHa = {};
	RNS.pigs.strawHa = {};

	RNS.pigs.feedName 			= {};
	RNS.pigs.feedVolume			= {};
	RNS.pigs.feedRoundBales		= {};
	RNS.pigs.feedSquareBales	= {};
	RNS.pigs.hectares			= {};

	for k = 1,4 do
		RNS.pigs.feedVolume[k]        	= {};
		RNS.pigs.feedRoundBales[k]		= {};
		RNS.pigs.feedSquareBales[k]		= {};
		RNS.pigs.hectares[k]			= {};

		RNS.pigs.numberOfspr[k]       = RNS.pigs.numberMature[k] * RNS.pigs.averageLitterSize[k];
		RNS.pigs.gainPerDay[k]        = (RNS.pigs.weight[k] - RNS.pigs.bornWeight[k])/RNS.pigs.weightDay[k];
		RNS.pigs.slaugtherWeight[k]   = RNS.pigs.bornWeight[k] + RNS.pigs.gainPerDay[k] * RNS.pigs.slaughterAge[k];
		RNS.pigs.averageWeight[k]     = 0.5 * (RNS.pigs.slaugtherWeight[k] + RNS.pigs.bornWeight[k]);

		RNS.pigs.matureWater[k]       = 365 * RNS.pigs.matureWeight[k] * RNS.pigs.waterPerDayPerKg[k];
		RNS.pigs.offsprWater[k]       = 182.5 * RNS.pigs.averageWeight[k] * RNS.pigs.waterPerDayPerKg[k];
		RNS.pigs.famWater[k]          = RNS.pigs.matureWater[k] + 2 * RNS.pigs.averageLitterSize[k] * RNS.pigs.offsprWater[k];
		RNS.pigs.breedWater[k]        = RNS.pigs.famWater[k] * RNS.pigs.numberMature[k];

		RNS.pigs.matureManure[k]      = 365 * RNS.pigs.matureWeight[k] * RNS.pigs.manurePerDayPerKg[k];		-- Manure per mature animal per year
		RNS.pigs.offsprManure[k]      = 182.5 * RNS.pigs.averageWeight[k] * RNS.pigs.manurePerDayPerKg[k];	-- Manure per offspring per year
		RNS.pigs.famManure[k]         = RNS.pigs.matureManure[k] + 2 * RNS.pigs.averageLitterSize[k] * RNS.pigs.offsprManure[k]; -- Manure per mother and her offspring per year
		RNS.pigs.breedManure[k]       = RNS.pigs.famManure[k] * RNS.pigs.numberMature[k];

		RNS.pigs.matureSlurry[k]      = 365 * RNS.pigs.matureWeight[k] * RNS.pigs.liquidManure[k];		-- Slurry per mature animal per year
		RNS.pigs.offsprSlurry[k]      = 182.5 * RNS.pigs.averageWeight[k] * RNS.pigs.liquidManure[k];	-- Slurry per offspring per year
		RNS.pigs.famSlurry[k]         = RNS.pigs.matureSlurry[k] + 2 * RNS.pigs.averageLitterSize[k] * RNS.pigs.offsprSlurry[k]; -- Slurry per mother and her offspring per year
		RNS.pigs.breedSlurry[k]       = RNS.pigs.famSlurry[k] * RNS.pigs.numberMature[k];

		RNS.pigs.matureFeed[k]        = 365 * RNS.pigs.matureWeight[k] * RNS.pigs.foodPerDayPerKg[k];
		RNS.pigs.offsprFeed[k]        = 182.5 * RNS.pigs.averageWeight[k] * RNS.pigs.foodPerDayPerKg[k];
		RNS.pigs.famFeed[k]           = RNS.pigs.matureFeed[k] + 2 * RNS.pigs.averageLitterSize[k] * RNS.pigs.offsprFeed[k];
		RNS.pigs.breedFeed[k]         = RNS.pigs.famFeed[k] * RNS.pigs.numberMature[k];
		RNS.pigs.troughFeed[k]        = RNS.pigs.foodTroughFraction[k] * RNS.pigs.breedFeed[k];
--		RNS.pigs.mixDensity[k]		  = (RN.cropDensity.WHEAT * RNS.pigs.cerealPercentage[k] + RN.cropDensity.MAIZE * RNS.pigs.cornPercentage[k] + RN.cropDensity.SOYBEAN * RNS.pigs.proteinPercentage[k])/100;
--		RNS.pigs.mixVolume[k]         = RNS.pigs.troughFeed[k]/RNS.pigs.mixDensity[k];

		RNS.pigs.bedStraw[k]          = 365 * RNS.pigs.numberMature[k] * RNS.pigs.matureWeight[k] * RNS.pigs.strawPerDayPerKg[k] / RN.commodityDensity.SQUAREBALE_WHEAT;
		RNS.pigs.bedStraw[k]          = RNS.pigs.bedStraw[k]  + RNS.pigs.numberMature[k] * 2 * RNS.pigs.slaughterAge[k] * RNS.pigs.averageLitterSize[k] * RNS.pigs.averageWeight[k] * RNS.pigs.strawPerDayPerKg[k] / RN.commodityDensity.SQUAREBALE_WHEAT;

		RNS.pigs.strawRoundBales[k]   = RNS.pigs.bedStraw[k] / RNS.pigs.roundBaleVolume[k];
		RNS.pigs.strawSquareBales[k]  = RNS.pigs.bedStraw[k] / RNS.pigs.squareBaleVolume[k];


		RNS.pigs.mixDensity[k]	= 0;

		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.PIG.content) do
			local meanDensity = 0;
			local mixNumbers = 0;
			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--					print(fillName);
					if RN.commodityDensity[fillName] ~= nil then
						meanDensity = meanDensity + RN.commodityDensity[fillName];
					elseif RN.cropDensity[fillName] ~= nil then
						meanDensity = meanDensity + RN.cropDensity[fillName];
					else
						print(fillName.."   density not defined");
						meanDensity = 0.3;		-- number used in case of error
					end;
					mixNumbers = mixNumbers + 1;
				end;
			end;
			meanDensity = meanDensity/mixNumbers;		-- mean mass density within each feed group
			if foodGroups.eatWeight < 1 then
				RNS.pigs.mixDensity[k] = RNS.pigs.mixDensity[k] + meanDensity * foodGroups.eatWeight; -- mass density of of complete feed mix
			else
				RNS.pigs.mixDensity[k] = RNS.pigs.mixDensity[k] + meanDensity * (1/RN.numberOfFoodGroups["PIGS"]); -- mass density of of complete feed mix
			end;
		end;

		RNS.pigs.mixVolume[k]         = RNS.pigs.troughFeed[k]/RNS.pigs.mixDensity[k];

		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.PIG.content) do

			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--					print(fillName);
					RNS.pigs.feedName[fillName] = fillName;
					RNS.pigs.feedVolume[k][fillName] =  foodGroups.eatWeight * RNS.pigs.mixVolume[k];
					if RN.roundBaleVolume[fillName] ~= nill then
						RNS.pigs.feedRoundBales[k][fillName] = RNS.pigs.feedVolume[k][fillName]/RN.roundBaleVolume[fillName];
					else
						RNS.pigs.feedRoundBales[k][fillName] = 0;
					end;
					if RN.squareBaleVolume[fillName] ~= nill then
						RNS.pigs.feedSquareBales[k][fillName] = RNS.pigs.feedVolume[k][fillName]/RN.squareBaleVolume[fillName];
					else
						RNS.pigs.feedSquareBales[k][fillName] = 0;
					end;
					if RN.netYield[fillName] ~= nill then
						RNS.pigs.hectares[k][fillName] = RNS.pigs.feedVolume[k][fillName]/RN.netYield[fillName];
					else
						RNS.pigs.hectares[k][fillName] = 0;
					end;
					RN.totalFeedHectares[fillName] = RN.totalFeedHectares[fillName] + RNS.pigs.hectares[k][fillName];
				end;
			end;
		end;
	end;


	print(" ");
	print("PIGS");
	print(" ");
--	print("                                            "..RNS.pigs.type[1].." "..RNS.pigs.type[2].." "..RNS.pigs.type[3].." "..RNS.pigs.type[4]);

	myPrintFeedNames(RNS.pigs.type[1], RNS.pigs.type[2], RNS.pigs.type[3], RNS.pigs.type[4], textWidth,textWidth1);

	myPrintFeed("Number of mature animals",RNS.pigs.numberMature[1],RNS.pigs.numberMature[2],RNS.pigs.numberMature[3],RNS.pigs.numberMature[4],textWidth, " ");
	myPrintFeed("Number of offsprings",RNS.pigs.numberOfspr[1],RNS.pigs.numberOfspr[2],RNS.pigs.numberOfspr[3],RNS.pigs.numberOfspr[4],textWidth, " ");
	myPrintFeed("Average weight", RNS.pigs.averageWeight[1],RNS.pigs.averageWeight[2],RNS.pigs.averageWeight[3],RNS.pigs.averageWeight[4],textWidth, " kg");
	myPrintFloatFeed("Average weight gain", RNS.pigs.gainPerDay[1],RNS.pigs.gainPerDay[2],RNS.pigs.gainPerDay[3],RNS.pigs.gainPerDay[4],textWidth, " kg/day");
	myPrintFeed("Slaughter age", RNS.pigs.slaughterAge[1],RNS.pigs.slaughterAge[2],RNS.pigs.slaughterAge[3],RNS.pigs.slaughterAge[4],textWidth, " days");
	myPrintFeed("Slaughter weight", RNS.pigs.slaugtherWeight[1],RNS.pigs.slaugtherWeight[2],RNS.pigs.slaugtherWeight[3],RNS.pigs.slaugtherWeight[4],textWidth, " kg");
	myPrintFeed("Herd manure per year", RNS.pigs.breedManure[1],RNS.pigs.breedManure[2],RNS.pigs.breedManure[3],RNS.pigs.breedManure[4],textWidth, " L/year");
	myPrintFeed("Herd slurry per year", RNS.pigs.breedSlurry[1],RNS.pigs.breedSlurry[2],RNS.pigs.breedSlurry[3],RNS.pigs.breedSlurry[4],textWidth, " L/year");
	myPrintFeed("Herd bedding straw", RNS.pigs.bedStraw[1],RNS.pigs.bedStraw[2],RNS.pigs.bedStraw[3],RNS.pigs.bedStraw[4],textWidth, " L/year");
	myPrintFeed("Round straw bales", RNS.pigs.strawRoundBales[1],RNS.pigs.strawRoundBales[2],RNS.pigs.strawRoundBales[3],RNS.pigs.strawRoundBales[4],textWidth, " Bales/year");
	myPrintFeed("Square straw bales", RNS.pigs.strawSquareBales[1],RNS.pigs.strawSquareBales[2],RNS.pigs.strawSquareBales[3],RNS.pigs.strawSquareBales[4],textWidth, " Bales/year");
	myPrintFeed("Water per year", RNS.pigs.breedWater[1],RNS.pigs.breedWater[2],RNS.pigs.breedWater[3],RNS.pigs.breedWater[4],textWidth," L/year");
	myPrintFeed("Herd feed intake", RNS.pigs.breedFeed[1],RNS.pigs.breedFeed[2],RNS.pigs.breedFeed[3],RNS.pigs.breedFeed[4],textWidth, " kg/year");
	myPrintFeed("Herd trough feed", RNS.pigs.troughFeed[1],RNS.pigs.troughFeed[2],RNS.pigs.troughFeed[3],RNS.pigs.troughFeed[4],textWidth, " kg/year");
	myPrintFloatFeed("Feedmix density", RNS.pigs.mixDensity[1],RNS.pigs.mixDensity[2],RNS.pigs.mixDensity[3],RNS.pigs.mixDensity[4],textWidth, " kg/L");
	myPrintFeed("Herd Feedmix volume", RNS.pigs.mixVolume[1],RNS.pigs.mixVolume[2],RNS.pigs.mixVolume[3],RNS.pigs.mixVolume[4],textWidth, " L/year");


	for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.PIG.content) do

		for l,iFillType in pairs(foodGroups.fillTypes) do
			if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print(" ");
				print(fillName);
				myPrintFloat("Volume fraction = ",foodGroups.eatWeight,textWidth, " ");
				myPrintFeed("Herd trough ", RNS.pigs.feedVolume[1][fillName],RNS.pigs.feedVolume[2][fillName],RNS.pigs.feedVolume[3][fillName],RNS.pigs.feedVolume[4][fillName],textWidth, " L/year");
				if RNS.pigs.feedRoundBales[1][fillName] > 0 then
					myPrintFeed("Round bales ", RNS.pigs.feedRoundBales[1][fillName],RNS.pigs.feedRoundBales[2][fillName],RNS.pigs.feedRoundBales[3][fillName],RNS.pigs.feedRoundBales[4][fillName],textWidth, " ");
					myPrintFeed("Square bales ", RNS.pigs.feedSquareBales[1][fillName],RNS.pigs.feedSquareBales[2][fillName],RNS.pigs.feedSquareBales[3][fillName],RNS.pigs.feedSquareBales[4][fillName],textWidth, " ");
				end;
				myPrintFloatFeed("Hectares ", RNS.pigs.hectares[1][fillName],RNS.pigs.hectares[2][fillName],RNS.pigs.hectares[3][fillName],RNS.pigs.hectares[4][fillName],textWidth, " Ha");
			else
				print(fillName.." is not defined on this map");
			end;
		end;
	end;

	if RN.hasAnimal["PIGLET"] then

		RNS.piglets.color               = {"PIGLET_TYPE_RED","PIGLET_TYPE_WHITE","PIGLET_TYPE_BLACK_WHITE","PIGLET_TYPE_BLACK"};
		RNS.piglets.type                = { "Piglet (pink)",   "Piglet (light)",   "Piglet (black/white)","Piglet (black)"};
		RNS.piglets.matureWeight		= {     250,              250,                250,                250       };  -- kg
		RNS.piglets.weightDay           = {     120,              120,                120,                120       };  -- Age (in days) of known weight
		RNS.piglets.weight              = {     122,              122,                122,                122       };  -- kg
		RNS.piglets.slaughterAge      	= {     120,              120,                120,                120       };  -- age of slaughter in days
		RNS.piglets.numberPiglets       = {       0,                0,                  0,                  0       };  -- number of mature animals
		RNS.piglets.strawPerDayPerKg	= {   0.005,            0.005,              0.005,              0.005       };  -- kg straw per day per kg bodyweight
		RNS.piglets.cerealPercentage    = {      25,               25,                 25,                 25       };  -- percentage of feed from straw
		RNS.piglets.cornPercentage      = {      50,               50,                 50,                 50       };  -- percentage of feed from hay
		RNS.piglets.proteinPercentage   = {      25,               25,                 25,                 25       };  -- perentage of feed from silage
		RNS.piglets.roundBaleVolume     = {    1500,             1500,               1500,               1500       };  -- Liters
		RNS.piglets.squareBaleVolume    = {    2600,             2600,               2600,               2600       };  -- Liters

		RNS.piglets.numberOfspr = {};
		RNS.piglets.gainPerDay = {};
		RNS.piglets.slaugtherWeight = {};
		RNS.piglets.averageWeight = {};
		RNS.piglets.matureWater = {};
		RNS.piglets.offsprWater = {};
		RNS.piglets.famWater = {};
		RNS.piglets.breedWater = {};
		RNS.piglets.matureFeed = {};
		RNS.piglets.offsprFeed = {};
		RNS.piglets.famFeed = {};
		RNS.piglets.breedFeed = {};
		RNS.piglets.troughFeed = {};
		RNS.piglets.mixDensity = {};
		RNS.piglets.mixVolume = {};
		RNS.piglets.troughCorn = {};
		RNS.piglets.troughCereal = {};
		RNS.piglets.troughProtein = {};
		RNS.piglets.bedStraw = {};
		RNS.piglets.straw = {};
		RNS.piglets.strawRoundBales = {};
		RNS.piglets.strawSquareBales = {};

		RNS.piglets.matureManure = {};
		RNS.piglets.offsprManure = {};
		RNS.piglets.famManure = {};
		RNS.piglets.breedManure = {};

		RNS.piglets.matureSlurry = {};
		RNS.piglets.offsprSlurry = {};
		RNS.piglets.famSlurry = {};
		RNS.piglets.breedSlurry = {};

		RNS.piglets.wheatHa = {};
		RNS.piglets.cornHa = {};
		RNS.piglets.soybeanHa = {};
		RNS.piglets.strawHa = {};

		RNS.piglets.feedName 			= {};
		RNS.piglets.feedVolume			= {};
		RNS.piglets.feedRoundBales		= {};
		RNS.piglets.feedSquareBales	= {};
		RNS.piglets.hectares			= {};

		for k = 1,4 do
			RNS.piglets.feedVolume[k]        	= {};
			RNS.piglets.feedRoundBales[k]		= {};
			RNS.piglets.feedSquareBales[k]		= {};
			RNS.piglets.hectares[k]			= {};

			RNS.piglets.numberOfspr[k]       = RNS.piglets.numberPiglets[k];
			RNS.piglets.gainPerDay[k]        = (RNS.piglets.weight[k] - RNS.piglets.bornWeight[k])/RNS.piglets.weightDay[k];
			RNS.piglets.slaugtherWeight[k]   = RNS.piglets.bornWeight[k] + RNS.piglets.gainPerDay[k] * RNS.piglets.slaughterAge[k];
			RNS.piglets.averageWeight[k]     = 0.5 * (RNS.piglets.slaugtherWeight[k] + RNS.piglets.bornWeight[k]);

			RNS.piglets.offsprWater[k]       = 365 * RNS.piglets.averageWeight[k] * RNS.piglets.waterPerDayPerKg[k];
			RNS.piglets.breedWater[k]        = RNS.piglets.offsprWater[k] * RNS.piglets.numberOfspr[k];

			RNS.piglets.offsprManure[k]      = 365 * RNS.piglets.averageWeight[k] * RNS.piglets.manurePerDayPerKg[k];	-- Manure per offspring per year
			RNS.piglets.breedManure[k]       = RNS.piglets.offsprManure[k] * RNS.piglets.numberOfspr[k];

			RNS.piglets.offsprSlurry[k]      = 365 * RNS.piglets.averageWeight[k] * RNS.piglets.liquidManure[k];	-- Slurry per offspring per year
			RNS.piglets.breedSlurry[k]       = RNS.piglets.offsprSlurry[k] * RNS.piglets.numberOfspr[k];

			RNS.piglets.offsprFeed[k]        = 365 * RNS.piglets.averageWeight[k] * RNS.piglets.foodPerDayPerKg[k];
			RNS.piglets.breedFeed[k]         = RNS.piglets.offsprFeed[k] * RNS.piglets.numberOfspr[k];
			RNS.piglets.troughFeed[k]        = RNS.piglets.foodTroughFraction[k] * RNS.piglets.breedFeed[k];

			RNS.piglets.bedStraw[k]          = 365 * RNS.piglets.numberOfspr[k] * RNS.piglets.averageWeight[k] * RNS.piglets.strawPerDayPerKg[k] / RN.commodityDensity.SQUAREBALE_WHEAT;

			RNS.piglets.strawRoundBales[k]   = RNS.piglets.bedStraw[k] / RNS.piglets.roundBaleVolume[k];
			RNS.piglets.strawSquareBales[k]  = RNS.piglets.bedStraw[k] / RNS.piglets.squareBaleVolume[k];


			RNS.piglets.mixDensity[k]	= 0;

			for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.PIG.content) do
				local meanDensity = 0;
				local mixNumbers = 0;
				for l,iFillType in pairs(foodGroups.fillTypes) do
					if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
						local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
	--					print(fillName);
						if RN.commodityDensity[fillName] ~= nil then
							meanDensity = meanDensity + RN.commodityDensity[fillName];
						elseif RN.cropDensity[fillName] ~= nil then
							meanDensity = meanDensity + RN.cropDensity[fillName];
						else
							print(fillName.."   density not defined");
							meanDensity = 0.3;		-- number used in case of error
						end;
						mixNumbers = mixNumbers + 1;
					end;
				end;
				meanDensity = meanDensity/mixNumbers;		-- mean mass density within each feed group
				if foodGroups.eatWeight < 1 then
					RNS.piglets.mixDensity[k] = RNS.piglets.mixDensity[k] + meanDensity * foodGroups.eatWeight; -- mass density of of complete feed mix
				else
					RNS.piglets.mixDensity[k] = RNS.piglets.mixDensity[k] + meanDensity * (1/RN.numberOfFoodGroups["PIGLETS"]); -- mass density of of complete feed mix
				end;
			end;

			RNS.piglets.mixVolume[k]         = RNS.piglets.troughFeed[k]/RNS.piglets.mixDensity[k];

			for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.PIG.content) do

				for l,iFillType in pairs(foodGroups.fillTypes) do
					if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
						local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
	--					print(fillName);
						RNS.piglets.feedName[fillName] = fillName;
						RNS.piglets.feedVolume[k][fillName] =  foodGroups.eatWeight * RNS.piglets.mixVolume[k];
						if RN.roundBaleVolume[fillName] ~= nill then
							RNS.piglets.feedRoundBales[k][fillName] = RNS.piglets.feedVolume[k][fillName]/RN.roundBaleVolume[fillName];
						else
							RNS.piglets.feedRoundBales[k][fillName] = 0;
						end;
						if RN.squareBaleVolume[fillName] ~= nill then
							RNS.piglets.feedSquareBales[k][fillName] = RNS.piglets.feedVolume[k][fillName]/RN.squareBaleVolume[fillName];
						else
							RNS.piglets.feedSquareBales[k][fillName] = 0;
						end;
						if RN.netYield[fillName] ~= nill then
							RNS.piglets.hectares[k][fillName] = RNS.piglets.feedVolume[k][fillName]/RN.netYield[fillName];
						else
							RNS.piglets.hectares[k][fillName] = 0;
						end;
						RN.totalFeedHectares[fillName] = RN.totalFeedHectares[fillName] + RNS.piglets.hectares[k][fillName];
					end;
				end;
			end;
		end;


		print(" ");
		print("PIGLETS");
		print(" ");
	--	print("                                            "..RNS.piglets.type[1].." "..RNS.piglets.type[2].." "..RNS.piglets.type[3].." "..RNS.piglets.type[4]);

		myPrintFeedNames(RNS.piglets.type[1], RNS.piglets.type[2], RNS.piglets.type[3], RNS.piglets.type[4], textWidth, textWidth1);

		myPrintFeed("Number of piglets",RNS.piglets.numberOfspr[1],RNS.piglets.numberOfspr[2],RNS.piglets.numberOfspr[3],RNS.piglets.numberOfspr[4],textWidth, " ");
		myPrintFeed("Average weight", RNS.piglets.averageWeight[1],RNS.piglets.averageWeight[2],RNS.piglets.averageWeight[3],RNS.piglets.averageWeight[4],textWidth, " kg");
		myPrintFloatFeed("Average weight gain", RNS.piglets.gainPerDay[1],RNS.piglets.gainPerDay[2],RNS.piglets.gainPerDay[3],RNS.piglets.gainPerDay[4],textWidth, " kg/day");
		myPrintFeed("Slaughter age", RNS.piglets.slaughterAge[1],RNS.piglets.slaughterAge[2],RNS.piglets.slaughterAge[3],RNS.piglets.slaughterAge[4],textWidth, " days");
		myPrintFeed("Slaughter weight", RNS.piglets.slaugtherWeight[1],RNS.piglets.slaugtherWeight[2],RNS.piglets.slaugtherWeight[3],RNS.piglets.slaugtherWeight[4],textWidth, " kg");
		myPrintFeed("Herd manure per year", RNS.piglets.breedManure[1],RNS.piglets.breedManure[2],RNS.piglets.breedManure[3],RNS.piglets.breedManure[4],textWidth, " L/year");
		myPrintFeed("Herd slurry per year", RNS.piglets.breedSlurry[1],RNS.piglets.breedSlurry[2],RNS.piglets.breedSlurry[3],RNS.piglets.breedSlurry[4],textWidth, " L/year");
		myPrintFeed("Herd bedding straw", RNS.piglets.bedStraw[1],RNS.piglets.bedStraw[2],RNS.piglets.bedStraw[3],RNS.piglets.bedStraw[4],textWidth, " L/year");
		myPrintFeed("Round straw bales", RNS.piglets.strawRoundBales[1],RNS.piglets.strawRoundBales[2],RNS.piglets.strawRoundBales[3],RNS.piglets.strawRoundBales[4],textWidth, " Bales/year");
		myPrintFeed("Square straw bales", RNS.piglets.strawSquareBales[1],RNS.piglets.strawSquareBales[2],RNS.piglets.strawSquareBales[3],RNS.piglets.strawSquareBales[4],textWidth, " Bales/year");
		myPrintFeed("Water per year", RNS.piglets.breedWater[1],RNS.piglets.breedWater[2],RNS.piglets.breedWater[3],RNS.piglets.breedWater[4],textWidth," L/year");
		myPrintFeed("Herd feed intake", RNS.piglets.breedFeed[1],RNS.piglets.breedFeed[2],RNS.piglets.breedFeed[3],RNS.piglets.breedFeed[4],textWidth, " kg/year");
		myPrintFeed("Herd trough feed", RNS.piglets.troughFeed[1],RNS.piglets.troughFeed[2],RNS.piglets.troughFeed[3],RNS.piglets.troughFeed[4],textWidth, " kg/year");
		myPrintFloatFeed("Feedmix density", RNS.piglets.mixDensity[1],RNS.piglets.mixDensity[2],RNS.piglets.mixDensity[3],RNS.piglets.mixDensity[4],textWidth, " kg/L");
		myPrintFeed("Herd Feedmix volume", RNS.piglets.mixVolume[1],RNS.piglets.mixVolume[2],RNS.piglets.mixVolume[3],RNS.piglets.mixVolume[4],textWidth, " L/year");


		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.PIG.content) do

			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
					print(" ");
					print(fillName);
					myPrintFloat("Volume fraction = ",foodGroups.eatWeight,textWidth, " ");
					myPrintFeed("Herd trough ", RNS.piglets.feedVolume[1][fillName],RNS.piglets.feedVolume[2][fillName],RNS.piglets.feedVolume[3][fillName],RNS.piglets.feedVolume[4][fillName],textWidth, " L/year");
					if RNS.piglets.feedRoundBales[1][fillName] > 0 then
						myPrintFeed("Round bales ", RNS.piglets.feedRoundBales[1][fillName],RNS.piglets.feedRoundBales[2][fillName],RNS.piglets.feedRoundBales[3][fillName],RNS.piglets.feedRoundBales[4][fillName],textWidth, " ");
						myPrintFeed("Square bales ", RNS.piglets.feedSquareBales[1][fillName],RNS.piglets.feedSquareBales[2][fillName],RNS.piglets.feedSquareBales[3][fillName],RNS.piglets.feedSquareBales[4][fillName],textWidth, " ");
					end;
					myPrintFloatFeed("Hectares ", RNS.piglets.hectares[1][fillName],RNS.piglets.hectares[2][fillName],RNS.piglets.hectares[3][fillName],RNS.piglets.hectares[4][fillName],textWidth, " Ha");
				else
					print(fillName.." is not defined on this map");
				end;
			end;
		end;
	end;


	RNS.sheep.color              = {   "WHITE",         "BROWN",          "BLACK_WHITE",          "BLACK"    };
	RNS.sheep.type               = {  "Dorset",         "Merino",           "Suffolk",            "Dorper"   };
	RNS.sheep.matureWeight		 = {      65,               65,                 65,                 65       };  -- kg
	RNS.sheep.weightDay          = {     240,              240,                240,                240       };  -- Age (in days) of known weight
	RNS.sheep.weight             = {      44,               44,                 44,                 44       };  -- kg
	RNS.sheep.slaughterAge       = {     240,              240,                240,                240       };  -- age of slaughter in days
	RNS.sheep.numberMature       = {      80,                0,                  0,                  0       };  -- number of mature animals
	RNS.sheep.grassPercentage    = {      50,               50,                 50,                 50       };  -- percentage of feed from straw
	RNS.sheep.hayPercentage      = {      50,               50,                 50,                 50       };  -- percentage of feed from hay
	RNS.sheep.roundBaleVolume    = {    1500,             1500,               1500,               1500       };  -- Liters
	RNS.sheep.squareBaleVolume   = {    2600,             2600,               2600,               2600       };  -- Liters

	RNS.sheep.numberOfspr = {};
	RNS.sheep.gainPerDay = {};
	RNS.sheep.slaugtherWeight = {};
	RNS.sheep.averageWeight = {};
	RNS.sheep.matureWater = {};
	RNS.sheep.offsprWater = {};
	RNS.sheep.famWater = {};
	RNS.sheep.breedWater = {};
	RNS.sheep.matureFeed = {};
	RNS.sheep.offsprFeed = {};
	RNS.sheep.famFeed = {};
	RNS.sheep.breedFeed = {};
	RNS.sheep.troughFeed = {};
    RNS.sheep.mixDensity = {};
	RNS.sheep.mixVolume = {};
	RNS.sheep.troughGrass = {};
	RNS.sheep.troughHay = {};
	RNS.sheep.hayRoundBales = {};
	RNS.sheep.haySquareBales = {};
	RNS.sheep.grassRoundBales = {};
    RNS.sheep.grassSquareBales = {};
	RNS.sheep.hayHa = {};
	RNS.sheep.grassHa = {};

	RNS.sheep.feedName 			= {};
	RNS.sheep.feedVolume			= {};
	RNS.sheep.feedRoundBales		= {};
	RNS.sheep.feedSquareBales	= {};
	RNS.sheep.hectares			= {};

	for k = 1,4 do
		RNS.sheep.feedVolume[k]        	= {};
		RNS.sheep.feedRoundBales[k]		= {};
		RNS.sheep.feedSquareBales[k]		= {};
		RNS.sheep.hectares[k]			= {};

		RNS.sheep.numberOfspr[k]       = RNS.sheep.numberMature[k] * RNS.sheep.averageLitterSize[k];
		RNS.sheep.gainPerDay[k]        = (RNS.sheep.weight[k] - RNS.sheep.bornWeight[k])/RNS.sheep.weightDay[k];
		RNS.sheep.slaugtherWeight[k]   = RNS.sheep.bornWeight[k] + RNS.sheep.gainPerDay[k] * RNS.sheep.slaughterAge[k];
		RNS.sheep.averageWeight[k]     = 0.5 * (RNS.sheep.slaugtherWeight[k] + RNS.sheep.bornWeight[k]);

		RNS.sheep.matureWater[k]       = 365 * RNS.sheep.matureWeight[k] * RNS.sheep.waterPerDayPerKg[k];
		RNS.sheep.offsprWater[k]       = RNS.sheep.slaughterAge[k] * RNS.sheep.averageWeight[k] * RNS.sheep.waterPerDayPerKg[k];
		RNS.sheep.famWater[k]          = RNS.sheep.matureWater[k] + RNS.sheep.averageLitterSize[k] * RNS.sheep.offsprWater[k];
		RNS.sheep.breedWater[k]        = RNS.sheep.famWater[k] * RNS.sheep.numberMature[k];

		RNS.sheep.matureFeed[k]        = 365 * RNS.sheep.matureWeight[k] * RNS.sheep.foodPerDayPerKg[k];
		RNS.sheep.offsprFeed[k]        = RNS.sheep.slaughterAge[k] * RNS.sheep.averageWeight[k] * RNS.sheep.foodPerDayPerKg[k];
		RNS.sheep.famFeed[k]           = RNS.sheep.matureFeed[k] + RNS.sheep.averageLitterSize[k] * RNS.sheep.offsprFeed[k];
		RNS.sheep.breedFeed[k]         = RNS.sheep.famFeed[k] * RNS.sheep.numberMature[k];
		RNS.sheep.troughFeed[k]        = RNS.sheep.foodTroughFraction[k] * RNS.sheep.breedFeed[k];


		RNS.sheep.mixDensity[k]	= 0;

		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.SHEEP.content) do
			local meanDensity = 0;
			local mixNumbers = 0;
			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--					print(fillName);
					if RN.commodityDensity[fillName] ~= nil then
						meanDensity = meanDensity + RN.commodityDensity[fillName];
					elseif RN.cropDensity[fillName] ~= nil then
						meanDensity = meanDensity + RN.cropDensity[fillName];
					else
						print(fillName.."   density not defined");
						meanDensity = 0.3;		-- number used in case of error
					end;
					mixNumbers = mixNumbers + 1;
				end;
			end;
			meanDensity = meanDensity/mixNumbers;		-- mean mass density within each feed group
			if foodGroups.eatWeight < 1 then
				RNS.sheep.mixDensity[k] = RNS.sheep.mixDensity[k] + meanDensity * foodGroups.eatWeight; -- mass density of of complete feed mix
			else
				RNS.sheep.mixDensity[k] = RNS.sheep.mixDensity[k] + meanDensity * (1/RN.numberOfFoodGroups["SHEEP"]); -- mass density of of complete feed mix
			end;
		end;

		RNS.sheep.mixVolume[k]         = RNS.sheep.troughFeed[k]/RNS.sheep.mixDensity[k];

		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.SHEEP.content) do

			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--					print(fillName);
					RNS.sheep.feedName[fillName] = fillName;
					RNS.sheep.feedVolume[k][fillName] =  foodGroups.eatWeight * RNS.sheep.mixVolume[k];
					if RN.roundBaleVolume[fillName] ~= nill then
						RNS.sheep.feedRoundBales[k][fillName] = RNS.sheep.feedVolume[k][fillName]/RN.roundBaleVolume[fillName];
					else
						RNS.sheep.feedRoundBales[k][fillName] = 0;
					end;
					if RN.squareBaleVolume[fillName] ~= nill then
						RNS.sheep.feedSquareBales[k][fillName] = RNS.sheep.feedVolume[k][fillName]/RN.squareBaleVolume[fillName];
					else
						RNS.sheep.feedSquareBales[k][fillName] = 0;
					end;
					if RN.netYield[fillName] ~= nill then
						RNS.sheep.hectares[k][fillName] = RNS.sheep.feedVolume[k][fillName]/RN.netYield[fillName];
					else
						RNS.sheep.hectares[k][fillName] = 0;
					end;
					RN.totalFeedHectares[fillName] = RN.totalFeedHectares[fillName] + RNS.sheep.hectares[k][fillName];
				end;
			end;
		end;
	end;


	print(" ");
	print("SHEEP");
	print(" ");

	myPrintFeedNames(RNS.sheep.type[1], RNS.sheep.type[2], RNS.sheep.type[3], RNS.sheep.type[4], textWidth,textWidth1);

	myPrintFeed("Number of mature animals",RNS.sheep.numberMature[1],RNS.sheep.numberMature[2],RNS.sheep.numberMature[3],RNS.sheep.numberMature[4],textWidth, " ");
	myPrintFeed("Number of offsprings",RNS.sheep.numberOfspr[1],RNS.sheep.numberOfspr[2],RNS.sheep.numberOfspr[3],RNS.sheep.numberOfspr[4],textWidth, " ");
	myPrintFeed("Average weight", RNS.sheep.averageWeight[1],RNS.sheep.averageWeight[2],RNS.sheep.averageWeight[3],RNS.sheep.averageWeight[4],textWidth, " kg");
	myPrintFloatFeed("Average weight gain", RNS.sheep.gainPerDay[1],RNS.sheep.gainPerDay[2],RNS.sheep.gainPerDay[3],RNS.sheep.gainPerDay[4],textWidth, " kg/day");
	myPrintFeed("Slaughter age", RNS.sheep.slaughterAge[1],RNS.sheep.slaughterAge[2],RNS.sheep.slaughterAge[3],RNS.sheep.slaughterAge[4],textWidth, " days");
	myPrintFeed("Slaughter weight", RNS.sheep.slaugtherWeight[1],RNS.sheep.slaugtherWeight[2],RNS.sheep.slaugtherWeight[3],RNS.sheep.slaugtherWeight[4],textWidth, " kg");
	myPrintFeed("Water per year", RNS.sheep.breedWater[1],RNS.sheep.breedWater[2],RNS.sheep.breedWater[3],RNS.sheep.breedWater[4],textWidth," L/year");
	myPrintFeed("Herd feed intake", RNS.sheep.breedFeed[1],RNS.sheep.breedFeed[2],RNS.sheep.breedFeed[3],RNS.sheep.breedFeed[4],textWidth, " kg/year");
	myPrintFeed("Herd trough feed", RNS.sheep.troughFeed[1],RNS.sheep.troughFeed[2],RNS.sheep.troughFeed[3],RNS.sheep.troughFeed[4],textWidth, " kg/year");
	myPrintFloatFeed("Feedmix density", RNS.sheep.mixDensity[1],RNS.sheep.mixDensity[2],RNS.sheep.mixDensity[3],RNS.sheep.mixDensity[4],textWidth, " kg/L");
	myPrintFeed("Herd Feedmix volume", RNS.sheep.mixVolume[1],RNS.sheep.mixVolume[2],RNS.sheep.mixVolume[3],RNS.sheep.mixVolume[4],textWidth, " L/year");


	for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.SHEEP.content) do

		for l,iFillType in pairs(foodGroups.fillTypes) do
			if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print(" ");
				print(fillName);
				myPrintFloat("Volume fraction = ",foodGroups.eatWeight,textWidth, " ");
				myPrintFeed("Herd trough ", RNS.sheep.feedVolume[1][fillName],RNS.sheep.feedVolume[2][fillName],RNS.sheep.feedVolume[3][fillName],RNS.sheep.feedVolume[4][fillName],textWidth, " L/year");
				if RNS.sheep.feedRoundBales[1][fillName] > 0 then
					myPrintFeed("Round bales ", RNS.sheep.feedRoundBales[1][fillName],RNS.sheep.feedRoundBales[2][fillName],RNS.sheep.feedRoundBales[3][fillName],RNS.sheep.feedRoundBales[4][fillName],textWidth, " ");
					myPrintFeed("Square bales ", RNS.sheep.feedSquareBales[1][fillName],RNS.sheep.feedSquareBales[2][fillName],RNS.sheep.feedSquareBales[3][fillName],RNS.sheep.feedSquareBales[4][fillName],textWidth, " ");
				end;
				myPrintFloatFeed("Hectares ", RNS.sheep.hectares[1][fillName],RNS.sheep.hectares[2][fillName],RNS.sheep.hectares[3][fillName],RNS.sheep.hectares[4][fillName],textWidth, " Ha");
			else
				print(fillName.." is not defined on this map");
			end;
		end;
	end;

--	if g_seasons.animals.animalManager.typeToAnimal["GOAT"] ~= nil then

	if RN.hasAnimal["GOAT"] then

		RNS.goats.color               = {   "BROWN",         "WHITE",          "BLACK"         };
		RNS.goats.type                = { "Brown goat",    "White goat",     "Black goat"      };
		RNS.goats.matureWeight		  = {      68,               77,                 72        };  -- kg http://adga.org/breed-standards/
		RNS.goats.weightDay           = {     365,              365,                565        };  -- Age (in days) of known weight
		RNS.goats.weight              = {      59,               59,                 59        };  -- kg 150 g/day
		RNS.goats.slaughterAge        = {     185,              185,                185        };  -- age of slaughter in days = 30 kg live body weight https://goats.extension.org/goat-consumption/
		RNS.goats.numberMature        = {       0,                0,                  0        };  -- number of mature animals
		RNS.goats.grassPercentage     = {      50,               50,                 50        };  -- percentage of feed from straw
		RNS.goats.hayPercentage       = {      50,               50,                 50        };  -- percentage of feed from hay
		RNS.goats.roundBaleVolume     = {    1500,             1500,               1500        };  -- Liters
		RNS.goats.squareBaleVolume    = {    2600,             2600,               2600        };  -- Liters

		RNS.goats.numberOfspr = {};
		RNS.goats.gainPerDay = {};
		RNS.goats.slaugtherWeight = {};
		RNS.goats.averageWeight = {};
		RNS.goats.matureWater = {};
		RNS.goats.offsprWater = {};
		RNS.goats.famWater = {};
		RNS.goats.breedWater = {};
		RNS.goats.matureFeed = {};
		RNS.goats.offsprFeed = {};
		RNS.goats.famFeed = {};
		RNS.goats.breedFeed = {};
		RNS.goats.troughFeed = {};
		RNS.goats.mixDensity = {};
		RNS.goats.mixVolume = {};
		RNS.goats.troughGrass = {};
		RNS.goats.troughHay = {};
		RNS.goats.hayRoundBales = {};
		RNS.goats.haySquareBales = {};
		RNS.goats.grassRoundBales = {};
		RNS.goats.grassSquareBales = {};
		RNS.goats.hayHa = {};
		RNS.goats.grassHa = {};

		RNS.goats.feedName 			= {};
		RNS.goats.feedVolume		= {};
		RNS.goats.feedRoundBales	= {};
		RNS.goats.feedSquareBales	= {};
		RNS.goats.hectares			= {};

		for k = 1,3 do
			RNS.goats.feedVolume[k]        	= {};
			RNS.goats.feedRoundBales[k]		= {};
			RNS.goats.feedSquareBales[k]	= {};
			RNS.goats.hectares[k]			= {};

			RNS.goats.numberOfspr[k]       = RNS.goats.numberMature[k] * RNS.goats.averageLitterSize[k];
			RNS.goats.gainPerDay[k]        = (RNS.goats.weight[k] - RNS.goats.bornWeight[k])/RNS.goats.weightDay[k];
			RNS.goats.slaugtherWeight[k]   = RNS.goats.bornWeight[k] + RNS.goats.gainPerDay[k] * RNS.goats.slaughterAge[k];
			RNS.goats.averageWeight[k]     = 0.5 * (RNS.goats.slaugtherWeight[k] + RNS.goats.bornWeight[k]);

			RNS.goats.matureWater[k]       = 365 * RNS.goats.matureWeight[k] * RNS.goats.waterPerDayPerKg[k];
			RNS.goats.offsprWater[k]       = RNS.goats.slaughterAge[k] * RNS.goats.averageWeight[k] * RNS.goats.waterPerDayPerKg[k];
			RNS.goats.famWater[k]          = RNS.goats.matureWater[k] + RNS.goats.averageLitterSize[k] * RNS.goats.offsprWater[k];
			RNS.goats.breedWater[k]        = RNS.goats.famWater[k] * RNS.goats.numberMature[k];

			RNS.goats.matureFeed[k]        = 365 * RNS.goats.matureWeight[k] * RNS.goats.foodPerDayPerKg[k];
			RNS.goats.offsprFeed[k]        = RNS.goats.slaughterAge[k] * RNS.goats.averageWeight[k] * RNS.goats.foodPerDayPerKg[k];
			RNS.goats.famFeed[k]           = RNS.goats.matureFeed[k] + RNS.goats.averageLitterSize[k] * RNS.goats.offsprFeed[k];
			RNS.goats.breedFeed[k]         = RNS.goats.famFeed[k] * RNS.goats.numberMature[k];
			RNS.goats.troughFeed[k]        = RNS.goats.foodTroughFraction[k] * RNS.goats.breedFeed[k];

			RNS.goats.mixDensity[k]	= 0;

			for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.GOAT.content) do
				local meanDensity = 0;
				local mixNumbers = 0;
				for l,iFillType in pairs(foodGroups.fillTypes) do
					if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
						local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
	--					print(fillName);
						if RN.commodityDensity[fillName] ~= nil then
							meanDensity = meanDensity + RN.commodityDensity[fillName];
						elseif RN.cropDensity[fillName] ~= nil then
							meanDensity = meanDensity + RN.cropDensity[fillName];
						else
							print(fillName.."   density not defined");
							meanDensity = 0.3;		-- number used in case of error
						end;
						mixNumbers = mixNumbers + 1;
					end;
				end;
				meanDensity = meanDensity/mixNumbers;		-- mean mass density within each feed group
				if foodGroups.eatWeight < 1 then
					RNS.goats.mixDensity[k] = RNS.goats.mixDensity[k] + meanDensity * foodGroups.eatWeight; -- mass density of of complete feed mix
				else
					RNS.goats.mixDensity[k] = RNS.goats.mixDensity[k] + meanDensity * (1/RN.numberOfFoodGroups["GOATS"]); -- mass density of of complete feed mix
				end;
			end;

			RNS.goats.mixVolume[k]         = RNS.goats.troughFeed[k]/RNS.goats.mixDensity[k];

			for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.GOAT.content) do

				for l,iFillType in pairs(foodGroups.fillTypes) do
					if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
						local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
	--					print(fillName);
						RNS.goats.feedName[fillName] = fillName;
						RNS.goats.feedVolume[k][fillName] =  foodGroups.eatWeight * RNS.goats.mixVolume[k];
						if RN.roundBaleVolume[fillName] ~= nill then
							RNS.goats.feedRoundBales[k][fillName] = RNS.goats.feedVolume[k][fillName]/RN.roundBaleVolume[fillName];
						else
							RNS.goats.feedRoundBales[k][fillName] = 0;
						end;
						if RN.squareBaleVolume[fillName] ~= nill then
							RNS.goats.feedSquareBales[k][fillName] = RNS.goats.feedVolume[k][fillName]/RN.squareBaleVolume[fillName];
						else
							RNS.goats.feedSquareBales[k][fillName] = 0;
						end;
						if RN.netYield[fillName] ~= nill then
							RNS.goats.hectares[k][fillName] = RNS.goats.feedVolume[k][fillName]/RN.netYield[fillName];
						else
							RNS.goats.hectares[k][fillName] = 0;
						end;
						RN.totalFeedHectares[fillName] = RN.totalFeedHectares[fillName] + RNS.goats.hectares[k][fillName];
					end;
				end;
			end;
		end;


		print(" ");
		print("GOATS");
		print(" ");

		myPrintFeedNames3(RNS.goats.type[1], RNS.goats.type[2], RNS.goats.type[3], textWidth,textWidth1);

		myPrintFeed3("Number of mature animals",RNS.goats.numberMature[1],RNS.goats.numberMature[2],RNS.goats.numberMature[3],textWidth, " ");
		myPrintFeed3("Number of offsprings",RNS.goats.numberOfspr[1],RNS.goats.numberOfspr[2],RNS.goats.numberOfspr[3],textWidth, " ");
		myPrintFeed3("Average weight", RNS.goats.averageWeight[1],RNS.goats.averageWeight[2],RNS.goats.averageWeight[3],textWidth, " kg");
		myPrintFloatFeed3("Average weight gain", RNS.goats.gainPerDay[1],RNS.goats.gainPerDay[2],RNS.goats.gainPerDay[3],textWidth, " kg/day");
		myPrintFeed3("Slaughter age", RNS.goats.slaughterAge[1],RNS.goats.slaughterAge[2],RNS.goats.slaughterAge[3],textWidth, " days");
		myPrintFeed3("Slaughter weight", RNS.goats.slaugtherWeight[1],RNS.goats.slaugtherWeight[2],RNS.goats.slaugtherWeight[3],textWidth, " kg");
		myPrintFeed3("Water per year", RNS.goats.breedWater[1],RNS.goats.breedWater[2],RNS.goats.breedWater[3],textWidth," L/year");
		myPrintFeed3("Herd feed intake", RNS.goats.breedFeed[1],RNS.goats.breedFeed[2],RNS.goats.breedFeed[3],textWidth, " kg/year");
		myPrintFeed3("Herd trough feed", RNS.goats.troughFeed[1],RNS.goats.troughFeed[2],RNS.goats.troughFeed[3],textWidth, " kg/year");
		myPrintFloatFeed3("Feedmix density", RNS.goats.mixDensity[1],RNS.goats.mixDensity[2],RNS.goats.mixDensity[3],textWidth, " kg/L");
		myPrintFeed3("Herd Feedmix volume", RNS.goats.mixVolume[1],RNS.goats.mixVolume[2],RNS.goats.mixVolume[3],textWidth, " L/year");


		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.GOAT.content) do

			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
					print(" ");
					print(fillName);
					myPrintFloat("Volume fraction = ",foodGroups.eatWeight,textWidth, " ");
					myPrintFeed3("Herd trough ", RNS.goats.feedVolume[1][fillName],RNS.goats.feedVolume[2][fillName],RNS.goats.feedVolume[3][fillName],textWidth, " L/year");
					if RNS.goats.feedRoundBales[1][fillName] > 0 then
						myPrintFeed3("Round bales ", RNS.goats.feedRoundBales[1][fillName],RNS.goats.feedRoundBales[2][fillName],RNS.goats.feedRoundBales[3][fillName],textWidth, " ");
						myPrintFeed3("Square bales ", RNS.goats.feedSquareBales[1][fillName],RNS.goats.feedSquareBales[2][fillName],RNS.goats.feedSquareBales[3][fillName],textWidth, " ");
					end;
					myPrintFloatFeed3("Hectares ", RNS.goats.hectares[1][fillName],RNS.goats.hectares[2][fillName],RNS.goats.hectares[3][fillName],textWidth, " Ha");
				else
					print(fillName.." is not defined on this map");
				end;
			end;
		end;
	end;

	if RN.hasAnimal["SHEEPGOAT"] then

		RNS.goats.color               = {   "BROWN",         "WHITE",          "BLACK"         };
		RNS.goats.type                = { "Brown goat",    "White goat",     "Black goat"      };
		RNS.goats.matureWeight		  = {      68,               77,                 72        };  -- kg http://adga.org/breed-standards/
		RNS.goats.weightDay           = {     365,              365,                565        };  -- Age (in days) of known weight
		RNS.goats.weight              = {      59,               59,                 59        };  -- kg 150 g/day
		RNS.goats.slaughterAge        = {     185,              185,                185        };  -- age of slaughter in days = 30 kg live body weight https://goats.extension.org/goat-consumption/
		RNS.goats.numberMature        = {       0,                0,                  0        };  -- number of mature animals
		RNS.goats.grassPercentage     = {      50,               50,                 50        };  -- percentage of feed from straw
		RNS.goats.hayPercentage       = {      50,               50,                 50        };  -- percentage of feed from hay
		RNS.goats.roundBaleVolume     = {    1500,             1500,               1500        };  -- Liters
		RNS.goats.squareBaleVolume    = {    2600,             2600,               2600        };  -- Liters

		RNS.goats.numberOfspr = {};
		RNS.goats.gainPerDay = {};
		RNS.goats.slaugtherWeight = {};
		RNS.goats.averageWeight = {};
		RNS.goats.matureWater = {};
		RNS.goats.offsprWater = {};
		RNS.goats.famWater = {};
		RNS.goats.breedWater = {};
		RNS.goats.matureFeed = {};
		RNS.goats.offsprFeed = {};
		RNS.goats.famFeed = {};
		RNS.goats.breedFeed = {};
		RNS.goats.troughFeed = {};
		RNS.goats.mixDensity = {};
		RNS.goats.mixVolume = {};
		RNS.goats.troughGrass = {};
		RNS.goats.troughHay = {};
		RNS.goats.hayRoundBales = {};
		RNS.goats.haySquareBales = {};
		RNS.goats.grassRoundBales = {};
		RNS.goats.grassSquareBales = {};
		RNS.goats.hayHa = {};
		RNS.goats.grassHa = {};

		RNS.goats.feedName 			= {};
		RNS.goats.feedVolume		= {};
		RNS.goats.feedRoundBales	= {};
		RNS.goats.feedSquareBales	= {};
		RNS.goats.hectares			= {};

		for k = 1,3 do
			RNS.goats.feedVolume[k]        	= {};
			RNS.goats.feedRoundBales[k]		= {};
			RNS.goats.feedSquareBales[k]	= {};
			RNS.goats.hectares[k]			= {};

			RNS.goats.numberOfspr[k]       = RNS.goats.numberMature[k] * RNS.goats.averageLitterSize[k];
			RNS.goats.gainPerDay[k]        = (RNS.goats.weight[k] - RNS.goats.bornWeight[k])/RNS.goats.weightDay[k];
			RNS.goats.slaugtherWeight[k]   = RNS.goats.bornWeight[k] + RNS.goats.gainPerDay[k] * RNS.goats.slaughterAge[k];
			RNS.goats.averageWeight[k]     = 0.5 * (RNS.goats.slaugtherWeight[k] + RNS.goats.bornWeight[k]);

			RNS.goats.matureWater[k]       = 365 * RNS.goats.matureWeight[k] * RNS.goats.waterPerDayPerKg[k];
			RNS.goats.offsprWater[k]       = RNS.goats.slaughterAge[k] * RNS.goats.averageWeight[k] * RNS.goats.waterPerDayPerKg[k];
			RNS.goats.famWater[k]          = RNS.goats.matureWater[k] + RNS.goats.averageLitterSize[k] * RNS.goats.offsprWater[k];
			RNS.goats.breedWater[k]        = RNS.goats.famWater[k] * RNS.goats.numberMature[k];

			RNS.goats.matureFeed[k]        = 365 * RNS.goats.matureWeight[k] * RNS.goats.foodPerDayPerKg[k];
			RNS.goats.offsprFeed[k]        = RNS.goats.slaughterAge[k] * RNS.goats.averageWeight[k] * RNS.goats.foodPerDayPerKg[k];
			RNS.goats.famFeed[k]           = RNS.goats.matureFeed[k] + RNS.goats.averageLitterSize[k] * RNS.goats.offsprFeed[k];
			RNS.goats.breedFeed[k]         = RNS.goats.famFeed[k] * RNS.goats.numberMature[k];
			RNS.goats.troughFeed[k]        = RNS.goats.foodTroughFraction[k] * RNS.goats.breedFeed[k];

			RNS.goats.mixDensity[k]	= 0;

			for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.SHEEP.content) do
				local meanDensity = 0;
				local mixNumbers = 0;
				for l,iFillType in pairs(foodGroups.fillTypes) do
					if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
						local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
	--					print(fillName);
						if RN.commodityDensity[fillName] ~= nil then
							meanDensity = meanDensity + RN.commodityDensity[fillName];
						elseif RN.cropDensity[fillName] ~= nil then
							meanDensity = meanDensity + RN.cropDensity[fillName];
						else
							print(fillName.."   density not defined");
							meanDensity = 0.3;		-- number used in case of error
						end;
						mixNumbers = mixNumbers + 1;
					end;
				end;
				meanDensity = meanDensity/mixNumbers;		-- mean mass density within each feed group
				if foodGroups.eatWeight < 1 then
					RNS.goats.mixDensity[k] = RNS.goats.mixDensity[k] + meanDensity * foodGroups.eatWeight; -- mass density of of complete feed mix
				else
					RNS.goats.mixDensity[k] = RNS.goats.mixDensity[k] + meanDensity * (1/RN.numberOfFoodGroups["GOATS"]); -- mass density of of complete feed mix
				end;
			end;

			RNS.goats.mixVolume[k]         = RNS.goats.troughFeed[k]/RNS.goats.mixDensity[k];

			for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.SHEEP.content) do

				for l,iFillType in pairs(foodGroups.fillTypes) do
					if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
						local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
	--					print(fillName);
						RNS.goats.feedName[fillName] = fillName;
						RNS.goats.feedVolume[k][fillName] =  foodGroups.eatWeight * RNS.goats.mixVolume[k];
						if RN.roundBaleVolume[fillName] ~= nill then
							RNS.goats.feedRoundBales[k][fillName] = RNS.goats.feedVolume[k][fillName]/RN.roundBaleVolume[fillName];
						else
							RNS.goats.feedRoundBales[k][fillName] = 0;
						end;
						if RN.squareBaleVolume[fillName] ~= nill then
							RNS.goats.feedSquareBales[k][fillName] = RNS.goats.feedVolume[k][fillName]/RN.squareBaleVolume[fillName];
						else
							RNS.goats.feedSquareBales[k][fillName] = 0;
						end;
						if RN.netYield[fillName] ~= nill then
							RNS.goats.hectares[k][fillName] = RNS.goats.feedVolume[k][fillName]/RN.netYield[fillName];
						else
							RNS.goats.hectares[k][fillName] = 0;
						end;
						RN.totalFeedHectares[fillName] = RN.totalFeedHectares[fillName] + RNS.goats.hectares[k][fillName];
					end;
				end;
			end;
		end;


		print(" ");
		print("GOATS");
		print(" ");

		myPrintFeedNames3(RNS.goats.type[1], RNS.goats.type[2], RNS.goats.type[3], textWidth,textWidth1);

		myPrintFeed3("Number of mature animals",RNS.goats.numberMature[1],RNS.goats.numberMature[2],RNS.goats.numberMature[3],textWidth, " ");
		myPrintFeed3("Number of offsprings",RNS.goats.numberOfspr[1],RNS.goats.numberOfspr[2],RNS.goats.numberOfspr[3],textWidth, " ");
		myPrintFeed3("Average weight", RNS.goats.averageWeight[1],RNS.goats.averageWeight[2],RNS.goats.averageWeight[3],textWidth, " kg");
		myPrintFloatFeed3("Average weight gain", RNS.goats.gainPerDay[1],RNS.goats.gainPerDay[2],RNS.goats.gainPerDay[3],textWidth, " kg/day");
		myPrintFeed3("Slaughter age", RNS.goats.slaughterAge[1],RNS.goats.slaughterAge[2],RNS.goats.slaughterAge[3],textWidth, " days");
		myPrintFeed3("Slaughter weight", RNS.goats.slaugtherWeight[1],RNS.goats.slaugtherWeight[2],RNS.goats.slaugtherWeight[3],textWidth, " kg");
		myPrintFeed3("Water per year", RNS.goats.breedWater[1],RNS.goats.breedWater[2],RNS.goats.breedWater[3],textWidth," L/year");
		myPrintFeed3("Herd feed intake", RNS.goats.breedFeed[1],RNS.goats.breedFeed[2],RNS.goats.breedFeed[3],textWidth, " kg/year");
		myPrintFeed3("Herd trough feed", RNS.goats.troughFeed[1],RNS.goats.troughFeed[2],RNS.goats.troughFeed[3],textWidth, " kg/year");
		myPrintFloatFeed3("Feedmix density", RNS.goats.mixDensity[1],RNS.goats.mixDensity[2],RNS.goats.mixDensity[3],textWidth, " kg/L");
		myPrintFeed3("Herd Feedmix volume", RNS.goats.mixVolume[1],RNS.goats.mixVolume[2],RNS.goats.mixVolume[3],textWidth, " L/year");


		for kk,foodGroups in pairs(g_animalFoodManager.foodGroups.SHEEP.content) do

			for l,iFillType in pairs(foodGroups.fillTypes) do
				if g_currentMission.fillTypeManager.fillTypes[iFillType] ~= nil then
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
					print(" ");
					print(fillName);
					myPrintFloat("Volume fraction = ",foodGroups.eatWeight,textWidth, " ");
					myPrintFeed3("Herd trough ", RNS.goats.feedVolume[1][fillName],RNS.goats.feedVolume[2][fillName],RNS.goats.feedVolume[3][fillName],textWidth, " L/year");
					if RNS.goats.feedRoundBales[1][fillName] > 0 then
						myPrintFeed3("Round bales ", RNS.goats.feedRoundBales[1][fillName],RNS.goats.feedRoundBales[2][fillName],RNS.goats.feedRoundBales[3][fillName],textWidth, " ");
						myPrintFeed3("Square bales ", RNS.goats.feedSquareBales[1][fillName],RNS.goats.feedSquareBales[2][fillName],RNS.goats.feedSquareBales[3][fillName],textWidth, " ");
					end;
					myPrintFloatFeed3("Hectares ", RNS.goats.hectares[1][fillName],RNS.goats.hectares[2][fillName],RNS.goats.hectares[3][fillName],textWidth, " Ha");
				else
					print(fillName.." is not defined on this map");
				end;
			end;
		end;
	end;


	print("\nRequired hectares for each feed");
	print("\nBased on number of animals defined in RealNumbersAnnualFeedPrediction.lua\n")
	for fillName,feedArea in pairs(RN.totalFeedHectares) do
		if feedArea > 0 then
			myPrintFloat(tostring(fillName),feedArea,textWidth," ha");
		end;
	end;
--	print_r(RN.totalFeedHectares);

end;

function RealNumbersAnnualFeedPrediction:keyEvent(unicode, sym, modifier, isDown)

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_z) then
		print("\nlAlt-rz, RealNumbersAnnualFeedPrediction");
		print(" ");
		print("PIGS");
		print(" ");
		RN.numberOfFoodGroups["PIGS"] = #g_animalFoodManager.foodGroups.PIG.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["PIGS"]);
		print(" ");
		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.PIG.content) do
			print("Feed category                 : "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;

		print(" ");
		print("PIGFOOD");
		print(" ");

		for k,foodMixtures in pairs(g_animalFoodManager.foodMixtures) do
			for l,ingredients in pairs(foodMixtures.ingredients) do
				print(" ");
				print("Mix component "..l.." weight     	: "..ingredients.weight);
				print(" ");
				for m,iFillType in pairs(ingredients.fillTypes) do
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
					print("Ingredient "..l.."               	: "..fillName);
				end;
			end;
		end;
		print(" ");

		print(" ");
		print("COWS");
		print(" ");
		RN.numberOfFoodGroups["COWS"] = #g_animalFoodManager.foodGroups.COW.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["COWS"]);
		print(" ");
		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.COW.content) do
			print("Feed category                 : "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;

		if g_seasons.animals.animalManager.typeToAnimal["CALF"] ~= nil then
			print(" ");

			print(" ");
			print("CALF");
			print(" ");
			RN.numberOfFoodGroups["CALF"] = #g_animalFoodManager.foodGroups.CALF.content;
			print("Number of feed categories     : "..RN.numberOfFoodGroups["CALF"]);
			print(" ");

			for k,foodGroups in pairs(g_animalFoodManager.foodGroups.CALF.content) do
				print("Feed category                 : "..foodGroups.title);
				print("Production weight     		: "..foodGroups.productionWeight);
				print("Eat weight            		: "..foodGroups.eatWeight);
				for l,iFillType in pairs(foodGroups.fillTypes) do
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
					print("Feed content          		: "..fillName);
					RN.totalFeedHectares[fillName] = 0;
				end;
				print(" ");
			end;
		end;

		print(" ");
		print("SHEEP");
		print(" ");
		RN.numberOfFoodGroups["SHEEP"] = #g_animalFoodManager.foodGroups.SHEEP.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["SHEEP"]);
		print(" ");

		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.SHEEP.content) do
			print("Feed category                 : "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;

		if g_seasons.animals.animalManager.typeToAnimal["GOAT"] ~= nil then
			print(" ");

			print(" ");
			print("GOAT");
			print(" ");
			RN.numberOfFoodGroups["GOATS"] = #g_animalFoodManager.foodGroups.GOAT.content;
			print("Number of feed categories     : "..RN.numberOfFoodGroups["GOATS"]);
			print(" ");

			for k,foodGroups in pairs(g_animalFoodManager.foodGroups.GOAT.content) do
				print("Feed category                 : "..foodGroups.title);
				print("Production weight     		: "..foodGroups.productionWeight);
				print("Eat weight            		: "..foodGroups.eatWeight);
				for l,iFillType in pairs(foodGroups.fillTypes) do
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
					print("Feed content          		: "..fillName);
					RN.totalFeedHectares[fillName] = 0;
				end;
				print(" ");
			end;
		end;

		print(" ");
		print("CHICKEN");
		print(" ");
		RN.numberOfFoodGroups["CHICKEN"] = #g_animalFoodManager.foodGroups.CHICKEN.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["CHICKEN"]);
		print(" ");

		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.CHICKEN.content) do
			print("Feed category               	: "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;

		if g_seasons.animals.animalManager.typeToAnimal["DUCK"] ~= nil then
			print(" ");

			print(" ");
			print("DUCK");
			print(" ");
			RN.numberOfFoodGroups["DUCKS"] = #g_animalFoodManager.foodGroups.DUCK.content;
			print("Number of feed categories     : "..RN.numberOfFoodGroups["DUCKS"]);
			print(" ");

			for k,foodGroups in pairs(g_animalFoodManager.foodGroups.DUCK.content) do
				print("Feed category                 : "..foodGroups.title);
				print("Production weight     		: "..foodGroups.productionWeight);
				print("Eat weight            		: "..foodGroups.eatWeight);
				for l,iFillType in pairs(foodGroups.fillTypes) do
					local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
					print("Feed content          		: "..fillName);
					RN.totalFeedHectares[fillName] = 0;
				end;
				print(" ");
			end;
		end;

		print(" ");
		print("HORSES");
		print(" ");
		RN.numberOfFoodGroups["HORSES"] = #g_animalFoodManager.foodGroups.HORSE.content;
		print("Number of feed categories     : "..RN.numberOfFoodGroups["HORSES"]);
		print(" ");

		for k,foodGroups in pairs(g_animalFoodManager.foodGroups.HORSE.content) do
			print("Feed category                 : "..foodGroups.title);
			print("Production weight     		: "..foodGroups.productionWeight);
			print("Eat weight            		: "..foodGroups.eatWeight);
			for l,iFillType in pairs(foodGroups.fillTypes) do
				local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
				print("Feed content          		: "..fillName);
				RN.totalFeedHectares[fillName] = 0;
			end;
			print(" ");
		end;
	end;
end;

function RealNumbersAnnualFeedPrediction:update(dt)
end;
function RealNumbersAnnualFeedPrediction:draw()
end;
function RealNumbersAnnualFeedPrediction:deleteMap()
end;
function RealNumbersAnnualFeedPrediction:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersAnnualFeedPrediction);
