--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersBalingEquipmentEconomy by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021

RealNumbersBalingEquipmentEconomy = {};

function myPrintEquipInfo60(header, textWidth, textWidth2, unit, S1, S2, S3, S4, S5, S6)

	local subtractLength = 0;

	if (string.match(unit,"€") == "€") then subtractLength = 2; end;
	if (string.match(unit,"$") == "$") then subtractLength = 2; end;
	if (string.match(unit,"£") == "£") then subtractLength = 2; end;


	local text = header..string.rep(" ",textWidth-string.len(header));
	local unitText = unit..string.rep(" ",textWidth2-(string.len(unit)-subtractLength));
	local text2 = text.." : "..unitText;
	print(string.format("%s: %13.0f %13.0f %13.0f %13.0f %13.0f %13.0f ", text2, S1, S2, S3, S4, S5, S6));
end;

function myPrintEquipInfo64(header, textWidth, textWidth2, unit, S1, S2, S3, S4, S5, S6)

	local subtractLength = 0;

	if (string.match(unit,"€") == "€") then subtractLength = 2; end;
	if (string.match(unit,"$") == "$") then subtractLength = 2; end;
	if (string.match(unit,"£") == "£") then subtractLength = 2; end;

	local text = header..string.rep(" ",textWidth-string.len(header));
	local unitText = unit..string.rep(" ",textWidth2-(string.len(unit)-subtractLength));
	local text2 = text.." : "..unitText;

	print(string.format("%s: %13.4f %13.4f %13.4f %13.4f %13.4f %13.4f", text2, S1, S2, S3, S4, S5, S6));
end;


function RealNumbersBalingEquipmentEconomy:loadMap(name)
	local textWidth = 35;
	local textWidth2 = 15;
	local currency ="€";
	local interestFactor = 0.0;

	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end



	print("\nFS19_RealLifeNumbers: RealNumbersBalingEquipmentEconomy active\n")

	RNS.notRunYetRealNumbersBalingEquipmentEconomy = true;
	RNS.upStartRealNumbersBalingEquipmentEconomy = true;

-- baling equipment economy

	RN.throughPutTonPerHour = {};

	RN.throughPutTonPerHour.SILAGEROUNDBALE      	= 16;	--Ton/hour
	RN.throughPutTonPerHour.SILAGESQUAREBALE     	= 16;	--Ton/hour
	RN.throughPutTonPerHour.DRYGRASSROUNDBALE    	= 16;	--Ton/hour
	RN.throughPutTonPerHour.DRYGRASSSQUAREBALE   	= 16;	--Ton/hour
	RN.throughPutTonPerHour.STRAWROUNDBALE      	= 16;	--Ton/hour
	RN.throughPutTonPerHour.STRAWSQUAREBALE      	= 16;	--Ton/hour

	RN.fieldArea.SILAGEROUNDBALE 					= 25;	-- ha
	RN.fieldArea.SILAGESQUAREBALE 					= 25;	-- ha
	RN.fieldArea.DRYGRASSROUNDBALE 					= 25;	-- ha
	RN.fieldArea.DRYGRASSSQUAREBALE 				= 25;	-- ha
	RN.fieldArea.STRAWROUNDBALE 					= 25;	-- ha
	RN.fieldArea.STRAWSQUAREBALE 					= 25;	-- ha

	local useActualAreas = true;				-- if true, than actul field crop areas are used to calculate break-even hectare for equipment
	local totalSilageBaleFieldArea 					= 0;	-- summing variable, do not change
	local totalDryGrassBaleFieldArea				= 0;	-- summing variable, do not change
	local totalStrawBaleFieldArea					= 0;	-- summing variable, do not change

	if useActualAreas then
		print("GRASS : "..tsum(RN.myFieldCrops["GRASS"]["myFieldArea"]));
		print("ALFALFA : "..tsum(RN.myFieldCrops["ALFALFA"]["myFieldArea"]));
		print("CLOVER : "..tsum(RN.myFieldCrops["CLOVER"]["myFieldArea"]));
		print("INCARASE_GRASS : "..tsum(RN.myFieldCrops["INCARASE_GRASS"]["myFieldArea"]));
		print("LUCERNE : "..tsum(RN.myFieldCrops["LUCERNE"]["myFieldArea"]));
		print("LUZERNE : "..tsum(RN.myFieldCrops["LUZERNE"]["myFieldArea"]));
--[[
		totalSilageBaleFieldArea = (1/3) *(2*tsum(RN.myFieldCrops["GRASS"]["myFieldArea"])
										+ 3*tsum(RN.myFieldCrops["ALFALFA"]["myFieldArea"])
										+ 2*tsum(RN.myFieldCrops["CLOVER"]["myFieldArea"])
										+ 1*tsum(RN.myFieldCrops["INCARASE_GRASS"]["myFieldArea"])
										+ 3*tsum(RN.myFieldCrops["LUCERNE"]["myFieldArea"])
										+ 3*tsum(RN.myFieldCrops["LUZERNE"]["myFieldArea"])	);


		RN.fieldArea.SILAGEROUNDBALE 	= totalSilageBaleFieldArea;
		RN.fieldArea.SILAGESQUAREBALE 	= totalSilageBaleFieldArea;

		totalDryGrassBaleFieldArea = (2/3) *(2*tsum(RN.myFieldCrops["GRASS"]["myFieldArea"])
										+ 3*tsum(RN.myFieldCrops["ALFALFA"]["myFieldArea"])
										+ 2*tsum(RN.myFieldCrops["CLOVER"]["myFieldArea"])
										+ 1*tsum(RN.myFieldCrops["INCARASE_GRASS"]["myFieldArea"])
										+ 3*tsum(RN.myFieldCrops["LUCERNE"]["myFieldArea"])
										+ 3*tsum(RN.myFieldCrops["LUZERNE"]["myFieldArea"]));

		RN.fieldArea.DRYGRASSROUNDBALE 	= totalDryGrassBaleFieldArea;
		RN.fieldArea.DRYGRASSSQUAREBALE = totalDryGrassBaleFieldArea;

		totalStrawBaleFieldArea	= 		tsum(RN.myFieldCrops["BARLEY"]["myFieldArea"])
										+ tsum(RN.myFieldCrops["OAT"]["myFieldArea"])
										+ tsum(RN.myFieldCrops["RYE"]["myFieldArea"])
										+ tsum(RN.myFieldCrops["SPELT"]["myFieldArea"])
										+ tsum(RN.myFieldCrops["TRITICALE"]["myFieldArea"])
										+ tsum(RN.myFieldCrops["WHEAT"]["myFieldArea"]);

		RN.fieldArea.STRAWROUNDBALE 	= totalStrawBaleFieldArea;
		RN.fieldArea.STRAWSQUAREBALE 	= totalStrawBaleFieldArea;
]]--
		totalSilageBaleFieldArea 	= RN.myFieldCrops["GRASS"]["SILAGE"]*tsum(RN.myFieldCrops["GRASS"]["myFieldArea"])
									+ RN.myFieldCrops["ALFALFA"]["SILAGE"]*tsum(RN.myFieldCrops["ALFALFA"]["myFieldArea"])
									+ RN.myFieldCrops["CLOVER"]["SILAGE"]*tsum(RN.myFieldCrops["CLOVER"]["myFieldArea"])
									+ RN.myFieldCrops["INCARASE_GRASS"]["SILAGE"]*tsum(RN.myFieldCrops["INCARASE_GRASS"]["myFieldArea"])
									+ RN.myFieldCrops["LUCERNE"]["SILAGE"]*tsum(RN.myFieldCrops["LUCERNE"]["myFieldArea"])
									+ RN.myFieldCrops["LUZERNE"]["SILAGE"]*tsum(RN.myFieldCrops["LUZERNE"]["myFieldArea"]);


		RN.fieldArea.SILAGEROUNDBALE 	= totalSilageBaleFieldArea;
		RN.fieldArea.SILAGESQUAREBALE 	= totalSilageBaleFieldArea;

		totalDryGrassBaleFieldArea 	= RN.myFieldCrops["GRASS"]["HAY"]*tsum(RN.myFieldCrops["GRASS"]["myFieldArea"])
									+ RN.myFieldCrops["ALFALFA"]["HAY"]*tsum(RN.myFieldCrops["ALFALFA"]["myFieldArea"])
									+ RN.myFieldCrops["CLOVER"]["HAY"]*tsum(RN.myFieldCrops["CLOVER"]["myFieldArea"])
									+ RN.myFieldCrops["INCARASE_GRASS"]["HAY"]*tsum(RN.myFieldCrops["INCARASE_GRASS"]["myFieldArea"])
									+ RN.myFieldCrops["LUCERNE"]["HAY"]*tsum(RN.myFieldCrops["LUCERNE"]["myFieldArea"])
									+ RN.myFieldCrops["LUZERNE"]["HAY"]*tsum(RN.myFieldCrops["LUZERNE"]["myFieldArea"]);

		RN.fieldArea.DRYGRASSROUNDBALE 	= totalDryGrassBaleFieldArea;
		RN.fieldArea.DRYGRASSSQUAREBALE = totalDryGrassBaleFieldArea;

		totalStrawBaleFieldArea	= 		tsum(RN.myFieldCrops["BARLEY"]["myFieldArea"])
										+ tsum(RN.myFieldCrops["OAT"]["myFieldArea"])
										+ tsum(RN.myFieldCrops["RYE"]["myFieldArea"])
										+ tsum(RN.myFieldCrops["SPELT"]["myFieldArea"])
										+ tsum(RN.myFieldCrops["TRITICALE"]["myFieldArea"])
										+ tsum(RN.myFieldCrops["WHEAT"]["myFieldArea"]);

		RN.fieldArea.STRAWROUNDBALE 	= totalStrawBaleFieldArea;
		RN.fieldArea.STRAWSQUAREBALE 	= totalStrawBaleFieldArea;


	end;

	local totalBaleFieldArea = totalSilageBaleFieldArea + totalDryGrassBaleFieldArea + totalStrawBaleFieldArea;
	if totalBaleFieldArea == 0 then totalBaleFieldArea = 25; end;
	RN.balerUseFraction = {};
	RN.balerUseFraction.SILAGEROUNDBALE 	= RN.fieldArea.SILAGEROUNDBALE/totalBaleFieldArea;
	RN.balerUseFraction.DRYGRASSROUNDBALE 	= RN.fieldArea.DRYGRASSROUNDBALE/totalBaleFieldArea;
	RN.balerUseFraction.STRAWROUNDBALE 		= RN.fieldArea.STRAWROUNDBALE/totalBaleFieldArea;
	RN.balerUseFraction.SILAGESQUAREBALE 	= RN.fieldArea.SILAGESQUAREBALE/totalBaleFieldArea;
	RN.balerUseFraction.DRYGRASSSQUAREBALE 	= RN.fieldArea.DRYGRASSSQUAREBALE/totalBaleFieldArea;
	RN.balerUseFraction.STRAWSQUAREBALE 	= RN.fieldArea.STRAWSQUAREBALE/totalBaleFieldArea;

	RN.contractRatePerBale = {};

	RN.contractRatePerBale.SILAGEROUNDBALE 			= 19;	-- contract fee per bale
	RN.contractRatePerBale.SILAGESQUAREBALE 		= 22;	-- contract fee per bale
	RN.contractRatePerBale.DRYGRASSROUNDBALE 		=  9;	-- contract fee per bale
	RN.contractRatePerBale.DRYGRASSSQUAREBALE 		= 11;	-- contract fee per bale
	RN.contractRatePerBale.STRAWROUNDBALE 			=  7;	-- contract fee per bale
	RN.contractRatePerBale.STRAWSQUAREBALE 			=  8;	-- contract fee per bale


	RN.tonPerHa = {};

	RN.tonPerHa.SILAGEROUNDBALE      			= RN.growth.grassMassPerHa/1000;	--Ton/ha
	RN.tonPerHa.SILAGESQUAREBALE     			= RN.growth.grassMassPerHa/1000;	--Ton/ha
	RN.tonPerHa.DRYGRASSROUNDBALE    			= RN.growth.drygrassMassPerHa/1000;	--Ton/ha;
	RN.tonPerHa.DRYGRASSSQUAREBALE   			= RN.growth.drygrassMassPerHa/1000;	--Ton/ha;
	RN.tonPerHa.STRAWROUNDBALE      			= RN.growth.strawMassPerHa/1000;	--Ton/ha;
	RN.tonPerHa.STRAWSQUAREBALE      			= RN.growth.strawMassPerHa/1000;	--Ton/ha;

	RN.balesPerHa = {};

	RN.balesPerHa.SILAGEROUNDBALE      			= RN.growth.grassSilageRoundBalesPerHa;
	RN.balesPerHa.SILAGESQUAREBALE     			= RN.growth.grassSilageSquareBalesPerHa;
	RN.balesPerHa.DRYGRASSROUNDBALE    			= RN.growth.drygrassRoundBalesPerHa;
	RN.balesPerHa.DRYGRASSSQUAREBALE   			= RN.growth.drygrassSquareBalesPerHa;
	RN.balesPerHa.STRAWROUNDBALE      			= RN.growth.strawRoundBalesPerHa;
	RN.balesPerHa.STRAWSQUAREBALE      			= RN.growth.strawSquareBalesPerHa;

	RN.balesPerYear = {};

	RN.balesPerYear.SILAGEROUNDBALE      		= RN.balesPerHa.SILAGEROUNDBALE * RN.fieldArea.SILAGEROUNDBALE;
	RN.balesPerYear.SILAGESQUAREBALE     		= RN.balesPerHa.SILAGESQUAREBALE * RN.fieldArea.SILAGESQUAREBALE;
	RN.balesPerYear.DRYGRASSROUNDBALE    		= RN.balesPerHa.DRYGRASSROUNDBALE * RN.fieldArea.DRYGRASSROUNDBALE;
	RN.balesPerYear.DRYGRASSSQUAREBALE   		= RN.balesPerHa.DRYGRASSSQUAREBALE * RN.fieldArea.DRYGRASSSQUAREBALE;
	RN.balesPerYear.STRAWROUNDBALE      		= RN.balesPerHa.STRAWROUNDBALE * RN.fieldArea.STRAWROUNDBALE;
	RN.balesPerYear.STRAWSQUAREBALE      		= RN.balesPerHa.STRAWSQUAREBALE * RN.fieldArea.STRAWSQUAREBALE;

	RN.equipment.price["SILAGEROUNDBALE"] 					= RN.usedEquipmentPriceScaling * 76000; --  €
	RN.equipment.loanTime["SILAGEROUNDBALE"]				= RN.loanYears;    -- years
	RN.equipment.lifeTime["SILAGEROUNDBALE"]				= 20;    -- years
	RN.equipment.depreciationRate["SILAGEROUNDBALE"]		= 0.1;
	RN.equipment.efficiency["SILAGEROUNDBALE"] 				= 0.80;
	RN.equipment.workArea["SILAGEROUNDBALE"] 				= RN.fieldArea["SILAGEROUNDBALE"];
	RN.equipment.neededHP["SILAGEROUNDBALE"] 				= 110;	-- hp
	RN.equipment.fuelPerHourPerHP["SILAGEROUNDBALE"]		= RN.fuelPerHourPerHP;
	RN.equipment.wrappingPerBale["SILAGEROUNDBALE"]			= 7.5;
	RN.equipment.plasticPerBale["SILAGEROUNDBALE"]			= 3;
	RN.equipment.movingPerBale["SILAGEROUNDBALE"]			= 1;
	RN.equipment.stackingPerBale["SILAGEROUNDBALE"]			= 2;
	RN.equipment.isLeasing["SILAGEROUNDBALE"] 				= false;
	
	RN.equipment.price["SILAGESQUAREBALE"] 					= RN.usedEquipmentPriceScaling * 105000; --  €
	RN.equipment.loanTime["SILAGESQUAREBALE"]				= RN.loanYears;    -- years
	RN.equipment.lifeTime["SILAGESQUAREBALE"]				= 20;    -- years
	RN.equipment.depreciationRate["SILAGESQUAREBALE"]		= 0.1;
	RN.equipment.efficiency["SILAGESQUAREBALE"] 			= 0.80;
	RN.equipment.workArea["SILAGESQUAREBALE"] 				= RN.fieldArea["SILAGESQUAREBALE"];
	RN.equipment.neededHP["SILAGESQUAREBALE"] 				= 140;	-- hp
	RN.equipment.fuelPerHourPerHP["SILAGESQUAREBALE"]		= RN.fuelPerHourPerHP;
	RN.equipment.wrappingPerBale["SILAGESQUAREBALE"]		= 7.5;
	RN.equipment.plasticPerBale["SILAGESQUAREBALE"]			= 3;
	RN.equipment.movingPerBale["SILAGESQUAREBALE"]			= 1;
	RN.equipment.stackingPerBale["SILAGESQUAREBALE"]		= 2;
	RN.equipment.isLeasing["SILAGESQUAREBALE"] 				= false;

	RN.equipment.price["DRYGRASSROUNDBALE"] 				= RN.usedEquipmentPriceScaling * 76000; --  €
	RN.equipment.loanTime["DRYGRASSROUNDBALE"]				= RN.loanYears;    -- years
	RN.equipment.lifeTime["DRYGRASSROUNDBALE"]				= 20;    -- years
	RN.equipment.depreciationRate["DRYGRASSROUNDBALE"]		= 0.1;
	RN.equipment.efficiency["DRYGRASSROUNDBALE"] 			= 0.80;
	RN.equipment.workArea["DRYGRASSROUNDBALE"] 				= RN.fieldArea["DRYGRASSROUNDBALE"];
	RN.equipment.neededHP["DRYGRASSROUNDBALE"] 				= 110;	-- hp
	RN.equipment.fuelPerHourPerHP["DRYGRASSROUNDBALE"]		= RN.fuelPerHourPerHP;
	RN.equipment.wrappingPerBale["DRYGRASSROUNDBALE"]		= 0;
	RN.equipment.plasticPerBale["DRYGRASSROUNDBALE"]		= 0;
	RN.equipment.movingPerBale["DRYGRASSROUNDBALE"]			= 1;
	RN.equipment.stackingPerBale["DRYGRASSROUNDBALE"]		= 2;
	RN.equipment.isLeasing["DRYGRASSROUNDBALE"] 			= false;

	RN.equipment.price["DRYGRASSSQUAREBALE"] 				= RN.usedEquipmentPriceScaling * 105000; --  €
	RN.equipment.loanTime["DRYGRASSSQUAREBALE"]				= RN.loanYears;    -- years
	RN.equipment.lifeTime["DRYGRASSSQUAREBALE"]				= 20;    -- years
	RN.equipment.depreciationRate["DRYGRASSSQUAREBALE"]		= 0.1;
	RN.equipment.efficiency["DRYGRASSSQUAREBALE"] 			= 0.80;
	RN.equipment.workArea["DRYGRASSSQUAREBALE"] 			= RN.fieldArea["DRYGRASSSQUAREBALE"];
	RN.equipment.neededHP["DRYGRASSSQUAREBALE"] 			= 140;	-- hp
	RN.equipment.fuelPerHourPerHP["DRYGRASSSQUAREBALE"]		= RN.fuelPerHourPerHP;
	RN.equipment.wrappingPerBale["DRYGRASSSQUAREBALE"]		= 0;
	RN.equipment.plasticPerBale["DRYGRASSSQUAREBALE"]		= 0;
	RN.equipment.movingPerBale["DRYGRASSSQUAREBALE"]		= 1;
	RN.equipment.stackingPerBale["DRYGRASSSQUAREBALE"]		= 2;
	RN.equipment.isLeasing["DRYGRASSSQUAREBALE"] 			= false;

	RN.equipment.price["STRAWROUNDBALE"] 					= RN.usedEquipmentPriceScaling * 76000; --  €
	RN.equipment.loanTime["STRAWROUNDBALE"]					= RN.loanYears;    -- years
	RN.equipment.lifeTime["STRAWROUNDBALE"]					= 20;    -- years
	RN.equipment.depreciationRate["STRAWROUNDBALE"]			= 0.1;
	RN.equipment.efficiency["STRAWROUNDBALE"] 				= 0.80;
	RN.equipment.workArea["STRAWROUNDBALE"] 				= RN.fieldArea["STRAWROUNDBALE"];
	RN.equipment.neededHP["STRAWROUNDBALE"] 				= 110;	-- hp
	RN.equipment.fuelPerHourPerHP["STRAWROUNDBALE"]			= RN.fuelPerHourPerHP;
	RN.equipment.wrappingPerBale["STRAWROUNDBALE"]			= 0;
	RN.equipment.plasticPerBale["STRAWROUNDBALE"]			= 0;
	RN.equipment.movingPerBale["STRAWROUNDBALE"]			= 1;
	RN.equipment.stackingPerBale["STRAWROUNDBALE"]			= 2;
	RN.equipment.isLeasing["STRAWROUNDBALE"] 				= false;

	RN.equipment.price["STRAWSQUAREBALE"] 					= RN.usedEquipmentPriceScaling * 105000; --  €
	RN.equipment.loanTime["STRAWSQUAREBALE"]				= RN.loanYears;    -- years
	RN.equipment.lifeTime["STRAWSQUAREBALE"]				= 20;    -- years
	RN.equipment.depreciationRate["STRAWSQUAREBALE"]		= 0.1;
	RN.equipment.efficiency["STRAWSQUAREBALE"] 				= 0.80;
	RN.equipment.workArea["STRAWSQUAREBALE"] 				= RN.fieldArea["STRAWSQUAREBALE"];
	RN.equipment.neededHP["STRAWSQUAREBALE"] 				= 140;	-- hp
	RN.equipment.fuelPerHourPerHP["STRAWSQUAREBALE"]		= RN.fuelPerHourPerHP;
	RN.equipment.wrappingPerBale["STRAWSQUAREBALE"]			= 0;
	RN.equipment.plasticPerBale["STRAWSQUAREBALE"]			= 0;
	RN.equipment.movingPerBale["STRAWSQUAREBALE"]			= 1;
	RN.equipment.stackingPerBale["STRAWSQUAREBALE"]			= 2;
	RN.equipment.isLeasing["STRAWSQUAREBALE"] 				= false;

	RN.balingList = {"SILAGEROUNDBALE","SILAGESQUAREBALE","DRYGRASSROUNDBALE","DRYGRASSSQUAREBALE","STRAWROUNDBALE","STRAWSQUAREBALE"};

	RN.equipment.fixedCostFraction			= {};
	RN.equipment.partialFixedCostPerYear	= {};

	local balingList = RN.balingList;

	for k,baleName in pairs(balingList) do

		interestFactor = math.pow(1 + RN.annualLoanInterest/100,RN.equipment.loanTime[baleName]);
--		print(baleName);
		RN.equipment.interestCost[baleName] 		= RN.equipment.price[baleName] * (interestFactor - 1);
		RN.equipment.loanCost[baleName] 			= RN.equipment.price[baleName] * interestFactor;
		RN.equipment.salvageFraction[baleName] 		= math.pow((1-RN.equipment.depreciationRate[baleName]),RN.equipment.lifeTime[baleName]);
		RN.equipment.sellPrice[baleName] 			= RN.equipment.price[baleName] * RN.equipment.salvageFraction[baleName];
		RN.equipment.loanPayment[baleName] 			= RN.equipment.loanCost[baleName] - RN.equipment.sellPrice[baleName];
		RN.equipment.depreciation[baleName] 		= RN.equipment.price[baleName] - RN.equipment.sellPrice[baleName];
		RN.equipment.investmentCost[baleName] 		= RN.equipment.loanPayment[baleName] + RN.equipment.depreciation[baleName];
		RN.equipment.investmentCostPerYear[baleName] = RN.equipment.investmentCost[baleName]/RN.equipment.lifeTime[baleName];
		RN.equipment.tax[baleName] 					= RN.equipmentTax * (RN.equipment.price[baleName] + RN.equipment.sellPrice[baleName])/2;
		RN.equipment.insurance[baleName] 			= RN.equipmentInsurance * (RN.equipment.price[baleName] + RN.equipment.sellPrice[baleName])/2;
		RN.equipment.housing[baleName] 				= RN.equipmentHousing * (RN.equipment.price[baleName] + RN.equipment.sellPrice[baleName])/2;
		RN.equipment.TIHperYear[baleName] 			= (RN.equipment.tax[baleName] + RN.equipment.insurance[baleName] + RN.equipment.housing[baleName])/RN.equipment.lifeTime[baleName];
		RN.equipment.fixedCostPerYear[baleName] 	= RN.equipment.investmentCostPerYear[baleName] + RN.equipment.TIHperYear[baleName];
		RN.equipment.fixedCostFraction[baleName]	= RN.balerUseFraction[baleName];
		RN.equipment.partialFixedCostPerYear[baleName]	= RN.equipment.fixedCostFraction[baleName] * RN.equipment.fixedCostPerYear[baleName];
		RN.equipment.fieldCapacity[baleName] 		= RN.throughPutTonPerHour[baleName] * RN.equipment.efficiency[baleName] / RN.tonPerHa[baleName];
		RN.equipment.fieldHours[baleName] 			= RN.equipment.workArea[baleName]/RN.equipment.fieldCapacity[baleName];
		RN.equipment.lifeTimeHours[baleName] 		= RN.equipment.lifeTime[baleName] * RN.equipment.fieldHours[baleName];
		RN.equipment.repairsPerYear[baleName] 		= RN.equipment.price[baleName] * RN.equipmentRepairFactor/RN.equipment.lifeTime[baleName];
		RN.equipment.repairsPerHour[baleName] 		= RN.equipment.repairsPerYear[baleName]/RN.equipment.fieldHours[baleName];
		RN.equipment.fuelPerHour[baleName] 			= RN.equipment.neededHP[baleName] * RN.equipment.fuelPerHourPerHP[baleName];
		RN.equipment.fuelCostPerHour[baleName] 		= RN.equipment.fuelPerHour[baleName] * RN.fuelCostPerLiter;
		RN.equipment.lubricationCostPerHour[baleName] 	= RN.equipment.fuelCostPerHour[baleName] * RN.lubricationFractionOfFuel;
		RN.equipment.operatingCostPerHour[baleName] = RN.salaryPerHour + RN.equipment.repairsPerHour[baleName] + RN.equipment.fuelCostPerHour[baleName] + RN.equipment.lubricationCostPerHour[baleName];
		RN.equipment.operatingCostPerYear[baleName] = RN.equipment.operatingCostPerHour[baleName] * RN.equipment.fieldHours[baleName];
		RN.equipment.operatingCostPerHa[baleName] 	= RN.equipment.operatingCostPerYear[baleName]/RN.equipment.workArea[baleName];
		RN.equipment.operatingCostPerBale[baleName] = RN.equipment.operatingCostPerYear[baleName]/RN.balesPerYear[baleName];
		RN.equipment.fixedCostPerHour[baleName] 	= RN.equipment.partialFixedCostPerYear[baleName]/RN.equipment.fieldHours[baleName];
		RN.equipment.fixedCostPerBale[baleName] 	= RN.equipment.partialFixedCostPerYear[baleName]/RN.balesPerYear[baleName];
		RN.equipment.fixedCostPerHa[baleName] 		= RN.equipment.fixedCostPerBale[baleName] * RN.balesPerHa[baleName];
		RN.equipment.equipmentCostPerHour[baleName] = RN.equipment.operatingCostPerHour[baleName] + RN.equipment.fixedCostPerHour[baleName];
		RN.equipment.equipmentCostPerYear[baleName] = RN.equipment.equipmentCostPerHour[baleName] * RN.equipment.fieldHours[baleName];
		RN.equipment.equipmentCostPerHa[baleName] 	= RN.equipment.equipmentCostPerHour[baleName]/RN.equipment.fieldCapacity[baleName];
		RN.equipment.equipmentCostPerBale[baleName] = RN.equipment.equipmentCostPerYear[baleName]/RN.balesPerYear[baleName];
		RN.equipment.supplyCostPerBale[baleName]	= RN.equipment.wrappingPerBale[baleName] + RN.equipment.plasticPerBale[baleName];
		RN.equipment.supplyCostPerHa[baleName]		= RN.equipment.supplyCostPerBale[baleName] * RN.balesPerHa[baleName];
		RN.equipment.opAndSupplyCostPerHa[baleName]	= RN.equipment.supplyCostPerHa[baleName] + RN.equipment.operatingCostPerHa[baleName];
		RN.equipment.useOwnEquipCostPerHa[baleName]	= RN.equipment.opAndSupplyCostPerHa[baleName] + RN.equipment.fixedCostPerHa[baleName];
		RN.contractRatePerYear[baleName] 			= RN.contractRatePerBale[baleName] * RN.balesPerYear[baleName];
		RN.contractRatePerHa[baleName] 				= RN.contractRatePerYear[baleName] / RN.equipment.workArea[baleName];
		RN.contractRatePerHour[baleName] 			= RN.contractRatePerHa[baleName] * RN.equipment.fieldCapacity[baleName];
		RN.equipment.surplusPerHa[baleName] 		= RN.contractRatePerHa[baleName] - RN.equipment.opAndSupplyCostPerHa[baleName];
		RN.equipment.breakEvenHa[baleName] 			= RN.equipment.partialFixedCostPerYear[baleName] / RN.equipment.surplusPerHa[baleName] ;
	end;



	RN.forageCost.mowing			= RN.equipment.equipmentCostPerHa["MOWERS"]; 				-- cost per ha
	RN.forageCost.raking			= RN.equipment.equipmentCostPerHa["WINDROWERS"]; 			-- cost per ha
	RN.forageCost.tedding			= RN.equipment.equipmentCostPerHa["TEDDERS"]; 				-- cost per ha
	RN.forageCost.roundBaling		= RN.equipment.equipmentCostPerHa["DRYGRASSROUNDBALE"]; 	-- cost per ha
	RN.forageCost.moving     		= 1.00;    	-- € per bale
	RN.forageCost.stacking   		= 2.00;    	-- € per bale
	RN.forageCost.wrapping   		= 7.50;    	-- € per bale
	RN.forageCost.plastic   		= 3.00;    	-- € per bale



	RN.fieldWorkCost.straw			= RN.forageCost.raking + RN.forageCost.roundBaling + RN.numberRoundBalesPerHa["WHEAT"] * (RN.forageCost.moving + RN.forageCost.stacking);	-- per ha
	RN.fieldWorkCost.hayBaling		= RN.forageCost.roundBaling + RN.forageCost.tedding + RN.forageCost.raking + RN.forageCost.roundBaling + RN.numberRoundBalesPerHa["DRYGRASS"]*(RN.forageCost.moving + RN.forageCost.stacking);	-- per bale
	RN.fieldWorkCost.silageBaling	= RN.forageCost.roundBaling + RN.forageCost.raking + RN.forageCost.roundBaling + RN.numberRoundBalesPerHa["GRASS"] * (RN.forageCost.wrapping + RN.forageCost.moving + RN.forageCost.stacking);-- per bale


	print("                                                                 SILAGE BALING               DRYGRASS BALING              STRAW BALING");
	print("                                                               Round        Square         Round        Square         Round       Square");
	print(" ")
	myPrintEquipInfo60("Price", textWidth, textWidth2, currency,
		RN.equipment.price[balingList[1]], RN.equipment.price[balingList[2]], RN.equipment.price[balingList[3]], RN.equipment.price[balingList[4]], RN.equipment.price[balingList[5]], RN.equipment.price[balingList[6]]);
	myPrintEquipInfo60("Loan time", textWidth, textWidth2, "years",
		RN.equipment.loanTime[balingList[1]], RN.equipment.loanTime[balingList[2]], RN.equipment.loanTime[balingList[3]], RN.equipment.loanTime[balingList[4]], RN.equipment.loanTime[balingList[5]], RN.equipment.loanTime[balingList[6]]);
	myPrintEquipInfo60("Life time", textWidth, textWidth2, "years",
		RN.equipment.lifeTime[balingList[1]], RN.equipment.lifeTime[balingList[2]], RN.equipment.lifeTime[balingList[3]], RN.equipment.lifeTime[balingList[4]], RN.equipment.lifeTime[balingList[5]], RN.equipment.lifeTime[balingList[6]]);
	myPrintEquipInfo64("Net interest rate", textWidth, textWidth2, "%",
		RN.annualLoanInterest, RN.annualLoanInterest, RN.annualLoanInterest, RN.annualLoanInterest, RN.annualLoanInterest, RN.annualLoanInterest);
	myPrintEquipInfo60("Interest cost", textWidth, textWidth2, currency,
		RN.equipment.interestCost[balingList[1]], RN.equipment.interestCost[balingList[2]], RN.equipment.interestCost[balingList[3]], RN.equipment.interestCost[balingList[4]], RN.equipment.interestCost[balingList[5]], RN.equipment.interestCost[balingList[6]]);
	myPrintEquipInfo60("Loan cost", textWidth, textWidth2, currency,
		RN.equipment.loanCost[balingList[1]], RN.equipment.loanCost[balingList[2]], RN.equipment.loanCost[balingList[3]], RN.equipment.loanCost[balingList[4]], RN.equipment.loanCost[balingList[5]], RN.equipment.loanCost[balingList[6]]);
	myPrintEquipInfo64("Depreciation rate per year", textWidth, textWidth2, "-",
		RN.equipment.depreciationRate[balingList[1]], RN.equipment.depreciationRate[balingList[2]], RN.equipment.depreciationRate[balingList[3]], RN.equipment.depreciationRate[balingList[4]], RN.equipment.depreciationRate[balingList[5]], RN.equipment.depreciationRate[balingList[6]]);
	myPrintEquipInfo64("Salvage fraction", textWidth, textWidth2, "-",
		RN.equipment.salvageFraction[balingList[1]], RN.equipment.salvageFraction[balingList[2]], RN.equipment.salvageFraction[balingList[3]], RN.equipment.salvageFraction[balingList[4]], RN.equipment.salvageFraction[balingList[5]], RN.equipment.salvageFraction[balingList[6]]);
	myPrintEquipInfo60("Sell price", textWidth, textWidth2, currency,
		RN.equipment.sellPrice[balingList[1]], RN.equipment.sellPrice[balingList[2]], RN.equipment.sellPrice[balingList[3]], RN.equipment.sellPrice[balingList[4]], RN.equipment.sellPrice[balingList[5]], RN.equipment.sellPrice[balingList[6]]);
	myPrintEquipInfo60("Loan payment", textWidth, textWidth2, currency,
		RN.equipment.loanPayment[balingList[1]], RN.equipment.loanPayment[balingList[2]], RN.equipment.loanPayment[balingList[3]], RN.equipment.loanPayment[balingList[4]], RN.equipment.loanPayment[balingList[5]], RN.equipment.loanPayment[balingList[6]]);
	myPrintEquipInfo60("Life time depreciation", textWidth, textWidth2, currency,
		RN.equipment.depreciation[balingList[1]], RN.equipment.depreciation[balingList[2]], RN.equipment.depreciation[balingList[3]], RN.equipment.depreciation[balingList[4]], RN.equipment.depreciation[balingList[5]], RN.equipment.depreciation[balingList[6]]);
	myPrintEquipInfo60("Investment cost", textWidth, textWidth2, currency,
		RN.equipment.investmentCost[balingList[1]], RN.equipment.investmentCost[balingList[2]], RN.equipment.investmentCost[balingList[3]],RN.equipment.investmentCost[balingList[4]], RN.equipment.investmentCost[balingList[5]], RN.equipment.investmentCost[balingList[6]]);
	myPrintEquipInfo60("Investment cost per year", textWidth, textWidth2, currency.."/year",
		RN.equipment.investmentCostPerYear[balingList[1]], RN.equipment.investmentCostPerYear[balingList[2]], RN.equipment.investmentCostPerYear[balingList[3]], RN.equipment.investmentCostPerYear[balingList[4]], RN.equipment.investmentCostPerYear[balingList[5]], RN.equipment.investmentCostPerYear[balingList[6]]);
	myPrintEquipInfo60("Tax, insurance, housing cost", textWidth, textWidth2, currency.."/year",
		RN.equipment.TIHperYear[balingList[1]], RN.equipment.TIHperYear[balingList[2]], RN.equipment.TIHperYear[balingList[3]], RN.equipment.TIHperYear[balingList[4]], RN.equipment.TIHperYear[balingList[5]], RN.equipment.TIHperYear[balingList[6]]);
	print(" ");
	myPrintEquipInfo60("Fixed cost per year", textWidth, textWidth2, currency.."/year",
		RN.equipment.fixedCostPerYear[balingList[1]], RN.equipment.fixedCostPerYear[balingList[2]], RN.equipment.fixedCostPerYear[balingList[3]], RN.equipment.fixedCostPerYear[balingList[4]], RN.equipment.fixedCostPerYear[balingList[5]], RN.equipment.fixedCostPerYear[balingList[6]]);
	myPrintEquipInfo60("Partial fixed cost per year", textWidth, textWidth2, currency.."/year",
		RN.equipment.partialFixedCostPerYear[balingList[1]], RN.equipment.partialFixedCostPerYear[balingList[2]], RN.equipment.partialFixedCostPerYear[balingList[3]], RN.equipment.partialFixedCostPerYear[balingList[4]], RN.equipment.partialFixedCostPerYear[balingList[5]], RN.equipment.partialFixedCostPerYear[balingList[6]]);
	print(" ");
	myPrintEquipInfo64("Throughput", textWidth, textWidth2, "Ton/hour",
		RN.throughPutTonPerHour[balingList[1]], RN.throughPutTonPerHour[balingList[2]], RN.throughPutTonPerHour[balingList[3]], RN.throughPutTonPerHour[balingList[4]], RN.throughPutTonPerHour[balingList[5]], RN.throughPutTonPerHour[balingList[6]]);
	myPrintEquipInfo64("Ton per ha", textWidth, textWidth2, "Ton/ha",
		RN.tonPerHa[balingList[1]], RN.tonPerHa[balingList[2]], RN.tonPerHa[balingList[3]], RN.tonPerHa[balingList[4]], RN.tonPerHa[balingList[5]], RN.tonPerHa[balingList[6]]);
	myPrintEquipInfo64("Implement efficiency", textWidth, textWidth2, "-",
		RN.equipment.efficiency[balingList[1]], RN.equipment.efficiency[balingList[2]], RN.equipment.efficiency[balingList[3]], RN.equipment.efficiency[balingList[4]], RN.equipment.efficiency[balingList[5]], RN.equipment.efficiency[balingList[6]]);
	myPrintEquipInfo64("Implement capacity", textWidth, textWidth2, "ha/hour",
		RN.equipment.fieldCapacity[balingList[1]], RN.equipment.fieldCapacity[balingList[2]], RN.equipment.fieldCapacity[balingList[3]], RN.equipment.fieldCapacity[balingList[4]], RN.equipment.fieldCapacity[balingList[5]], RN.equipment.fieldCapacity[balingList[6]]);
	myPrintEquipInfo64("Implement work area", textWidth, textWidth2, "ha/year",
		RN.equipment.workArea[balingList[1]], RN.equipment.workArea[balingList[2]], RN.equipment.workArea[balingList[3]], RN.equipment.workArea[balingList[4]], RN.equipment.workArea[balingList[5]], RN.equipment.workArea[balingList[6]]);
	myPrintEquipInfo64("Implement hours per year", textWidth, textWidth2, "hours/year",
		RN.equipment.fieldHours[balingList[1]], RN.equipment.fieldHours[balingList[2]], RN.equipment.fieldHours[balingList[3]], RN.equipment.fieldHours[balingList[4]], RN.equipment.fieldHours[balingList[5]], RN.equipment.fieldHours[balingList[6]]);
	myPrintEquipInfo60("Implement hours life time", textWidth, textWidth2, "hours",
		RN.equipment.lifeTimeHours[balingList[1]], RN.equipment.lifeTimeHours[balingList[2]], RN.equipment.lifeTimeHours[balingList[3]], RN.equipment.lifeTimeHours[balingList[4]], RN.equipment.lifeTimeHours[balingList[5]], RN.equipment.lifeTimeHours[balingList[6]]);
	myPrintEquipInfo64("Repair factor", textWidth, textWidth2, "-",
		RN.equipmentRepairFactor, RN.equipmentRepairFactor, RN.equipmentRepairFactor, RN.equipmentRepairFactor, RN.equipmentRepairFactor, RN.equipmentRepairFactor);
	myPrintEquipInfo60("Repairs per year", textWidth, textWidth2, currency.."/year",
		RN.equipment.repairsPerYear[balingList[1]], RN.equipment.repairsPerYear[balingList[2]], RN.equipment.repairsPerYear[balingList[3]],RN.equipment.repairsPerYear[balingList[4]], RN.equipment.repairsPerYear[balingList[5]], RN.equipment.repairsPerYear[balingList[6]]);
	myPrintEquipInfo64("Repairs per hour", textWidth, textWidth2, currency.."/hour",
		RN.equipment.repairsPerHour[balingList[1]], RN.equipment.repairsPerHour[balingList[2]], RN.equipment.repairsPerHour[balingList[3]], RN.equipment.repairsPerHour[balingList[4]], RN.equipment.repairsPerHour[balingList[5]], RN.equipment.repairsPerHour[balingList[6]]);
	myPrintEquipInfo60("Required HP", textWidth, textWidth2, "hp",
		RN.equipment.neededHP[balingList[1]], RN.equipment.neededHP[balingList[2]], RN.equipment.neededHP[balingList[3]], RN.equipment.neededHP[balingList[4]], RN.equipment.neededHP[balingList[5]], RN.equipment.neededHP[balingList[6]]);
	myPrintEquipInfo64("Fuel per hour", textWidth, textWidth2, "L/hour",
		RN.equipment.fuelPerHour[balingList[1]], RN.equipment.fuelPerHour[balingList[2]], RN.equipment.fuelPerHour[balingList[3]], RN.equipment.fuelPerHour[balingList[4]], RN.equipment.fuelPerHour[balingList[5]], RN.equipment.fuelPerHour[balingList[6]]);
	myPrintEquipInfo64("Fuel cost per hour", textWidth, textWidth2, currency.."/hour",
		RN.equipment.fuelCostPerHour[balingList[1]], RN.equipment.fuelCostPerHour[balingList[2]], RN.equipment.fuelCostPerHour[balingList[3]], RN.equipment.fuelCostPerHour[balingList[4]], RN.equipment.fuelCostPerHour[balingList[5]], RN.equipment.fuelCostPerHour[balingList[6]]);
	myPrintEquipInfo64("Lubrication cost per hour", textWidth, textWidth2, currency.."/hour",
		RN.equipment.lubricationCostPerHour[balingList[1]], RN.equipment.lubricationCostPerHour[balingList[2]], RN.equipment.lubricationCostPerHour[balingList[3]], RN.equipment.lubricationCostPerHour[balingList[4]], RN.equipment.lubricationCostPerHour[balingList[5]], RN.equipment.lubricationCostPerHour[balingList[6]]);
	myPrintEquipInfo64("Labor cost per hour", textWidth, textWidth2, currency.."/hour",
		RN.salaryPerHour, RN.salaryPerHour, RN.salaryPerHour, RN.salaryPerHour, RN.salaryPerHour, RN.salaryPerHour);
	myPrintEquipInfo64("Operating cost per hour", textWidth, textWidth2, currency.."/hour",
		RN.equipment.operatingCostPerHour[balingList[1]], RN.equipment.operatingCostPerHour[balingList[2]], RN.equipment.operatingCostPerHour[balingList[3]], RN.equipment.operatingCostPerHour[balingList[4]], RN.equipment.operatingCostPerHour[balingList[5]], RN.equipment.operatingCostPerHour[balingList[6]]);
	myPrintEquipInfo64("Operating cost per year", textWidth, textWidth2, currency.."/year",
		RN.equipment.operatingCostPerYear[balingList[1]], RN.equipment.operatingCostPerYear[balingList[2]], RN.equipment.operatingCostPerYear[balingList[3]], RN.equipment.operatingCostPerYear[balingList[4]], RN.equipment.operatingCostPerYear[balingList[5]], RN.equipment.operatingCostPerYear[balingList[6]]);
	myPrintEquipInfo64("Operating cost per ha", textWidth, textWidth2, currency.."/ha",
		RN.equipment.operatingCostPerHa[balingList[1]], RN.equipment.operatingCostPerHa[balingList[2]], RN.equipment.operatingCostPerHa[balingList[3]], RN.equipment.operatingCostPerHa[balingList[4]], RN.equipment.operatingCostPerHa[balingList[5]], RN.equipment.operatingCostPerHa[balingList[6]]);
	myPrintEquipInfo64("Operating cost per bale", textWidth, textWidth2, currency.."/bale",
		RN.equipment.operatingCostPerBale[balingList[1]], RN.equipment.operatingCostPerBale[balingList[2]], RN.equipment.operatingCostPerBale[balingList[3]], RN.equipment.operatingCostPerBale[balingList[4]], RN.equipment.operatingCostPerBale[balingList[5]], RN.equipment.operatingCostPerBale[balingList[6]]);
	myPrintEquipInfo64("Fixed cost per ha", textWidth, textWidth2, currency.."/ha",
		RN.equipment.fixedCostPerHa[balingList[1]], RN.equipment.fixedCostPerHa[balingList[2]], RN.equipment.fixedCostPerHa[balingList[3]], RN.equipment.fixedCostPerHa[balingList[4]], RN.equipment.fixedCostPerHa[balingList[5]], RN.equipment.fixedCostPerHa[balingList[6]]);
	myPrintEquipInfo64("Fixed cost per bale", textWidth, textWidth2, currency.."/bale",
		RN.equipment.fixedCostPerBale[balingList[1]], RN.equipment.fixedCostPerBale[balingList[2]], RN.equipment.fixedCostPerBale[balingList[3]], RN.equipment.fixedCostPerBale[balingList[4]], RN.equipment.fixedCostPerBale[balingList[5]], RN.equipment.fixedCostPerBale[balingList[6]]);
		print(" ");
	myPrintEquipInfo60("Fixed + op. cost per ha", textWidth, textWidth2, currency.."/ha",
		RN.equipment.equipmentCostPerHa[balingList[1]], RN.equipment.equipmentCostPerHa[balingList[2]], RN.equipment.equipmentCostPerHa[balingList[3]], RN.equipment.equipmentCostPerHa[balingList[4]], RN.equipment.equipmentCostPerHa[balingList[5]], RN.equipment.equipmentCostPerHa[balingList[6]]);
	myPrintEquipInfo60("Fixed + op. cost per year", textWidth, textWidth2, currency.."/year",
		RN.equipment.equipmentCostPerYear[balingList[1]], RN.equipment.equipmentCostPerYear[balingList[2]], RN.equipment.equipmentCostPerYear[balingList[3]], RN.equipment.equipmentCostPerYear[balingList[4]], RN.equipment.equipmentCostPerYear[balingList[5]], RN.equipment.equipmentCostPerYear[balingList[6]]);
	myPrintEquipInfo60("Fixed + op. cost per bale", textWidth, textWidth2, currency.."/bale",
		RN.equipment.equipmentCostPerBale[balingList[1]], RN.equipment.equipmentCostPerBale[balingList[2]], RN.equipment.equipmentCostPerBale[balingList[3]], RN.equipment.equipmentCostPerBale[balingList[4]], RN.equipment.equipmentCostPerBale[balingList[5]], RN.equipment.equipmentCostPerBale[balingList[6]]);
	myPrintEquipInfo60("Supply cost per bale", textWidth, textWidth2, currency.."/bale",
		RN.equipment.supplyCostPerBale[balingList[1]], RN.equipment.supplyCostPerBale[balingList[2]], RN.equipment.supplyCostPerBale[balingList[3]], RN.equipment.supplyCostPerBale[balingList[4]], RN.equipment.supplyCostPerBale[balingList[5]], RN.equipment.supplyCostPerBale[balingList[6]]);
	myPrintEquipInfo60("Supply cost per ha", textWidth, textWidth2, currency.."/ha",
		RN.equipment.supplyCostPerHa[balingList[1]], RN.equipment.supplyCostPerHa[balingList[2]], RN.equipment.supplyCostPerHa[balingList[3]], RN.equipment.supplyCostPerHa[balingList[4]], RN.equipment.supplyCostPerHa[balingList[5]], RN.equipment.supplyCostPerHa[balingList[6]]);
	myPrintEquipInfo60("Operating and supply cost per ha", textWidth, textWidth2, currency.."/ha",
		RN.equipment.opAndSupplyCostPerHa[balingList[1]], RN.equipment.opAndSupplyCostPerHa[balingList[2]], RN.equipment.opAndSupplyCostPerHa[balingList[3]], RN.equipment.opAndSupplyCostPerHa[balingList[4]], RN.equipment.opAndSupplyCostPerHa[balingList[5]], RN.equipment.opAndSupplyCostPerHa[balingList[6]]);
	myPrintEquipInfo60("Fixed + op. + supply cost per ha", textWidth, textWidth2, currency.."/ha",
		RN.equipment.useOwnEquipCostPerHa[balingList[1]], RN.equipment.useOwnEquipCostPerHa[balingList[2]], RN.equipment.useOwnEquipCostPerHa[balingList[3]], RN.equipment.useOwnEquipCostPerHa[balingList[4]], RN.equipment.useOwnEquipCostPerHa[balingList[5]], RN.equipment.useOwnEquipCostPerHa[balingList[6]]);
		print(" ");
	myPrintEquipInfo60("Contract cost per bale", textWidth, textWidth2, currency.."/bale",
		RN.contractRatePerBale[balingList[1]], RN.contractRatePerBale[balingList[2]], RN.contractRatePerBale[balingList[3]], RN.contractRatePerBale[balingList[4]], RN.contractRatePerBale[balingList[5]], RN.contractRatePerBale[balingList[6]]);
	myPrintEquipInfo60("Contract cost per ha", textWidth, textWidth2, currency.."/ha",
		RN.contractRatePerHa[balingList[1]], RN.contractRatePerHa[balingList[2]], RN.contractRatePerHa[balingList[3]], RN.contractRatePerHa[balingList[4]], RN.contractRatePerHa[balingList[5]], RN.contractRatePerHa[balingList[6]]);
	myPrintEquipInfo60("Contract cost per year", textWidth, textWidth2, currency.."/year",
		RN.contractRatePerYear[balingList[1]], RN.contractRatePerYear[balingList[2]], RN.contractRatePerYear[balingList[3]], RN.contractRatePerYear[balingList[4]], RN.contractRatePerYear[balingList[5]], RN.contractRatePerYear[balingList[6]]);
		print(" ");
	myPrintEquipInfo60("Break-even fixed cost per ha", textWidth, textWidth2, currency.."/ha",
		RN.equipment.surplusPerHa[balingList[1]], RN.equipment.surplusPerHa[balingList[2]], RN.equipment.surplusPerHa[balingList[3]], RN.equipment.surplusPerHa[balingList[4]], RN.equipment.surplusPerHa[balingList[5]], RN.equipment.surplusPerHa[balingList[6]]);
		print(" ");
	myPrintEquipInfo60("Break-even ha", textWidth, textWidth2, "ha/year",
		RN.equipment.breakEvenHa[balingList[1]], RN.equipment.breakEvenHa[balingList[2]], RN.equipment.breakEvenHa[balingList[3]], RN.equipment.breakEvenHa[balingList[4]], RN.equipment.breakEvenHa[balingList[5]], RN.equipment.breakEvenHa[balingList[6]]);
	print(" ")



end;

function RealNumbersBalingEquipmentEconomy:keyEvent(unicode, sym, modifier, isDown)
end;

function RealNumbersBalingEquipmentEconomy:update(dt)
end;
function RealNumbersBalingEquipmentEconomy:draw()
end;
function RealNumbersBalingEquipmentEconomy:deleteMap()
end;
function RealNumbersBalingEquipmentEconomy:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersBalingEquipmentEconomy);
