--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersCommodityPrices by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021


-- Names for FillTypes

-- WHEAT BARLEY OAT CANOLA SUNFLOWER SOYBEAN MAIZE POTATO SUGARBEET OILSEEDRADISH
-- MANURE SEEDS FORAGE FORAGE_MIXING CHAFF WOODCHIPS SILAGE
-- STRAW GRASS_WINDROW DRYGRASS_WINDROW SUGARCANE FERTILIZER PIGFOOD LIME
-- WOOL TREESAPLINGS EGG
-- MILK FUEL WATER DIESEL DEF
-- LIQUIDFERTILIZER HERBICIDE
-- CHAFF GRASS_WINDROW
-- LIQUIDMANURE DIGESTATE
-- COW_TYPE_BRAHMAN_GREY COW_TYPE_BRAHMAN_LIGHT_BROWN COW_TYPE_BRAHMAN_WHITE
-- COW_TYPE_BRAHMAN_BROWN COW_TYPE_BROWN COW_TYPE_BROWN_WHITE COW_TYPE_BLACK
-- COW_TYPE_BLACK_WHITE
-- SHEEP_TYPE_WHITE SHEEP_TYPE_BROWN SHEEP_TYPE_BLACK_WHITE SHEEP_TYPE_BLACK
-- PIG_TYPE_RED PIG_TYPE_WHITE PIG_TYPE_BLACK_WHITE PIG_TYPE_BLACK
-- CHICKEN_TYPE_BLACK CHICKEN_TYPE_WHITE CHICKEN_TYPE_BROWN CHICKEN_TYPE_ROOSTER

--[[

	Version 1.1

	More fillTypes have been included.

Commodity prices

Farmland

	Price per hectar (farmland) is obtained from EUROSTAT for different EU countries.
	FS19 operates with two areas (1) farmland area and (2) field area. When a field is bought, you buy a larger piece of land, the farmland.
	The field area is only the area tillaged for crop growth. The purchase price for the ntire farmland is the pricePerHa * farmlandArea. The
	in-game mission page will give information about field area, but not the farmland are. To get information about both use the script
	RealNumbersFieldInfo included in this mod. To use it press ,LeftAlt-rf. Information is printed to the log file.

Fuel

	Fuel and diesel: National averagage values.

Seed

	Seed price is calculated as follow. From the US department of agriculture (USDA) statistical service seed prices were collected as national
	average values (2010 - 2014) for spring wheat, winter wheat, barley, oat, sunflower, soybean, and maize, and scaled to $/100 kg. For each crop, these numbers were
	multiplied by the seed usage for that crop to calculate the $/ha for each crop. Adding up the seed cost for each crop gives the seed cost for
	1 ha of each crop. The seed usage for each crop was converted from mass to volume by dividing the mass amount per ha by 50% of the fresh crop
	mass density (assuming that seeds contain less water than fresh crop). Dividing the total seed cost by the total seed volume gives the
	seed price per liter. Dividing the total seed mass by the total seed volume gives a seed density. Potatoes have been excluded from this calulation
	because seed usage and seed density for potatoes differs significantly from grain type seeds and would bias the result heavily toward potatoes.

	Seed price: 0.3626 $/liter (default ingame: 0.3 pricePerLiter)
	Seed density: 0.3207 kg/Liter (default ingame: 0.35 massPerLiter)

Spray types

	Fertilizer prices are averaged prices over several NPK type fertilizers, as different countries use different NPK mix.

	Liquid fertilizer: data are not published by EUROSTAT or USDA. Default in-game values are used.

	Lime data are only available as US national averages. US values are also used for EU.

	Herbicide data are only available as US national averages. US values are also used for EU.

Feed

	There are no straw prices at USDA. The average value for EU is used.

	Hay prices are purchase pricess for EU and Sell prices for US.

	Pig food prices is an average over a variety of complete feed formulas


]]--


RealNumbersCommodityPrices = {};

function myPrintShopInfo(Category, textWidth1, itemName, textWidth2, itemId, itemVolume, itemUnit, itemPrice, currency)
	local text1 = Category..string.rep(" ",textWidth1-string.len(Category));
	local text2 = itemName..string.rep(" ",textWidth2-string.len(itemName));
	print(string.format("%s %s Id : %4.0f, %6.0f %s, %8.2f %s", text1, text2, itemId, itemVolume, itemUnit, itemPrice, currency));
end;

function RealNumbersCommodityPrices:loadMap(name)
	local currency = "€";	-- or  "$" or "£"
    local textWidth = 40; 	-- text width in log file
	local textWidth2 = 50; 	-- text width in log file
    local iFillType = 0;
	local storeObject = 0;
	local Item = "Empty";
	local str = "Empty";
	local idx = 0;
	local price = 0;
	local pricePerHa = 0;
	local massScale = 1000;
	local randomness = 1; 			--1: on, 0: off
	local isDebug = RN.isDebug;  	-- Change to False when not debugging

	RNS.notRunYetRealNumbersCommodityPrices = true;
	RNS.upStartRealNumbersCommodityPrices = true;

	local gameMoneyUnit = g_i18n.moneyUnit;
	local volumeUnit = "L";

	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;
	RN.fieldPriceList = {};
	RN.fieldStatus = {};														-- For sale, For rent, Owned, Rented
	RN.sprayCost = {};
	RN.sprayPrice = {};
	RN2.pricePerLiter = {};
	RN2.massPerLiter = {};


	for k = 1, 300 do
		local randomFieldPriceFactor = 1 + randomness * 1 * (math.random()-0.5)/10;
		RN.fieldPriceList[k] = randomFieldPriceFactor * RN.pricePerHa;									-- list of purchase prices per hectare
		RN.fieldStatus[k] = " For sale";
	end;
	for k = 1, #RN.rentedFields do
		local randomFieldPriceFactor = 1 + randomness * 1 * (math.random()-0.5)/10;
		RN.fieldPriceList[RN.rentedFields[k]] = randomFieldPriceFactor * RN.rentPricePerHa; 			-- overwrite purchase prices with rent prices on rentable field
		RN.fieldStatus[RN.rentedFields[k]] = " For rent";
	end;


	print("\nFS19_RealLifeNumbers: RealNumbersCommodityPrices active\n")

-- Interest rate

	if isDebug then
		myPrint("Annual interest rate minus inflation", RN.annualLoanInterest,textWidth,"%");
		myPrint("Max loan", RN.loanMax,textWidth,currency);
		end;

-- Farmland

	g_farmlandManager.pricePerHa = RN.pricePerHa;  -- set new value value
	local pricePerHa = g_farmlandManager.pricePerHa;  -- read new value
	if isDebug then
		myPrint("Farmland purchase price per ha", pricePerHa,textWidth,currency.."/ha");
		myPrint("Farmland rent price per ha", RN.rentPricePerHa,textWidth,currency.."/ha");
		print(" ");
	end;

--	local fillTypeCategoryGroup = g_currentMission.fillTypeManager:getFillTypesByCategoryNames("FARMSILO");
--	for i, v in pairs(g_currentMission.fillTypeManager.fillTypes) do
	local fillTypeName = RN.commodityName;
	for i, fillType in pairsByKeys(fillTypeName) do
		randomPriceFactor = 1 + randomness * RN.commodityPriceVariation * (math.random()-0.5)/100;
		local iFillType = g_currentMission.fillTypeManager:getFillTypeIndexByName(fillType);
		if iFillType ~= nil then		-- do only if the fillType is included in the map?

			local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--			print(fillName);	-- uncomment for debug only
			RN2.pricePerLiter[fillName] = randomPriceFactor * g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter;
			g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = RN2.pricePerLiter[fillName];
			g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice  = RN2.pricePerLiter[fillName];
			g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = RN2.pricePerLiter[fillName];
			RN2.massPerLiter[fillName] = massScale * g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter;
			if RN.commodityName[fillName] ~= nil then		-- the fill type is defined in the mod
				local price = 0;
				if fillName == "HERBICIDE" then
					price = RN.commodityDensity[fillName] * RN.commodityPricePer100kg[fillName] / (RN.herbicideDilutionFactor * 100); -- price/L
				elseif fillName == "LIQUIDFERTILIZER" then
					price = RN.commodityDensity[fillName] * RN.commodityPricePer100kg[fillName] / (RN.liqfertDilutionFactor * 100); -- price/L
				else
					price = RN.commodityDensity[fillName] * RN.commodityPricePer100kg[fillName] / 100; -- price/L
				end;
				g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter 	 = randomPriceFactor * price;
				g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice  = randomPriceFactor * price;
				g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = randomPriceFactor * price;
				g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = RN.commodityDensity[fillName]/massScale; --T/L
				RN2.pricePerLiter[fillName] = randomPriceFactor * price;
				RN2.massPerLiter[fillName] = RN.commodityDensity[fillName];
			end;

			if not(string.find(fillName, "DRY") or string.find(fillName, "WET") or string.find(fillName, "WINDROW") or string.find(fillName, "FERMENTED")) then

				if isDebug then
					myPrint(fillName.." fillTypeIndex",iFillType,textWidth," ");
					myPrintFloat(fillName.." massPerLiter",RN2.massPerLiter[fillName],textWidth," kg/L");
					myPrintFloat("RandomPriceFactor",randomPriceFactor,textWidth," ");
					if fillName == "HERBICIDE" then
						myPrintFloat(fillName.." price (diluted)",1000 * RN2.pricePerLiter[fillName],textWidth,currency.."/1000 L");
					elseif fillName == "LIQUIDFERTILIZER" then
						myPrintFloat(fillName.." price (diluted)",1000 * RN2.pricePerLiter[fillName],textWidth,currency.."/1000 L");
					else
						myPrintFloat(fillName.." price",1000 * RN2.pricePerLiter[fillName],textWidth,currency.."/1000 L");
					end;
					print(" ");
				end;
			end;
		end;
	end;

--BIGBAGS

	if g_storeManager.items ~= nil then
		print("\nStore items of commodity types\n")
		for k,items in pairs(g_storeManager.items) do
			local itemId = items.id;
			local itemName = items.name;
			local itemCategory = items.categoryName;
			local itemPrice = items.price;
			if itemCategory == "BIGBAGS" then
--				print_r(items);
				local specs = items.specs;
				local capacity = specs.capacity;
				local fillType = specs.fillTypes;
				if fillType.fillTypeNames ~= nil then
					local fillName = string.upper(fillType.fillTypeNames);
					local cap1 = capacity[1];
					local cap11 = cap1[1];
					local itemVolume = cap11.capacity;
					local itemUnit = volumeUnit;
					randomPriceFactor = 1 + randomness * RN.commodityPriceVariation * (math.random()-0.5)/100;
					if RN.commodityDensity[fillName] ~= nil then
						items.price = randomPriceFactor * itemVolume * RN.commodityDensity[fillName] * RN.commodityPricePer100kg[fillName]/100;
					end;
					myPrintShopInfo(itemCategory, 9, itemName, 40, itemId, itemVolume, itemUnit, items.price, currency);
--					print_r(items);
				end;
			end;
		end;
		print(" ");

--BBPAL

		for k,items in pairs(g_storeManager.items) do
			local itemId = items.id;
			local itemName = items.name;
			local itemCategory = items.categoryName;
			local itemPrice = items.price;
			if itemCategory == "BBPAL" then
--				print_r(items);
				local specs = items.specs;
				local capacity = specs.capacity;
				local fillType = specs.fillTypes;
				if fillType.fillTypeNames ~= nil then
					local fillName = string.upper(fillType.fillTypeNames);
					local cap1 = capacity[1];
					local cap11 = cap1[1];
					local itemVolume = cap11.capacity;
					local itemUnit = volumeUnit;
					randomPriceFactor = 1 + randomness * RN.commodityPriceVariation * (math.random()-0.5)/100;
					if RN.commodityDensity[fillName] ~= nil then
						items.price = randomPriceFactor * itemVolume * RN.commodityDensity[fillName] * RN.commodityPricePer100kg[fillName]/100;
					end;
					myPrintShopInfo(itemCategory, 9, itemName, 40, itemId, itemVolume, itemUnit, items.price, currency);
--					print_r(items);
				end;
			end;
		end;
		print(" ");

--PALLETS

		for k,items in pairs(g_storeManager.items) do

			local itemId = items.id;
			local itemName = items.name;
			local customEnvironment = items.customEnvironment;
			local itemCategory = items.categoryName;
			local itemPrice = items.price;
			local fillName = " ";
			if itemCategory == "PALLETS" then
--				print_r(items);
--				print("itemName : "..itemName);
				local specs = items.specs;
				local capacity = specs.capacity;
				local fillType = specs.fillTypes;
				local fuel = specs.fuel;
				local fillUnits = fuel.fillUnits[1];
				if fillType.fillTypeNames ~= nil then
					fillName = string.upper(fillType.fillTypeNames);
				elseif fillType.categoryNames == "bulk" then
					fillName = "BULK";
				end;
				
				if fillName ~= nil then
					local dilutionFactor = 1;
--					fillName = string.upper(fillType.fillTypeNames);
--					print("fillName : "..fillName);
					if fillName == "LIQUIDFERTILIZER" then
						dilutionFactor = 1/RN.liqfertDilutionFactor;
					end;
					if fillName == "HERBICIDE" then
						dilutionFactor = 1/RN.herbicideDilutionFactor;
					end;
					local cap1 = capacity[1];
					if cap1 ~= nil then		
						local cap11 = cap1[1];

--RealisticSeeder mod

						if string.find(fillName, "SEED_") ~= nil then
							if RN.commoditySeedVolumePerPallet[fillName] ~= nil then
								cap11.capacity = RN.commoditySeedVolumePerPallet[fillName];
								cap11.fillLevel = cap11.capacity;
								cap11.startFillLevel = cap11.capacity;
								RN.seedTypesInMod[fillName] = fillName;
								items.canBeSold = RN.seedPalletsCanSell;
								
								fillUnits[1].capacity = cap11.capacity;
							end;
						end;

						local itemVolume = cap11.capacity;
						local itemUnit = volumeUnit;
						randomPriceFactor = 1 + randomness * RN.commodityPriceVariation * (math.random()-0.5)/100;
						if fillName == "TREESAPLINGS" then
							items.price = randomPriceFactor * itemVolume * RN.treeSaplingsUnitPrice;
						elseif fillName == "POPLAR" then
							items.price = randomPriceFactor * itemVolume * RN.seedDensity.POPLAR * RN.seedPricePer100kg.POPLAR/100;
						elseif  fillName == "SUGARCANE" then
							items.price = randomPriceFactor * itemVolume * RN.seedDensity.SUGARCANE * RN.seedPricePer100kg.SUGARCANE/100;
						elseif  fillName == "EGG" then
							items.price = randomPriceFactor * itemVolume * RN.eggContainerPricePerLiter;
						elseif  fillName == "WOOL" then
							items.price = randomPriceFactor * itemVolume * RN.woolContainerPricePerLiter;
						elseif RN.commodityDensity[fillName] ~= nil then
							items.price = dilutionFactor *randomPriceFactor * itemVolume * RN.commodityDensity[fillName] * RN.commodityPricePer100kg[fillName]/100;
						end;
						if customEnvironment == "FS19_PALOX" then
							items.price = randomPriceFactor * itemVolume * RN.paloxPricePerLiter;			
						end;
						if customEnvironment == "FS19_MaizePlus_forageExtension" then									
							if itemName == "Fillable Pallet" then
								items.price = randomPriceFactor * itemVolume * RN.paloxPricePerLiter;
							end;					
						end;
						if customEnvironment == "FS19_RM_PalletBox" then
							items.price = randomPriceFactor * itemVolume * RN.paloxPricePerLiter;
						end;		
						if itemName == "Palox FillTrigger" then
							items.price = randomPriceFactor * itemVolume * RN.paloxPricePerLiter;
						end;
						if itemName == "fillablePallet" then
							items.price = randomPriceFactor * itemVolume * RN.paloxPricePerLiter;
						end;
						if itemName == "Palox Shovel" then
							items.price = randomPriceFactor * itemVolume * RN.paloxPricePerLiter;
						end;
						if itemName == "Naus Potato Storage Box" then
							items.price = randomPriceFactor * itemVolume * RN.paloxPricePerLiter;
						end;					
				

						if fillName == "WOODBEAMS" then
							items.price = randomPriceFactor * itemVolume * RN.woodBeamsPricePerLiter;
						end;

						myPrintShopInfo(itemCategory, 9, itemName, 40, itemId, itemVolume, itemUnit, items.price, currency);
	--					print_r(items);
					end;
				end;
			end;
		end;
		print(" ");

-- BALES

		for k,items in pairs(g_storeManager.items) do
			local itemId = items.id;
			local itemName = items.name;
			str = string.upper(itemName);
			local itemCategory = items.categoryName;
			local itemPrice = items.price;
			if itemCategory == "BALES" then
--			print_r(items)
				local specs = items.specs;
				local capacity = specs.capacity;
--				local fillType = specs.fillTypes;
				local cap1 = capacity[1];
				local cap11 = cap1[1];
				randomPriceFactor = 1 + randomness * RN.commodityPriceVariation * (math.random()-0.5)/100;

				if string.find(str, "SQUARE") ~= nil or string.find(str, "QUADER") ~= nil  then
--					cap11.capacity = RN.commodityVolume.SQUAREBALE;
					if string.find(str, "STRAW") ~= nil or string.find(str, "STROH") ~= nil then
--						local strawSquareBaleMass = RN.commodityDensity.SQUAREBALE_WHEAT * RN.commodityVolume.SQUAREBALE_WHEAT;
						local strawSquareBaleMass = RN.commodityDensity.SQUAREBALE_WHEAT * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * strawSquareBaleMass * RN.commodityPricePer100kg.SQUAREBALE_WHEAT/100;
						for n = 1,8 do
							items.configurations.buyableBaleAmount[n].price = (n-1) * items.price;
						end;
					end;
					if string.find(str, "HAY") ~= nil or string.find(str, "HEU") ~= nil then
--						local haySquareBaleMass = RN.commodityDensity.SQUAREBALE * RN.commodityVolume.SQUAREBALE;
						local haySquareBaleMass = RN.commodityDensity.SQUAREBALE_DRYGRASS * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * haySquareBaleMass * RN.commodityPricePer100kg.SQUAREBALE_DRYGRASS/100;
						for n = 1,8 do
							items.configurations.buyableBaleAmount[n].price = (n-1) * items.price;
						end;
					end;
					if string.find(str, "SILAGE") ~= nil then
--						local silageSquareBaleMass = RN.commodityDensity.SQUAREBALE_SILAGE * RN.commodityVolume.SQUAREBALE_SILAGE;
						local silageSquareBaleMass = RN.commodityDensity.SQUAREBALE_SILAGE * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * silageSquareBaleMass * RN.commodityPricePer100kg.SQUAREBALE_SILAGE /100;
						for n = 1,8 do
							items.configurations.buyableBaleAmount[n].price = (n-1) * items.price;
						end;
					end;
					if string.find(str, "GRASS") ~= nil then
--						local silageSquareBaleMass = RN.commodityDensity.SQUAREBALE_SILAGE * RN.commodityVolume.SQUAREBALE_SILAGE;
						local grassSquareBaleMass = RN.commodityDensity.SQUAREBALE_GRASS * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * grassSquareBaleMass * RN.commodityPricePer100kg.SQUAREBALE_GRASS /100;
						for n = 1,8 do
							items.configurations.buyableBaleAmount[n].price = (n-1) * items.price;
						end;
					end;
					if string.find(str, "COTTON") ~= nil or string.find(str, "BAUMWOLLE") ~= nil then
						local cottonSquareBaleMass = RN.commodityDensity.SQUAREBALE_COTTON * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * cottonSquareBaleMass * RN.commodityPricePer100kg.SQUAREBALE_COTTON/100;
					end;
				elseif string.find(str, "ROUND") ~= nil or string.find(str, "RUND") ~= nil then
--					cap11.capacity = RN.commodityVolume.ROUNDBALE;
					if string.find(str, "STRAW") ~= nil or string.find(str, "STROH") ~= nil then
--						local strawRoundBaleMass = RN.commodityDensity.ROUNDBALE_WHEAT * RN.commodityVolume.ROUNDBALE_WHEAT;
						local strawRoundBaleMass = RN.commodityDensity.ROUNDBALE_WHEAT * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * strawRoundBaleMass * RN.commodityPricePer100kg.ROUNDBALE_WHEAT/100;
						for n = 1,8 do
							items.configurations.buyableBaleAmount[n].price = (n-1) * items.price;
						end;
					end;
					if string.find(str, "HAY") ~= nil or string.find(str, "HEU") ~= nil then
--						local hayRoundBaleMass = RN.commodityDensity.ROUNDBALE_DRYGRASS * RN.commodityVolume.ROUNDBALE_DRYGRASS;
						local hayRoundBaleMass = RN.commodityDensity.ROUNDBALE_DRYGRASS * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * hayRoundBaleMass * RN.commodityPricePer100kg.ROUNDBALE_DRYGRASS/100;
						for n = 1,8 do
							items.configurations.buyableBaleAmount[n].price = (n-1) * items.price;
						end;
					end;
					if string.find(str, "SILAGE") ~= nil then
--						local silageRoundBaleMass = RN.commodityDensity.ROUNDBALE * RN.commodityVolume.ROUNDBALE;
						local silageRoundBaleMass = RN.commodityDensity.ROUNDBALE * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * silageRoundBaleMass * RN.commodityPricePer100kg.ROUNDBALE/100;
						for n = 1,8 do
							items.configurations.buyableBaleAmount[n].price = (n-1) * items.price;
						end;
					end;
					if string.find(str, "GRASS") ~= nil then
--						local silageRoundBaleMass = RN.commodityDensity.ROUNDBALE * RN.commodityVolume.ROUNDBALE;
						local grassRoundBaleMass = RN.commodityDensity.ROUNDBALE_GRASS * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * grassRoundBaleMass * RN.commodityPricePer100kg.ROUNDBALE_GRASS/100;
						for n = 1,8 do
							items.configurations.buyableBaleAmount[n].price = (n-1) * items.price;
						end;
					end;
					if string.find(str, "CCM") ~= nil or string.find(str, "CCM") ~= nil then
--						local hayRoundBaleMass = RN.commodityDensity.ROUNDBALE_DRYGRASS * RN.commodityVolume.ROUNDBALE_DRYGRASS;
						local CCMRoundBaleMass = RN.commodityDensity.CCM * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * CCMRoundBaleMass * RN.commodityPricePer100kg.CCM/100;
						for n = 1,8 do
							items.configurations.buyableBaleAmount[n].price = (n-1) * items.price;
						end;
					end;

					if string.find(str, "COTTON") ~= nil or string.find(str, "BAUMWOLLE") ~= nil then
						local cottonSquareBaleMass = RN.commodityDensity.SQUAREBALE_COTTON * cap11.capacity;
						items.price = 1.1 * randomPriceFactor * cottonSquareBaleMass * RN.commodityPricePer100kg.SQUAREBALE_COTTON/100;
					end;

				end;
				if string.find(str, "COTTON") ~= nil or string.find(str, "BAUMWOLLE") ~= nil then
					local cottonSquareBaleMass = RN.commodityDensity.SQUAREBALE_COTTON * cap11.capacity;
					items.price = 1.1 * randomPriceFactor * cottonSquareBaleMass * RN.commodityPricePer100kg.SQUAREBALE_COTTON/100;
				end;
				local itemVolume = cap11.capacity;
				local itemUnit = volumeUnit;
				myPrintShopInfo(itemCategory, 9, itemName, 40, itemId, itemVolume, itemUnit, items.price, currency);
--[[
				if itemName ~= "Cotton" or itemName ~= "Baumwolle" then
					for n = 1,8 do
						items.configurations.buyableBaleAmount[n].price = (n-1) * items.price;
					end;
				end;
]]--
			end;
		end;
	end;
	print(" ");

end;


function RealNumbersCommodityPrices:keyEvent(unicode, sym, modifier, isDown)
	local currency = "€";	-- or  "$" or "£"
    local textWidth = 40; 	-- text width in log file

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_a) then
		print("\nlAlt-ra pressed: RealNumbersCommodityPrices\n");

		myPrint("Current number of cows",RN.numberOfCows,textWidth," ");
		myPrint("Annual upkeep: cows",RN.annualUpkeep["COW"],textWidth,currency.."/year");
		print(" ");
		if g_seasons.animals.animalManager.typeToAnimal["CALF"] ~= nil then
			myPrint("Current number of calves",RN.numberOfCalves,textWidth," ");
			myPrint("Annual upkeep: calves",RN.annualUpkeep["CALF"],textWidth,currency.."/year");
			print(" ");
		end;
		myPrint("Current number of pigs",RN.numberOfPigs,textWidth," ");
		myPrint("Annual upkeep: pigs",RN.annualUpkeep["PIG"],textWidth,currency.."/year");
		print(" ");
		myPrint("Current number of sheep",RN.numberOfSheep,textWidth," ");
		myPrint("Annual upkeep: sheep",RN.annualUpkeep["SHEEP"],textWidth,currency.."/year");
		print(" ");
		if g_seasons.animals.animalManager.typeToAnimal["GOAT"] ~= nil then
			myPrint("Current number of goats",RN.numberOfGoats,textWidth," ");
			myPrint("Annual upkeep: goats",RN.annualUpkeep["GOAT"],textWidth,currency.."/year");
			print(" ");
		end;
		myPrint("Current number of chickens",RN.numberOfChickens,textWidth," ");
		myPrint("Annual upkeep: chickens",RN.annualUpkeep["CHICKEN"],textWidth,currency.."/year");
		print(" ");
		if g_seasons.animals.animalManager.typeToAnimal["DUCK"] ~= nil then
			myPrint("Current number of ducks",RN.numberOfGoats,textWidth," ");
			myPrint("Annual upkeep: ducks",RN.annualUpkeep["DUCK"],textWidth,currency.."/year");
			print(" ");
		end;
		myPrint("Current number of horses",RN.numberOfHorses,textWidth," ");
		myPrint("Annual upkeep: horses",RN.annualUpkeep["HORSE"],textWidth,currency.."/year");
		print(" ");
		
		print("\nRequired hectares for each feed");
		print("\nBased on number of animals defined in RealNumbersAnnualFeedPrediction.lua\n")
		for fillName,feedArea in pairs(RN.totalFeedHectares) do
			if feedArea > 0 then
				myPrintFloat(tostring(fillName),feedArea,textWidth," ha");
			end;
		end;
		print(" ");
		
--[[
-- Adjust seed pallet volumes
--		local jj = 0;
		for k,item in pairs(g_currentMission.vehicles) do
			if item.typeName == "FS19_realisticSeeder.realisticSeederPallet" then
				local iFillType = item.spec_fillUnit.fillUnits[1].fillType;
				local palletVolume = item.spec_fillUnit.fillUnits[1].capacity;
				local seedName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--				jj = jj + 1;
				RN.seedTypesInMod[seedName] = seedName;
				if palletVolume ~= nil then
					print(seedName.." : pallet volume = "..palletVolume);
				else
					print(seedName.." : pallet volume is nil");
				end;
--				print_r(item.spec_fillUnit.fillUnits)
				item.spec_fillUnit.fillUnits[1].capacity = RN.commoditySeedVolumePerPallet[seedName];
				item.spec_fillUnit.fillUnits[1].startFillLevel = RN.commoditySeedVolumePerPallet[seedName];
				if item.spec_fillUnit.fillUnits[1].capacity < item.spec_fillUnit.fillUnits[1].fillLevel then
					item.spec_fillUnit.fillUnits[1].fillLevel = item.spec_fillUnit.fillUnits[1].capacity;
				end;
				local newPalletVolume = item.spec_fillUnit.fillUnits[1].capacity;
				if newPalletVolume ~= nil then
					print(seedName.." : pallet volume = "..newPalletVolume);
				else
					print(seedName.." : pallet volume is nil");
				end;
			end;
		end;
--]]
	end;
end;

function RealNumbersCommodityPrices:update(dt)
	local minute = g_currentMission.environment.currentMinute;
	local runMinute = minute % 10; -- remainder
	local massScale = 1000;
	
-- Adjust seed pallet volumes

			for k,item in pairs(g_currentMission.vehicles) do
				if item.typeName == "FS19_realisticSeeder.realisticSeederPallet" then
					local iFillType = item.spec_fillUnit.fillUnits[1].fillType;
					local palletVolume = item.spec_fillUnit.fillUnits[1].capacity;
					local fillVolume = item.spec_fillUnit.fillUnits[1].fillLevel;
					local seedName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name)	
					item.price = 0.8 * fillVolume * RN.commodityDensity[seedName] * RN.commodityPricePer100kg[seedName]/100;
					item.spec_fillUnit.fillUnits[1].capacity = RN.commoditySeedVolumePerPallet[seedName];
					item.spec_fillUnit.fillUnits[1].startFillLevel = RN.commoditySeedVolumePerPallet[seedName];
					if item.spec_fillUnit.fillUnits[1].capacity < item.spec_fillUnit.fillUnits[1].fillLevel then
						item.spec_fillUnit.fillUnits[1].fillLevel = item.spec_fillUnit.fillUnits[1].capacity;
					end;
				end;
			end;



			
	if runMinute ~= 4 then RNS.notRunYetRealNumbersCommodityPrices = true; end;
	if runMinute == 4 or RNS.upStartRealNumbersCommodityPrices then
		if RNS.notRunYetRealNumbersCommodityPrices then

--			print("RealNumbersCommodityPrices:update"); -- comment out when not debugging

-- update fillType prices

	local fillTypeName = RN.commodityName;
	for i, fillType in pairsByKeys(fillTypeName) do
--		randomPriceFactor = 1 + randomness * RN.commodityPriceVariation * (math.random()-0.5)/100;
		local randomPriceFactor = 1;
		local iFillType = g_currentMission.fillTypeManager:getFillTypeIndexByName(fillType);
		if iFillType ~= nil then		-- do only if the fillType is included in the map?

			local fillName = tostring(g_currentMission.fillTypeManager.fillTypes[iFillType].name);
--			print(fillName);	-- uncomment for debug only
			RN2.pricePerLiter[fillName] = randomPriceFactor * g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter;
			g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = RN2.pricePerLiter[fillName];
			g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice  = RN2.pricePerLiter[fillName];
			g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = RN2.pricePerLiter[fillName];
			RN2.massPerLiter[fillName] = massScale * g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter;
			if RN.commodityName[fillName] ~= nil then		-- the fill type is defined in the mod
				local price = 0;
				if fillName == "HERBICIDE" then
					price = RN.commodityDensity[fillName] * RN.commodityPricePer100kg[fillName] / (RN.herbicideDilutionFactor * 100); -- price/L
				elseif fillName == "LIQUIDFERTILIZER" then
					price = RN.commodityDensity[fillName] * RN.commodityPricePer100kg[fillName] / (RN.liqfertDilutionFactor * 100); -- price/L
				else
					price = RN.commodityDensity[fillName] * RN.commodityPricePer100kg[fillName] / 100; -- price/L
				end;
				g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = randomPriceFactor * price;
				g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice  = randomPriceFactor * price;
				g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = randomPriceFactor * price;
				g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = RN.commodityDensity[fillName]/massScale; --T/L
				RN2.pricePerLiter[fillName] = randomPriceFactor * price;
				RN2.massPerLiter[fillName] = RN.commodityDensity[fillName];
			end;
		end;
	end;



-- set field prices

			RN.currentDay = g_currentMission.environment.currentDay;
			RN.gameDayofYear = math.fmod(RN.currentDay + RNS.daysPerSeason * 2/3,RN.gameDaysPerYear);
			if RN.gameDayofYear == 0 then RN.gameDayofYear = RN.gameDaysPerYear; end;

			RN.rentDaysLeft = RN.gameDayOfYearRentTerminates - RN.gameDayofYear;
			if RN.rentDaysLeft < 0 then RN.rentDaysLeft = RN.gameDaysPerYear + RN.rentDaysLeft; end;
			RN.rentYearFraction = RN.rentDaysLeft/RN.gameDaysPerYear;



			if g_fieldManager.fields ~= nil then
				g_farmlandManager.pricePerHa = RN.pricePerHa;   -- set new value value
				local randomness = 1;							-- set to zero for no fluctuation, set to 1 for +/- 5% fluctuation
				local isLastDayOfRent = false;
				if RN.rentDaysLeft == 0 then    				-- this is the end of the rent year
					isLastDayOfRent = true;
		--			print("Rent pay day");
				end;

				for k,field in pairs(g_fieldManager.fields) do
					local farmland = field.farmland;
					local farmlandArea = farmland.areaInHa;
					local farmlandId = farmland.id;
		--			local randomFieldPriceFactor = 1 + randomness * 1 * (math.random()-0.5)/10;
					farmland.price = RN.fieldPriceList[farmlandId] * farmlandArea;
					for n = 1,#RN.rentedFields do
						if farmlandId == RN.rentedFields[n] then
							if isLastDayOfRent then 						-- Discontinue field rent contract at LastDayOfRent
								farmland.isOwned = false;
								field.mapHotspot.textBold = false;
								g_farmlandManager.farmlandMapping[farmlandId] = 0;
							end;
							farmland.price = RN.rentYearFraction * farmland.price;
						end;
					end;
					local fieldId = field.fieldId;
					if field.fieldArea < 0.15 then
						field.fieldArea = farmlandArea;		-- if field area is set to a very low value it is reset to the farmland area
					end;
				end;
			end;

-- Value of owned equipment and calculation of maintenance and equipment insurance

			RN.accumulatedValue = 0;
			local itemBaseMaintenanceCost = 0;
			local itemMaintenanceCost = 0;
			RN.vehicleRunningCost = 0;
			if g_currentMission.vehicles ~= nil then
				for k,items in pairs(g_currentMission.vehicles) do
					if items.ownerFarmId == 1 then
						RN.accumulatedValue = RN.accumulatedValue + items.price;
						itemBaseMaintenanceCost = RN.maintenanceCostPercentage * items.price/100;
						hoursPerDay = items.operatingTime/(3600000 * RN.currentDay);
						local itemExtraMaintenanceCost = 0;
						if hoursPerDay > 3 then
							itemExtraMaintenanceCost = itemBaseMaintenanceCost * RN.heavyUseMaintenanceFactor;
						end;
						itemMaintenanceCost = itemBaseMaintenanceCost + itemExtraMaintenanceCost;
						RN.vehicleRunningCost = RN.vehicleRunningCost + itemMaintenanceCost;
					end;
				end;
			end;
			RN.equipmentInsurance = RN.accumulatedValue * RN.equipmentInsurancePercentage/100
			RN.vehicleRunningCost = RN.vehicleRunningCost + RN.equipmentInsurance;

		-- Value of owned placeables

			RN.accumulatedValuePlaceables = 0;
			if g_currentMission.placeables ~= nil then
				for k,items in pairs(g_currentMission.placeables) do
					if items.ownerFarmId == 1 then
						RN.accumulatedValuePlaceables = RN.accumulatedValuePlaceables + items.price;
					end;
				end;
			end;
			RN.propertyMaintenance = RN.accumulatedValuePlaceables * RN.propertyMaintenanceCostPercentage/100;

			local farmId = 0;
			if g_currentMission:getIsClient() then
				farmId = g_currentMission.player.farmId;
			end;

-- Number of animal types and upkeep cost

			RN.numberOfCows 	= 0;
			RN.numberOfPigs 	= 0;
			RN.numberOfSheep 	= 0;
			RN.numberOfChickens = 0;
			RN.numberOfHorses 	= 0;
			RN.numberOfCalves 	= 0;
			RN.numberOfGoats 	= 0;
			RN.numberOfDucks 	= 0;
			

			
			for _,husbandry in pairs(g_currentMission.husbandries) do
				local penOfCows 	= 0;
				local penOfPigs 	= 0;
				local penOfSheep 	= 0;
				local penOfChickens = 0;
				local penOfHorses 	= 0;
				local penOfCalves 	= 0;
				local penOfGoats 	= 0;
				local penOfDucks 	= 0;
				local animalType = husbandry.modulesByName.animals.animalType;
				local ownerId = husbandry.modulesByName.animals.owner.ownerFarmId;
				if ownerId == farmId then
					for k,v in pairs(husbandry.modulesByName.animals.animals) do
						if k > 0 then
							if animalType == "COW" 		then penOfCows 		= tonumber(k); end;
							if animalType == "PIG" 		then penOfPigs 		= tonumber(k); end;
							if animalType == "SHEEP" 	then penOfSheep 	= tonumber(k); end;
							if animalType == "CHICKEN" 	then penOfChickens 	= tonumber(k); end;
							if animalType == "HORSE" 	then penOfHorses 	= tonumber(k); end;
							if animalType == "CALF" 	then penOfCalves 	= tonumber(k); end;
							if animalType == "GOAT" 	then penOfGoats 	= tonumber(k); end;
							if animalType == "DUCK" 	then penOfDucks 	= tonumber(k); end;
						else
							if animalType == "COW" 		then penOfCows 		= 0; end;
							if animalType == "PIG" 		then penOfPigs 		= 0; end;
							if animalType == "SHEEP" 	then penOfSheep 	= 0; end;
							if animalType == "CHICKEN" 	then penOfChickens 	= 0; end;
							if animalType == "HORSE" 	then penOfHorses 	= 0; end;
							if animalType == "CALF" 	then penOfCalves 	= 0; end;
							if animalType == "GOAT" 	then penOfGoats 	= 0; end;
							if animalType == "DUCK" 	then penOfDucks 	= 0; end;
						end;
					end;
				end;
				RN.numberOfCows 	= RN.numberOfCows 		+ penOfCows;
				RN.numberOfPigs 	= RN.numberOfPigs 		+ penOfPigs;
				RN.numberOfSheep 	= RN.numberOfSheep 		+ penOfSheep;
				RN.numberOfChickens = RN.numberOfChickens 	+ penOfChickens;
				RN.numberOfHorses 	= RN.numberOfHorses 	+ penOfHorses;
				RN.numberOfCalves 	= RN.numberOfCalves 	+ penOfCalves;
				RN.numberOfGoats 	= RN.numberOfGoats 		+ penOfGoats;
				RN.numberOfDucks 	= RN.numberOfDucks 		+ penOfDucks;				
			end;

			RN.annualUpkeep["COW"] 		= RN.numberOfCows 		* RN.annualUpkeepPerAnimal["COW"];
			RN.annualUpkeep["PIG"] 		= RN.numberOfPigs 		* RN.annualUpkeepPerAnimal["PIG"];
			RN.annualUpkeep["SHEEP"] 	= RN.numberOfSheep 		* RN.annualUpkeepPerAnimal["SHEEP"];
			RN.annualUpkeep["CHICKEN"] 	= RN.numberOfChickens 	* RN.annualUpkeepPerAnimal["CHICKEN"];
			RN.annualUpkeep["HORSE"] 	= RN.numberOfHorses 	* RN.annualUpkeepPerAnimal["HORSE"];
			RN.annualUpkeep["CALF"] 	= RN.numberOfCalves 	* RN.annualUpkeepPerAnimal["CALF"];
			RN.annualUpkeep["GOAT"] 	= RN.numberOfGoats 		* RN.annualUpkeepPerAnimal["GOAT"];
			RN.annualUpkeep["DUCK"] 	= RN.numberOfDucks 		* RN.annualUpkeepPerAnimal["DUCK"];
			RN.totalAnimalUpkeep = RN.annualUpkeep["COW"] + RN.annualUpkeep["PIG"]
								+ RN.annualUpkeep["SHEEP"] + RN.annualUpkeep["CHICKEN"]
								+ RN.annualUpkeep["HORSE"] + RN.annualUpkeep["CALF"]
								+ RN.annualUpkeep["GOAT"] + RN.annualUpkeep["DUCK"];

-- set running, maintenance and upkeep costs

			if g_farmManager.farms ~= nil then
				for k,farm in pairs(g_farmManager.farms) do
					farm.loanAnnualInterestRate = RN.annualLoanInterest*360/RN.gameDaysPerYear;
					farm.loanMax = RN.loanMax;
					farm.stats.finances.vehicleRunningCost = -RN.vehicleRunningCost/RN.gameDaysPerYear;
					farm.stats.finances.propertyMaintenance = -RN.propertyMaintenance/RN.gameDaysPerYear;
					farm.stats.finances.animalUpkeep = -RN.totalAnimalUpkeep/RN.gameDaysPerYear;
					farm.stats.finances.other = -1000/RN.gameDaysPerYear;
				end;
			end;


-- set bale dimensions

			if g_baleTypeManager.squareBales ~= nil then
				for k,bale in pairs(g_baleTypeManager.squareBales) do
					bale.diameter = RN.squareBale.width;
					bale.width = RN.squareBale.width;
					bale.height = RN.squareBale.height;
					bale.length = RN.squareBale.length;
				end;
				g_baleTypeManager.defaultSquareBale.diameter = RN.squareBale.width;
				g_baleTypeManager.defaultSquareBale.width = RN.squareBale.width;
			end;

		--[[
		-- set bale dimensions

			if g_baleTypeManager.roundBales ~= nil then
				for k,bale in pairs(g_baleTypeManager.roundBales) do
					bale.diameter = RN.roundBale.diameter;
					bale.width = RN.roundBale.width;
					bale.height = RN.roundBale.width;
				end;
				g_baleTypeManager.defaultRoundBale.diameter = RN.roundBale.diameter;
				g_baleTypeManager.defaultRoundBale.width = RN.roundBale.width;
			end;

		-- reset purchased bales from 4000 L to the proper volumes for round bales and square bales, effectice only after game reload.
		-- for unknown reasons, shop bales spawn at 4000 L even if the shop volume is set to another value. This started with patch 1.4.

			if g_currentMission.loadItemsById ~= nil then
				for k,items in pairs(g_currentMission.loadItemsById) do
					if round(items.fillLevel) == 4000  then				-- added after version 1.2.1.0
						if items.baleDiameter ~= nil then items.fillLevel = RN.commodityVolume.ROUNDBALE; end;
						if items.baleLength ~= nil then items.fillLevel = RN.commodityVolume.SQUAREBALE; end;
					end;
				end;
			end;
		]]--

-- sets daily upkeep to zero
-- Maintenance is paid elsewhere

			if g_currentMission.shopController.ownedFarmItems ~= nil then
				for k,items in pairs(g_currentMission.shopController.ownedFarmItems) do
					if items.ownerFarmId == farmId then
						items.dailyUpkeep = 0;					-- paid based on total value of placeables
					end;
				end;
			end;

			if g_storeManager.items ~= nil then
				for k,items in pairs(g_storeManager.items) do
					items.dailyUpkeep = 0;						-- paid based on total value of placeables
				end;
			end;


--[[
			if g_storeManager.items ~= nil then
				for k,items in pairs(g_storeManager.items) do
					if items.allowLeasing then
						items.runningLeasingFactor = RN.DEFAULT_RUNNING_LEASING_FACTOR;
					end;
				end;
			end;

			EconomyManager.DEFAULT_RUNNING_LEASING_FACTOR = RN.DEFAULT_RUNNING_LEASING_FACTOR;
			EconomyManager.PER_DAY_LEASING_FACTOR = RN.PER_DAY_LEASING_FACTOR;
			EconomyManager.DEFAULT_LEASING_DEPOSIT_FACTOR = RN.DEFAULT_LEASING_DEPOSIT_FACTOR;
]]--

--[[
			if g_densityMapHeightManager.fillTypeNameToHeightType["SEMIDRY_GRASS_WINDROW"] ~= nil then
				g_densityMapHeightManager.fillTypeNameToHeightType["SEMIDRY_GRASS_WINDROW"].fillToGroundScale = 17;
			end;
			if g_densityMapHeightManager.fillTypeNameToHeightType["straw"] ~= nil then
				g_densityMapHeightManager.fillTypeNameToHeightType["straw"].fillToGroundScale = 17;
			end;
			if g_densityMapHeightManager.fillTypeNameToHeightType["grass_windrow"] ~= nil then
				g_densityMapHeightManager.fillTypeNameToHeightType["grass_windrow"].fillToGroundScale = 17;
			end;
			if g_densityMapHeightManager.fillTypeNameToHeightType["dryGrass_windrow"] ~= nil then
				g_densityMapHeightManager.fillTypeNameToHeightType["dryGrass_windrow"].fillToGroundScale = 17;
			end;
--]]

			local gameLevel = g_currentMission.missionInfo.economicDifficulty;
			EconomyManager.PRICE_MULTIPLIER[gameLevel] = RN.gameLevel.sellPriceMultiplier[gameLevel];
			EconomyManager.COST_MULTIPLIER[gameLevel] = RN.gameLevel.buyPriceMultiplier[gameLevel];
			EconomyManager.DIRECT_SELL_MULTIPLIER = RN.DIRECT_SELL_MULTIPLIER;

			PricingDynamics.AMP_DIST_LINEAR_UP 		= 1/2.000000;	-- original: 3.000000
			PricingDynamics.TREND_FALLING 			= 3.000000;
			PricingDynamics.TREND_CLIMBING 			= 2.000000;
			PricingDynamics.AMP_DIST_CONSTANT 		= 1.000000;
			PricingDynamics.AMP_DIST_LINEAR_DOWN 	= 1/3.000000;	-- original: 2.000000
			PricingDynamics.TREND_PLATEAU 			= 1.000000;
		end;
		RNS.notRunYetRealNumbersCommodityPrices = false;
		RNS.upStartRealNumbersCommodityPrices = false;
	end;

-- set original placeable upkeep to zero

end;
function RealNumbersCommodityPrices:draw()
end;
function RealNumbersCommodityPrices:deleteMap()
end;
function RealNumbersCommodityPrices:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersCommodityPrices);
