--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersCropProductionCost by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021


RealNumbersCropProductionCost = {};

function myPrintCropCost(crop, textWidth, unit, S1, S2, S3, S4, S5, S6, S7, S8)
	local text = crop..string.rep(" ",textWidth-string.len(crop))
	print(string.format("%s: %s %9.0f %9.0f %9.0f %9.0f %9.0f %9.0f %9.0f %9.0f", text, unit, S1, S2, S3, S4, S5, S6, S7, S8));
end;
function myPrintFieldWorkCost(crop, textWidth, unit, S1, S2, S3, S4, S5, S6, S7)
	local text = crop..string.rep(" ",textWidth-string.len(crop))
	print(string.format("%s: %s %9.0f %9.0f %9.0f %9.0f %9.0f %9.0f %9.0f", text, unit, S1, S2, S3, S4, S5, S6, S7));
end;
function RealNumbersCropProductionCost:loadMap()
	local currency = " ";
	local isDebug = RN.isDebug;
	local isDebug2 = false;
    local textWidth = 30;
    local textWidth2 = 27;
	local textWidth3 = 40;
	local grossIncome  = 0;
	local netIncome  = 0;
	local fieldWork  = 0;
	local productCostPerHa = 0.0000;
	local feedCostPer1000Liter = 0.0000;
	local feedBuyPricePer1000Liter = 0.0000;
	local Fert  = 0;
	local Lime  = 0;
	local Seed  = 0;
	local Herbicide  = 0;
	local Rent  = 0;
	local profit = 0;
	local natFertLime	= 0;
	local plowCost	= 0;
	local seederCost	= 0;
	local cultSeedRoll	= 0;
	local fertCost	= 0;
	local herbCost	= 0;
	local harvestCost	= 0;
	local fieldWorkCost = 0;

	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;

--[[
	RN.seeders					= {};
	RN.seeders.grain			= {"BARLEY","CANOLA", "MILLET", "MUSTARD", "OAT", "PEANUT", "PEAS", "POPPY", "RICE", "RYE", "SPELT", "SUDANGRASS", "TRITICALE", "WHEAT"};
	RN.seeders.rowcrop      	= {"ASPARAGUS", "BEAN", "BEANS", "BLACKBEANS", "CABBAGE", "CARROT", "COTTON", "LETTUCE", "MAIZE", "ONION", "REDCABBAGE","SORGHUM", "SOYBEAN", "SUGARBEET", "SUNFLOWER", "WHITECABBAGE"};
	RN.harvesters				= {};
	RN.harvesters.combine 		= {"BARLEY","CANOLA", "MILLET", "MUSTARD", "OAT", "PEANUT", "PEAS", "POPPY", "RICE", "RYE", "SOYBEAN", "SPELT", "TRITICALE", "WHEAT"};
	RN.harvesters.rowCrop 		= {"MAIZE", "SUNFLOWER", "SORGHUM"};
	RN.harvesters.vegetables	= {"ASPARAGUS", "BEAN", "BEANS", "BLACKBEANS", "CABBAGE", "CARROT", "LETTUCE", "ONION", "REDCABBAGE","SUGARBEET", "WHITECABBAGE"};
	RN.harvesters.forage 		= {"SUDANGRASS"};
]]--

	RN.fieldWorkCost.ASPARAGUS				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.BARLEY					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.BEAN					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.BEANS					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.BLACKBEANS				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.CABBAGE				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.CANOLA					= RN.fieldWorkCost.CANOLA;
	RN.fieldWorkCost.CARROT					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.CHAFF					= RN.fieldWorkCost.MAIZESILAGE;
	RN.fieldWorkCost.COTTON					= 0;
	RN.fieldWorkCost.CRANBERRY				= 0;
	RN.fieldWorkCost.FORAGE					= RN.fieldWorkCost.GRASS;
	RN.fieldWorkCost.HEMP					= 0;
	RN.fieldWorkCost.HOPS					= 0;
	RN.fieldWorkCost.INCARASE_GRASS			= RN.fieldWorkCost.GRASS;
	RN.fieldWorkCost.LETTUCE				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.MAIZE					= RN.fieldWorkCost.MAIZE;
	RN.fieldWorkCost.MAIZESLAGE				= RN.fieldWorkCost.MAIZESILAGE;
	RN.fieldWorkCost.MILLET					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.MUSTARD				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.OAT					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.OILSEEDRADISH			= RN.fieldWorkCost.GRASS;
	RN.fieldWorkCost.ONION					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.PEANUT					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.PEAS					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.POPLAR					= 0;
	RN.fieldWorkCost.POPPY					= 0;
	RN.fieldWorkCost.POTATO					= RN.fieldWorkCost.POTATO;
	RN.fieldWorkCost.REDCABBAGE				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.RICE					= 0;
	RN.fieldWorkCost.RYE					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.SORGHUM				= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.SOYBEAN				= RN.fieldWorkCost.SOYBEAN;
	RN.fieldWorkCost.SPELT					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.SUDANGRASS				= RN.fieldWorkCost.GRASS;
	RN.fieldWorkCost.SUGARBEET				= RN.fieldWorkCost.SUGARBEET;
	RN.fieldWorkCost.SUGARCANE				= RN.fieldWorkCost.SUGARCANE;
	RN.fieldWorkCost.SUNFLOWER				= RN.fieldWorkCost.SUNFLOWER;
	RN.fieldWorkCost.TOBACCO				= RN.fieldWorkCost.TOBACCO;
	RN.fieldWorkCost.TRITICALE				= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.WEED					= 0;
	RN.fieldWorkCost.WHEAT					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.WHITECABBAGE			= RN.fieldWorkCost.vegetable;

	RN.cropEstabCostPerHA					= {};

-- field work cost for each fruit type

	print("FS19_RealLifeNumbers: RealNumbersCropProductionCost active")
	print("\nField work cost\n");

	print(" ")
	print("                                        Nat Fert    Plow    Cultivate   Fert      Herb    Harvest  Field work")
	print(currency.."/Ha                                      Lime      costs     Seed      costs     costs     costs     Total    ")
	print(" ")


	for i,fruitName in ipairs(RN.sortedFruits) do
		if (fruitName ~= "WEED") then
			if RN.fruits[fruitName] ~= "not defined in RLN" then

--				print(fruitName.."    :    "..RN.fruits[fruitName]);

				natFertLime = RN.manureApplications[fruitName] * RN.fieldWorkCost.manureSpreader +
							  RN.slurryApplications[fruitName] * RN.fieldWorkCost.slurrySpreader +
							  RN.limeApplications[fruitName]   * RN.fieldWorkCost.limeSpreader;

				plowCost 	= RN.isPlowing[fruitName] * RN.fieldWorkCost.Plow;

				seederCost = 0;

				if RN.seederType[fruitName] == "SEEDERS" then
					seederCost = RN.fieldWorkCost.seedDrill;
				end;
				if RN.seederType[fruitName] == "PLANTERS" then
					seederCost = RN.fieldWorkCost.beetPlanter;
				end;
				if RN.seederType[fruitName] == "POTATOPLANTERS" then
					seederCost = RN.fieldWorkCost.potatoPlanter;
				end;

				cultSeedRoll = 0;
				if RN.isDirectSeeding[fruitName] == 1 then
					cultSeedRoll = seederCost;
				else
					cultSeedRoll = seederCost + RN.fieldWorkCost.discHarrow;
				end;

				fertCost	= RN.solidFertApplications[fruitName] * RN.fieldWorkCost.fertSpreader
							+ RN.liquidFertApplications[fruitName] * RN.fieldWorkCost.fertSpray;

				herbCost	= RN.herbicideApplications[fruitName] * RN.fieldWorkCost.herbicideSpray;

				harvestCost = 0;
				if RN.harvesterType[fruitName] == "HARVESTERS" then
					harvestCost = RN.fieldWorkCost.combineHarvest;
				end;
				if RN.harvesterType[fruitName] == "BEETHARVESTING" then
					harvestCost = RN.fieldWorkCost.beetHarvest;
				end;
				if RN.harvesterType[fruitName] == "POTATOHARVESTING" then
					harvestCost = RN.fieldWorkCost.potatoHarvest;
				end;

				if RN.harvesterType[fruitName] == "MOWERS" then
					harvestCost = RN.isBaling[fruitName] *  RN.equipment.equipmentCostPerHa["MOWERS"];
				end;
				if RN.harvesterType[fruitName] == "HAY" then
					harvestCost = RN.isBaling[fruitName] *  RN.equipment.equipmentCostPerHa["MOWERS"]
				end;



				local balerCost = 0;
				local windrowerCost = 0;
				local handlingCost = 0;

				if RN.isBaling[fruitName] ~= 0 then
					if RN.baleType[fruitName] == "SILAGE" then
						windrowerCost 	= RN.isBaling[fruitName] * RN.fieldWorkCost.WINDROWERS;
						if RN.equipment.isLeasing["SILAGEROUNDBALE"] then
							balerCost 		= RN.isBaling[fruitName] * RN.contractRatePerHa["SILAGEROUNDBALE"];
						else
							balerCost 		= RN.isBaling[fruitName] * RN.equipment.useOwnEquipCostPerHa["SILAGEROUNDBALE"];
						end;
						handlingCost = RN.isBaling[fruitName] * RN.balesPerHa.SILAGEROUNDBALE
										* (RN.equipment.stackingPerBale["SILAGEROUNDBALE"] + RN.equipment.movingPerBale["SILAGEROUNDBALE"]);
						harvestCost = harvestCost + windrowerCost + balerCost + handlingCost;
					elseif RN.baleType[fruitName] == "HAY" then
						windrowerCost 	= RN.isBaling[fruitName] * (RN.fieldWorkCost.WINDROWERS
																+ 3 * RN.fieldWorkCost.TEDDERS);
						if RN.equipment.isLeasing["DRYGRASSROUNDBALE"] then
							balerCost 		= RN.isBaling[fruitName] * RN.contractRatePerHa["DRYGRASSROUNDBALE"];
						else
							balerCost 		= RN.isBaling[fruitName] * RN.equipment.useOwnEquipCostPerHa["DRYGRASSROUNDBALE"];
						end;
						handlingCost = RN.isBaling[fruitName] * RN.balesPerHa.DRYGRASSROUNDBALE
										* (RN.equipment.stackingPerBale["DRYGRASSROUNDBALE"] + RN.equipment.movingPerBale["DRYGRASSROUNDBALE"]);
						harvestCost = harvestCost + windrowerCost + balerCost + handlingCost;
					end;
				end;

				if RN.harvesterType[fruitName] == "MOWERS" then
					fieldWorkCost = natFertLime + (plowCost + cultSeedRoll)/3 + fertCost + herbCost + harvestCost;
				else
					fieldWorkCost = natFertLime + plowCost + cultSeedRoll + fertCost + herbCost + harvestCost;
				end;
				RN.fieldWorkCost[fruitName] = fieldWorkCost;
				if not(string.find(fruitName, "DRY") or string.find(fruitName, "WET") or string.find(fruitName, "WINDROW") or string.find(fruitName, "FERMENTED")) then
					myPrintFieldWorkCost(fruitName, textWidth, currency.."/Ha", natFertLime, plowCost, cultSeedRoll, fertCost, herbCost, harvestCost, fieldWorkCost);
				end;
			end;
		end;
	end;



	print("\nCrop production cost\n");
	print(" ")
	print("                                          Gross     Supply     Net      Field     Field    Profit  Feed cost  Feed price")
	print(currency.."/Ha                                     income     costs     income     work      rent               "..currency.."/1000 L  "..currency.."/1000 L")
	print(" ")

	RN.costTotalPerHa = {};
--	RN.netIncomePerHa = {};

	for i,fruitName in ipairs(RN.sortedFruits) do
--		if RN.fruits[fruitName] ~= nil then
			if fruitName ~= "WEED" then

				if RN.cropPricePerHa[fruitName] ~= nil then
					grossIncome = RN.cropPricePerHa[fruitName];
				else
					grossIncome = 0.0;
				end;
				if RN.fieldWorkCost[fruitName] ~= nil then
					fieldWork = RN.fieldWorkCost[fruitName];
				else
					fieldWork = 0.0;
				end;
				Rent = RN.rentPricePerHa;

				if RN.productCostPerHa[fruitName] ~= nil then
					productCostPerHa = RN.productCostPerHa[fruitName];
					netIncome = grossIncome - productCostPerHa;
					RN.netIncomePerHa[fruitName] = netIncome;
				else
					productCostPerHa = 0.0;
					netIncome = grossIncome - productCostPerHa;
				end;


				if RN.cropBonusYieldLitersPerHa[fruitName] ~= nil then
					if RN.cropBonusYieldLitersPerHa[fruitName] ~= 0 then
						RN.feedCostPerLiter[fruitName] = (fieldWork + RN.productCostPerHa[fruitName])/RN.cropBonusYieldLitersPerHa[fruitName];
						feedCostPer1000Liter = 1000 * RN.feedCostPerLiter[fruitName];
						feedBuyPricePer1000Liter = RN.buyPriceScaleFactor * 1000 * RN.cropPricePerLiter[fruitName];
					end;
				else
					feedCostPer1000Liter = 0.0000;
					feedBuyPricePer1000Liter = 0.0000;
				end;

				local profit = netIncome - fieldWork - Rent;
				if not(string.find(fruitName, "DRY") or string.find(fruitName, "WET") or string.find(fruitName, "WINDROW") or string.find(fruitName, "FERMENTED")) then
					myPrintCropCost(fruitName, textWidth, currency.."/Ha", grossIncome, productCostPerHa, netIncome, fieldWork, Rent, profit, feedCostPer1000Liter, feedBuyPricePer1000Liter);
				end;	
			end;
--		end;
	end;
	print(" ")
end;

function RealNumbersCropProductionCost:keyEvent(unicode, sym, modifier, isDown)

	local textWidth = 30;
    local textWidth2 = 27;
	local textWidth3 = 40;
	local grossIncome  = 0;
	local netIncome  = 0;
	local fieldWork  = 0;
	local Fert  = 0;
	local Lime  = 0;
	local Seed  = 0;
	local Herbicide  = 0;
	local Rent  = 0;
	local profit = 0;
	local natFertLime	= 0;
	local plowCost	= 0;
	local seederCost	= 0;
	local cultSeedRoll	= 0;
	local fertCost	= 0;
	local herbCost	= 0;
	local harvestCost	= 0;
	local fieldWorkCost = 0;
	local productCostPerHa = 0.0000;
	local feedCostPer1000Liter = 0.0000;
	local feedBuyPricePer1000Liter = 0.0000;

	local isDebug = RN.isDebug;
	local currency = "€";	-- or  "$" or "£"
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;

--	local savegameDirectory = g_currentMission.missionInfo.savegameDirectory;	-- works only after savegame is present and not in multiplayer

--	if savegameDirectory ~= nil then   -- will not work in multiplayer so commented out

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_y) then

		local hour = g_currentMission.environment.currentHour;
		local minute = g_currentMission.environment.currentMinute;
		local money = g_currentMission.missionInfo.money;
		local economicDifficulty = g_currentMission.missionInfo.economicDifficulty;
		local currentDay = g_currentMission.environment.currentDay;
		local currentMap = tostring(g_currentMission.missionInfo.map.title.." "..g_currentMission.missionInfo.displayName);
		if isDebug then
			print("\nLeft Alt-ry pressed: RealNumbersCropProductionCost\n");
			if currentMap ~= nil then print("Map                   : "..currentMap); end;
			if money ~= nil then print("Money                 : "..money); end;
			if economicDifficulty ~=  nil then print("Economic difficulty   : "..economicDifficulty); end;
			print("Gamedays per year     : "..RN.gameDaysPerYear);
			if currentDay ~= nil then print("Current game day      : "..currentDay); end;
			if hour ~= nil or minute ~= nil then print("Time of day           : "..hour..":"..minute); end;
			print(" ");
		end;
--		if g_fruitTypeManager.fruitTypes ~= nil then
		if isDebug then print("\nCrop yield \n");end;
		for i,fruitName in ipairs(RN.sortedFruits) do
			myPrint(fruitName.." max yield",RN.cropBonusYieldLitersPerHa[fruitName],textWidth3," L/Ha");
		end;

		myPrint("Alfalfa silage max yield",RN.growth.alfalfaSilageNetVolumePerHa,textWidth3," L/Ha");
		myPrint("Clover silage max yield",RN.growth.cloverSilageNetVolumePerHa,textWidth3," L/Ha");
		myPrint("Grass silage max yield",RN.growth.grassSilageNetVolumePerHa,textWidth3," L/Ha");
		print(" ");
--		if isDebug then print("\nCrop income \n");end;
--		for i,fruitName in ipairs(RN.sortedFruits) do
--			myPrint(fruitName.." max income",RN.cropPricePerHa[fruitName],textWidth,currency.."/Ha");
--		end;

-- field work cost for each fruit type

		print("\nFS19_RealLifeNumbers: RealNumbersCropProductionCost active")
		print("\nField work cost\n");

		print(" ")
		print("                                        Nat Fert    Plow    Cultivate   Fert      Herb    Harvest  Field work")
		print(currency.."/Ha                                      Lime      costs     Seed      costs     costs     costs     Total    ")
		print(" ")

		print("\nCrop production cost\n");

		for i,fruitName in ipairs(RN.sortedFruits) do
			if (fruitName ~= "WEED") then
				if RN.fruits[fruitName] ~= "not defined in RLN" then

	--				print(fruitName.."    :    "..RN.fruits[fruitName]);

					natFertLime = RN.manureApplications[fruitName] * RN.fieldWorkCost.manureSpreader +
								  RN.slurryApplications[fruitName] * RN.fieldWorkCost.slurrySpreader +
								  RN.limeApplications[fruitName]   * RN.fieldWorkCost.limeSpreader;

					plowCost 	= RN.isPlowing[fruitName] * RN.fieldWorkCost.Plow;

					seederCost = 0;

					if RN.seederType[fruitName] == "SEEDERS" then
						seederCost = RN.fieldWorkCost.seedDrill;
					end;
					if RN.seederType[fruitName] == "PLANTERS" then
						seederCost = RN.fieldWorkCost.beetPlanter;
					end;
					if RN.seederType[fruitName] == "POTATOPLANTERS" then
						seederCost = RN.fieldWorkCost.potatoPlanter;
					end;

					cultSeedRoll = 0;
					if RN.isDirectSeeding[fruitName] == 1 then
						cultSeedRoll = seederCost;
					else
						cultSeedRoll = seederCost + RN.fieldWorkCost.discHarrow;
					end;

					fertCost	= RN.solidFertApplications[fruitName] * RN.fieldWorkCost.fertSpreader
								+ RN.liquidFertApplications[fruitName] * RN.fieldWorkCost.fertSpray;

					herbCost	= RN.herbicideApplications[fruitName] * RN.fieldWorkCost.herbicideSpray;

					harvestCost = 0;

--[[
					if RN.harvesterType[fruitName] == "HARVESTERS" then
						if RN.isLeasing["HARVESTERS"] then
							harvestCost = RN.contractRatePerHa["HARVESTERS"];
						else
							harvestCost = RN.equipment.equipmentCostPerHa["HARVESTERS"];
						end;
					end;
					if RN.harvesterType[fruitName] == "BEETHARVESTING" then
						if RN.isLeasing["BEETHARVESTING"] then
							harvestCost = RN.contractRatePerHa["BEETHARVESTING"];
						else
							harvestCost = RN.equipment.equipmentCostPerHa["BEETHARVESTING"];
						end;
					end;
					if RN.harvesterType[fruitName] == "POTATOHARVESTING" then
						if RN.isLeasing["POTATOHARVESTING"] then
							harvestCost = RN.contractRatePerHa["POTATOHARVESTING"];
						else
							harvestCost = RN.equipment.equipmentCostPerHa["POTATOHARVESTING"];
						end;
					end;
]]--
					harvestCost = 0;
					if RN.harvesterType[fruitName] == "HARVESTERS" then
						harvestCost = RN.fieldWorkCost.combineHarvest;
					end;
					if RN.harvesterType[fruitName] == "BEETHARVESTING" then
						harvestCost = RN.fieldWorkCost.beetHarvest;
					end;
					if RN.harvesterType[fruitName] == "POTATOHARVESTING" then
						harvestCost = RN.fieldWorkCost.potatoHarvest;
					end;


					if RN.harvesterType[fruitName] == "MOWERS" then
						harvestCost = RN.equipment.equipmentCostPerHa["MOWERS"]
									+ RN.equipment.equipmentCostPerHa["WINDROWERS"]
									+ RN.equipment.equipmentCostPerHa["DRYGRASSROUNDBALE"]
									+ RN.equipment.useOwnEquipCostPerHa["SILAGEROUNDBALE"];
					end;
					if RN.harvesterType[fruitName] == "HAY" then
						harvestCost = RN.equipment.equipmentCostPerHa["MOWERS"]
									+ RN.equipment.equipmentCostPerHa["WINDROWERS"]
									+ RN.equipment.equipmentCostPerHa["TEDDERS"]
									+ RN.equipment.equipmentCostPerHa["DRYGRASSROUNDBALE"]
									+ RN.equipment.useOwnEquipCostPerHa["DRYGRASSROUNDBALE"];
					end;

--					fieldWorkCost = natFertLime + plowCost + cultSeedRoll + fertCost + herbCost + harvestCost;
--					RN.fieldWorkCost[fruitName] = fieldWorkCost;
--					myPrintFieldWorkCost(fruitName, textWidth, currency.."/Ha", natFertLime, plowCost, cultSeedRoll, fertCost, herbCost, harvestCost, fieldWorkCost)

					local balerCost = 0;
					local windrowerCost = 0;

					if RN.isBaling[fruitName] ~= 0 then
						windrowerCost = RN.isBaling[fruitName] * RN.forageCost.raking;
						balerCost = RN.isBaling[fruitName] * RN.forageCost.roundBaling;
						harvestCost = harvestCost + windrowerCost + balerCost;
					end;

					if RN.harvesterType[fruitName] == "MOWERS" then
						fieldWorkCost = natFertLime + (plowCost + cultSeedRoll)/3 + fertCost + herbCost + harvestCost;
					else
						fieldWorkCost = natFertLime + plowCost + cultSeedRoll + fertCost + herbCost + harvestCost;
					end;
					RN.fieldWorkCost[fruitName] = fieldWorkCost;
					if not(string.find(fruitName, "DRY") or string.find(fruitName, "WET") or string.find(fruitName, "WINDROW") or string.find(fruitName, "FERMENTED")) then
						myPrintFieldWorkCost(fruitName, textWidth, currency.."/Ha", natFertLime, plowCost, cultSeedRoll, fertCost, herbCost, harvestCost, fieldWorkCost);
					end;
				end;
			end;
		end;



		print(" ")
		print("                                          Gross     Supply     Net      Field     Field    Profit  Feed cost  Feed price")
		print(currency.."/Ha                                     income     costs     income     work      rent               "..currency.."/1000 L  "..currency.."/1000 L")
		print(" ")

--		RN.costTotalPerHa = {};
--		RN.netIncomePerHa = {};

		for i,fruitName in ipairs(RN.sortedFruits) do

			if fruitName ~= "WEED" then
--				Income = RN.cropPricePerHa[fruitName];

				if RN.cropPricePerHa[fruitName] ~= nil then
					grossIncome = RN.cropPricePerHa[fruitName];
				else
					grossIncome = 0.0;
				end;
				if RN.fieldWorkCost[fruitName] ~= nil then
					fieldWork = RN.fieldWorkCost[fruitName];
				else
					fieldWork = 0.0;
				end;

				Rent = RN.rentPricePerHa;

				if RN.productCostPerHa[fruitName] ~= nil then
					productCostPerHa = RN.productCostPerHa[fruitName];
					netIncome = grossIncome - productCostPerHa;
					RN.netIncomePerHa[fruitName] = netIncome;
				else
					productCostPerHa = 0.0;
					netIncome = grossIncome - productCostPerHa;
				end;


				if RN.cropBonusYieldLitersPerHa[fruitName] ~= nil then
					if RN.cropBonusYieldLitersPerHa[fruitName] ~= 0 then
						RN.feedCostPerLiter[fruitName] = (fieldWork + RN.productCostPerHa[fruitName])/RN.cropBonusYieldLitersPerHa[fruitName];
						feedCostPer1000Liter = 1000 * RN.feedCostPerLiter[fruitName];
						feedBuyPricePer1000Liter = RN.buyPriceScaleFactor * 1000 * RN.cropPricePerLiter[fruitName];
					end;
				else
					feedCostPer1000Liter = 0.0000;
					feedBuyPricePer1000Liter = 0.0000;
				end;

				local profit = netIncome - fieldWork - Rent;
				if not(string.find(fruitName, "DRY") or string.find(fruitName, "WET") or string.find(fruitName, "WINDROW") or string.find(fruitName, "FERMENTED")) then
					myPrintCropCost(fruitName, textWidth, currency.."/Ha", grossIncome, productCostPerHa, netIncome, fieldWork, Rent, profit, feedCostPer1000Liter, feedBuyPricePer1000Liter);
				end;
			end;
		end;
		print(" ")


				if isDebug then print(" ");end;
				if currentDay ~= nil then print("Current game day      : "..currentDay); end;
				print("Gamedays per year     : "..RN.gameDaysPerYear);
				if isDebug then print(" ");end;
--			end;
	end;
--	else
--		if not RN.multiPlayer then print("No save game yet. Save the game, quit and reload"); end;
--	end;
end;
function RealNumbersCropProductionCost:update(dt)
end;
function RealNumbersCropProductionCost:draw()
end;
function RealNumbersCropProductionCost:deleteMap()
end;
function RealNumbersCropProductionCost:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersCropProductionCost);
