--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersEnvironments by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021


RealNumbersEnvironments = {};

function RealNumbersEnvironments:loadMap()
end;

function RealNumbersEnvironments:keyEvent(unicode, sym, modifier, isDown)
	local textWidth = 40;
	local isDebug = RN.isDebug;
	local currency = "€";
	local currentPeriod = 3;   -- March
	local latestCurrentTemp = 0;
	local cropMoistureContent = 0;
	local cropMoistureEnabled = true;
	local soilWaterContent = 0;
	local soilTempMax = 0;
	local cloudProbability  = 0;
	local wind = 0;
	local rainProbability = 0;
	local rainfall = 0;
	local temperature = 0;
	local soilTempStart = 0;
	local snowDepthStart = 0;
	local highAirTempStart = 0;
	local months = {"March","April","May","June","July","August","September","November","December","January","February"};
	
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_w) then

		if isDebug	then
			print("\nlAlt-rw pressed\n");
			print("Environment and weather information");
			print(" ");
		end;

		soilTempStart = g_seasons.weather.data.startValues.soilTemp;
		snowDepthStart = g_seasons.weather.data.startValues.snowDepth;
		highAirTempStart = g_seasons.weather.data.startValues.highAirTemp;
		
		latestCurrentTemp = g_seasons.weather.latestCurrentTemp;
		cropMoistureContent = g_seasons.weather.cropMoistureContent;
		cropMoistureEnabled = g_seasons.weather.cropMoistureEnabled;
		soilWaterContent = g_seasons.weather.soilWaterContent;
		soilTempMax = g_seasons.weather.soilTempMax;

		currentPeriod = g_seasons.weather.environment.period;		
		cloudProbability = g_seasons.weather.data.cloudProbability[currentPeriod];
		wind = g_seasons.weather.data.wind[currentPeriod];
		rainProbability = g_seasons.weather.data.rainProbability[currentPeriod];
		rainfall = g_seasons.weather.data.rainfall[currentPeriod];
		temperature = g_seasons.weather.data.temperature[currentPeriod];
		
		myPrint("Map starting air temperature", highAirTempStart, textWidth, "C");
		myPrint("Map starting soil temperature", soilTempStart, textWidth, "C");
		myPrint("Map starting snow depth", snowDepthStart, textWidth, "cm");
		print(" ");
		myPrintString("Current month", months[currentPeriod], textWidth, " ");
		myPrint("Forecast temperature", temperature, textWidth, "C");
		myPrint("Forecast cloud probability", cloudProbability*100, textWidth, "%");
		myPrint("Forecast wind speed ", wind, textWidth, "m/s");
		myPrint("Forecast rain probability ", rainProbability*100, textWidth, "%");
		myPrint("Forecast rain fall ", rainfall, textWidth, "mm");
		print(" ");
		myPrint("Current air temperature", latestCurrentTemp, textWidth, "C");
		myPrint("Current soil temperature", soilTempMax, textWidth, "C");
		myPrint("Current crop moisture", cropMoistureContent, textWidth, "%");
		myPrint("Current soil moisture", soilWaterContent*100, textWidth, "%");
		print(" ");		
	end;
end;

function RealNumbersEnvironments:update(dt)
end;
function RealNumbersEnvironments:draw()
end;
function RealNumbersEnvironments:deleteMap()
end;
function RealNumbersEnvironments:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersEnvironments);