--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersFarmland by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021


RealNumbersFarmland = {};


function myPrintFieldInfo5(farmlandId, landArea,  landPrice, currency, owned)
	print(string.format("Farmland %3.0f: Land area = %4.1f ha,  Price = %7.0f %s, Ownership: %s",  farmlandId*1.0, landArea, landPrice*1.0, tostring(currency), tostring(owned)));
end;

function  myPrintFieldInfo6(fieldId, fieldArea, fruitName)
	print(string.format("              Field %3.0f: Field area = %4.1f ha,   Fruit: %s",  fieldId*1.0, fieldArea, tostring(fruitName)));
end;

function myPrintFieldInfo8(fieldId, farmlandId, farmlandArea, fieldArea, farmlandPrice, fruitTypeIndex, fruitName, farmlandIsOwned)
	print(string.format("Field %4.0f  %4.0f  %4.1f ha  %4.1f ha %6.0f %4.0, %s %s",  fieldId*1.0, farmlandId*1.0, farmlandArea, fieldArea, farmlandPrice*1.0, fruitTypeIndex*1.0, tostring(fruitName), tostring(farmlandIsOwned)));
end;

function myPFPrintIntegerFloat(text,textWidth,value1,unit1,value2,unit2)
	print(string.format("%s = %12.0f %s %12.2f %s",text..string.rep(" ",textWidth-string.len(text)),value1,unit1,value2,unit2));
end;

function myPFPrintFloatFloat(text,textWidth,value1,unit1,value2,unit2)
	print(string.format("%s = %12.2f %s %12.2f %s",text..string.rep(" ",textWidth-string.len(text)),value1,unit1,value2,unit2));
end;

function myPFPrintBlankFloat(text,textWidth,value2,unit2)
	print(string.format("%s = %12.2f %s",text..string.rep(" ",textWidth-string.len(text)),value2,unit2));
end;

function myPFPrint3Floats(text, textWidth, value1, value2, value3)
	print(string.format("%s = %9.0f %9.0f %9.0f",text..string.rep(" ",textWidth-string.len(text)),value1,value2,value3));
end;

function RealNumbersFarmland:loadMap()
	print("\nFS19_RealLifeNumbers: RealNumbersFarmland active,  press lAlt-rt");
	print("-- Lists fields in farmland order\n");
	RN.farmLandStat = {};
	RN.fieldInfo = {};
	RN.farmlandId2fieldId = {};

	RN.pF = {};			-- precision Farming table of field data
	RN.pF.numSoilSamples1  = {};
	RN.pF.numSoilSamples2  = {};
	RN.pF.numSoilSamples1Cost  = {};
	RN.pF.numSoilSamples2Cost  = {};
	RN.pF.usedLime1  = {};
	RN.pF.usedLime2  = {};
	RN.pF.usedLime1Cost  = {};
	RN.pF.usedLime2Cost  = {};
	RN.pF.usedLimeRegular1  = {};
	RN.pF.usedLimeRegular2  = {};
	RN.pF.usedLimeRegular1Cost  = {};
	RN.pF.usedLimeRegular2Cost  = {};
	RN.pF.usedMineralFertilizer1  = {};
	RN.pF.usedMineralFertilizer2  = {};
	RN.pF.usedMineralFertilizer1Cost  = {};
	RN.pF.usedMineralFertilizer2Cost  = {};
	RN.pF.usedMineralFertilizerRegular1  = {};
	RN.pF.usedMineralFertilizerRegular2  = {};
	RN.pF.usedMineralFertilizerRegular1Cost  = {};
	RN.pF.usedMineralFertilizerRegular2Cost  = {};
	RN.pF.usedLiquidFertilizer1  = {};
	RN.pF.usedLiquidFertilizer2  = {};
	RN.pF.usedLiquidFertilizer1Cost  = {};
	RN.pF.usedLiquidFertilizer2Cost  = {};
	RN.pF.usedLiquidFertilizerRegular1  = {};
	RN.pF.usedLiquidFertilizerRegular2  = {};
	RN.pF.usedLiquidFertilizerRegular1Cost  = {};
	RN.pF.usedLiquidFertilizerRegular2Cost  = {};
	RN.pF.usedManure1  = {};
	RN.pF.usedManure2  = {};
	RN.pF.usedManure1Cost  = {};
	RN.pF.usedManure2Cost  = {};
	RN.pF.usedManureRegular1  = {};
	RN.pF.usedManureRegular2  = {};
	RN.pF.usedManureRegular1Cost  = {};
	RN.pF.usedManureRegular2Cost  = {};
	RN.pF.usedLiquidManure1  = {};
	RN.pF.usedLiquidManure2  = {};
	RN.pF.usedLiquidManure1Cost  = {};
	RN.pF.usedLiquidManure2Cost  = {};
	RN.pF.usedLiquidManureRegular1  = {};
	RN.pF.usedLiquidManureRegular2  = {};
	RN.pF.usedLiquidManureRegular1Cost  = {};
	RN.pF.usedLiquidManureRegular2Cost  = {};
	RN.pF.usedSeeds1  = {};
	RN.pF.usedSeeds2  = {};
	RN.pF.usedSeeds1Cost  = {};
	RN.pF.usedSeeds2Cost  = {};
	RN.pF.usedSeedsRegular1  = {};
	RN.pF.usedSeedsRegular2  = {};
	RN.pF.usedSeedsRegular1Cost  = {};
	RN.pF.usedSeedsRegular2Cost  = {};
	RN.pF.yield1  = {};
	RN.pF.yield2  = {};
	RN.pF.yieldRegular1  = {};
	RN.pF.yieldRegular2  = {};
	RN.pF.yieldWeight1  = {};
	RN.pF.yieldWeight2  = {};
	RN.pF.yieldBestPrice1  = {};
	RN.pF.yieldBestPrice2  = {};
	RN.pF.usedFuel1  = {};
	RN.pF.usedFuel2  = {};
	RN.pF.usedFuel1Cost  = {};
	RN.pF.usedFuel2Cost  = {};
	RN.pF.vehicleCosts1  = {};
	RN.pF.vehicleCosts2  = {};
	RN.pF.helperCosts1  = {};
	RN.pF.helperCosts2  = {};
	RN.pF.totalCosts1 = {};
	RN.pF.totalCosts2 = {};
	RN.pF.earnings1 = {};

	RN.pF.fieldId  = {};
	RN.pF.farmlandArea  = {};
	RN.pF.fieldArea  = {};
	RN.pF.farmlandPrice  = {};
	RN.pF.fruitTypeIndex  = {};
	RN.pF.fruitName  = {};
	RN.pF.farmlandIsOwned  = {};


	local savegameDirectory = g_currentMission.missionInfo.savegameDirectory;	-- works only after savegame is present
	if savegameDirectory ~= nil then
		RN.usesPrecisionFarming = fileExists(savegameDirectory .. '/precisionFarming_yieldMap.grle');
		if RN.usesPrecisionFarming then
			print("\n Precision Farming DLC is used on this map \n");
		else
			print("\n Precision Farming DLC is not used \n");
		end;
	else
		print("Game data has not been saved yet");
	end;
end;

function RealNumbersFarmland:keyEvent(unicode, sym, modifier, isDown)
	local currency = " ";
	local isDebug = true;
	local isDebug2 = false;
	local neededN = 0;
	local neededP = 0;
	local neededK = 0;

    local textWidth = 40;
	local textWidth2 = 30;
	local textWidth3 = 46;
	local textWidth4 = 30;


	local Fruits = {"Wheat", "Barley", "Oat", "Cotton", "Canola", "Sunflower", "Soybean", "Maize", "Potato", "Sugarbeet", "Oilseed Radish", "Poplar","Grass","Drygrass","Sugarcane","Weed"};
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;



	local farmland = {};
	local farmlandId = 0;
	local farmlandArea = 0;
	local farmlandPrice = 0;
	local farmlandIsOwned = false;

	local fieldId = 0;
	local fieldArea = 0;
	local fruitName = "Undefined";
	local fruitTypeIndex = 0;
	local fillTypeIndex = 0;

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_t) then
		print("\nLeft Alt-rt pressed\n");
		print("Map                   : "..g_currentMission.missionInfo.map.title.." "..g_currentMission.missionInfo.displayName);
		local money = g_currentMission.missionInfo.money;
		if money ~= nil then print("Money                 : "..money); end;
		local gameLevel = g_currentMission.missionInfo.economicDifficulty;
		if gameLevel ~= nil then
			print("Economic difficulty   : "..gameLevel);
			print("Sell price multiplier : "..g_currentMission.economyManager.PRICE_MULTIPLIER[gameLevel]);
			print("Buy price multiplier  : "..g_currentMission.economyManager.COST_MULTIPLIER[gameLevel]);
		end;
		print("Gamedays per year     : "..RN.gameDaysPerYear);
		local currentDay = g_currentMission.environment.currentDay;
		if currentDay ~= nil then print("Current game day      : "..currentDay); end;
		local hour = g_currentMission.environment.currentHour;
		local minute = g_currentMission.environment.currentMinute;
		if hour ~= nil or minute ~= nil then print("Time of day           : "..hour..":"..minute); end;
		print(" ");

		print("Mean land purchase price = "..g_farmlandManager.pricePerHa.." "..currency.."/ha");
		print("Mean land rent price per year = "..RN.rentPricePerHa.." "..currency.."/ha");
		print(string.format("%s = %8.0f  %s","Mean land rent price for rest of year ",RN.rentYearFraction * RN.rentPricePerHa,currency.."/ha"));
		print(string.format("%s = %8.4f","Fraction of remaining rent year ",RN.rentYearFraction));
		print("\nAll field rent contracts are automatically terminated on the first day of mid-winter.");
		print("The rent fee decreases gradually in proportion to the remainding numbers of days in the rent year.");
		print("On all of the first day of mid-winter, the rent price is zero, and all attempts to rent land is nullified.");
		print("Starting on the next day, you can renew your rent contract or rent another field.");
		print("You can terminate a rent contract at any time by selling the rented field. The sell price ");
		print("corresponds to the rent for the remainder of the rent year. You pay only for time in use.\n");
		for k,v in pairs (g_fieldManager.farmlandIdFieldMapping) do

			for j,field in pairs (v) do
					farmland = field.farmland;
					farmlandId = farmland.id;
					farmlandArea = farmland.areaInHa;
					farmlandPrice = farmland.price;
					farmlandIsOwned = farmland.isOwned;
					if farmlandIsOwned then
						if RN.fieldStatus[farmlandId] == " For sale" then RN.fieldStatus[farmlandId] = " Owned   "; end;
						if RN.fieldStatus[farmlandId] == " For rent" then RN.fieldStatus[farmlandId] = " Rented  "; end;
					else
						if RN.fieldStatus[farmlandId] == " Rented" then RN.fieldStatus[farmlandId] = " For rent"; end;
					end;
					RN.farmlandId2fieldId[farmlandId] = {};
			end;
			myPrintFieldInfo5(farmlandId, farmlandArea,  farmlandPrice, currency, RN.fieldStatus[farmlandId]);

			for j,field in pairs (v) do
				fieldId = field.fieldId;
				RN.fieldInfo[fieldId] = {};
				fieldArea = field.fieldArea;
				fruitTypeIndex = field.fruitType;
				if fruitTypeIndex == nil then
					fruitName = RN.fieldFruits[fieldId];
					if fruitName == nil then 
						fruitName = "Undefined" 
						fruitTypeIndex = 0;
					else
--						fillTypeIndex = g_fruitTypeManager:getFillTypesByFruitTypeNames(fruitName);
--						fruitTypeIndex = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(fillTypeIndex);
						fruitTypeIndex = RN.mapFruits[fruitName][2];
						fillTypeIndex = RN.mapFruits[fruitName][3];
					end;
				else
					fruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
					fruitName = fruitType.name;
					if fruitType.name == nil then fruitName = RN.fieldFruits[fieldId] end;
				end;
				myPrintFieldInfo6(fieldId, fieldArea, fruitName);
				RN.farmlandId2fieldId[farmlandId][j] = fieldId;
				RN.fieldInfo[fieldId] = {fieldId, farmlandId, farmlandArea, fieldArea, farmlandPrice, fruitTypeIndex, fruitName, farmlandIsOwned};
--				myPrintFieldInfo8(fieldId, farmlandId, farmlandArea, fieldArea, farmlandPrice, fruitTypeIndex, fruitName, farmlandIsOwned);
			end;
		end;
		print(" ");
--		print_r(RN.farmlandId2fieldId);
--		print_r(RN.fieldInfo);

-- Precision Farming statistics


		if RN.usesPrecisionFarming then
			local itemsFile = g_currentMission.missionInfo.itemsXML;					-- works only after savegame is present
			local xmlFile = loadXMLFile("itemsXML", itemsFile);
			local key = "items";

			print("\n Precision Farming Field Economy\n")


			if hasXMLProperty(xmlFile, key) then
				local i = 0;
				local fieldId = 0;
				while true do
--					print("i : "..i+1);
					RN.farmLandStat[i+1] = {};
					local statkey = string.format("%s.precisionFarming.farmlandStatistics.farmlandStatistic(%d)", key,i);
					if not hasXMLProperty(xmlFile, statkey) then
						   break;
					end;
					local farmlandId = tonumber(getXMLString(xmlFile, statkey .. "#farmlandId"));
--					print("farmlandId : "..farmlandId);
					if RN.farmlandId2fieldId[farmlandId] == nil then
						fieldId = 0;
					else
						fieldId = RN.farmlandId2fieldId[farmlandId][1];
--						print("fieldId : "..fieldId);
						RN.pF.farmlandArea[fieldId] = RN.fieldInfo[fieldId][3];
--						print("farmlandArea = "..RN.pF.farmlandArea[fieldId]);
						RN.pF.fieldArea[fieldId] = RN.fieldInfo[fieldId][4];
--						print("fieldArea = "..RN.pF.fieldArea[fieldId]);
						RN.pF.farmlandPrice[fieldId] = RN.fieldInfo[fieldId][5];
--						print("farmlandPrice = "..RN.pF.farmlandPrice[fieldId]);
						RN.pF.fruitTypeIndex[fieldId] = RN.fieldInfo[fieldId][6];
						RN.pF.fruitName[fieldId] = RN.fieldInfo[fieldId][7];
--						print("fruitName = "..RN.pF.fruitName[fieldId]);
						RN.pF.farmlandIsOwned[fieldId] = RN.fieldInfo[fieldId][8];
--						print(RN.pF.farmlandIsOwned[fieldId]);
--						print(" ");


						local statkey1 = string.format("%s.periodCounter", statkey);
						if not hasXMLProperty(xmlFile, statkey1) then
							   break;
						end;
						local statkey2 = string.format("%s.totalCounter", statkey);
						if not hasXMLProperty(xmlFile, statkey2) then
							   break;
						end;

						RN.pF.totalCosts1[fieldId] = 0;
						RN.pF.numSoilSamples1[fieldId] = tonumber(getXMLString(xmlFile, statkey1 .. "#numSoilSamples"));
						RN.pF.numSoilSamples2[fieldId] = tonumber(getXMLString(xmlFile, statkey2 .. "#numSoilSamples"));
						RN.pF.numSoilSamples1Cost[fieldId] = RN.pF.numSoilSamples1[fieldId] * 15;
						RN.pF.numSoilSamples2Cost[fieldId] = RN.pF.numSoilSamples2[fieldId] * 15;
						RN.pF.totalCosts1[fieldId] = RN.pF.totalCosts1[fieldId] + RN.pF.numSoilSamples1Cost[fieldId];

						RN.pF.usedLime1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedLime"));
						RN.pF.usedLime2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedLime"));
						RN.pF.usedLime1Cost[fieldId] = RN.pF.usedLime1[fieldId] * RN2.pricePerLiter["LIME"];
						RN.pF.usedLime2Cost[fieldId] = RN.pF.usedLime2[fieldId] * RN2.pricePerLiter["LIME"];
						RN.pF.totalCosts1[fieldId] = RN.pF.totalCosts1[fieldId] + RN.pF.usedLime1Cost[fieldId];


						RN.pF.usedLimeRegular1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedLimeRegular"));
						RN.pF.usedLimeRegular2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedLimeRegular"));
						RN.pF.usedLimeRegular1Cost[fieldId] = RN.pF.usedLimeRegular1[fieldId] * RN2.pricePerLiter["LIME"];
						RN.pF.usedLimeRegular2Cost[fieldId] = RN.pF.usedLimeRegular2[fieldId] * RN2.pricePerLiter["LIME"];

						RN.pF.usedMineralFertilizer1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedMineralFertilizer"));
						RN.pF.usedMineralFertilizer2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedMineralFertilizer"));
						RN.pF.usedMineralFertilizer1Cost[fieldId] = RN.pF.usedMineralFertilizer1[fieldId] * RN2.pricePerLiter["FERTILIZER"];
						RN.pF.usedMineralFertilizer2Cost[fieldId] = RN.pF.usedMineralFertilizer2[fieldId] * RN2.pricePerLiter["FERTILIZER"];
						RN.pF.totalCosts1[fieldId] = RN.pF.totalCosts1[fieldId] + RN.pF.usedMineralFertilizer1Cost[fieldId];

						RN.pF.usedMineralFertilizerRegular1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedMineralFertilizerRegular"));
						RN.pF.usedMineralFertilizerRegular2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedMineralFertilizerRegular"));
						RN.pF.usedMineralFertilizerRegular1Cost[fieldId] = RN.pF.usedMineralFertilizerRegular1[fieldId] * RN2.pricePerLiter["FERTILIZER"];
						RN.pF.usedMineralFertilizerRegular2Cost[fieldId] = RN.pF.usedMineralFertilizerRegular2[fieldId] * RN2.pricePerLiter["FERTILIZER"];

						RN.pF.usedLiquidFertilizer1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedLiquidFertilizer"));
						RN.pF.usedLiquidFertilizer2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedLiquidFertilizer"));
						RN.pF.usedLiquidFertilizer1Cost[fieldId] = RN.pF.usedLiquidFertilizer1[fieldId] * RN2.pricePerLiter["LIQUIDFERTILIZER"];
						RN.pF.usedLiquidFertilizer2Cost[fieldId] = RN.pF.usedLiquidFertilizer2[fieldId] * RN2.pricePerLiter["LIQUIDFERTILIZER"];
						RN.pF.totalCosts1[fieldId] = RN.pF.totalCosts1[fieldId] + RN.pF.usedLiquidFertilizer1Cost[fieldId];

						RN.pF.usedLiquidFertilizerRegular1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedLiquidFertilizerRegular"));
						RN.pF.usedLiquidFertilizerRegular2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedLiquidFertilizerRegular"));
						RN.pF.usedLiquidFertilizerRegular1Cost[fieldId] = RN.pF.usedLiquidFertilizerRegular1[fieldId] * RN2.pricePerLiter["LIQUIDFERTILIZER"];
						RN.pF.usedLiquidFertilizerRegular2Cost[fieldId] = RN.pF.usedLiquidFertilizerRegular2[fieldId] * RN2.pricePerLiter["LIQUIDFERTILIZER"];

						RN.pF.usedManure1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedManure"));
						RN.pF.usedManure2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedManure"));
						RN.pF.usedManure1Cost[fieldId] = RN.pF.usedManure1[fieldId] * RN2.pricePerLiter["MANURE"];
						RN.pF.usedManure2Cost[fieldId] = RN.pF.usedManure2[fieldId] * RN2.pricePerLiter["MANURE"];
						RN.pF.totalCosts1[fieldId] = RN.pF.totalCosts1[fieldId] + RN.pF.usedManure1Cost[fieldId];

						RN.pF.usedManureRegular1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedManureRegular"));
						RN.pF.usedManureRegular2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedManureRegular"));
						RN.pF.usedManureRegular1Cost[fieldId] = RN.pF.usedManureRegular1[fieldId] * RN2.pricePerLiter["MANURE"];
						RN.pF.usedManureRegular2Cost[fieldId] = RN.pF.usedManureRegular2[fieldId] * RN2.pricePerLiter["MANURE"];

						RN.pF.usedLiquidManure1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedLiquidManure"));
						RN.pF.usedLiquidManure2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedLiquidManure"));
						RN.pF.usedLiquidManure1Cost[fieldId] = RN.pF.usedLiquidManure1[fieldId] * RN2.pricePerLiter["LIQUIDMANURE"];
						RN.pF.usedLiquidManure2Cost[fieldId] = RN.pF.usedLiquidManure2[fieldId] * RN2.pricePerLiter["LIQUIDMANURE"];
						RN.pF.totalCosts1[fieldId] = RN.pF.totalCosts1[fieldId] + RN.pF.usedLiquidManure1Cost[fieldId];

						RN.pF.usedLiquidManureRegular1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedLiquidManureRegular"));
						RN.pF.usedLiquidManureRegular2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedLiquidManureRegular"));
						RN.pF.usedLiquidManureRegular1Cost[fieldId] = RN.pF.usedLiquidManureRegular1[fieldId] * RN2.pricePerLiter["LIQUIDMANURE"];
						RN.pF.usedLiquidManureRegular2Cost[fieldId] = RN.pF.usedLiquidManureRegular2[fieldId] * RN2.pricePerLiter["LIQUIDMANURE"];

						RN.pF.usedSeeds1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedSeeds"));
						RN.pF.usedSeeds2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedSeeds"));
						RN.pF.usedSeeds1Cost[fieldId] = RN.pF.usedSeeds1[fieldId] * RN2.pricePerLiter["SEEDS"];
						RN.pF.usedSeeds2Cost[fieldId] = RN.pF.usedSeeds2[fieldId] * RN2.pricePerLiter["SEEDS"];
						RN.pF.totalCosts1[fieldId] = RN.pF.totalCosts1[fieldId] + RN.pF.usedSeeds1Cost[fieldId];

						RN.pF.usedSeedsRegular1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedSeedsRegular"));
						RN.pF.usedSeedsRegular2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedSeedsRegular"));
						RN.pF.usedSeedsRegular1Cost[fieldId] = RN.pF.usedSeedsRegular1[fieldId] * RN2.pricePerLiter["SEEDS"];
						RN.pF.usedSeedsRegular2Cost[fieldId] = RN.pF.usedSeedsRegular2[fieldId] * RN2.pricePerLiter["SEEDS"];

						RN.pF.yield1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#yield"));
						RN.pF.yield2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#yield"));
						RN.pF.yieldRegular1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#yieldRegular"));
						RN.pF.yieldRegular2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#yieldRegular"));
						RN.pF.yieldWeight1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#yieldWeight"));
						RN.pF.yieldWeight2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#yieldWeight"));
						RN.pF.yieldBestPrice1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#yieldBestPrice"));
						RN.pF.yieldBestPrice2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#yieldBestPrice"));
						RN.pF.usedFuel1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#usedFuel"));
						RN.pF.usedFuel2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#usedFuel"));
						RN.pF.usedFuel1Cost[fieldId] = RN.pF.usedFuel1[fieldId] * RN2.pricePerLiter["DIESEL"];
						RN.pF.usedFuel2Cost[fieldId] = RN.pF.usedFuel2[fieldId] * RN2.pricePerLiter["DIESEL"];
						RN.pF.totalCosts1[fieldId] = RN.pF.totalCosts1[fieldId] + RN.pF.usedFuel1Cost[fieldId];

						RN.pF.vehicleCosts1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#vehicleCosts"));
						RN.pF.vehicleCosts2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#vehicleCosts"));
						RN.pF.totalCosts1[fieldId] = RN.pF.totalCosts1[fieldId] + RN.pF.vehicleCosts1[fieldId];

						RN.pF.helperCosts1[fieldId] = tonumber(getXMLFloat(xmlFile, statkey1 .. "#helperCosts"));
						RN.pF.helperCosts2[fieldId] = tonumber(getXMLFloat(xmlFile, statkey2 .. "#helperCosts"));
						RN.pF.totalCosts1[fieldId] = RN.pF.totalCosts1[fieldId] + RN.pF.helperCosts1[fieldId];

						RN.pF.earnings1[fieldId] = RN.pF.yieldBestPrice1[fieldId] - RN.pF.totalCosts1[fieldId];


					end;
					i=i+1;
				end;
			end;

			for k,field in pairs(g_fieldManager.fields) do
				local fieldId = field.fieldId;
				local farmlandId = RN.fieldInfo[fieldId][2]
				local isOwned = RN.fieldInfo[fieldId][8];
				local fruitName = RN.fieldInfo[fieldId][7];
				local fieldArea = RN.fieldInfo[fieldId][4]
				local cropProtectionCost = 0;
				local cropProtectionAmount = 0;
--				print("fieldId : "..fieldId.." ; fruitName = "..fruitName);

				if isOwned then
					if RN.pF.numSoilSamples1[fieldId] ~= nil then
						if fruitName == nil then fruitName = RN.fieldFruits[fieldId] end;
						if string.upper(fruitName) ~= "UNDEFINED" then
-- fertilizer
--							print("fieldId : "..fieldId.." ; fruitName = "..fruitName);
							if RN.Nitrogen[fruitName] ~= nil then
								neededN = RN.Nitrogen[fruitName]  * fieldArea;
								neededP = RN.Phosphate[fruitName] * fieldArea;
								neededK = RN.Potassium[fruitName] * fieldArea;
							else
								neededN = RN.Nitrogen["UNDEFINED"]  * fieldArea;
								neededP = RN.Phosphate["UNDEFINED"] * fieldArea;
								neededK = RN.Potassium["UNDEFINED"] * fieldArea;
							end;
--[[
								local appliedManure = neededP / RN.PAvailablePerTonne.cowMANURE; -- Ton
								local manureN = appliedManure * RN.NAvailablePerTonne.cowMANURE; -- kg
								local manureP = appliedManure * RN.PAvailablePerTonne.cowMANURE; -- kg
								local manureK = appliedManure * RN.KAvailablePerTonne.cowMANURE; -- kg
								local minFertN = math.max(neededN - manureN,0); -- kg
								local minFertP = math.max(neededP - manureP,0); -- kg
								local minFertK = math.max(neededK - manureK,0); -- kg
								local mineralNApplied = minFertN/0.27;
								local appliedManureCost = appliedManure * 10 * RN.commodityPricePer100kg.MANURE;
								local minFertNCost = minFertN * RN.fertCostPerKg.N;
]]--

--							print(fruitName);
--							print(RN.fert1DeliveredN[fruitName]);
--							print(fieldArea);
							local fert1N    = RN.fert1DeliveredN[fruitName] * fieldArea;	-- kg
							local fert1P    = RN.fert1DeliveredP[fruitName] * fieldArea;	-- kg
							local fert1K    = RN.fert1DeliveredK[fruitName] * fieldArea;	-- kg
							local fert2N    = RN.fert2DeliveredN[fruitName] * fieldArea;	-- kg
							local fert2P    = RN.fert2DeliveredP[fruitName] * fieldArea;	-- kg						
							local fert2K    = RN.fert2DeliveredK[fruitName] * fieldArea;	-- kg
							local fert1Cost = RN.fert1CostPerHa[fruitName]  * fieldArea;	-- €
							local fert2Cost = RN.fert2CostPerHa[fruitName]  * fieldArea;	-- €
							local fert1Rate = RN.fert1SprayRate[fruitName]  * fieldArea;	-- Tonne
							local fert2Rate = RN.fert2SprayRate[fruitName]  * fieldArea;	-- Tonne
							local fertType1 = tostring(RN.fertFirstApplication[fruitName]);
							local fertType2 = tostring(RN.fertSecondApplication[fruitName]);

-- lime
							local appliedLime = (1/3) * fieldArea * RN.sprayLitersPerHa.LIME * RN.commodityDensity.LIME / 1000; -- Ton
							local appliedLimeCost = 10 * appliedLime * RN.commodityPricePer100kg.LIME;

-- seed

							local seedCost = 0;
							local seedAmount = 0;
							local seedName = " ";

							if string.upper(fruitName) ~= "UNDEFINED" then
								seedName = "SEED_"..fruitName;
								seedAmount = RN.seedMassRatePerHa[fruitName] * fieldArea; -- kg
								if RN.commodityName[seedName] ~= nil then
									seedCost = seedAmount * RN.commodityPricePer100kg[seedName]/100;
									seedName = "Seed - "..string.lower(fruitName);
								else
									seedCost = seedAmount * RN.commodityPricePer100kg["SEEDS"]/100;
									seedName = "Seed - generic";
								end;
							end;
						
							if string.find("GRASS ALFALFA LUCERNE LUZERNE CLOVER",fruitName) ~= nil then
								seedCost = seedCost/3;
								seedAmount = seedAmount/3;
							end;
						
						
-- herbicide
							if RN.cropProtectionCost[fruitName] ~= nil then
								cropProtectionCost = RN.cropProtectionCost[fruitName] * fieldArea;
								cropProtectionAmount = 100 * cropProtectionCost / RN.commodityPricePer100kg.HERBICIDE; -- kg
							else
								cropProtectionCost = RN.cropProtectionCost["WHEAT"] * fieldArea;
								cropProtectionAmount = 100 * cropProtectionCost / RN.commodityPricePer100kg.HERBICIDE; -- kg
							end;
--							local supplyCost = appliedManureCost + minFertNCost + appliedLimeCost + seedCost + cropProtectionCost;
							local supplyCost = fert1Cost + fert2Cost + appliedLimeCost + seedCost + cropProtectionCost;

-- field work cost
							local fruitName2 = fruitName;
							if string.upper(fruitName) == "UNDEFINED" then fruitName2 = "WHEAT"; end;

							local plowCost = 0;
							local cultivatorCost = 0;
							if RN.isDirectSeeding[fruitName2] == 0 then
								if RN.isPlowing[fruitName2] == 1 then
								plowCost = fieldArea * RN.fieldWorkCost.turnPlow;
								end;
								cultivatorCost = fieldArea * RN.fieldWorkCost.discHarrow;
							end;
							local manureSpreaderCost = fieldArea * RN.manureApplications[fruitName2] * RN.fieldWorkCost.manureSpreader;
							local slurrySprayerCost = fieldArea * RN.slurryApplications[fruitName2] * RN.fieldWorkCost.slurrySpreader;
							local limeSpreaderCost = fieldArea * RN.limeApplications[fruitName2] * RN.fieldWorkCost.limeSpreader;
							local fertSpreaderCost = fieldArea * RN.solidFertApplications[fruitName2] * RN.fieldWorkCost.fertSpreader;
							local liqFertSprayerCost = fieldArea * RN.liquidFertApplications[fruitName2] * RN.fieldWorkCost.fertSpray;
							local herbicideSprayerCost = fieldArea * RN.herbicideApplications[fruitName2] * RN.fieldWorkCost.fertSpray;

							local seederCost = 0;
							local seederName = " ";
							if RN.seederType[fruitName2] == "SEEDERS" then
								seederCost = fieldArea * RN.fieldWorkCost.seedDrill;
								seederName = "Seed drill cost";
							elseif RN.seederType[fruitName2] == "PLANTERS" then
								seederCost = fieldArea * RN.fieldWorkCost.beetPlanter;
								seederName = "Seed planter cost";
							elseif RN.seederType[fruitName2] == "POPLARPLANTERS" then
								seederCost = fieldArea * 0;
								seederName = "Poplar planter cost";
							elseif RN.seederType[fruitName2] == "POTATOPLANTERS" then
								seederCost = fieldArea * RN.fieldWorkCost.potatoPlanter;
								seederName = "Potato planter cost";
							elseif RN.seederType[fruitName2] == "SUGARCANEPLANTERS" then
								seederCost = fieldArea * RN.fieldWorkCost.sugarcanePlanter;
								seederName = "Sugarcane planter cost";
							end;

							local harvesterCost = 0;
							local harvesterName = " ";
							if RN.harvesterType[fruitName2] == "HARVESTERS" then
								harvesterCost = fieldArea * RN.fieldWorkCost.combineHarvest;
								harvesterName = "Combine harvester cost";
							elseif  RN.harvesterType[fruitName2] == "POTATOHARVESTING" then
								harvesterCost = fieldArea * RN.fieldWorkCost.potatoHarvest;
								harvesterName = "Potato harvester cost";
							elseif  RN.harvesterType[fruitName2] == "BEETHARVESTING" then
								harvesterCost = fieldArea * RN.fieldWorkCost.beetHarvest;
								harvesterName = "Sugarbeet harvester cost";
							elseif  RN.harvesterType[fruitName2] == "POPLARHARVESTERS" then
								harvesterCost = fieldArea * 0;
								harvesterName = "Poplar harvester cost";
							elseif  RN.harvesterType[fruitName2] == "COTTONHARVESTERS" then
								harvesterCost = fieldArea * 0;
								harvesterName = "Cotton harvester cost";
							elseif  RN.harvesterType[fruitName2] == "SUGARCANEHARVESTING" then
								harvesterCost = fieldArea * RN.fieldWorkCost.sugarcaneHarvest;
								harvesterName = "Sugarcane harvester cost";
							elseif  RN.harvesterType[fruitName2] == "MOWERS" then
								harvesterCost = fieldArea * RN.forageCost.mowing;
								harvesterName = "Mower cost";
							end;


							local balerCost = 0;
							local windrowerCost = 0;

							if RN.isBaling[fruitName2] ~= 0 then
								windrowerCost = fieldArea * RN.isBaling[fruitName2] * RN.forageCost.raking;
								balerCost = fieldArea * RN.isBaling[fruitName2] * RN.forageCost.roundBaling;
							end;



							local fieldWorkCostTotal = plowCost + cultivatorCost + manureSpreaderCost + slurrySprayerCost +
												   limeSpreaderCost + fertSpreaderCost + liqFertSprayerCost +
												   herbicideSprayerCost + seederCost + harvesterCost +
												   windrowerCost + balerCost;

							local totalFieldCost = fieldWorkCostTotal + supplyCost;

-- Harvest value
							local cropYield = fieldArea * RN.cropDensity[fruitName2] * RN.cropBonusYieldLitersPerHa[fruitName2]/1000; -- Tonnes
							local cropValue = 10 * RN.cropPricePer100kg[fruitName2] * cropYield;
	
	-- check if crop has windrow						
							local fruitTypeIndex = RN.pF.fruitTypeIndex[fieldId]; 
							local hasWindrow = g_currentMission.fruitTypeManager.fruitTypes[fruitTypeIndex].hasWindrow;
							
							local windrowYieldVolume = 0;
							local windrowYieldValue = 0;
							local windrowType = "No windrow"
							if hasWindrow == false then RN.isBaling[fruitName2] = 0; end;
							if RN.isBaling[fruitName2] ~= 0 then
								windrowYieldVolume = fieldArea * RN.windrowYieldLitersPerHa[fruitName2];
								if RN.baleType[fruitName2] == "STRAW" then
									windrowYieldValue = windrowYieldVolume * RN.forageCost.strawPricePer1000L/1000;
									windrowType = "Staw bales";
								elseif RN.baleType[fruitName2] == "HAY" then
									if fruitName2 == "GRASS" then
										windrowYieldValue = windrowYieldVolume * RN.forageCost.drygrassPricePer1000L/1000;
										windrowType = "Grass hay bales";
										cropYield = 0;
										cropValue = 0;
									elseif fruitName2 == "ALFALFA" then
										windrowYieldValue = windrowYieldVolume * RN.forageCost.dryalfalfaPricePer1000L/1000;
										windrowType = "Alfalfa hay bales";
										cropYield = 0;
										cropValue = 0;
									elseif fruitName2 == "LUCERNE" then
										windrowYieldValue = windrowYieldVolume * RN.forageCost.dryalfalfaPricePer1000L/1000;
										windrowType = "Lucerne hay bales";
										cropYield = 0;
										cropValue = 0;
									elseif fruitName2 == "LUZERNE" then
										windrowYieldValue = windrowYieldVolume * RN.forageCost.dryalfalfaPricePer1000L/1000;
										windrowType = "Luzerne hay bales";
										cropYield = 0;
										cropValue = 0;
									elseif fruitName2 == "CLOVER" then
										windrowYieldValue = windrowYieldVolume * RN.forageCost.drycloverPricePer1000L/1000;
										windrowType = "Clover hay bales";
										cropYield = 0;
										cropValue = 0;
									end;
								elseif RN.baleType[fruitName2] == "SILAGE" then
									if fruitName2 == "GRASS" then
										windrowYieldValue = windrowYieldVolume * RN.forageCost.grassSilagePricePer1000L/1000;
										windrowType = "Grass silage bales";
										cropYield = 0;
										cropValue = 0;
									elseif fruitName2 == "ALFALFA" then
										windrowYieldValue = windrowYieldVolume * RN.forageCost.alfalfaSilagePricePer1000L/1000;
										windrowType = "Alfalfa silage bales";
										cropYield = 0;
										cropValue = 0;
									elseif fruitName2 == "LUCERNE" then
										windrowYieldValue = windrowYieldVolume * RN.forageCost.alfalfaSilagePricePer1000L/1000;
										windrowType = "Lucerne silage bales";
										cropYield = 0;
										cropValue = 0;
									elseif fruitName2 == "LUZERNE" then
										windrowYieldValue = windrowYieldVolume * RN.forageCost.alfalfaSilagePricePer1000L/1000;
										windrowType = "Luzerne silage bales";
										cropYield = 0;
										cropValue = 0;
									elseif fruitName2 == "CLOVER" then
										windrowYieldValue = windrowYieldVolume * RN.forageCost.cloverSilagePricePer1000L/1000;
										windrowType = "Clover silage bales";
										cropYield = 0;
										cropValue = 0;
									end;							
								end;
							end;
						
							local fieldEarnings = cropValue + windrowYieldValue - totalFieldCost;
							local fieldRentValue = fieldArea * RN.rentPricePerHa;

							print(" ")
							print("---------------------------------------------------------------");
							myPrint("Field",RN.fieldInfo[fieldId][1],textWidth2," ");
							myPrint("Farmland",RN.fieldInfo[fieldId][2],textWidth2," ");
							myPrintFloat("Farmland Area",RN.fieldInfo[fieldId][3],textWidth2,"ha");
							myPrintFloat("Field Area",RN.fieldInfo[fieldId][4],textWidth2,"ha");
							myPrintFloat("Farmland price",RN.fieldInfo[fieldId][5],textWidth2,currency);
							myPrintString("Fruit name",RN.fieldInfo[fieldId][7],textWidth2," ");
							myPrintString("Owner status",RN.fieldStatus[farmlandId],textWidth2," ");
							print(" ");
							print("---------------------------------------------------------------");
							print(" ");
							print("Supply costs")
							print(" ");
							print("                                         N         P         K ");
							myPFPrint3Floats("Removed from soil (kg)", textWidth4, neededN, neededP, neededK);
--							myPFPrint3Floats("Manure NPK (kg)", textWidth4, manureN, manureP, manureK);
							myPFPrint3Floats(fertType1.." (kg)", textWidth4,fert1N,fert1P, fert1K);
--							myPFPrint3Floats("Mineral fertilizer NPK (kg)", textWidth4, minFertN, minFertP, minFertK);
							myPFPrint3Floats(fertType2.." (kg)", textWidth4, fert2N, fert2P, fert2K);
							print(" ");
--							myPFPrintFloatFloat("Manure",textWidth2,appliedManure,"To",appliedManureCost,currency);
--							myPFPrintFloatFloat("Nitrogen",textWidth2,mineralNApplied,"kg",minFertNCost,currency);
							myPFPrintFloatFloat(fertType1,textWidth2,fert1Rate,"To",fert1Cost,currency);
							myPFPrintFloatFloat(fertType2,textWidth2,fert2Rate,"To",fert2Cost,currency);
							myPFPrintFloatFloat("Lime (1/3)",textWidth2,appliedLime,"To",appliedLimeCost,currency);
							myPFPrintFloatFloat(seedName,textWidth2,seedAmount,"kg",seedCost,currency);
							myPFPrintFloatFloat("Herbicide",textWidth2,cropProtectionAmount,"kg",cropProtectionCost,currency);
							print(" ");
							myPFPrintBlankFloat("Supply cost",textWidth3,supplyCost,currency)



							print(" ");
							print("---------------------------------------------------------------");
							print(" ");
							print("Field work costs")
							print(" ");
							myPFPrintBlankFloat("Plow cost",textWidth3,plowCost,currency);
							myPFPrintBlankFloat("Cultivator cost",textWidth3,cultivatorCost,currency);
							myPFPrintBlankFloat("Manure spreader cost",textWidth3,manureSpreaderCost,currency);
							myPFPrintBlankFloat("Slurry sprayer cost",textWidth3,slurrySprayerCost,currency);
							myPFPrintBlankFloat("Lime spreader cost (1/3)",textWidth3,limeSpreaderCost,currency);
							myPFPrintBlankFloat("Mineral fertilizer spreader cost",textWidth3,fertSpreaderCost,currency);
							myPFPrintBlankFloat("Liquid fertilizer sprayer cost",textWidth3,liqFertSprayerCost,currency);
							myPFPrintBlankFloat("Herbicide sprayer cost",textWidth3,herbicideSprayerCost,currency);
							myPFPrintBlankFloat(seederName,textWidth3,seederCost,currency);
							myPFPrintBlankFloat(harvesterName,textWidth3,harvesterCost,currency);
							if RN.isBaling[fruitName2] ~= 0 then
								myPFPrintBlankFloat("Windrower cost",textWidth3,windrowerCost,currency);
								myPFPrintBlankFloat("Baler cost",textWidth3,balerCost,currency);
							end;

							print(" ");
							myPFPrintBlankFloat("Total field work cost",textWidth3,fieldWorkCostTotal,currency);

							print(" ");
							print("---------------------------------------------------------------");
							print(" ");
							print("Crop value")
							myPFPrintFloatFloat("Yield",textWidth2,cropYield,"To",cropValue,currency);
							myPFPrintFloatFloat(windrowType,textWidth2,windrowYieldVolume," L",windrowYieldValue,currency);
						
							myPFPrintBlankFloat("Total cost",textWidth3,totalFieldCost,currency);
							myPFPrintBlankFloat("Field earnings",textWidth3,fieldEarnings,currency);
							myPFPrintBlankFloat("Field rent value",textWidth3,fieldRentValue,currency);


							print(" ");
							print("---------------------------------------------------------------");
							print(" ");
							print("Precision Farming Data")
							print(" ");
							myPFPrintIntegerFloat("Soilsamples",textWidth2,RN.pF.numSoilSamples1[fieldId],"  ",RN.pF.numSoilSamples1Cost[fieldId],currency)
							myPFPrintFloatFloat("Lime",textWidth2,RN.pF.usedLime1[fieldId]," L",RN.pF.usedLime1Cost[fieldId],currency)
							myPFPrintFloatFloat("Mineral fertilizer",textWidth2,RN.pF.usedMineralFertilizer1[fieldId]," L",RN.pF.usedMineralFertilizer1Cost[fieldId],currency)
							myPFPrintFloatFloat("Liquid fertilizer",textWidth2,RN.pF.usedLiquidFertilizer1[fieldId]," L",RN.pF.usedLiquidFertilizer1Cost[fieldId],currency)
							myPFPrintFloatFloat("Manure",textWidth2,RN.pF.usedManure1[fieldId]," L",RN.pF.usedManure1Cost[fieldId],currency)
							myPFPrintFloatFloat("Slurry",textWidth2,RN.pF.usedLiquidManure1[fieldId]," L",RN.pF.usedLiquidManure1Cost[fieldId],currency)
							myPFPrintFloatFloat("Seeds",textWidth2,RN.pF.usedSeeds1[fieldId]," L",RN.pF.usedSeeds1Cost[fieldId],currency)
							myPFPrintFloatFloat("Diesel",textWidth2,RN.pF.usedFuel1[fieldId]," L",RN.pF.usedFuel1Cost[fieldId],currency)
							myPFPrintBlankFloat("Vehicle cost",textWidth3,RN.pF.vehicleCosts1[fieldId],currency)
							myPFPrintBlankFloat("Helper cost",textWidth3,RN.pF.helperCosts1[fieldId],currency)
							print("---------------------------------------------------------------");
							myPFPrintFloatFloat("Yield",textWidth2,RN.pF.yield1[fieldId]," L",RN.pF.yieldBestPrice1[fieldId],currency)
							print(" ");
							myPFPrintBlankFloat("Total cost",textWidth3,RN.pF.totalCosts1[fieldId],currency)
							print(" ");
							myPFPrintBlankFloat("Earnings",textWidth3,RN.pF.earnings1[fieldId],currency)

							print("===============================================================");
						end;
					else
						print("\n Field "..fieldId.." has no Precision Farming statistics\n");
					end;
				end;
			end;
		end;	-- if RN.usesPrecisionFarming then
	end;		-- key stroke
end;

function RealNumbersFarmland:update(dt)
end;
function RealNumbersFarmland:draw()
end;
function RealNumbersFarmland:deleteMap()
end;
function RealNumbersFarmland:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersFarmland);
