--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersFieldInfo by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021

-- Names for FillTypes

-- WHEAT BARLEY OAT CANOLA SUNFLOWER SOYBEAN MAIZE POTATO SUGARBEET OILSEEDRADISH
-- MANURE SEEDS FORAGE FORAGE_MIXING CHAFF WOODCHIPS SILAGE
-- STRAW GRASS_WINDROW DRYGRASS_WINDROW SUGARCANE FERTILIZER PIGFOOD LIME
-- WOOL TREESAPLINGS EGG
-- MILK FUEL WATER DIESEL DEF
-- LIQUIDFERTILIZER HERBICIDE
-- CHAFF GRASS_WINDROW
-- LIQUIDMANURE DIGESTATE
-- COW_TYPE_BRAHMAN_GREY COW_TYPE_BRAHMAN_LIGHT_BROWN COW_TYPE_BRAHMAN_WHITE COW_TYPE_BRAHMAN_BROWN
-- COW_TYPE_BROWN COW_TYPE_BROWN_WHITE COW_TYPE_BLACK COW_TYPE_BLACK_WHITE
-- SHEEP_TYPE_WHITE SHEEP_TYPE_BROWN SHEEP_TYPE_BLACK_WHITE SHEEP_TYPE_BLACK
-- PIG_TYPE_RED PIG_TYPE_WHITE PIG_TYPE_BLACK_WHITE PIG_TYPE_BLACK
-- CHICKEN_TYPE_BLACK CHICKEN_TYPE_WHITE CHICKEN_TYPE_BROWN CHICKEN_TYPE_ROOSTER

--[[
	Version 1.1

	Now handling maps with multifruits. I hope.

Field info

	This script provides information on size, price, ownership and crop on each field on the map.
	This information is needed to plan what fields to buy to meet animal feed needs.

Invocation

	This script needs to be executed when the map is finished loading. For this reason, the mod user
	needs to trigger it by pressing LeftAlt-rf.

Harvest work

	The script also adds up the total area owned to be harvested with various harvesters or headers.
	This information will help decide on the size of harvesters and headers to buy.

	The script prints a usability ratio, indicating how much of the farmland has been converted
	to arable land (field area). If you do not plan on plowing a lot of unused farmland, then you
	should buy farmlands with a high usability ratio in order to reduce money wasted on unused
	land.

	All information is printed to the log file.
]]--

RealNumbersFieldInfo = {};

function myPrintFieldInfo(Id, landArea, fieldArea, landPrice, currency, owned, fruitName)
	print(string.format("Field %2.0f: Landarea = %4.1f ha, Fieldarea = %4.1f ha, Price = %7.0f %s, Is owned: %s, Fruittype: %s", Id*1.0, landArea, fieldArea, landPrice*1.0, tostring(currency), tostring(owned), tostring(fruitName)));
end;
function myPrintFieldInfo2(Id, landArea, fieldArea, landPrice, currency, owned, fruitName)
	print(string.format("Field %2.0f: Landarea = %4.1f ha, Fieldarea = %4.1f ha, Price = %7.0f %s, %s, Fruittype: %s", Id*1.0, landArea, fieldArea, landPrice*1.0, currency, tostring(owned), tostring(fruitName)));
end;
function myPrintFieldInfo3(text, number, textWidth, unit)
	print(string.format("%s =  %8.1f %s", text..string.rep(" ",textWidth-string.len(text)),number, unit));
end;
function myPrintFieldInfo4(number, number2)
	print(string.format("Field %2.0f: Usability ratio = %8.4f", number, number2));
end;

function RealNumbersFieldInfo:loadMap()
	print("\nFS19_RealLifeNumbers: RealNumbersFieldInfo active,  press lAlt-rf");
	print("-- Lists fields in field number order\n");
end;

function RealNumbersFieldInfo:keyEvent(unicode, sym, modifier, isDown)
	local currency = " ";
	local isDebug = RN.isDebug;
	local isDebug2 = false;
	local isDebug2 = false;
	local months = {"March","April","May","June","July","August","September","October","November","December","January","February"};



    local textWidth = 40;
	local ownedCropHa = {};
	local usabilityRatio = {};
	local Fruits = RN.Fruits;
	local grainCrops = "BARLEY MILLET OAT RYE SORGHUM SPELT TRITICALE WHEAT";
	local proteinCrops = "CANOLA SOYBEAN SUNFLOWER";
	local grassCrops = "ALFALFA CLOVER DRYLUZERNE GRASS INCARASE_GRASS LUCERNE LUZERNE SUDANGRASS";
	local vegetableCrops = "BEAN BEANS BLACKBEANS CABBAGE CARROT LETTUCE ONION PEAS REDCABBAGE";
	local specialtyCrops = "COFFEE COTTON CRANBERRY HEMP HOPS MUSTARD PEANUT POPLAR POPPY RICE SUGARCANE TOBACCO";
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end

	ownedCropHa.grain = 0;									--grain crops
	ownedCropHa.proteinCrop = 0;							--protein crop
	ownedCropHa.maize = 0;									--maize
	ownedCropHa.potato = 0;									--potato
	ownedCropHa.sugarbeet = 0;								--sugarbeet
	ownedCropHa.vegetables = 0;								--area harvested with with vegetable harvester
	ownedCropHa.grass = 0;									--area mowed with grass mower
	ownedCropHa.specialties = 0;
	ownedCropHa.farmlandtotal = 0;
	ownedCropHa.fieldstotal = 0;



	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_f) then

--		if g_currentMission.missionInfo.savegameDirectory ~= nil then


			print("\nLeft Alt-rf pressed\n");
			print("Map                   : "..g_currentMission.missionInfo.map.title.." "..g_currentMission.missionInfo.displayName);
			local money = g_currentMission.missionInfo.money;
			if money ~= nil then print("Money                 : "..money); end;
			local gameLevel = g_currentMission.missionInfo.economicDifficulty;
			if gameLevel ~= nil then
				print("Economic difficulty   : "..gameLevel);
				print("Sell price multiplier : "..g_currentMission.economyManager.PRICE_MULTIPLIER[gameLevel]);
				print("Buy price multiplier  : "..g_currentMission.economyManager.COST_MULTIPLIER[gameLevel]);
			end;
			print("Gamedays per year     : "..RN.gameDaysPerYear);

			local currentPeriod = g_seasons.weather.environment.period;
			if currentPeriod ~= nil then print("Current month      : "..months[currentPeriod]); end;

			local currentDay = g_currentMission.environment.currentDay;
			if currentDay ~= nil then print("Current game day      : "..currentDay); end;
				local hour = g_currentMission.environment.currentHour;
			local minute = g_currentMission.environment.currentMinute;

			if hour ~= nil or minute ~= nil then print("Time of day           : "..hour..":"..minute); end;
			print(" ");


			if g_fieldManager.fields ~= nil then
				print("Mean land purchase price = "..g_farmlandManager.pricePerHa.." "..currency.."/ha");
				print("Mean land rent price per year = "..RN.rentPricePerHa.." "..currency.."/ha");
				print(string.format("%s = %8.0f  %s","Mean land rent price for rest of year ",RN.rentYearFraction * RN.rentPricePerHa,currency.."/ha"));
				print(string.format("%s = %8.4f","Fraction of remaining rent year ",RN.rentYearFraction));
				print("\nAll field rent contracts are automatically terminated on the first day of mid-winter.");
				print("The rent fee decreases gradually in proportion to the remainding numbers of days in the rent year.");
				print("On all of the first day of mid-winter, the rent price is zero, and all attempts to rent land is nullified.");
				print("Starting on the next day, you can renew your rent contract or rent another field.");
				print("You can terminate a rent contract at any time by selling the rented field. The sell price ");
				print("corresponds to the rent for the remainder of the rent year. You pay only for time in use.\n");

				for k,field in pairs(g_fieldManager.fields) do
					local farmland = field.farmland;
					local farmlandId = farmland.id;
					local fieldId = field.fieldId;
					local fieldArea = field.fieldArea;
					local farmlandArea = farmland.areaInHa;
					local farmlandPrice = farmland.price;
					local farmlandIsOwned = farmland.isOwned;
					usabilityRatio[k] = fieldArea/farmlandArea;
					local maxKnownWeedState = field.maxKnownWeedState;
					local maxKnownGrowthState = field.maxKnownGrowthState;
					
					if maxKnownWeedState == nil then maxKnownWeedState = 0; end;
					if maxKnownGrowthState == nil then maxKnownGrowthState = 0; end;
					
					local fruitName = "Undefined";
					local fruitTypeIndex = field.fruitType;
					if fruitTypeIndex == nil then
--						fruitName = "Undefined";
						fruitName = RN.fieldFruits[fieldId];
						if fruitName == nil then fruitName = "Undefined" end;
						if farmlandIsOwned then
							ownedCropHa.farmlandtotal = ownedCropHa.farmlandtotal + farmlandArea;
							ownedCropHa.fieldstotal = ownedCropHa.fieldstotal + fieldArea;
							if RN.fieldStatus[farmlandId] == " For sale" then RN.fieldStatus[farmlandId] = " Owned   "; end;
							if RN.fieldStatus[farmlandId] == " For rent" then RN.fieldStatus[farmlandId] = " Rented  "; end;
						else
							if RN.fieldStatus[farmlandId] == " Rented" then RN.fieldStatus[farmlandId] = " For rent"; end;
						end;
					else
						fruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
						fruitName = fruitType.name;
						if fruitType.name == nil then fruitName = RN.fieldFruits[fieldId] end;
						if farmlandIsOwned then
							ownedCropHa.farmlandtotal = ownedCropHa.farmlandtotal + farmlandArea;
							ownedCropHa.fieldstotal = ownedCropHa.fieldstotal + fieldArea;
							if RN.fieldStatus[farmlandId] == " For sale" then RN.fieldStatus[farmlandId] = " Owned   "; end;
							if RN.fieldStatus[farmlandId] == " For rent" then RN.fieldStatus[farmlandId] = " Rented  "; end;
							local i1 = 0;
							i1,j1 = string.find(grainCrops,fruitName);
							if i1 ~= nil then ownedCropHa.grain = ownedCropHa.grain + fieldArea; end;
							local i2 = 0;
							i2,j2 = string.find(grassCrops,fruitName);
							if i2 ~= nil then ownedCropHa.grass = ownedCropHa.grass + fieldArea; end;
							local i3 = 0;
							i3,j3 = string.find(vegetableCrops,fruitName);
							if i3 ~= nil then ownedCropHa.vegetables = ownedCropHa.vegetables + fieldArea; end;
							local i4 = 0;
							i4,j4 = string.find(specialtyCrops,fruitName);
							if i4 ~= nil then ownedCropHa.specialties = ownedCropHa.specialties + fieldArea; end;
							local i5 = 0;
							i5,j5 = string.find(proteinCrops,fruitName);
							if i5 ~= nil then ownedCropHa.proteinCrop = ownedCropHa.proteinCrop + fieldArea; end;
							if (fruitName == "MAIZE") then ownedCropHa.maize = ownedCropHa.maize + fieldArea; end;
							if fruitName == "POTATO" then ownedCropHa.potato = ownedCropHa.potato + fieldArea; end;
							if fruitName == "SUGARBEET" then ownedCropHa.sugarbeet = ownedCropHa.sugarbeet + fieldArea; end;
						else
							if RN.fieldStatus[farmlandId] == " Rented" then RN.fieldStatus[farmlandId] = " For rent"; end;
						end;
					end;
					myPrintFieldInfo2(fieldId, farmlandArea, fieldArea, farmlandPrice, currency, RN.fieldStatus[farmlandId], fruitName);
--					print("maxKnownWeedState : "..maxKnownWeedState..";		maxKnownGrowthState : "..maxKnownGrowthState);
--					print(" ");
				end;
			end;
			print("\n---Owned land and feed-crop area---\n")

			myPrintFieldInfo3("Total farmland area owned/rented",ownedCropHa.farmlandtotal,textWidth," Ha");
			myPrintFieldInfo3("Total field area owned/rented",ownedCropHa.fieldstotal,textWidth," Ha");
			myPrintFieldInfo3("Grain crop area",ownedCropHa.grain,textWidth," Ha");
			myPrintFieldInfo3("Protein crop area",ownedCropHa.proteinCrop,textWidth," Ha");
			myPrintFieldInfo3("Maize area",ownedCropHa.maize,textWidth," Ha");
			myPrintFieldInfo3("Potato area",ownedCropHa.potato,textWidth," Ha");
			myPrintFieldInfo3("Sugarbeet area",ownedCropHa.sugarbeet,textWidth," Ha");
			myPrintFieldInfo3("Grass area",ownedCropHa.grass,textWidth," Ha");
--			myPrintFieldInfo3("Vegetable area",ownedCropHa.vegetables,textWidth," Ha");
--			myPrintFieldInfo3("Specialty area",ownedCropHa.specialties,textWidth," Ha\n");

			if g_fieldManager.fields ~= nil then
				print("\nThe usability ratio is: field area / farmland area");
				print("If the usability ratio is 0.5, the field area is 50% of the land area");
				print("The higher the usability ratio, the more arable field area you get for your money\n")
				for k,field in pairs(g_fieldManager.fields) do
					myPrintFieldInfo4(k, usabilityRatio[k]);
				end;
			end;
--		else
--			if not RN.multiPlayer then print("No save game yet. Save the game, quit and reload"); end;
--		end;
	end;


	ownedCropHa.grain = 0;									--grain crops
	ownedCropHa.proteinCrop = 0;							--protein crop
	ownedCropHa.maize = 0;									--maize
	ownedCropHa.potato = 0;									--potato
	ownedCropHa.sugarbeet = 0;								--sugarbeet
	ownedCropHa.vegetables = 0;								--area harvested with with vegetable harvester
	ownedCropHa.grass = 0;									--area mowed with grass mower
	ownedCropHa.specialties = 0;
	ownedCropHa.farmlandtotal = 0;
	ownedCropHa.fieldstotal = 0;



	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_g) then

--		if g_currentMission.missionInfo.savegameDirectory ~= nil then


			print("\nLeft Alt-rg pressed\n");
			print("Map                   : "..g_currentMission.missionInfo.map.title.." "..g_currentMission.missionInfo.displayName);
			local money = g_currentMission.missionInfo.money;
			if money ~= nil then print("Money                 : "..money); end;
			local gameLevel = g_currentMission.missionInfo.economicDifficulty;
			if gameLevel ~= nil then
				print("Economic difficulty   : "..gameLevel);
				print("Sell price multiplier : "..g_currentMission.economyManager.PRICE_MULTIPLIER[gameLevel]);
				print("Buy price multiplier  : "..g_currentMission.economyManager.COST_MULTIPLIER[gameLevel]);
			end;
			print("Gamedays per year     : "..RN.gameDaysPerYear);

			local currentPeriod = g_seasons.weather.environment.period;
			if currentPeriod ~= nil then print("Current month      : "..months[currentPeriod]); end;

			local currentDay = g_currentMission.environment.currentDay;
			if currentDay ~= nil then print("Current game day      : "..currentDay); end;
				local hour = g_currentMission.environment.currentHour;
			local minute = g_currentMission.environment.currentMinute;

			if hour ~= nil or minute ~= nil then print("Time of day           : "..hour..":"..minute); end;
			print(" ");


			if g_fieldManager.fields ~= nil then
				print("Mean land purchase price = "..g_farmlandManager.pricePerHa.." "..currency.."/ha");
				print("Mean land rent price per year = "..RN.rentPricePerHa.." "..currency.."/ha");
				print(string.format("%s = %8.0f  %s","Mean land rent price for rest of year ",RN.rentYearFraction * RN.rentPricePerHa,currency.."/ha"));
				print(string.format("%s = %8.4f","Fraction of remaining rent year ",RN.rentYearFraction));
				print("\nAll field rent contracts are automatically terminated on the first day of mid-winter.");
				print("The rent fee decreases gradually in proportion to the remainding numbers of days in the rent year.");
				print("On all of the first day of mid-winter, the rent price is zero, and all attempts to rent land is nullified.");
				print("Starting on the next day, you can renew your rent contract or rent another field.");
				print("You can terminate a rent contract at any time by selling the rented field. The sell price ");
				print("corresponds to the rent for the remainder of the rent year. You pay only for time in use.\n");

				for k,field in pairs(g_fieldManager.fields) do
					local farmland = field.farmland;
					local farmlandId = farmland.id;
					local fieldId = field.fieldId;
					local fieldArea = field.fieldArea;
					local farmlandArea = farmland.areaInHa;
					local farmlandPrice = farmland.price;
					local farmlandIsOwned = farmland.isOwned;
					usabilityRatio[k] = fieldArea/farmlandArea;
					local maxKnownWeedState = field.maxKnownWeedState;
					local maxKnownGrowthState = field.maxKnownGrowthState;
					
					if maxKnownWeedState == nil then maxKnownWeedState = 0; end;
					if maxKnownGrowthState == nil then maxKnownGrowthState = 0; end;
					
--					local fruitName = RN.fieldFruits[fieldId];
--					local fillTypeIndex = g_fruitTypeManager:getFillTypesByFruitTypeNames(fruitName);
--					local fruitTypeIndex = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(fillTypeIndex);
					local fruitTypeIndex = field.fruitType;
					if fruitTypeIndex == nil then
--						fruitName = "Undefined";
						fruitName = RN.fieldFruits[fieldId];
						if fruitName == nil then fruitName = "Undefined" end;
						if farmlandIsOwned then
							ownedCropHa.farmlandtotal = ownedCropHa.farmlandtotal + farmlandArea;
							ownedCropHa.fieldstotal = ownedCropHa.fieldstotal + fieldArea;
							if RN.fieldStatus[farmlandId] == " For sale" then RN.fieldStatus[farmlandId] = " Owned   "; end;
							if RN.fieldStatus[farmlandId] == " For rent" then RN.fieldStatus[farmlandId] = " Rented  "; end;
						else
							if RN.fieldStatus[farmlandId] == " Rented" then RN.fieldStatus[farmlandId] = " For rent"; end;
						end;
					else
						fruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
						fruitName = fruitType.name;
						if fruitType.name == nil then fruitName = RN.fieldFruits[fieldId] end;
						if farmlandIsOwned then
							ownedCropHa.farmlandtotal = ownedCropHa.farmlandtotal + farmlandArea;
							ownedCropHa.fieldstotal = ownedCropHa.fieldstotal + fieldArea;
							if RN.fieldStatus[farmlandId] == " For sale" then RN.fieldStatus[farmlandId] = " Owned   "; end;
							if RN.fieldStatus[farmlandId] == " For rent" then RN.fieldStatus[farmlandId] = " Rented  "; end;
							local i1 = 0;
							i1,j1 = string.find(grainCrops,fruitName);
							if i1 ~= nil then ownedCropHa.grain = ownedCropHa.grain + fieldArea; end;
							local i2 = 0;
							i2,j2 = string.find(grassCrops,fruitName);
							if i2 ~= nil then ownedCropHa.grass = ownedCropHa.grass + fieldArea; end;
							local i3 = 0;
							i3,j3 = string.find(vegetableCrops,fruitName);
							if i3 ~= nil then ownedCropHa.vegetables = ownedCropHa.vegetables + fieldArea; end;
							local i4 = 0;
							i4,j4 = string.find(specialtyCrops,fruitName);
							if i4 ~= nil then ownedCropHa.specialties = ownedCropHa.specialties + fieldArea; end;
							local i5 = 0;
							i5,j5 = string.find(proteinCrops,fruitName);
							if i5 ~= nil then ownedCropHa.proteinCrop = ownedCropHa.proteinCrop + fieldArea; end;
							if (fruitName == "MAIZE") then ownedCropHa.maize = ownedCropHa.maize + fieldArea; end;
							if fruitName == "POTATO" then ownedCropHa.potato = ownedCropHa.potato + fieldArea; end;
							if fruitName == "SUGARBEET" then ownedCropHa.sugarbeet = ownedCropHa.sugarbeet + fieldArea; end;
						else
							if RN.fieldStatus[farmlandId] == " Rented" then RN.fieldStatus[farmlandId] = " For rent"; end;
						end;
					end;
					if farmlandIsOwned then
						myPrintFieldInfo2(fieldId, farmlandArea, fieldArea, farmlandPrice, currency, RN.fieldStatus[farmlandId], fruitName);
--						print("maxKnownWeedState : "..maxKnownWeedState..";		maxKnownGrowthState : "..maxKnownGrowthState);
--						print(" ");
					end;
				end;
			end;
			print("\n---Owned land and feed-crop area---\n")

			myPrintFieldInfo3("Total farmland area owned/rented",ownedCropHa.farmlandtotal,textWidth," Ha");
			myPrintFieldInfo3("Total field area owned/rented",ownedCropHa.fieldstotal,textWidth," Ha");
			myPrintFieldInfo3("Grain crop area",ownedCropHa.grain,textWidth," Ha");
			myPrintFieldInfo3("Protein crop area",ownedCropHa.proteinCrop,textWidth," Ha");
			myPrintFieldInfo3("Maize area",ownedCropHa.maize,textWidth," Ha");
			myPrintFieldInfo3("Potato area",ownedCropHa.potato,textWidth," Ha");
			myPrintFieldInfo3("Sugarbeet area",ownedCropHa.sugarbeet,textWidth," Ha");
			myPrintFieldInfo3("Grass area",ownedCropHa.grass,textWidth," Ha");
--			myPrintFieldInfo3("Vegetable area",ownedCropHa.vegetables,textWidth," Ha");
--			myPrintFieldInfo3("Specialty area",ownedCropHa.specialties,textWidth," Ha\n");

	end;




	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_d) then
		print(" ");
		print("lAlt-rd pressed, defined in RealNumbersCommodityPrices.lua ");
		print(" ");
		print("Game days per year      : "..RN.gameDaysPerYear);
		print("Game days per season    : "..RNS.daysPerSeason);
		local dayInSeason = g_seasons.weather.environment.dayInSeason;
		print("Day in season           : "..dayInSeason);

		local currentPeriod = g_seasons.weather.environment.period;
		print("Current month           : "..months[currentPeriod]);

		print("Game days since start   : "..RN.currentDay);
		print("Game day of the year    : "..RN.gameDayofYear);
		print("Rent termination day    : "..RN.gameDayOfYearRentTerminates);
		print("Rent days left          : "..RN.rentDaysLeft);
		print("Rent year fraction left : "..round(RN.rentYearFraction * 1000)/1000);
		print(" ");
	end;

end;
function RealNumbersFieldInfo:update(dt)
end;
function RealNumbersFieldInfo:draw()
end;
function RealNumbersFieldInfo:deleteMap()
end;
function RealNumbersFieldInfo:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersFieldInfo);
