--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersForageProductionCost by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021

RealNumbersForageProductionCost = {};

function RealNumbersForageProductionCost:loadMap(name)
	print("\nFS19_RealLifeNumbers: RealNumbersForageProductionCost active\n")

	RNS.notRunYetRealNumbersForageProductionCost = true;
	RNS.upStartRealNumbersForageProductionCost = true;


	RN.forageCost.mowing 	 						= RN.equipment.equipmentCostPerHa["MOWERS"]; 				-- € per ha
	RN.forageCost.raking	 						= RN.equipment.equipmentCostPerHa["WINDROWERS"];			-- € per ha
	RN.forageCost.tedding    						= RN.equipment.equipmentCostPerHa["TEDDERS"];    			-- € per ha
	RN.forageCost.roundBaling   					= RN.equipment.equipmentCostPerHa["DRYGRASSROUNDBALE"];    	-- € per ha
	RN.forageCost.squareBaling  					= RN.equipment.equipmentCostPerHa["DRYGRASSSQUAREBALE"];    -- € per ha
	RN.forageCost.moving     						= 1.00;    	-- € per bale
	RN.forageCost.stacking   						= 2.00;    	-- € per bale
	RN.forageCost.wrapping   						= 7.50;    	-- € per bale
	RN.forageCost.plastic   						= 3.00;    	-- € per bale
	RN.forageCost.fertilizing						= 10.00;    -- € per bale per application
	RN.forageCost.maizeSilage						= 150.00;   -- € for foraging
	RN.forageCost.profit     						= 1.10;    	-- 10 %

-- Field work cost - Round bales

	RN.forageCost.grassRoundBales    		= (RN.fieldWorkCost.GRASS + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.roundBaling)/RN.growth.grassRoundBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.drygrassRoundBales    	= (RN.fieldWorkCost.DRYGRASS + RN.forageCost.mowing + RN.forageCost.tedding + RN.forageCost.raking + RN.forageCost.roundBaling)/RN.growth.drygrassRoundBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.grassSilageRoundBales   	= (RN.fieldWorkCost.GRASS + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.roundBaling)/RN.growth.grassSilageRoundBalesPerHa + RN.forageCost.wrapping + RN.forageCost.plastic  + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.strawRoundBales   		= (RN.forageCost.raking + RN.forageCost.roundBaling)/RN.growth.strawRoundBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.alfalfaRoundBales    		= (RN.fieldWorkCost.ALFALFA + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.roundBaling)/RN.growth.alfalfaRoundBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.dryalfalfaRoundBales  	= (RN.fieldWorkCost.DRYALFALFA + RN.forageCost.mowing + RN.forageCost.tedding + RN.forageCost.raking + RN.forageCost.roundBaling)/RN.growth.dryalfalfaRoundBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.alfalfaSilageRoundBales 	= (RN.fieldWorkCost.ALFALFA + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.roundBaling )/RN.growth.alfalfaSilageRoundBalesPerHa  + RN.forageCost.wrapping + RN.forageCost.plastic + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.cloverRoundBales    		= (RN.fieldWorkCost.CLOVER + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.roundBaling )/RN.growth.cloverRoundBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.drycloverRoundBales   	= (RN.fieldWorkCost.DRYCLOVER + RN.forageCost.mowing + RN.forageCost.tedding + RN.forageCost.raking + RN.forageCost.roundBaling)/RN.growth.drycloverRoundBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.cloverSilageRoundBales 	= (RN.fieldWorkCost.CLOVER + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.roundBaling)/RN.growth.cloverSilageRoundBalesPerHa + RN.forageCost.wrapping + RN.forageCost.plastic + RN.forageCost.moving + RN.forageCost.stacking;

	RN.forageCost.grassRoundBaleCost  		= RN.forageCost.grassRoundBales 					+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.drygrassRoundBaleCost  	= RN.forageCost.drygrassRoundBales 					+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.grassSilageRoundBaleCost 	= RN.forageCost.grassSilageRoundBales 				+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.strawRoundBaleCost  		= RN.forageCost.strawRoundBales;
	RN.forageCost.alfalfaRoundBaleCost 		= RN.forageCost.alfalfaRoundBales 					+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.dryalfalfaRoundBaleCost  	= RN.forageCost.dryalfalfaRoundBales 				+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.alfalfaSilageRoundBaleCost= RN.forageCost.alfalfaSilageRoundBales 			+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.cloverRoundBaleCost  		= RN.forageCost.cloverRoundBales 					+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.drycloverRoundBaleCost   	= RN.forageCost.drycloverRoundBales 				+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.cloverSilageRoundBaleCost	= RN.forageCost.cloverSilageRoundBales 				+ 2 * RN.forageCost.fertilizing;


-- Field work cost - Square bales

	RN.forageCost.grassSquareBales    		= (RN.fieldWorkCost.GRASS + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.squareBaling)/RN.growth.grassSquareBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.drygrassSquareBales    	= (RN.fieldWorkCost.DRYGRASS + RN.forageCost.mowing + RN.forageCost.tedding + RN.forageCost.raking + RN.forageCost.squareBaling)/RN.growth.drygrassSquareBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.grassSilageSquareBales   	= (RN.fieldWorkCost.GRASS + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.squareBaling)/RN.growth.grassSilageSquareBalesPerHa + RN.forageCost.wrapping + RN.forageCost.plastic  + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.strawSquareBales   		= (RN.forageCost.raking + RN.forageCost.squareBaling)/RN.growth.strawSquareBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.alfalfaSquareBales    	= (RN.fieldWorkCost.ALFALFA + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.squareBaling)/RN.growth.alfalfaSquareBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.dryalfalfaSquareBales  	= (RN.fieldWorkCost.DRYALFALFA + RN.forageCost.mowing + RN.forageCost.tedding + RN.forageCost.raking + RN.forageCost.squareBaling )/RN.growth.dryalfalfaSquareBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.alfalfaSilageSquareBales 	= (RN.fieldWorkCost.ALFALFA + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.squareBaling )/RN.growth.alfalfaSilageSquareBalesPerHa  + RN.forageCost.wrapping + RN.forageCost.plastic + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.cloverSquareBales    		= (RN.fieldWorkCost.CLOVER + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.squareBaling )/RN.growth.cloverSquareBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.drycloverSquareBales   	= (RN.fieldWorkCost.DRYCLOVER + RN.forageCost.mowing + RN.forageCost.tedding + RN.forageCost.raking + RN.forageCost.squareBaling)/RN.growth.drycloverSquareBalesPerHa + RN.forageCost.moving + RN.forageCost.stacking;
	RN.forageCost.cloverSilageSquareBales 	= (RN.fieldWorkCost.CLOVER + RN.forageCost.mowing + RN.forageCost.raking + RN.forageCost.squareBaling)/RN.growth.cloverSilageSquareBalesPerHa + RN.forageCost.wrapping + RN.forageCost.plastic + RN.forageCost.moving + RN.forageCost.stacking;


	RN.forageCost.grassSquareBaleCost  			= RN.forageCost.grassSquareBales   				+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.drygrassSquareBaleCost  		= RN.forageCost.drygrassSquareBales     		+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.grassSilageSquareBaleCost		= RN.forageCost.grassSilageSquareBales  		+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.strawSquareBaleCost  			= RN.forageCost.strawSquareBales;
	RN.forageCost.alfalfaSquareBaleCost			= RN.forageCost.alfalfaSquareBales 				+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.dryalfalfaSquareBaleCost 		= RN.forageCost.dryalfalfaSquareBales     		+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.alfalfaSilageSquareBaleCost	= RN.forageCost.alfalfaSilageSquareBales  	    + 2 * RN.forageCost.fertilizing;
	RN.forageCost.cloverSquareBaleCost 			= RN.forageCost.cloverSquareBales  				+ 2 * RN.forageCost.fertilizing;
	RN.forageCost.drycloverSquareBaleCost 		= RN.forageCost.drycloverSquareBales     	    + 2 * RN.forageCost.fertilizing;
	RN.forageCost.cloverSilageSquareBaleCost	= RN.forageCost.cloverSilageSquareBales  	    + 2 * RN.forageCost.fertilizing;


--[[
	print(" ")
	print("grassRoundBalePrice 			= "..RN.forageCost.grassRoundBalePrice.."  €");
	print("alfalfaRoundBalePrice 		= "..RN.forageCost.alfalfaRoundBalePrice.."  €");
	print("cloverRoundBalePrice 		= "..RN.forageCost.cloverRoundBalePrice.."  €");
	print("drygrassRoundBalePrice 		= "..RN.forageCost.drygrassRoundBalePrice.."  €");
	print("dryalfalfaRoundBalePrice 	= "..RN.forageCost.dryalfalfaRoundBalePrice.."  €");
	print("drycloverRoundBalePrice 		= "..RN.forageCost.drycloverRoundBalePrice.."  €");
	print("grassSilageRoundBalePrice 	= "..RN.forageCost.grassSilageRoundBalePrice.."  €");
	print("alfalfaSilageRoundBalePrice 	= "..RN.forageCost.alfalfaSilageRoundBalePrice.."  €");
	print("cloverSilageRoundBalePrice 	= "..RN.forageCost.cloverSilageRoundBalePrice.."  €");
	print("strawRoundBalePrice 			= "..RN.forageCost.strawRoundBalePrice.."  €");
	print(" ")
	print("grassSquareBalePrice         = "..RN.forageCost.grassSquareBalePrice.."  €");
	print("alfalfaSquareBalePrice       = "..RN.forageCost.alfalfaSquareBalePrice.."  €");
	print("cloverSquareBalePrice 		= "..RN.forageCost.cloverSquareBalePrice.."  €");
	print("drygrassSquareBalePrice		= "..RN.forageCost.drygrassSquareBalePrice.."  €");
	print("dryalfalfaSquareBalePrice 	= "..RN.forageCost.dryalfalfaSquareBalePrice.."  €");
	print("drycloverSquareBalePrice 	= "..RN.forageCost.drycloverSquareBalePrice.."  €");
	print("grassSilageSquareBalePrice 	= "..RN.forageCost.grassSilageSquareBalePrice.."  €");
	print("alfalfaSilageSquareBalePrice = "..RN.forageCost.alfalfaSilageSquareBalePrice.."  €");
	print("cloverSilageSquareBalePrice 	= "..RN.forageCost.cloverSilageSquareBalePrice.."  €");
	print("strawSquareBalePrice 		= "..RN.forageCost.strawSquareBalePrice.."  €");
	print(" ")

]]--

--FORAGE income per ha


	RN.forageCost.grassBaleIncomePerHa			= RN.growth.grassRoundBalesPerHa  			* RN.forageCost.grassRoundBalePrice;
	RN.forageCost.drygrassBaleIncomePerHa		= RN.growth.drygrassRoundBalesPerHa    		* RN.forageCost.drygrassRoundBalePrice;
	RN.forageCost.grassSilageBaleIncomePerHa	= RN.growth.grassSilageRoundBalesPerHa 		* RN.forageCost.grassSilageRoundBalePrice;
	RN.forageCost.alfalfaBaleIncomePerHa		= RN.growth.alfalfaRoundBalesPerHa			* RN.forageCost.alfalfaRoundBalePrice;
	RN.forageCost.dryalfalfaBaleIncomePerHa		= RN.growth.dryalfalfaRoundBalesPerHa    	* RN.forageCost.dryalfalfaRoundBalePrice;
	RN.forageCost.alfalfaSilageBaleIncomePerHa	= RN.growth.alfalfaSilageRoundBalesPerHa 	* RN.forageCost.alfalfaSilageRoundBalePrice;
	RN.forageCost.cloverBaleIncomePerHa	    	= RN.growth.cloverRoundBalesPerHa 			* RN.forageCost.cloverRoundBalePrice;
	RN.forageCost.drycloverBaleIncomePerHa		= RN.growth.drycloverRoundBalesPerHa    	* RN.forageCost.drycloverRoundBalePrice;
	RN.forageCost.cloverSilageBaleIncomePerHa	= RN.growth.cloverSilageRoundBalesPerHa 	* RN.forageCost.cloverSilageRoundBalePrice;

--FORAGE cost per ha

	RN.forageCost.grassBaleCostPerHa			= RN.growth.grassRoundBalesPerHa  			* RN.forageCost.grassRoundBaleCost;
	RN.forageCost.drygrassBaleCostPerHa			= RN.growth.drygrassRoundBalesPerHa    		* RN.forageCost.drygrassRoundBaleCost;
	RN.forageCost.grassSilageBaleCostPerHa		= RN.growth.grassSilageRoundBalesPerHa 		* RN.forageCost.grassSilageRoundBaleCost;
	RN.forageCost.alfalfaBaleCostPerHa			= RN.growth.alfalfaRoundBalesPerHa			* RN.forageCost.alfalfaRoundBaleCost;
	RN.forageCost.dryalfalfaBaleCostPerHa		= RN.growth.dryalfalfaRoundBalesPerHa    	* RN.forageCost.dryalfalfaRoundBaleCost;
	RN.forageCost.alfalfaSilageBaleCostPerHa	= RN.growth.alfalfaSilageRoundBalesPerHa 	* RN.forageCost.alfalfaSilageRoundBaleCost;
	RN.forageCost.cloverBaleCostPerHa	    	= RN.growth.cloverRoundBalesPerHa 			* RN.forageCost.cloverRoundBaleCost;
	RN.forageCost.drycloverBaleCostPerHa		= RN.growth.drycloverRoundBalesPerHa    	* RN.forageCost.drycloverRoundBaleCost;
	RN.forageCost.cloverSilageBaleCostPerHa		= RN.growth.cloverSilageRoundBalesPerHa 	* RN.forageCost.cloverSilageRoundBaleCost;



end;

function RealNumbersForageProductionCost:keyEvent(unicode, sym, modifier, isDown)
	local currency = "€";	-- or  "$" or "£"
    local textWidth = 40; 	-- text width in log file

	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_b) then
		print("\nlAlt-rb pressed: RealNumbersForageProductionCost\n");

		print("Yield numbers are per cut");
		print("Grass cuts per year : "..RN.annualGrassCuttings);
		print("Alfalfa cuts per year : "..RN.annualAlfalfaCuttings);

		print(" ")
		myPrint("Alfalfa Mass Per Ha",RN.growth.alfalfaMassPerHa,textWidth,"  kg/ha");
		myPrintFloat("Alfalfa Bale Density",RN.growth.alfalfaBaleDensity ,textWidth,"  kg/L");
		myPrint("Alfalfa Volume Per Ha",RN.growth.alfalfaVolumePerHa,textWidth,"  L/ha");
		myPrint("Alfalfa Net Volume Per Ha",RN.growth.alfalfaNetVolumePerHa,textWidth,"  L/ha");
		myPrint("Alfalfa Round Bale Volume",RN.growth.alfalfaRoundBaleVolume,textWidth,"  L");
		myPrint("Alfalfa Square Bale Volume",RN.growth.alfalfaSquareBaleVolume,textWidth,"  L");
		myPrint("Alfalfa Round Bale Mass",RN.growth.alfalfaRoundBaleMass,textWidth,"  kg");
		myPrint("Alfalfa Square Bale Mass",RN.growth.alfalfaSquareBaleMass,textWidth,"  kg");
		myPrintFloat("Alfalfa Round Bales Per Ha",RN.growth.alfalfaRoundBalesPerHa,textWidth,"  -");
		myPrintFloat("Alfalfa Square Bales Per Ha",RN.growth.alfalfaSquareBalesPerHa,textWidth,"  -");
		myPrint("Alfalfa Income Per Ha",RN.forageCost.alfalfaBaleIncomePerHa,textWidth,currency);
		myPrintFloat("Alfalfa Round Bale Cost",RN.forageCost.alfalfaRoundBaleCost,textWidth,currency);
		myPrintFloat("Alfalfa Round Bale Price",RN.forageCost.alfalfaRoundBalePrice,textWidth,currency);
		myPrintFloat("Alfalfa Square Bale Cost",RN.forageCost.alfalfaSquareBaleCost,textWidth,currency);
		myPrintFloat("Alfalfa Square Bale Price",RN.forageCost.alfalfaSquareBalePrice,textWidth,currency);
		myPrintFloat("Alfalfa Price Per 1000 L",RN.forageCost.alfalfaPricePer1000L,textWidth,currency.."/1000L");
		myPrintFloat("Alfalfa Price Per 100 kg",RN.forageCost.alfalfaPricePer100kg,textWidth,currency.."/100kg");

		print(" ")
		myPrint("Clover Mass Per Ha",RN.growth.cloverMassPerHa,textWidth,"  kg/ha");
		myPrintFloat("Clover Bale Density",RN.growth.cloverBaleDensity ,textWidth,"  kg/L");
		myPrint("Clover Volume Per Ha",RN.growth.cloverVolumePerHa,textWidth,"  L/ha");
		myPrint("Clover Net Volume Per Ha",RN.growth.cloverNetVolumePerHa,textWidth,"  L/ha");
		myPrint("Clover Round Bale Volume",RN.growth.cloverRoundBaleVolume,textWidth,"  L");
		myPrint("Clover Square Bale Volume",RN.growth.cloverSquareBaleVolume,textWidth,"  L");
		myPrint("Clover Round Bale Mass",RN.growth.cloverRoundBaleMass,textWidth,"  kg");
		myPrint("Clover Square Bale Mass",RN.growth.cloverSquareBaleMass,textWidth,"  kg");
		myPrintFloat("Clover Round Bales Per Ha",RN.growth.cloverRoundBalesPerHa,textWidth,"  -");
		myPrintFloat("Clover Square Bales Per Ha",RN.growth.cloverSquareBalesPerHa,textWidth,"  -");
		myPrint("Clover Income Per Ha",RN.forageCost.cloverBaleIncomePerHa,textWidth,currency);
		myPrintFloat("Clover Round Bale Cost",RN.forageCost.cloverRoundBaleCost,textWidth,currency);
		myPrintFloat("Clover Round Bale Price",RN.forageCost.cloverRoundBalePrice,textWidth,currency);
		myPrintFloat("Clover Square Bale Cost",RN.forageCost.cloverSquareBaleCost,textWidth,currency);
		myPrintFloat("Clover Square Bale Price",RN.forageCost.cloverSquareBalePrice,textWidth,currency);
		myPrintFloat("Clover Price Per 1000 L",RN.forageCost.cloverPricePer1000L,textWidth,currency.."/1000L");
		myPrintFloat("Clover Price Per 100 kg",RN.forageCost.cloverPricePer100kg,textWidth,currency.."/100kg");

		print(" ")
		myPrint("Grass Mass Per Ha",RN.growth.grassMassPerHa,textWidth,"  kg/ha");
		myPrintFloat("Grass Bale Density",RN.growth.grassBaleDensity ,textWidth,"  kg/L");
		myPrint("Grass Volume Per Ha",RN.growth.grassVolumePerHa,textWidth,"  L/ha");
		myPrint("Grass Net Volume Per Ha",RN.growth.grassNetVolumePerHa,textWidth,"  L/ha");
		myPrint("Grass Round Bale Volume",RN.growth.grassRoundBaleVolume,textWidth,"  L");
		myPrint("Grass Square Bale Volume",RN.growth.grassSquareBaleVolume,textWidth,"  L");
		myPrint("Grass Round Bale Mass",RN.growth.grassRoundBaleMass,textWidth,"  kg");
		myPrint("Grass Square Bale Mass",RN.growth.grassSquareBaleMass,textWidth,"  kg");
		myPrintFloat("Grass Round Bales Per Ha",RN.growth.grassRoundBalesPerHa,textWidth,"  -");
		myPrintFloat("Grass Square Bales Per Ha",RN.growth.grassSquareBalesPerHa,textWidth,"  -");
		myPrint("Grass Income Per Ha",RN.forageCost.grassBaleIncomePerHa,textWidth,currency);
		myPrintFloat("Grass Round Bale Cost",RN.forageCost.grassRoundBaleCost,textWidth,currency);
		myPrintFloat("Grass Round Bale Price",RN.forageCost.grassRoundBalePrice,textWidth,currency);
		myPrintFloat("Grass Square Bale Cost",RN.forageCost.grassSquareBaleCost,textWidth,currency);
		myPrintFloat("Grass Square Bale Price",RN.forageCost.grassSquareBalePrice,textWidth,currency);
		myPrintFloat("Grass Price Per 1000 L",RN.forageCost.grassPricePer1000L,textWidth,currency.."/1000L");
		myPrintFloat("Grass Price Per 100 kg",RN.forageCost.grassPricePer100kg,textWidth,currency.."/100kg");

		print(" ")

		myPrint("Dryalfalfa Mass Per Ha",RN.growth.dryalfalfaMassPerHa,textWidth,"  kg/ha");
		myPrintFloat("Dryalfalfa Grass Bale Density",RN.growth.dryalfalfaBaleDensity,textWidth,"  kg/L");
		myPrint("Dryalfalfa Grass Volume Per Ha",RN.growth.dryalfalfaVolumePerHa,textWidth,"  L/ha");
		myPrint("Dryalfalfa Net Volume Per Ha",RN.growth.dryalfalfaNetVolumePerHa,textWidth,"  L/ha");
		myPrint("Dryalfalfa Round Bale Volume",RN.growth.dryalfalfaRoundBaleVolume,textWidth,"  L");
		myPrint("Dryalfalfa Square Bale Volume",RN.growth.dryalfalfaSquareBaleVolume,textWidth,"  L");
		myPrint("Dryalfalfa Round Bale Mass",RN.growth.dryalfalfaRoundBaleMass,textWidth,"  kg");
		myPrint("Dryalfalfa Square Bale Mass",RN.growth.dryalfalfaSquareBaleMass,textWidth,"  kg");
		myPrintFloat("Dryalfalfa Round Bales Per Ha",RN.growth.dryalfalfaRoundBalesPerHa,textWidth,"  -");
		myPrintFloat("Dryalfalfa Square Bales Per Ha",RN.growth.dryalfalfaSquareBalesPerHa,textWidth,"  -");
		myPrint("Dryalfalfa Income Per Ha",RN.forageCost.dryalfalfaBaleIncomePerHa,textWidth,currency);
		myPrintFloat("Dryalfalfa Round Bale Cost",RN.forageCost.dryalfalfaRoundBaleCost,textWidth,currency)
		myPrintFloat("Dryalfalfa Round Bale Price",RN.forageCost.dryalfalfaRoundBalePrice,textWidth,currency);
		myPrintFloat("Dryalfalfa Square Bale Cost",RN.forageCost.dryalfalfaSquareBaleCost,textWidth,currency);
		myPrintFloat("Dryalfalfa Square Bale Price",RN.forageCost.dryalfalfaSquareBalePrice,textWidth,currency);
		myPrintFloat("Dryalfalfa Price Per 1000L",RN.forageCost.dryalfalfaPricePer1000L,textWidth,currency.."/1000L");
		myPrintFloat("Dryalfalfa Price Per 100kg",RN.forageCost.dryalfalfaPricePer100kg,textWidth,currency.."/100kg");
		print(" ")

		myPrint("Dryclover Mass Per Ha",RN.growth.drycloverMassPerHa,textWidth,"  kg/ha");
		myPrintFloat("Dryclover Grass Bale Density",RN.growth.drycloverBaleDensity,textWidth,"  kg/L");
		myPrint("Dryclover Grass Volume Per Ha",RN.growth.drycloverVolumePerHa,textWidth,"  L/ha");
		myPrint("Dryclover Net Volume Per Ha",RN.growth.drycloverNetVolumePerHa,textWidth,"  L/ha");
		myPrint("Dryclover Round Bale Volume",RN.growth.drycloverRoundBaleVolume,textWidth,"  L");
		myPrint("Dryclover Square Bale Volume",RN.growth.drycloverSquareBaleVolume,textWidth,"  L");
		myPrint("Dryclover Round Bale Mass",RN.growth.drycloverRoundBaleMass,textWidth,"  kg");
		myPrint("Dryclover Square Bale Mass",RN.growth.drycloverSquareBaleMass,textWidth,"  kg");
		myPrintFloat("Dryclover Round Bales Per Ha",RN.growth.drycloverRoundBalesPerHa,textWidth,"  -");
		myPrintFloat("Dryclover Square Bales Per Ha",RN.growth.drycloverSquareBalesPerHa,textWidth,"  -");
		myPrint("Dryclover Income Per Ha",RN.forageCost.drycloverBaleIncomePerHa,textWidth,currency);
		myPrintFloat("Dryclover Round Bale Cost",RN.forageCost.drycloverRoundBaleCost,textWidth,currency);
		myPrintFloat("Dryclover Round Bale Price",RN.forageCost.drycloverRoundBalePrice,textWidth,currency);
		myPrintFloat("Dryclover Square Bale Cost",RN.forageCost.drycloverSquareBaleCost,textWidth,currency);
		myPrintFloat("Dryclover Square Bale Price",RN.forageCost.drycloverSquareBalePrice,textWidth,currency);
		myPrintFloat("Dryclover Price Per 1000L",RN.forageCost.drycloverPricePer1000L,textWidth,currency.."/1000L");
		myPrintFloat("Dryclover Price Per 100kg",RN.forageCost.drycloverPricePer100kg,textWidth,currency.."/100kg");
		print(" ")

		myPrint("Drygrass Mass Per Ha",RN.growth.drygrassMassPerHa,textWidth,"  kg/ha");
		myPrintFloat("Drygrass Grass Bale Density",RN.growth.drygrassBaleDensity,textWidth,"  kg/L");
		myPrint("Drygrass Grass Volume Per Ha",RN.growth.drygrassVolumePerHa,textWidth,"  L/ha");
		myPrint("Drygrass Net Volume Per Ha",RN.growth.drygrassNetVolumePerHa,textWidth,"  L/ha");
		myPrint("Drygrass Round Bale Volume",RN.growth.drygrassRoundBaleVolume,textWidth,"  L");
		myPrint("Drygrass Square Bale Volume",RN.growth.drygrassSquareBaleVolume,textWidth,"  L");
		myPrint("Drygrass Round Bale Mass",RN.growth.drygrassRoundBaleMass,textWidth,"  kg");
		myPrint("Drygrass Square Bale Mass",RN.growth.drygrassSquareBaleMass,textWidth,"  kg");
		myPrintFloat("Drygrass Round Bales Per Ha",RN.growth.drygrassRoundBalesPerHa,textWidth,"  -");
		myPrintFloat("Drygrass Square Bales Per Ha",RN.growth.drygrassSquareBalesPerHa,textWidth,"  -");
		myPrint("Drygrass Income Per Ha",RN.forageCost.drygrassBaleIncomePerHa,textWidth,currency);
		myPrintFloat("Drygrass Round Bale Cost",RN.forageCost.drygrassRoundBaleCost,textWidth,currency);
		myPrintFloat("Drygrass Round Bale Price",RN.forageCost.drygrassRoundBalePrice,textWidth,currency);
		myPrintFloat("Drygrass Square Bale Cost",RN.forageCost.drygrassSquareBaleCost,textWidth,currency);
		myPrintFloat("Drygrass Square Bale Price",RN.forageCost.drygrassSquareBalePrice,textWidth,currency);
		myPrintFloat("Drygrass Price Per 1000L",RN.forageCost.drygrassPricePer1000L,textWidth,currency.."/1000L");
		myPrintFloat("Drygrass Price Per 100kg",RN.forageCost.drygrassPricePer100kg,textWidth,currency.."/100kg");
		print(" ")

		myPrint("Alfalfa silage Mass Per Ha",RN.growth.alfalfaSilageMassPerHa,textWidth," kg/ha");
		myPrintFloat("Alfalfa silage Alfalfa Bale Density",RN.growth.alfalfaSilageBaleDensity,textWidth,currency);
		myPrint("Alfalfa silage Alfalfa Volume Per Ha",RN.growth.alfalfaSilageVolumePerHa,textWidth,"  L/ha");
		myPrint("Alfalfa silage Net Volume Per Ha",RN.growth.alfalfaSilageNetVolumePerHa,textWidth,"  L/ha");
		myPrint("Alfalfa silage Round Bale Volume",RN.growth.alfalfaSilageRoundBaleVolume,textWidth,"  L");
		myPrint("Alfalfa silage Square Bale Volume",RN.growth.alfalfaSilageSquareBaleVolume,textWidth,"  L");
		myPrint("Alfalfa silage Round Bale Mass",RN.growth.alfalfaSilageRoundBaleMass,textWidth,"  kg");
		myPrint("Alfalfa silage Square Bale Mass",RN.growth.alfalfaSilageSquareBaleMass,textWidth,"  kg");
		myPrintFloat("Alfalfa silage Round Bales Per Ha",RN.growth.alfalfaSilageRoundBalesPerHa,textWidth,"  -");
		myPrintFloat("Alfalfa silage Square Bales Per Ha",RN.growth.alfalfaSilageSquareBalesPerHa,textWidth,"  -");
		myPrint("Alfalfa silage Income Per Ha",RN.forageCost.alfalfaSilageBaleIncomePerHa,textWidth,currency);
		myPrintFloat("Alfalfa silage Round Bale Cost",RN.forageCost.alfalfaSilageRoundBaleCost,textWidth,currency);
		myPrintFloat("Alfalfa silage Round Bale Price",RN.forageCost.alfalfaSilageRoundBalePrice,textWidth,currency);
		myPrintFloat("Alfalfa silage Square Bale Cost",RN.forageCost.alfalfaSilageSquareBaleCost,textWidth,currency);
		myPrintFloat("Alfalfa silage Square Bale Price",RN.forageCost.alfalfaSilageSquareBalePrice,textWidth,currency);
		myPrintFloat("Alfalfa silage Price Per 1000L",RN.forageCost.alfalfaSilagePricePer1000L,textWidth,currency.."/1000L");
		myPrintFloat("Alfalfa silage Price Per 100kg",RN.forageCost.alfalfaSilagePricePer100kg,textWidth,currency.."/100kg");
		print(" ")

		myPrint("Clover silage Mass Per Ha",RN.growth.cloverSilageMassPerHa,textWidth," kg/ha");
		myPrintFloat("Clover silage Clover Bale Density",RN.growth.cloverSilageBaleDensity,textWidth,currency);
		myPrint("Clover silage Clover Volume Per Ha",RN.growth.cloverSilageVolumePerHa,textWidth,"  L/ha");
		myPrint("Clover silage Net Volume Per Ha",RN.growth.cloverSilageNetVolumePerHa,textWidth,"  L/ha");
		myPrint("Clover silage Round Bale Volume",RN.growth.cloverSilageRoundBaleVolume,textWidth,"  L");
		myPrint("Clover silage Square Bale Volume",RN.growth.cloverSilageSquareBaleVolume,textWidth,"  L");
		myPrint("Clover silage Round Bale Mass",RN.growth.cloverSilageRoundBaleMass,textWidth,"  kg");
		myPrint("Clover silage Square Bale Mass",RN.growth.cloverSilageSquareBaleMass,textWidth,"  kg");
		myPrintFloat("Clover silage Round Bales Per Ha",RN.growth.cloverSilageRoundBalesPerHa,textWidth,"  -");
		myPrintFloat("Clover silage Square Bales Per Ha",RN.growth.cloverSilageSquareBalesPerHa,textWidth,"  -");
		myPrint("Clover silage Income Per Ha",RN.forageCost.cloverSilageBaleIncomePerHa,textWidth,currency);
		myPrintFloat("Clover silage Round Bale Cost",RN.forageCost.cloverSilageRoundBaleCost,textWidth,currency);
		myPrintFloat("Clover silage Round Bale Price",RN.forageCost.cloverSilageRoundBalePrice,textWidth,currency);
		myPrintFloat("Clover silage Square Bale Cost",RN.forageCost.cloverSilageSquareBaleCost,textWidth,currency);
		myPrintFloat("Clover silage Square Bale Price",RN.forageCost.cloverSilageSquareBalePrice,textWidth,currency);
		myPrintFloat("Clover silage Price Per 1000L",RN.forageCost.cloverSilagePricePer1000L,textWidth,currency.."/1000L");
		myPrintFloat("Clover silage Price Per 100kg",RN.forageCost.cloverSilagePricePer100kg,textWidth,currency.."/100kg");
		print(" ")

		myPrint("Grass silage Mass Per Ha",RN.growth.grassSilageMassPerHa,textWidth," kg/ha");
		myPrintFloat("Grass silage Grass Bale Density",RN.growth.grassSilageBaleDensity,textWidth,currency);
		myPrint("Grass silage Grass Volume Per Ha",RN.growth.grassSilageVolumePerHa,textWidth,"  L/ha");
		myPrint("Grass silage Net Volume Per Ha",RN.growth.grassSilageNetVolumePerHa,textWidth,"  L/ha");
		myPrint("Grass silage Round Bale Volume",RN.growth.grassSilageRoundBaleVolume,textWidth,"  L");
		myPrint("Grass silage Square Bale Volume",RN.growth.grassSilageSquareBaleVolume,textWidth,"  L");
		myPrint("Grass silage Round Bale Mass",RN.growth.grassSilageRoundBaleMass,textWidth,"  kg");
		myPrint("Grass silage Square Bale Mass",RN.growth.grassSilageSquareBaleMass,textWidth,"  kg");
		myPrintFloat("Grass silage Round Bales Per Ha",RN.growth.grassSilageRoundBalesPerHa,textWidth,"  -");
		myPrintFloat("Grass silage Square Bales Per Ha",RN.growth.grassSilageSquareBalesPerHa,textWidth,"  -");
		myPrint("Grass silage Income Per Ha",RN.forageCost.grassSilageBaleIncomePerHa,textWidth,currency);
		myPrintFloat("Grass silage Round Bale Cost",RN.forageCost.grassSilageRoundBaleCost,textWidth,currency);
		myPrintFloat("Grass silage Round Bale Price",RN.forageCost.grassSilageRoundBalePrice,textWidth,currency);
		myPrintFloat("Grass silage Square Bale Cost",RN.forageCost.grassSilageSquareBaleCost,textWidth,currency);
		myPrintFloat("Grass silage Square Bale Price",RN.forageCost.grassSilageSquareBalePrice,textWidth,currency);
		myPrintFloat("Grass silage Price Per 1000L",RN.forageCost.grassSilagePricePer1000L,textWidth,currency.."/1000L");
		myPrintFloat("Grass silage Price Per 100kg",RN.forageCost.grassSilagePricePer100kg,textWidth,currency.."/100kg");
		print(" ")
		myPrintFloat("straw Round Bale Cost",RN.forageCost.strawRoundBaleCost,textWidth,currency);
		myPrintFloat("straw Round Bale Price",RN.forageCost.strawRoundBalePrice,textWidth,currency);
		myPrintFloat("straw Square Bale Cost",RN.forageCost.strawSquareBaleCost,textWidth,currency);
		myPrintFloat("straw Square Bale Price",RN.forageCost.strawSquareBalePrice,textWidth,currency);
		myPrintFloat("straw Price Per 1000L",RN.forageCost.strawPricePer1000L,textWidth,currency.."/1000L");
		myPrintFloat("straw Price Per 100kg = ",RN.forageCost.strawPricePer100kg,textWidth,currency.."/100kg");
		print(" ")


	end;
end;

function RealNumbersForageProductionCost:update(dt)
end;
function RealNumbersForageProductionCost:draw()
end;
function RealNumbersForageProductionCost:deleteMap()
end;
function RealNumbersForageProductionCost:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersForageProductionCost);
