--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersLeasing by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021


RealNumbersLeasing = {};


function RealNumbersLeasing:loadMap(name)
	local currency = "€";	-- or  "$" or "£"
	local textWidth = 40; 	-- text width in log file
	local isDebug = RN.isDebug;  	-- Change to False when not debugging
	local lifeTime = RN.equipmentLifeYears ;
	local annualLoss = RN.equipmentAnnualLoss;
	local intialPayment = RN.leaseInitialInstallment;
	local leaseInterest = RN.leaseAnnualInterestRate;

	local baseValue = 100000;
	local endTimeValue = (1-annualLoss)^lifeTime * baseValue;
	local initialPaymentValue = intialPayment * baseValue;
	local baseLoan = baseValue - (initialPaymentValue + endTimeValue);
	local loanInterest = ((1+leaseInterest)^lifeTime - 1) * baseLoan;
	local totalLoan = baseLoan + loanInterest;
	local installmentPerDay = totalLoan/(RN.gameDaysPerYear * lifeTime);
	local installmentPerHour = installmentPerDay/24;
	local leaseFactorPerDay = installmentPerDay/baseValue;
	local leaseFactorPerHour = installmentPerHour/baseValue;

	local gameMoneyUnit = g_i18n.monloanInteresteyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;

	print("\nFS19_RealLifeNumbers: RealNumbersLeasing active\n")

	RNS.notRunYetRealNumbersLeasing = true;
	RNS.upStartRealNumbersLeasing = true;

	if isDebug then
		print("\n Long term leasing model: RN.leaseMode = 1 \n");
		myPrint("Equipment life time",lifeTime,textWidth," years ");
		myPrintFloat("Annual depreciation factor",annualLoss,textWidth," ");
		myPrintFloat("Initial down payment",intialPayment,textWidth, " ");
		myPrintFloat("Loan interest",leaseInterest,textWidth, " ");
		myPrint("Example loan", baseValue, textWidth, currency);
		myPrint("End time value", endTimeValue, textWidth, currency);
		myPrint("Initial down payment", initialPaymentValue, textWidth, currency);
		myPrint("Base loan", baseLoan, textWidth, currency);
		myPrint("Loan interest (accumulated)", loanInterest, textWidth, currency);
		myPrint("Total loan", totalLoan, textWidth, currency);
		myPrint("Daily payment", installmentPerDay, textWidth, currency);
		myPrint("Hourly payment", installmentPerHour, textWidth, currency);
		myPrintFloat("Dayly payment factor", leaseFactorPerDay, textWidth, " ");
		myPrintFloat("Hourly payment factor", leaseFactorPerHour, textWidth, " ");
		print(" ");
		
		print("\nContract leasing: RN.leaseMode = 0 \n");
		print("Only active fee is the hourly rate. Deposit and day fee are set to zero.");
		print("The hourly rate is higher for contract rate. It is calculated based on");
		print("real-life contract rates per ha and an estimated field capacity (ha/hour)");
		print("calculated from the implement width, real-life implement work speed, and");
		print("field efficiency.\n");
	end;

	if RN.leaseMode == 0 then
		RN.DEFAULT_RUNNING_LEASING_FACTOR = RN.leasePerHourScale * 0.002;
	else
		RN.DEFAULT_RUNNING_LEASING_FACTOR = RN.leasePerHourScale * leaseFactorPerHour; 	-- Lease/hour as fraction of price. Ingame = 0.021.
	end;
	RN.PER_DAY_LEASING_FACTOR         = RN.leaseMode * leaseFactorPerDay;		-- Lease/day as fraction of price. Ingame default = 0.01
	RN.DEFAULT_LEASING_DEPOSIT_FACTOR = RN.leaseMode * intialPayment;			-- Lease deposit as fraction of price. Ingame default = 0.02

	myPrintFloat("DEFAULT_LEASING_DEPOSIT_FACTOR",RN.DEFAULT_LEASING_DEPOSIT_FACTOR,textWidth," -");
	myPrintFloat("DEFAULT_RUNNING_LEASING_FACTOR",RN.DEFAULT_RUNNING_LEASING_FACTOR,textWidth," -");
	myPrintFloat("PER_DAY_LEASING_FACTOR",RN.PER_DAY_LEASING_FACTOR,textWidth," -");
	print("\n To calculate the actual lease costs, multiply by the item purchase price. \n");
end;

function RealNumbersLeasing:keyEvent(unicode, sym, modifier, isDown)
end;

function RealNumbersLeasing:update(dt)
	local minute = g_currentMission.environment.currentMinute;


	local runMinute = minute % 10; -- remainder
	if runMinute ~= 6 then RNS.notRunYetRealNumbersLeasing = true; end;
	if runMinute == 6 or RNS.upStartRealNumbersLeasing then 
		if RNS.notRunYetRealNumbersLeasing then

--			print("RealNumbersLeasing:update"); -- comment out when not debugging
			
			if g_storeManager.items ~= nil then
				for k,items in pairs(g_storeManager.items) do
					if items.allowLeasing then
						items.runningLeasingFactor = RN.DEFAULT_RUNNING_LEASING_FACTOR;
					end;
				end;
			end;
			EconomyManager.DEFAULT_RUNNING_LEASING_FACTOR = RN.DEFAULT_RUNNING_LEASING_FACTOR;
			EconomyManager.PER_DAY_LEASING_FACTOR = RN.PER_DAY_LEASING_FACTOR;
			EconomyManager.DEFAULT_LEASING_DEPOSIT_FACTOR = RN.DEFAULT_LEASING_DEPOSIT_FACTOR;
			EconomyManager.MAX_DAILYUPKEEP_MULTIPLIER = 0.0010;
			Farm.LOAN_INTEREST_RATE = RN.annualLoanInterest
		end;
		RNS.notRunYetRealNumbersLeasing = false;
		RNS.upStartRealNumbersLeasing = false;
	end;

end;
function RealNumbersLeasing:draw()
end;
function RealNumbersLeasing:deleteMap()
end;
function RealNumbersLeasing:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersLeasing);
