--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersForageCrops by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.9 Compatible with Seasons and Precision Farming
-- 30.11.2018 - 02.01.2021

RealNumbersForageCrops = {};

function RealNumbersForageCrops:loadMap(name)
	print("\nFS19_RealLifeNumbers: RealNumbersForageCrops active\n")

	local massScale = 1000;	
	
-- Bale prices

	RN.forageCost = {};
	RN.roundBaleVolume = {};
	RN.squareBaleVolume = {};

	RN.forageCost.grassRoundBalePrice  				= 37; -- €/round bale
	RN.forageCost.drygrassRoundBalePrice  			= 31;
	RN.forageCost.grassSilageRoundBalePrice 		= 38;
	RN.forageCost.strawRoundBalePrice  				= 15;
	RN.forageCost.alfalfaRoundBalePrice 			= 37;
	RN.forageCost.dryalfalfaRoundBalePrice  		= 31;
	RN.forageCost.alfalfaSilageRoundBalePrice		= 38;
	RN.forageCost.cloverRoundBalePrice  			= 37;
	RN.forageCost.drycloverRoundBalePrice   		= 31;
	RN.forageCost.cloverSilageRoundBalePrice		= 38;

	RN.forageCost.grassSquareBalePrice  			= 65;
	RN.forageCost.drygrassSquareBalePrice  			= 53;
	RN.forageCost.grassSilageSquareBalePrice		= 65;
	RN.forageCost.strawSquareBalePrice  			= 26;
	RN.forageCost.alfalfaSquareBalePrice			= 65;
	RN.forageCost.dryalfalfaSquareBalePrice 		= 53;
	RN.forageCost.alfalfaSilageSquareBalePrice		= 65;
	RN.forageCost.cloverSquareBalePrice 			= 65;
	RN.forageCost.drycloverSquareBalePrice 			= 53;
	RN.forageCost.cloverSilageSquareBalePrice		= 65;	

-- ALFALFA fresh bales per ha


	RN.growth.alfalfaMassPerHa         		= RN.growth.alfalfaDryMatterMassPerHa/RN.growth.alfalfaDryMatterFraction;
	RN.growth.alfalfaBaleDensity  			= RN.forageDensity.ALFALFA;
	RN.growth.alfalfaVolumePerHa 			= RN.growth.alfalfaMassPerHa/RN.growth.alfalfaBaleDensity;
	RN.growth.alfalfaNetVolumePerHa    		= (1 - RN.growth.windrowLoss) * RN.growth.alfalfaVolumePerHa;
	RN.growth.alfalfaRoundBaleVolume        = RN.roundBale.volume;
	RN.growth.alfalfaSquareBaleVolume       = RN.squareBale.volume;
	RN.growth.alfalfaRoundBaleMass			= RN.growth.alfalfaBaleDensity * RN.growth.alfalfaRoundBaleVolume;
	RN.growth.alfalfaRoundBalesPerHa        = RN.growth.alfalfaNetVolumePerHa/RN.growth.alfalfaRoundBaleVolume;
	RN.growth.alfalfaSquareBaleMass			= RN.growth.alfalfaBaleDensity * RN.growth.alfalfaSquareBaleVolume;
	RN.growth.alfalfaSquareBalesPerHa       = RN.growth.alfalfaNetVolumePerHa/RN.growth.alfalfaSquareBaleVolume;
	RN.netYield["ALFALFA_WINDROW"]			= RN.growth.alfalfaNetVolumePerHa;

-- Clover fresh bales per ha


	RN.growth.cloverMassPerHa         		= RN.growth.cloverDryMatterMassPerHa/RN.growth.cloverDryMatterFraction;
	RN.growth.cloverBaleDensity  			= RN.forageDensity.CLOVER;
	RN.growth.cloverVolumePerHa 			= RN.growth.cloverMassPerHa/RN.growth.cloverBaleDensity;
	RN.growth.cloverNetVolumePerHa    		= (1 - RN.growth.windrowLoss) * RN.growth.cloverVolumePerHa;
	RN.growth.cloverRoundBaleVolume         = RN.roundBale.volume;
	RN.growth.cloverSquareBaleVolume        = RN.squareBale.volume;
	RN.growth.cloverRoundBaleMass			= RN.growth.cloverBaleDensity * RN.growth.cloverRoundBaleVolume;
	RN.growth.cloverRoundBalesPerHa         = RN.growth.cloverNetVolumePerHa/RN.growth.cloverRoundBaleVolume;
	RN.growth.cloverSquareBaleMass			= RN.growth.cloverBaleDensity * RN.growth.cloverSquareBaleVolume;
	RN.growth.cloverSquareBalesPerHa        = RN.growth.cloverNetVolumePerHa/RN.growth.cloverSquareBaleVolume;
	RN.netYield["CLOVER_WINDROW"]			= RN.growth.cloverNetVolumePerHa;

--GRASS bales per ha


	RN.growth.grassMassPerHa         		= RN.growth.grassDryMatterMassPerHa/RN.growth.grassDryMatterFraction;
	RN.growth.grassBaleDensity  			= RN.forageDensity.GRASS;
	RN.growth.grassVolumePerHa 				= RN.growth.grassMassPerHa/RN.growth.grassBaleDensity;
	RN.growth.grassNetVolumePerHa    		= (1 - RN.growth.windrowLoss) * RN.growth.grassVolumePerHa;
	RN.growth.grassRoundBaleVolume        	= RN.roundBale.volume;
	RN.growth.grassSquareBaleVolume        	= RN.squareBale.volume;
	RN.growth.grassRoundBaleMass			= RN.growth.grassBaleDensity * RN.growth.grassRoundBaleVolume;
	RN.growth.grassRoundBalesPerHa        	= RN.growth.grassNetVolumePerHa/RN.growth.grassRoundBaleVolume;
	RN.growth.grassSquareBaleMass			= RN.growth.grassBaleDensity * RN.growth.grassSquareBaleVolume;
	RN.growth.grassSquareBalesPerHa        	= RN.growth.grassNetVolumePerHa/RN.growth.grassSquareBaleVolume;
	RN.netYield["GRASS_WINDROW"]			= RN.growth.grassNetVolumePerHa;

--dryalfalfa bales per ha


	RN.growth.dryalfalfaMassPerHa         	= RN.growth.alfalfaDryMatterMassPerHa/RN.growth.dryalfalfaDryMatterFraction;
	RN.growth.dryalfalfaBaleDensity  		= RN.forageDensity.DRYALFALFA;
	RN.growth.dryalfalfaVolumePerHa 		= RN.growth.dryalfalfaMassPerHa/RN.growth.dryalfalfaBaleDensity;
	RN.growth.dryalfalfaNetVolumePerHa    	= (1 - RN.growth.tedderLoss - RN.growth.windrowLoss) * RN.growth.dryalfalfaVolumePerHa;
	RN.growth.dryalfalfaRoundBaleVolume     = RN.roundBale.volume;
	RN.growth.dryalfalfaSquareBaleVolume    = RN.squareBale.volume;
	RN.growth.dryalfalfaRoundBaleMass		= RN.growth.dryalfalfaBaleDensity * RN.growth.dryalfalfaRoundBaleVolume;
	RN.growth.dryalfalfaRoundBalesPerHa     = RN.growth.dryalfalfaNetVolumePerHa/RN.growth.dryalfalfaRoundBaleVolume;
	RN.growth.dryalfalfaSquareBaleMass		= RN.growth.dryalfalfaBaleDensity * RN.growth.dryalfalfaSquareBaleVolume;
	RN.growth.dryalfalfaSquareBalesPerHa    = RN.growth.dryalfalfaNetVolumePerHa/RN.growth.dryalfalfaSquareBaleVolume;
	RN.netYield["DRYALFALFA_WINDROW"]		= RN.growth.dryalfalfaNetVolumePerHa;
	
--dryclover bales per ha


	RN.growth.drycloverMassPerHa         	= RN.growth.cloverDryMatterMassPerHa/RN.growth.drycloverDryMatterFraction;
	RN.growth.drycloverBaleDensity  		= RN.forageDensity.DRYCLOVER;
	RN.growth.drycloverVolumePerHa 			= RN.growth.drycloverMassPerHa/RN.growth.drycloverBaleDensity;
	RN.growth.drycloverNetVolumePerHa    	= (1 - RN.growth.tedderLoss - RN.growth.windrowLoss) * RN.growth.drycloverVolumePerHa;
	RN.growth.drycloverRoundBaleVolume      = RN.roundBale.volume;
	RN.growth.drycloverSquareBaleVolume     = RN.squareBale.volume;
	RN.growth.drycloverRoundBaleMass		= RN.growth.drycloverBaleDensity * RN.growth.drycloverRoundBaleVolume;
	RN.growth.drycloverRoundBalesPerHa      = RN.growth.drycloverNetVolumePerHa/RN.growth.drycloverRoundBaleVolume;
	RN.growth.drycloverSquareBaleMass		= RN.growth.drycloverBaleDensity * RN.growth.drycloverSquareBaleVolume;
	RN.growth.drycloverSquareBalesPerHa     = RN.growth.drycloverNetVolumePerHa/RN.growth.drycloverSquareBaleVolume;
	RN.netYield["DRYCLOVER_WINDROW"]		= RN.growth.drycloverNetVolumePerHa;
	
--drygrass bales per ha


	RN.growth.drygrassMassPerHa         	= RN.growth.grassDryMatterMassPerHa/RN.growth.drygrassDryMatterFraction;
	RN.growth.drygrassBaleDensity  			= RN.forageDensity.DRYGRASS;
	RN.growth.drygrassVolumePerHa 			= RN.growth.drygrassMassPerHa/RN.growth.drygrassBaleDensity;
	RN.growth.drygrassNetVolumePerHa    	= (1 - RN.growth.tedderLoss - RN.growth.windrowLoss) * RN.growth.drygrassVolumePerHa;
	RN.growth.drygrassRoundBaleVolume       = RN.roundBale.volume;
	RN.growth.drygrassSquareBaleVolume      = RN.squareBale.volume;
	RN.growth.drygrassRoundBaleMass			= RN.growth.drygrassBaleDensity * RN.growth.drygrassRoundBaleVolume;
	RN.growth.drygrassRoundBalesPerHa       = RN.growth.drygrassNetVolumePerHa/RN.growth.drygrassRoundBaleVolume;
	RN.growth.drygrassSquareBaleMass		= RN.growth.drygrassBaleDensity * RN.growth.drygrassSquareBaleVolume;
	RN.growth.drygrassSquareBalesPerHa      = RN.growth.drygrassNetVolumePerHa/RN.growth.drygrassSquareBaleVolume;
	RN.netYield["DRYGRASS_WINDROW"]			= RN.growth.drygrassNetVolumePerHa;
	
--alfalfa silage bales per ha


	RN.growth.alfalfaSilageMassPerHa         	= RN.growth.alfalfaDryMatterMassPerHa/RN.growth.alfalfaSilageDryMatterFraction;
	RN.growth.alfalfaSilageBaleDensity  		= RN.forageDensity.ALFALFASILAGE;
	RN.growth.alfalfaSilageVolumePerHa 			= RN.growth.alfalfaSilageMassPerHa/RN.growth.alfalfaSilageBaleDensity;
	RN.growth.alfalfaSilageNetVolumePerHa    	= (1 - RN.growth.windrowLoss) * RN.growth.alfalfaSilageVolumePerHa;
	RN.growth.alfalfaSilageRoundBaleVolume    	= RN.roundBale.volume;
	RN.growth.alfalfaSilageSquareBaleVolume   	= RN.squareBale.volume;
	RN.growth.alfalfaSilageRoundBaleMass		= RN.growth.alfalfaSilageBaleDensity * RN.growth.alfalfaSilageRoundBaleVolume;
	RN.growth.alfalfaSilageRoundBalesPerHa    	= RN.growth.alfalfaSilageNetVolumePerHa/RN.growth.alfalfaSilageRoundBaleVolume;
	RN.growth.alfalfaSilageSquareBaleMass		= RN.growth.alfalfaSilageBaleDensity * RN.growth.alfalfaSilageSquareBaleVolume;
	RN.growth.alfalfaSilageSquareBalesPerHa   	= RN.growth.alfalfaSilageNetVolumePerHa/RN.growth.alfalfaSilageSquareBaleVolume;
	RN.netYield["ALFALFA_FERMENTED"]			= RN.growth.alfalfaSilageNetVolumePerHa;


--clover silage bales per ha


	RN.growth.cloverSilageMassPerHa         	= RN.growth.cloverDryMatterMassPerHa/RN.growth.cloverSilageDryMatterFraction;
	RN.growth.cloverSilageBaleDensity  			= RN.forageDensity.CLOVERSILAGE;
	RN.growth.cloverSilageVolumePerHa 			= RN.growth.cloverSilageMassPerHa/RN.growth.cloverSilageBaleDensity;
	RN.growth.cloverSilageNetVolumePerHa    	= (1 - RN.growth.windrowLoss) * RN.growth.cloverSilageVolumePerHa;
	RN.growth.cloverSilageRoundBaleVolume    	= RN.roundBale.volume;
	RN.growth.cloverSilageSquareBaleVolume   	= RN.squareBale.volume;
	RN.growth.cloverSilageRoundBaleMass			= RN.growth.cloverSilageBaleDensity * RN.growth.cloverSilageRoundBaleVolume;
	RN.growth.cloverSilageRoundBalesPerHa    	= RN.growth.cloverSilageNetVolumePerHa/RN.growth.cloverSilageRoundBaleVolume;
	RN.growth.cloverSilageSquareBaleMass		= RN.growth.cloverSilageBaleDensity * RN.growth.cloverSilageSquareBaleVolume;
	RN.growth.cloverSilageSquareBalesPerHa   	= RN.growth.cloverSilageNetVolumePerHa/RN.growth.cloverSilageSquareBaleVolume;
	RN.netYield["CLOVER_FERMENTED"]				= RN.growth.cloverSilageNetVolumePerHa;

--grass silage bales per ha

	RN.growth.grassSilageMassPerHa         	= RN.growth.grassDryMatterMassPerHa/RN.growth.grassSilageDryMatterFraction;
	RN.growth.grassSilageBaleDensity  		= RN.forageDensity.SILAGE;
	RN.growth.grassSilageVolumePerHa 		= RN.growth.grassSilageMassPerHa/RN.growth.grassSilageBaleDensity;
	RN.growth.grassSilageNetVolumePerHa    	= (1 - RN.growth.windrowLoss) * RN.growth.grassSilageVolumePerHa;
	RN.growth.grassSilageRoundBaleVolume    = RN.roundBale.volume;
	RN.growth.grassSilageSquareBaleVolume   = RN.squareBale.volume;
	RN.growth.grassSilageRoundBaleMass		= RN.growth.grassSilageBaleDensity * RN.growth.grassSilageRoundBaleVolume;
	RN.growth.grassSilageRoundBalesPerHa    = RN.growth.grassSilageNetVolumePerHa/RN.growth.grassSilageRoundBaleVolume;
	RN.growth.grassSilageSquareBaleMass		= RN.growth.grassSilageBaleDensity * RN.growth.grassSilageSquareBaleVolume;
	RN.growth.grassSilageSquareBalesPerHa   = RN.growth.grassSilageNetVolumePerHa/RN.growth.grassSilageSquareBaleVolume;
	RN.netYield["GRASS_FERMENTED"]			= RN.growth.grassSilageNetVolumePerHa;
	RN.netYield["SILAGE"]					= RN.growth.grassSilageNetVolumePerHa;

--straw bales per ha

	RN.growth.strawMassPerHa         		= RN.strawYieldFactor * RN.cropYield["WHEAT"] * 100; --kg/ha
	RN.growth.strawBaleDensity  			= RN.forageDensity.STRAW;
	RN.growth.strawVolumePerHa 				= RN.growth.strawMassPerHa/RN.growth.strawBaleDensity;
	RN.growth.strawNetVolumePerHa    		= (1 - RN.growth.windrowLoss) * RN.growth.strawVolumePerHa;
	RN.growth.strawRoundBaleVolume    		= RN.roundBale.volume;
	RN.growth.strawSquareBaleVolume   		= RN.squareBale.volume;
	RN.growth.strawRoundBaleMass			= RN.growth.strawBaleDensity * RN.growth.strawRoundBaleVolume;
	RN.growth.strawRoundBalesPerHa    		= RN.growth.strawNetVolumePerHa/RN.growth.strawRoundBaleVolume;
	RN.growth.strawSquareBaleMass			= RN.growth.strawBaleDensity * RN.growth.strawSquareBaleVolume;
	RN.growth.strawSquareBalesPerHa   		= RN.growth.strawNetVolumePerHa/RN.growth.strawSquareBaleVolume;
	RN.netYield["STRAW"]					= RN.growth.strawNetVolumePerHa;
	

--FORAGE price per 100 kg

	RN.forageCost.grassPricePer100kg			= 100 * RN.forageCost.grassRoundBalePrice/RN.growth.grassRoundBaleMass;
	RN.forageCost.grassSilagePricePer100kg		= 100 * RN.forageCost.grassSilageRoundBalePrice/RN.growth.grassSilageRoundBaleMass;
	RN.forageCost.drygrassPricePer100kg			= 100 * RN.forageCost.drygrassRoundBalePrice/RN.growth.drygrassRoundBaleMass;
	RN.forageCost.strawPricePer100kg        	= 100*	RN.forageCost.strawRoundBalePrice/RN.growth.strawRoundBaleMass;
	RN.forageCost.alfalfaPricePer100kg			= 100 * RN.forageCost.alfalfaRoundBalePrice/RN.growth.alfalfaRoundBaleMass;
	RN.forageCost.alfalfaSilagePricePer100kg	= 100 * RN.forageCost.alfalfaSilageRoundBalePrice/RN.growth.alfalfaSilageRoundBaleMass;
	RN.forageCost.dryalfalfaPricePer100kg		= 100 * RN.forageCost.dryalfalfaRoundBalePrice/RN.growth.dryalfalfaRoundBaleMass;
	RN.forageCost.cloverPricePer100kg			= 100 * RN.forageCost.cloverRoundBalePrice/RN.growth.cloverRoundBaleMass;
	RN.forageCost.cloverSilagePricePer100kg		= 100 * RN.forageCost.cloverSilageRoundBalePrice/RN.growth.cloverSilageRoundBaleMass;
	RN.forageCost.drycloverPricePer100kg		= 100 * RN.forageCost.drycloverRoundBalePrice/RN.growth.drycloverRoundBaleMass;
	RN.forageCost.maizeSilagePricePer100kg		= (RN.forageCost.alfalfaSilagePricePer100kg + RN.forageCost.cloverSilagePricePer100kg
												  + RN.forageCost.grassSilagePricePer100kg)/3;
	
--FORAGE price per 1000 Liter

	RN.forageCost.grassPricePer1000L			= 1000 * RN.forageCost.grassRoundBalePrice/RN.growth.grassRoundBaleVolume;
	RN.forageCost.drygrassPricePer1000L			= 1000 * RN.forageCost.drygrassRoundBalePrice/RN.growth.drygrassRoundBaleVolume;
	RN.forageCost.grassSilagePricePer1000L		= 1000 * RN.forageCost.grassSilageRoundBalePrice/RN.growth.grassSilageRoundBaleVolume;
	RN.forageCost.strawPricePer1000L        	= 1000 * RN.forageCost.strawRoundBalePrice/RN.roundBale.volume;
	RN.forageCost.alfalfaPricePer1000L			= 1000 * RN.forageCost.alfalfaRoundBalePrice/RN.growth.alfalfaRoundBaleVolume;
	RN.forageCost.dryalfalfaPricePer1000L		= 1000 * RN.forageCost.dryalfalfaRoundBalePrice/RN.growth.dryalfalfaRoundBaleVolume;
	RN.forageCost.alfalfaSilagePricePer1000L	= 1000 * RN.forageCost.alfalfaSilageRoundBalePrice/RN.growth.alfalfaSilageRoundBaleVolume;
	RN.forageCost.cloverPricePer1000L			= 1000 * RN.forageCost.cloverRoundBalePrice/RN.growth.cloverRoundBaleVolume;
	RN.forageCost.drycloverPricePer1000L		= 1000 * RN.forageCost.drycloverRoundBalePrice/RN.growth.drycloverRoundBaleVolume;
	RN.forageCost.cloverSilagePricePer1000L		= 1000 * RN.forageCost.cloverSilageRoundBalePrice/RN.growth.cloverSilageRoundBaleVolume;
	RN.forageCost.maizeSilagePricePer1000L		= (RN.forageCost.alfalfaSilagePricePer1000L + RN.forageCost.cloverSilagePricePer1000L
												  + RN.forageCost.grassSilagePricePer1000L)/3;

--FORAGE definitions

-- ALFALFA = LUCERNE = LUZERNE, different names, different spellings, but same crop

	RN.fruits.ALFALFA 						= "ALFALFA";-- Lucerne
	RN.cropDensity.ALFALFA 					= RN.forageDensity.ALFALFA;		-- kg/L
	RN.cropYield.ALFALFA  					= RN.growth.alfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha
	RN.yieldRange.ALFALFA  					= 0.177		-- GEO EU
	RN.seedDensity.ALFALFA  				= 0.737;	-- kg/L
	RN.TSM.ALFALFA  						= 2;		-- 1000 seed mass			Source: AGRI-FACTS 2018 Agdex 100/22-1 Using 1000 Kernel weight...
	RN.plantsPerSqm.ALFALFA  				= 1000;		-- number of plants per sqm 360  175 - 550,  UK 1120
	RN.germination.ALFALFA  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.ALFALFA 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.ALFALFA  			= 655;		-- GEO DE, price / 100 kg 46   Manitoba; UK 6.55 €/kg
	RN.cropPricePer100kg.ALFALFA  			= RN.forageCost.alfalfaPricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.ALFALFA  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.ALFALFA						=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.ALFALFA					=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.ALFALFA					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.ALFALFA			= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.ALFALFA					= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.ALFALFA				= RN.fieldWorkCost.ALFALFA;
	RN.manureApplications.ALFALFA 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.ALFALFA 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.ALFALFA 			= 1/3;		-- Number of lime applications
	RN.isPlowing.ALFALFA 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.ALFALFA 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.ALFALFA 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.ALFALFA 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.ALFALFA 		= "cowMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.ALFALFA 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.ALFALFA 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.ALFALFA 				= RN.roundBale.volume;
	RN.squareBaleVolume.ALFALFA 			= RN.squareBale.volume;
	RN.seederType.ALFALFA					= "SEEDERS";
	RN.harvesterType.ALFALFA				= "MOWERS";
	RN.isBaling.ALFALFA	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.ALFALFA						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.ALFALFA_FERMENTED 			= "ALFALFA_FERMENTED";-- Lucerne
	RN.cropDensity.ALFALFA_FERMENTED 		= RN.forageDensity.ALFALFA_FERMENTED;		-- kg/L
	RN.cropYield.ALFALFA_FERMENTED  		= RN.growth.alfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha
	RN.yieldRange.ALFALFA_FERMENTED  		= 0.177		-- GEO EU
	RN.seedDensity.ALFALFA_FERMENTED  		= 0.737;	-- kg/L
	RN.TSM.ALFALFA_FERMENTED  				= 2;		-- 1000 seed mass			Source: AGRI-FACTS 2018 Agdex 100/22-1 Using 1000 Kernel weight...
	RN.plantsPerSqm.ALFALFA_FERMENTED  		= 1000;		-- number of plants per sqm 360  175 - 550,  UK 1120
	RN.germination.ALFALFA_FERMENTED  		= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.ALFALFA_FERMENTED 	= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.ALFALFA_FERMENTED  = 655;		-- GEO DE, price / 100 kg 46   Manitoba; UK 6.55 €/kg
	RN.cropPricePer100kg.ALFALFA_FERMENTED  = RN.forageCost.alfalfaSilagePricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.ALFALFA_FERMENTED  = 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.ALFALFA_FERMENTED			=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.ALFALFA_FERMENTED			=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.ALFALFA_FERMENTED			= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.ALFALFA_FERMENTED	= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.ALFALFA_FERMENTED			= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.ALFALFA_FERMENTED		= RN.fieldWorkCost.ALFALFA;
	RN.manureApplications.ALFALFA_FERMENTED 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.ALFALFA_FERMENTED 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.ALFALFA_FERMENTED 			= 1/3;		-- Number of lime applications
	RN.isPlowing.ALFALFA_FERMENTED 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.ALFALFA_FERMENTED 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.ALFALFA_FERMENTED 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.ALFALFA_FERMENTED 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.ALFALFA_FERMENTED 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.ALFALFA_FERMENTED 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.ALFALFA_FERMENTED 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.ALFALFA_FERMENTED 			= RN.roundBale.volume;
	RN.squareBaleVolume.ALFALFA_FERMENTED 			= RN.squareBale.volume;
	RN.seederType.ALFALFA_FERMENTED					= "SEEDERS";
	RN.harvesterType.ALFALFA_FERMENTED				= "MOWERS";
	RN.isBaling.ALFALFA_FERMENTED	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.ALFALFA_FERMENTED					= "SILAGE"; -- Bale type for crop, if any
	
	RN.fruits.ALFALFA_WINDROW 				= "ALFALFA_WINDROW";-- Lucerne
	RN.cropDensity.ALFALFA_WINDROW 			= RN.forageDensity.ALFALFA_WINDROW;		-- kg/L
	RN.cropYield.ALFALFA_WINDROW  			= RN.growth.alfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha
	RN.yieldRange.ALFALFA_WINDROW  			= 0.177		-- GEO EU
	RN.seedDensity.ALFALFA_WINDROW  		= 0.737;	-- kg/L
	RN.TSM.ALFALFA_WINDROW  				= 2;		-- 1000 seed mass			Source: AGRI-FACTS 2018 Agdex 100/22-1 Using 1000 Kernel weight...
	RN.plantsPerSqm.ALFALFA_WINDROW  		= 1000;		-- number of plants per sqm 360  175 - 550,  UK 1120
	RN.germination.ALFALFA_WINDROW  		= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.ALFALFA_WINDROW 		= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.ALFALFA_WINDROW  	= 655;		-- GEO DE, price / 100 kg 46   Manitoba; UK 6.55 €/kg
	RN.cropPricePer100kg.ALFALFA_WINDROW  	= RN.forageCost.alfalfaPricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.ALFALFA_WINDROW  	= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.ALFALFA_WINDROW				=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.ALFALFA_WINDROW			=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.ALFALFA_WINDROW			= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.ALFALFA_WINDROW	= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.ALFALFA_WINDROW			= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.ALFALFA_WINDROW		= RN.fieldWorkCost.ALFALFA;
	RN.manureApplications.ALFALFA_WINDROW 	= 0;		-- Number of solid manure applications
	RN.slurryApplications.ALFALFA_WINDROW 	= 1;		-- Number of liquid manure applications
	RN.limeApplications.ALFALFA_WINDROW 		= 1/3;		-- Number of lime applications
	RN.isPlowing.ALFALFA_WINDROW 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.ALFALFA_WINDROW 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.ALFALFA_WINDROW 	= 1;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.ALFALFA_WINDROW 	= 0;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.ALFALFA_WINDROW 	= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.ALFALFA_WINDROW 	= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.ALFALFA_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.ALFALFA_WINDROW 			= RN.roundBale.volume;
	RN.squareBaleVolume.ALFALFA_WINDROW 		= RN.squareBale.volume;
	RN.seederType.ALFALFA_WINDROW				= "SEEDERS";
	RN.harvesterType.ALFALFA_WINDROW			= "MOWERS";
	RN.isBaling.ALFALFA_WINDROW	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.ALFALFA_WINDROW					= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.DRYALFALFA 					= "DRYALFALFA";-- Lucerne
	RN.cropDensity.DRYALFALFA 				= RN.forageDensity.DRYALFALFA;		-- kg/L
	RN.cropYield.DRYALFALFA  				= RN.growth.dryalfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha
	RN.yieldRange.DRYALFALFA  				= 0.177		-- GEO EU
	RN.seedDensity.DRYALFALFA  				= 0.737;	-- kg/L
	RN.TSM.DRYALFALFA  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.DRYALFALFA  			= 1000;		-- number of plants per sqm 175 - 550,  UK 1120
	RN.germination.DRYALFALFA  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYALFALFA 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.DRYALFALFA  		= 655;		-- GEO DE, price / 100 kg 46	Manitoba
	RN.cropPricePer100kg.DRYALFALFA  		= RN.forageCost.dryalfalfaPricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.DRYALFALFA  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYALFALFA					=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYALFALFA					=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYALFALFA					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.DRYALFALFA		= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.DRYALFALFA				= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.DRYALFALFA				= RN.fieldWorkCost.ALFALFA; -- no harvest or baling
	RN.manureApplications.DRYALFALFA 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.DRYALFALFA 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.DRYALFALFA 			= 1/3;		-- Number of lime applications
	RN.isPlowing.DRYALFALFA 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.DRYALFALFA 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.DRYALFALFA 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.DRYALFALFA 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.DRYALFALFA 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.DRYALFALFA		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.DRYALFALFA 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.DRYALFALFA 			= RN.roundBale.volume;
	RN.squareBaleVolume.DRYALFALFA 			= RN.squareBale.volume;
	RN.seederType.DRYALFALFA				= "SEEDERS";
	RN.harvesterType.DRYALFALFA				= "HAY";
	RN.isBaling.DRYALFALFA	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.DRYALFALFA					= "HAY"; -- Bale type for crop, if any


	RN.fruits.DRYALFALFA_WINDROW 			= "DRYALFALFA_WINDROW";-- Lucerne
	RN.cropDensity.DRYALFALFA_WINDROW 		= RN.forageDensity.DRYALFALFA_WINDROW;		-- kg/L
	RN.cropYield.DRYALFALFA_WINDROW  		= RN.growth.dryalfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha
	RN.yieldRange.DRYALFALFA_WINDROW  		= 0.177		-- GEO EU
	RN.seedDensity.DRYALFALFA_WINDROW  		= 0.737;	-- kg/L
	RN.TSM.DRYALFALFA_WINDROW  				= 2;		-- 1000 seed mass
	RN.plantsPerSqm.DRYALFALFA_WINDROW  	= 1000;		-- number of plants per sqm 175 - 550,  UK 1120
	RN.germination.DRYALFALFA_WINDROW  		= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYALFALFA_WINDROW 	= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.DRYALFALFA_WINDROW = 655;		-- GEO DE, price / 100 kg 46	Manitoba
	RN.cropPricePer100kg.DRYALFALFA_WINDROW = RN.forageCost.dryalfalfaPricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.DRYALFALFA_WINDROW = 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYALFALFA_WINDROW			=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYALFALFA_WINDROW			=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYALFALFA_WINDROW			= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.DRYALFALFA_WINDROW= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.DRYALFALFA_WINDROW		= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.DRYALFALFA_WINDROW		= RN.fieldWorkCost.ALFALFA; -- no harvest or baling
	RN.manureApplications.DRYALFALFA_WINDROW 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.DRYALFALFA_WINDROW 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.DRYALFALFA_WINDROW 			= 1/3;		-- Number of lime applications
	RN.isPlowing.DRYALFALFA_WINDROW 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.DRYALFALFA_WINDROW 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.DRYALFALFA_WINDROW 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.DRYALFALFA_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.DRYALFALFA_WINDROW 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.DRYALFALFA_WINDROW		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.DRYALFALFA_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.DRYALFALFA_WINDROW 			= RN.roundBale.volume;
	RN.squareBaleVolume.DRYALFALFA_WINDROW 			= RN.squareBale.volume;
	RN.seederType.DRYALFALFA_WINDROW				= "SEEDERS";
	RN.harvesterType.DRYALFALFA_WINDROW				= "HAY";
	RN.isBaling.DRYALFALFA_WINDROW	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.DRYALFALFA_WINDROW					= "HAY"; -- Bale type for crop, if any

	RN.fruits.SEMIDRYALFALFA 						= "SEMIDRYALFALFA";-- Lucerne
	RN.cropDensity.SEMIDRYALFALFA 					= RN.forageDensity.SEMIDRYALFALFA;		-- kg/L
	RN.cropYield.SEMIDRYALFALFA  					= RN.growth.dryalfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha
	RN.yieldRange.SEMIDRYALFALFA  					= 0.177		-- GEO EU
	RN.seedDensity.SEMIDRYALFALFA  					= 0.737;	-- kg/L
	RN.TSM.SEMIDRYALFALFA  							= 2;		-- 1000 seed mass
	RN.plantsPerSqm.SEMIDRYALFALFA  				= 1000;		-- number of plants per sqm 175 - 550,  UK 1120
	RN.germination.SEMIDRYALFALFA  					= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SEMIDRYALFALFA 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.SEMIDRYALFALFA  			= 655;		-- GEO DE, price / 100 kg 46	Manitoba
	RN.cropPricePer100kg.SEMIDRYALFALFA  			= RN.forageCost.dryalfalfaPricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.SEMIDRYALFALFA  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SEMIDRYALFALFA						=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SEMIDRYALFALFA						=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SEMIDRYALFALFA						= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.SEMIDRYALFALFA			= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.SEMIDRYALFALFA					= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.SEMIDRYALFALFA					= RN.fieldWorkCost.ALFALFA; -- no harvest or baling
	RN.manureApplications.SEMIDRYALFALFA 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.SEMIDRYALFALFA 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.SEMIDRYALFALFA 				= 1/3;		-- Number of lime applications
	RN.isPlowing.SEMIDRYALFALFA 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.SEMIDRYALFALFA 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.SEMIDRYALFALFA 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.SEMIDRYALFALFA 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.SEMIDRYALFALFA	 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.SEMIDRYALFALFA			= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.SEMIDRYALFALFA 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.SEMIDRYALFALFA 				= RN.roundBale.volume;
	RN.squareBaleVolume.SEMIDRYALFALFA 				= RN.squareBale.volume;
	RN.seederType.SEMIDRYALFALFA					= "SEEDERS";
	RN.harvesterType.SEMIDRYALFALFA					= "HAY";
	RN.isBaling.SEMIDRYALFALFA	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.SEMIDRYALFALFA						= "HAY"; -- Bale type for crop, if any

	RN.fruits.SEMIDRYALFALFA_WINDROW 					= "SEMIDRYALFALFA_WINDROW";-- Lucerne
	RN.cropDensity.SEMIDRYALFALFA_WINDROW 				= RN.forageDensity.SEMIDRYALFALFA_WINDROW;		-- kg/L
	RN.cropYield.SEMIDRYALFALFA_WINDROW  				= RN.growth.dryalfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha
	RN.yieldRange.SEMIDRYALFALFA_WINDROW  				= 0.177		-- GEO EU
	RN.seedDensity.SEMIDRYALFALFA_WINDROW  				= 0.737;	-- kg/L
	RN.TSM.SEMIDRYALFALFA_WINDROW  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.SEMIDRYALFALFA_WINDROW  			= 1000;		-- number of plants per sqm 175 - 550,  UK 1120
	RN.germination.SEMIDRYALFALFA_WINDROW  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SEMIDRYALFALFA_WINDROW 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.SEMIDRYALFALFA_WINDROW  		= 655;		-- GEO DE, price / 100 kg 46	Manitoba
	RN.cropPricePer100kg.SEMIDRYALFALFA_WINDROW  		= RN.forageCost.dryalfalfaPricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.SEMIDRYALFALFA_WINDROW  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SEMIDRYALFALFA_WINDROW					=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SEMIDRYALFALFA_WINDROW					=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SEMIDRYALFALFA_WINDROW					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.SEMIDRYALFALFA_WINDROW		= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.SEMIDRYALFALFA_WINDROW				= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.SEMIDRYALFALFA_WINDROW				= RN.fieldWorkCost.ALFALFA; -- no harvest or baling
	RN.manureApplications.SEMIDRYALFALFA_WINDROW 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.SEMIDRYALFALFA_WINDROW 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.SEMIDRYALFALFA_WINDROW 			= 1/3;		-- Number of lime applications
	RN.isPlowing.SEMIDRYALFALFA_WINDROW 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.SEMIDRYALFALFA_WINDROW 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.SEMIDRYALFALFA_WINDROW 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.SEMIDRYALFALFA_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.SEMIDRYALFALFA_WINDROW 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.SEMIDRYALFALFA_WINDROW		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.SEMIDRYALFALFA_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.SEMIDRYALFALFA_WINDROW 			= RN.roundBale.volume;
	RN.squareBaleVolume.SEMIDRYALFALFA_WINDROW 			= RN.squareBale.volume;
	RN.seederType.SEMIDRYALFALFA_WINDROW				= "SEEDERS";
	RN.harvesterType.SEMIDRYALFALFA_WINDROW				= "HAY";
	RN.isBaling.SEMIDRYALFALFA_WINDROW	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.SEMIDRYALFALFA_WINDROW					= "HAY"; -- Bale type for crop, if any

	RN.fruits.WETALFALFA 								= "WETALFALFA";-- Lucerne
	RN.cropDensity.WETALFALFA 							= RN.forageDensity.WETALFALFA;		-- kg/L
	RN.cropYield.WETALFALFA  							= RN.growth.alfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha
	RN.yieldRange.WETALFALFA  							= 0.177		-- GEO EU
	RN.seedDensity.WETALFALFA  							= 0.737;	-- kg/L
	RN.TSM.WETALFALFA  									= 2;		-- 1000 seed mass
	RN.plantsPerSqm.WETALFALFA  						= 1000;		-- number of plants per sqm 175 - 550,  UK 1120
	RN.germination.WETALFALFA  							= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WETALFALFA 						= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.WETALFALFA  					= 655;		-- GEO DE, price / 100 kg 46	Manitoba
	RN.cropPricePer100kg.WETALFALFA  					= RN.forageCost.alfalfaPricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.WETALFALFA  					= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WETALFALFA								=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WETALFALFA								=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WETALFALFA								= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.WETALFALFA					= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.WETALFALFA							= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.WETALFALFA							= RN.fieldWorkCost.ALFALFA; -- no harvest or baling
	RN.manureApplications.WETALFALFA 					= 0;		-- Number of solid manure applications
	RN.slurryApplications.WETALFALFA 					= 1;		-- Number of liquid manure applications
	RN.limeApplications.WETALFALFA 						= 1/3;		-- Number of lime applications
	RN.isPlowing.WETALFALFA 							= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.WETALFALFA 						= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.WETALFALFA 				= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.WETALFALFA 				= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.WETALFALFA 					= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.WETALFALFA			 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.WETALFALFA 				= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.WETALFALFA 						= RN.roundBale.volume;
	RN.squareBaleVolume.WETALFALFA 						= RN.squareBale.volume;
	RN.seederType.WETALFALFA							= "SEEDERS";
	RN.harvesterType.WETALFALFA							= "MOWERS";
	RN.isBaling.WETALFALFA	 							= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.WETALFALFA								= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.WETALFALFA_WINDROW 					= "WETALFALFA_WINDROW";-- Lucerne
	RN.cropDensity.WETALFALFA_WINDROW 				= RN.forageDensity.WETALFALFA_WINDROW;		-- kg/L
	RN.cropYield.WETALFALFA_WINDROW  				= RN.growth.alfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha
	RN.yieldRange.WETALFALFA_WINDROW  				= 0.177		-- GEO EU
	RN.seedDensity.WETALFALFA_WINDROW  				= 0.737;	-- kg/L
	RN.TSM.WETALFALFA_WINDROW  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.WETALFALFA_WINDROW  			= 1000;		-- number of plants per sqm 175 - 550,  UK 1120
	RN.germination.WETALFALFA_WINDROW  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WETALFALFA_WINDROW 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.WETALFALFA_WINDROW  		= 655;		-- GEO DE, price / 100 kg 46	Manitoba
	RN.cropPricePer100kg.WETALFALFA_WINDROW  		= RN.forageCost.alfalfaPricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.WETALFALFA_WINDROW  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WETALFALFA_WINDROW					=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WETALFALFA_WINDROW					=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WETALFALFA_WINDROW					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.WETALFALFA_WINDROW		= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.WETALFALFA_WINDROW				= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.WETALFALFA_WINDROW				= RN.fieldWorkCost.ALFALFA; -- no harvest or baling
	RN.manureApplications.WETALFALFA_WINDROW 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.WETALFALFA_WINDROW 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.WETALFALFA_WINDROW 			= 1/3;		-- Number of lime applications
	RN.isPlowing.WETALFALFA_WINDROW 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.WETALFALFA_WINDROW 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.WETALFALFA_WINDROW 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.WETALFALFA_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.WETALFALFA_WINDROW 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.WETALFALFA_WINDROW		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.WETALFALFA_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.WETALFALFA_WINDROW 			= RN.roundBale.volume;
	RN.squareBaleVolume.WETALFALFA_WINDROW 			= RN.squareBale.volume;
	RN.seederType.WETALFALFA_WINDROW				= "SEEDERS";
	RN.harvesterType.WETALFALFA_WINDROW				= "MOWERS";
	RN.isBaling.WETALFALFA_WINDROW	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.WETALFALFA_WINDROW					= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.LUCERNE 						= "LUCERNE";-- Lucerne
	RN.cropDensity.LUCERNE 					= RN.forageDensity.ALFALFA;		-- kg/L
	RN.cropYield.LUCERNE  					= RN.growth.alfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha 198.12
	RN.yieldRange.LUCERNE  					= 0.177		-- GEO EU
	RN.seedDensity.LUCERNE  				= 0.737;	-- kg/L
	RN.TSM.LUCERNE  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.LUCERNE  				= 1100;		-- number of plants per sqm 360 175 - 550,  UK 1120
	RN.germination.LUCERNE  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.LUCERNE 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.LUCERNE  			= 655;		-- GEO DE, price / 100 kg
	RN.cropPricePer100kg.LUCERNE  			= RN.forageCost.alfalfaPricePer100kg;	-- GEO DE,  price / 100 kg 16.69
	RN.seederCalibration.LUCERNE  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.LUCERNE						=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.LUCERNE					=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.LUCERNE					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.LUCERNE			= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.LUCERNE					= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.LUCERNE				= RN.fieldWorkCost.ALFALFA;
	RN.manureApplications.LUCERNE 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.LUCERNE 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.LUCERNE 			= 1/3;		-- Number of lime applications
	RN.isPlowing.LUCERNE 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.LUCERNE 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.LUCERNE 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.LUCERNE 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.LUCERNE 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.LUCERNE 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.LUCERNE 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.LUCERNE 				= RN.roundBale.volume;
	RN.squareBaleVolume.LUCERNE 			= RN.squareBale.volume;
	RN.seederType.LUCERNE					= "SEEDERS";
	RN.harvesterType.LUCERNE				= "MOWERS";
	RN.isBaling.LUCERNE	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.LUCERNE						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.LUZERNE 						= "LUZERNE";-- Lucerne
	RN.cropDensity.LUZERNE 					= RN.forageDensity.ALFALFA;		-- kg/L
	RN.cropYield.LUZERNE  					= RN.growth.alfalfaMassPerHa/100; 	-- GEO EU 100 kg/ha 198.12
	RN.yieldRange.LUZERNE  					= 0.177		-- GEO EU
	RN.seedDensity.LUZERNE  				= 0.737;	-- kg/L
	RN.TSM.LUZERNE  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.LUZERNE  				= 1100;		-- number of plants per sqm 360,  175 - 550,  UK 1120
	RN.germination.LUZERNE  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.LUZERNE 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.LUZERNE  			= 655;		-- GEO DE, price / 100 kg 46
	RN.cropPricePer100kg.LUZERNE  			= RN.forageCost.alfalfaPricePer100kg;	-- GEO DE,  price / 100 kg 16.69
	RN.seederCalibration.LUZERNE  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.LUZERNE						=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.LUZERNE					=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.LUZERNE					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.LUZERNE			= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.LUZERNE					= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.LUCERNE				= RN.fieldWorkCost.ALFALFA;
	RN.manureApplications.LUZERNE 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.LUZERNE 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.LUZERNE 			= 1/3;		-- Number of lime applications
	RN.isPlowing.LUZERNE 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.LUZERNE 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.LUZERNE 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.LUZERNE 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.LUZERNE 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.LUZERNE 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.LUZERNE 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.LUZERNE 				= RN.roundBale.volume;
	RN.squareBaleVolume.LUZERNE 			= RN.squareBale.volume;
	RN.seederType.LUZERNE					= "SEEDERS";
	RN.harvesterType.LUZERNE				= "MOWERS";
	RN.isBaling.LUZERNE	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.LUZERNE						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.DRYLUCERNE 					= "DRYLUCERNE";-- Lucerne
	RN.cropDensity.DRYLUCERNE 				= RN.forageDensity.DRYALFALFA;	 -- kg/L
	RN.cropYield.DRYLUCERNE  				= RN.growth.dryalfalfaMassPerHa/100; -- GEO EU 100 kg/ha
	RN.yieldRange.DRYLUCERNE  				= 0.177		-- GEO EU
	RN.seedDensity.DRYLUCERNE  				= 0.737;	-- kg/L
	RN.TSM.DRYLUCERNE  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.DRYLUCERNE  			= 1100;		-- number of plants per sqm 175 - 550,  UK 1120
	RN.germination.DRYLUCERNE  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYLUCERNE 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.DRYLUCERNE  		= 609.00;	-- GEO DE, price / 100 kg
	RN.cropPricePer100kg.DRYLUCERNE  		= RN.forageCost.dryalfalfaPricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.DRYLUCERNE  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYLUCERNE					=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYLUCERNE					=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYLUCERNE					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.DRYLUCERNE		= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.DRYLUCERNE				= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.DRYLUCERNE				= RN.fieldWorkCost.ALFALFA;	-- no harvest
	RN.manureApplications.DRYLUCERNE 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.DRYLUCERNE 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.DRYLUCERNE 			= 1/3;		-- Number of lime applications
	RN.isPlowing.DRYLUCERNE 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.DRYLUCERNE 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.DRYLUCERNE 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.DRYLUCERNE 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.DRYLUCERNE 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.DRYLUCERNE		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.DRYLUCERNE 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.DRYLUCERNE 			= RN.roundBale.volume;
	RN.squareBaleVolume.DRYLUCERNE 			= RN.squareBale.volume;
	RN.seederType.DRYLUCERNE				= "SEEDERS";
	RN.harvesterType.DRYLUCERNE				= "HAY";
	RN.isBaling.DRYLUCERNE	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.DRYLUCERNE					= "HAY"; -- Bale type for crop, if any

	RN.fruits.DRYLUZERNE 					= "DRYLUZERNE";-- Lucerne
	RN.cropDensity.DRYLUZERNE 				= RN.forageDensity.DRYALFALFA;	 -- kg/L
	RN.cropYield.DRYLUZERNE  				= RN.growth.dryalfalfaMassPerHa/100; -- GEO EU 100 kg/ha
	RN.yieldRange.DRYLUZERNE  				= 0.177		-- GEO EU
	RN.seedDensity.DRYLUZERNE  				= 0.737;	-- kg/L
	RN.TSM.DRYLUZERNE  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.DRYLUZERNE  			= 1100;		-- number of plants per sqm 175 - 550,  UK 1120
	RN.germination.DRYLUZERNE  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYLUZERNE 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.DRYLUZERNE  		= 609.00;	-- GEO DE, price / 100 kg
	RN.cropPricePer100kg.DRYLUZERNE  		= RN.forageCost.dryalfalfaPricePer100kg;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.DRYLUZERNE  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYLUZERNE					=   0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYLUZERNE					=  80;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYLUZERNE					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.DRYLUZERNE		= 74;		-- UK: 74; Ontario: 24;
	RN.growthDays.DRYLUZERNE				= 40;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.DRYLUZERNE				= RN.fieldWorkCost.ALFALFA;	-- no harvest
	RN.manureApplications.DRYLUZERNE 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.DRYLUZERNE 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.DRYLUZERNE 			= 1/3;		-- Number of lime applications
	RN.isPlowing.DRYLUZERNE 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.DRYLUZERNE 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.DRYLUZERNE 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.DRYLUZERNE 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.DRYLUZERNE 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.DRYLUZERNE		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.DRYLUZERNE 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.DRYLUZERNE 			= RN.roundBale.volume;
	RN.squareBaleVolume.DRYLUZERNE 			= RN.squareBale.volume;
	RN.seederType.DRYLUZERNE				= "SEEDERS";
	RN.harvesterType.DRYLUZERNE				= "HAY";
	RN.isBaling.DRYLUZERNE	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.DRYLUZERNE					= "HAY"; -- Bale type for crop, if any

	RN.fruits.CLOVER  						= "CLOVER"; -- White clover
	RN.cropDensity.CLOVER 					= RN.forageDensity.CLOVER;		-- kg/L
	RN.cropYield.CLOVER  					= RN.growth.cloverMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.CLOVER  					= 0.153;	-- GEO COM
	RN.seedDensity.CLOVER  					= 0.641;	-- kg/L
	RN.TSM.CLOVER  							= 0.58;		-- 1000 seed mass
	RN.plantsPerSqm.CLOVER  				= 1350;		-- number of plants per sqm		DK: 1350; Alberta: 750
	RN.germination.CLOVER  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.CLOVER 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.CLOVER  			= 850.00;	-- GEO COM, price / 100 kg UK 38 £/5 kg
	RN.cropPricePer100kg.CLOVER  			= RN.forageCost.cloverPricePer100kg;		-- GEO Com, price / 100 kg, 
	RN.seederCalibration.CLOVER  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.CLOVER						= 289;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.CLOVER						= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.CLOVER						= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.CLOVER			= 25;		-- DK: 25; Ontario: -;
	RN.growthDays.CLOVER					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.CLOVER					= RN.fieldWorkCost.CLOVER;	-- no harvest
	RN.manureApplications.CLOVER 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.CLOVER 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.CLOVER 				= 1/3;		-- Number of lime applications
	RN.isPlowing.CLOVER 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.CLOVER 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.CLOVER 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.CLOVER 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.CLOVER	 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.CLOVER 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.CLOVER 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.CLOVER 				= RN.roundBale.volume;
	RN.squareBaleVolume.CLOVER 				= RN.squareBale.volume;
	RN.seederType.CLOVER					= "SEEDERS";
	RN.harvesterType.CLOVER					= "MOWERS";
	RN.isBaling.CLOVER	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.CLOVER						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.WETCLOVER  						= "WETCLOVER"; -- White clover
	RN.cropDensity.WETCLOVER 					= RN.forageDensity.WETCLOVER;		-- kg/L
	RN.cropYield.WETCLOVER  					= RN.growth.cloverMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.WETCLOVER  					= 0.153;	-- GEO COM
	RN.seedDensity.WETCLOVER  					= 0.641;	-- kg/L
	RN.TSM.WETCLOVER  							= 0.58;		-- 1000 seed mass
	RN.plantsPerSqm.WETCLOVER  					= 1350;		-- number of plants per sqm		DK: 1350; Alberta: 750
	RN.germination.WETCLOVER  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WETCLOVER 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.WETCLOVER  			= 850.00;	-- GEO COM, price / 100 kg UK 38 £/5 kg
	RN.cropPricePer100kg.WETCLOVER  			= RN.forageCost.cloverPricePer100kg;		-- GEO Com, price / 100 kg,
	RN.seederCalibration.WETCLOVER  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WETCLOVER						= 289;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WETCLOVER						= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WETCLOVER						= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.WETCLOVER				= 25;		-- DK: 25; Ontario: -;
	RN.growthDays.WETCLOVER						= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.WETCLOVER					= RN.fieldWorkCost.WETCLOVER;	-- no harvest
	RN.manureApplications.WETCLOVER 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.WETCLOVER 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.WETCLOVER 				= 1/3;		-- Number of lime applications
	RN.isPlowing.WETCLOVER 						= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.WETCLOVER 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.WETCLOVER 			= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.WETCLOVER 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.WETCLOVER 			= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.WETCLOVER	 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.WETCLOVER 			= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.WETCLOVER 				= RN.roundBale.volume;
	RN.squareBaleVolume.WETCLOVER 				= RN.squareBale.volume;
	RN.seederType.WETCLOVER						= "SEEDERS";
	RN.harvesterType.WETCLOVER					= "MOWERS";
	RN.isBaling.WETCLOVER	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.WETCLOVER						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.WETCLOVER_WINDROW  						= "WETCLOVER_WINDROW"; -- White clover
	RN.cropDensity.WETCLOVER_WINDROW 					= RN.forageDensity.WETCLOVER_WINDROW;		-- kg/L
	RN.cropYield.WETCLOVER_WINDROW  					= RN.growth.cloverMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.WETCLOVER_WINDROW  					= 0.153;	-- GEO COM
	RN.seedDensity.WETCLOVER_WINDROW  					= 0.641;	-- kg/L
	RN.TSM.WETCLOVER_WINDROW  							= 0.58;		-- 1000 seed mass
	RN.plantsPerSqm.WETCLOVER_WINDROW  					= 1350;		-- number of plants per sqm		DK: 1350; Alberta: 750
	RN.germination.WETCLOVER_WINDROW  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WETCLOVER_WINDROW 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.WETCLOVER_WINDROW  			= 850.00;	-- GEO COM, price / 100 kg UK 38 £/5 kg
	RN.cropPricePer100kg.WETCLOVER_WINDROW  			= RN.forageCost.cloverPricePer100kg;		-- GEO Com, price / 100 kg,
	RN.seederCalibration.WETCLOVER_WINDROW  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WETCLOVER_WINDROW						= 289;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WETCLOVER_WINDROW						= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WETCLOVER_WINDROW						= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.WETCLOVER_WINDROW				= 25;		-- DK: 25; Ontario: -;
	RN.growthDays.WETCLOVER_WINDROW						= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.WETCLOVER_WINDROW					= RN.fieldWorkCost.WETCLOVER_WINDROW;	-- no harvest
	RN.manureApplications.WETCLOVER_WINDROW 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.WETCLOVER_WINDROW 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.WETCLOVER_WINDROW 				= 1/3;		-- Number of lime applications
	RN.isPlowing.WETCLOVER_WINDROW 						= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.WETCLOVER_WINDROW 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.WETCLOVER_WINDROW 			= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.WETCLOVER_WINDROW 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.WETCLOVER_WINDROW 			= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.WETCLOVER_WINDROW	 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.WETCLOVER_WINDROW 			= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.WETCLOVER_WINDROW 				= RN.roundBale.volume;
	RN.squareBaleVolume.WETCLOVER_WINDROW 				= RN.squareBale.volume;
	RN.seederType.WETCLOVER_WINDROW						= "SEEDERS";
	RN.harvesterType.WETCLOVER_WINDROW					= "MOWERS";
	RN.isBaling.WETCLOVER_WINDROW	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.WETCLOVER_WINDROW						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.CLOVER_FERMENTED  			= "CLOVER_FERMENTED"; -- White CLOVER_FERMENTED
	RN.cropDensity.CLOVER_FERMENTED 		= RN.forageDensity.CLOVER_FERMENTED;		-- kg/L
	RN.cropYield.CLOVER_FERMENTED  			= RN.growth.cloverSilageMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.CLOVER_FERMENTED  		= 0.153;	-- GEO COM
	RN.seedDensity.CLOVER_FERMENTED  		= 0.641;	-- kg/L
	RN.TSM.CLOVER_FERMENTED  				= 0.58;		-- 1000 seed mass
	RN.plantsPerSqm.CLOVER_FERMENTED  		= 1350;		-- number of plants per sqm		DK: 1350; Alberta: 750
	RN.germination.CLOVER_FERMENTED  		= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.CLOVER_FERMENTED 	= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.CLOVER_FERMENTED  	= 850.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.CLOVER_FERMENTED  	= RN.forageCost.cloverSilagePricePer100kg;		-- GEO Com, price / 100 kg, 
	RN.seederCalibration.CLOVER_FERMENTED  	= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.CLOVER_FERMENTED			= 289;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.CLOVER_FERMENTED			= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.CLOVER_FERMENTED			= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.CLOVER_FERMENTED	= 25;		-- DK: 25; Ontario: -;
	RN.growthDays.CLOVER_FERMENTED			= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.CLOVER_FERMENTED		= RN.fieldWorkCost.CLOVER;	-- no harvest
	RN.manureApplications.CLOVER_FERMENTED 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.CLOVER_FERMENTED 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.CLOVER_FERMENTED 		= 1/3;		-- Number of lime applications
	RN.isPlowing.CLOVER_FERMENTED 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.CLOVER_FERMENTED 		= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.CLOVER_FERMENTED 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.CLOVER_FERMENTED 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.CLOVER_FERMENTED 	= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.CLOVER_FERMENTED	= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.CLOVER_FERMENTED 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.CLOVER_FERMENTED 		= RN.roundBale.volume;
	RN.squareBaleVolume.CLOVER_FERMENTED 		= RN.squareBale.volume;
	RN.seederType.CLOVER_FERMENTED				= "SEEDERS";
	RN.harvesterType.CLOVER_FERMENTED			= "MOWERS";
	RN.isBaling.CLOVER_FERMENTED	 			= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.CLOVER_FERMENTED				= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.CLOVER_WINDROW  				= "CLOVER_WINDROW"; -- White clover
	RN.cropDensity.CLOVER_WINDROW 			= RN.forageDensity.CLOVER_WINDROW;		-- kg/L
	RN.cropYield.CLOVER_WINDROW  			= RN.growth.cloverMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.CLOVER_WINDROW  			= 0.153;	-- GEO COM
	RN.seedDensity.CLOVER_WINDROW  			= 0.641;	-- kg/L
	RN.TSM.CLOVER_WINDROW  					= 0.58;		-- 1000 seed mass
	RN.plantsPerSqm.CLOVER_WINDROW  		= 1350;		-- number of plants per sqm		DK: 1350; Alberta: 750
	RN.germination.CLOVER_WINDROW  			= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.CLOVER_WINDROW 		= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.CLOVER_WINDROW  	= 850.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.CLOVER_WINDROW  	= RN.forageCost.cloverPricePer100kg;		-- GEO Com, price / 100 kg, 
	RN.seederCalibration.CLOVER_WINDROW  	= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.CLOVER_WINDROW				= 289;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.CLOVER_WINDROW				= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.CLOVER_WINDROW				= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.CLOVER_WINDROW	= 25;		-- DK: 25; Ontario: -;
	RN.growthDays.CLOVER_WINDROW			= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.CLOVER_WINDROW			= RN.fieldWorkCost.CLOVER;	-- no harvest
	RN.manureApplications.CLOVER_WINDROW 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.CLOVER_WINDROW 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.CLOVER_WINDROW 			= 1/3;		-- Number of lime applications
	RN.isPlowing.CLOVER_WINDROW 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.CLOVER_WINDROW 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.CLOVER_WINDROW 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.CLOVER_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.CLOVER_WINDROW 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.CLOVER_WINDROW		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.CLOVER_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.CLOVER_WINDROW 			= RN.roundBale.volume;
	RN.squareBaleVolume.CLOVER_WINDROW 			= RN.squareBale.volume;
	RN.seederType.CLOVER_WINDROW				= "SEEDERS";
	RN.harvesterType.CLOVER_WINDROW				= "MOWERS";
	RN.isBaling.CLOVER_WINDROW	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.CLOVER_WINDROW					= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.SEMIDRYCLOVER  					= "SEMIDRYCLOVER"; -- White clover
	RN.cropDensity.SEMIDRYCLOVER 				= RN.forageDensity.SEMIDRYCLOVER;		-- kg/L
	RN.cropYield.SEMIDRYCLOVER  				= RN.growth.drycloverMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.SEMIDRYCLOVER  				= 0.153;	-- GEO COM
	RN.seedDensity.SEMIDRYCLOVER  				= 0.641;	-- kg/L
	RN.TSM.SEMIDRYCLOVER  						= 0.58;		-- 1000 seed mass
	RN.plantsPerSqm.SEMIDRYCLOVER  				= 1350;		-- number of plants per sqm		DK: 1350; Alberta: 750
	RN.germination.SEMIDRYCLOVER  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SEMIDRYCLOVER 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SEMIDRYCLOVER  		= 850.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.SEMIDRYCLOVER  		= RN.forageCost.drycloverPricePer100kg;		-- GEO Com, price / 100 kg,
	RN.seederCalibration.SEMIDRYCLOVER  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SEMIDRYCLOVER					= 289;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SEMIDRYCLOVER					= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SEMIDRYCLOVER					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.SEMIDRYCLOVER			= 25;		-- DK: 25; Ontario: -;
	RN.growthDays.SEMIDRYCLOVER					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.SEMIDRYCLOVER				= RN.fieldWorkCost.CLOVER;	-- no harvest
	RN.manureApplications.SEMIDRYCLOVER 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.SEMIDRYCLOVER 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.SEMIDRYCLOVER 			= 1/3;		-- Number of lime applications
	RN.isPlowing.SEMIDRYCLOVER 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.SEMIDRYCLOVER 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.SEMIDRYCLOVER 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.SEMIDRYCLOVER 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.SEMIDRYCLOVER 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.SEMIDRYCLOVER 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.SEMIDRYCLOVER 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.SEMIDRYCLOVER 			= RN.roundBale.volume;
	RN.squareBaleVolume.SEMIDRYCLOVER 			= RN.squareBale.volume;
	RN.seederType.SEMIDRYCLOVER					= "SEEDERS";
	RN.harvesterType.SEMIDRYCLOVER				= "HAY";
	RN.isBaling.SEMIDRYCLOVER	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.SEMIDRYCLOVER					= "HAY"; -- Bale type for crop, if any

	RN.fruits.SEMIDRYCLOVER_WINDROW  					= "SEMIDRYCLOVER_WINDROW"; -- White clover
	RN.cropDensity.SEMIDRYCLOVER_WINDROW 				= RN.forageDensity.SEMIDRYCLOVER_WINDROW;		-- kg/L
	RN.cropYield.SEMIDRYCLOVER_WINDROW  				= RN.growth.drycloverMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.SEMIDRYCLOVER_WINDROW  				= 0.153;	-- GEO COM
	RN.seedDensity.SEMIDRYCLOVER_WINDROW  				= 0.641;	-- kg/L
	RN.TSM.SEMIDRYCLOVER_WINDROW  						= 0.58;		-- 1000 seed mass
	RN.plantsPerSqm.SEMIDRYCLOVER_WINDROW  				= 1350;		-- number of plants per sqm		DK: 1350; Alberta: 750
	RN.germination.SEMIDRYCLOVER_WINDROW  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SEMIDRYCLOVER_WINDROW 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SEMIDRYCLOVER_WINDROW  		= 850.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.SEMIDRYCLOVER_WINDROW  		= RN.forageCost.drycloverPricePer100kg;		-- GEO Com, price / 100 kg,
	RN.seederCalibration.SEMIDRYCLOVER_WINDROW  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SEMIDRYCLOVER_WINDROW					= 289;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SEMIDRYCLOVER_WINDROW					= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SEMIDRYCLOVER_WINDROW					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.SEMIDRYCLOVER_WINDROW			= 25;		-- DK: 25; Ontario: -;
	RN.growthDays.SEMIDRYCLOVER_WINDROW					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.SEMIDRYCLOVER_WINDROW				= RN.fieldWorkCost.CLOVER;	-- no harvest
	RN.manureApplications.SEMIDRYCLOVER_WINDROW 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.SEMIDRYCLOVER_WINDROW 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.SEMIDRYCLOVER_WINDROW 			= 1/3;		-- Number of lime applications
	RN.isPlowing.SEMIDRYCLOVER_WINDROW 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.SEMIDRYCLOVER_WINDROW 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.SEMIDRYCLOVER_WINDROW 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.SEMIDRYCLOVER_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.SEMIDRYCLOVER_WINDROW 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.SEMIDRYCLOVER_WINDROW 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.SEMIDRYCLOVER_WINDROW 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.SEMIDRYCLOVER_WINDROW 			= RN.roundBale.volume;
	RN.squareBaleVolume.SEMIDRYCLOVER_WINDROW 			= RN.squareBale.volume;
	RN.seederType.SEMIDRYCLOVER_WINDROW					= "SEEDERS";
	RN.harvesterType.SEMIDRYCLOVER_WINDROW				= "HAY";
	RN.isBaling.SEMIDRYCLOVER_WINDROW	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.SEMIDRYCLOVER_WINDROW					= "HAY"; -- Bale type for crop, if any

	RN.fruits.DRYCLOVER  					= "DRYCLOVER"; -- White clover
	RN.cropDensity.DRYCLOVER 				= RN.forageDensity.DRYCLOVER;		-- kg/L
	RN.cropYield.DRYCLOVER  				= RN.growth.drycloverMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.DRYCLOVER  				= 0.153;	-- GEO COM
	RN.seedDensity.DRYCLOVER  				= 0.641;	-- kg/L
	RN.TSM.DRYCLOVER  						= 0.58;		-- 1000 seed mass
	RN.plantsPerSqm.DRYCLOVER  				= 1350;		-- number of plants per sqm		DK: 1350; Alberta: 750
	RN.germination.DRYCLOVER  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYCLOVER 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.DRYCLOVER  		= 850.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.DRYCLOVER  		= RN.forageCost.drycloverPricePer100kg;		-- GEO Com, price / 100 kg, 
	RN.seederCalibration.DRYCLOVER  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYCLOVER					= 289;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYCLOVER					= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYCLOVER					= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.DRYCLOVER			= 25;		-- DK: 25; Ontario: -;
	RN.growthDays.DRYCLOVER					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.DRYCLOVER				= RN.fieldWorkCost.CLOVER;	-- no harvest
	RN.manureApplications.DRYCLOVER 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.DRYCLOVER 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.DRYCLOVER 			= 1/3;		-- Number of lime applications
	RN.isPlowing.DRYCLOVER 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.DRYCLOVER 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.DRYCLOVER 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.DRYCLOVER 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.DRYCLOVER 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.DRYCLOVER 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.DRYCLOVER 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.DRYCLOVER 			= RN.roundBale.volume;
	RN.squareBaleVolume.DRYCLOVER 			= RN.squareBale.volume;
	RN.seederType.DRYCLOVER					= "SEEDERS";
	RN.harvesterType.DRYCLOVER				= "HAY";
	RN.isBaling.DRYCLOVER	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.DRYCLOVER					= "HAY"; -- Bale type for crop, if any

	RN.fruits.DRYCLOVER_WINDROW  			= "DRYCLOVER_WINDROW"; -- White clover
	RN.cropDensity.DRYCLOVER_WINDROW 		= RN.forageDensity.DRYCLOVER_WINDROW;		-- kg/L
	RN.cropYield.DRYCLOVER_WINDROW  		= RN.growth.drycloverMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.DRYCLOVER_WINDROW  		= 0.153;	-- GEO COM
	RN.seedDensity.DRYCLOVER_WINDROW  		= 0.641;	-- kg/L
	RN.TSM.DRYCLOVER_WINDROW  				= 0.58;		-- 1000 seed mass
	RN.plantsPerSqm.DRYCLOVER_WINDROW  		= 1350;		-- number of plants per sqm		DK: 1350; Alberta: 750
	RN.germination.DRYCLOVER_WINDROW  		= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYCLOVER_WINDROW 	= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.DRYCLOVER_WINDROW  = 850.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.DRYCLOVER_WINDROW  = RN.forageCost.drycloverPricePer100kg;		-- GEO Com, price / 100 kg, 
	RN.seederCalibration.DRYCLOVER_WINDROW  = 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYCLOVER_WINDROW			= 289;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYCLOVER_WINDROW			= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYCLOVER_WINDROW			= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.DRYCLOVER_WINDROW	= 25;		-- DK: 25; Ontario: -;
	RN.growthDays.DRYCLOVER_WINDROW			= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.DRYCLOVER_WINDROW		= RN.fieldWorkCost.CLOVER;	-- no harvest
	RN.manureApplications.DRYCLOVER_WINDROW 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.DRYCLOVER_WINDROW 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.DRYCLOVER_WINDROW 			= 1/3;		-- Number of lime applications
	RN.isPlowing.DRYCLOVER_WINDROW 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.DRYCLOVER_WINDROW 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.DRYCLOVER_WINDROW 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.DRYCLOVER_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.DRYCLOVER_WINDROW 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.DRYCLOVER_WINDROW 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.DRYCLOVER_WINDROW 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.DRYCLOVER_WINDROW 			= RN.roundBale.volume;
	RN.squareBaleVolume.DRYCLOVER_WINDROW 			= RN.squareBale.volume;
	RN.seederType.DRYCLOVER_WINDROW					= "SEEDERS";
	RN.harvesterType.DRYCLOVER_WINDROW				= "HAY";
	RN.isBaling.DRYCLOVER_WINDROW	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.DRYCLOVER_WINDROW					= "HAY"; -- Bale type for crop, if any

	RN.fruits.GRASS  						= "GRASS";
	RN.cropDensity.GRASS 					= RN.forageDensity.GRASS;	-- kg/L
	RN.cropYield.GRASS  					= RN.growth.grassMassPerHa/100; 	-- GEO DE,100 kg/ha (165.8)
	RN.yieldRange.GRASS  					= 0.153;	-- GEO DE
	RN.seedDensity.GRASS  					= 0.31;	-- kg/L
	RN.TSM.GRASS  							= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.GRASS  					= 550;		-- number of plants per sqm
	RN.germination.GRASS  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.GRASS 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.GRASS  			= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.GRASS  			= RN.forageCost.grassPricePer100kg; -- GEO DE, price / 100 kg (5.00)
	RN.seederCalibration.GRASS  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.GRASS						= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.GRASS						= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.GRASS						= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.GRASS				= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.GRASS						= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.GRASS					= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.GRASS 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.GRASS 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.GRASS 				= 1/3;		-- Number of lime applications
	RN.isPlowing.GRASS 						= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.GRASS 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.GRASS 			= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.GRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.GRASS	 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.GRASS	 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.GRASS 			= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.GRASS 				= RN.roundBale.volume;
	RN.squareBaleVolume.GRASS 				= RN.squareBale.volume;
	RN.seederType.GRASS						= "SEEDERS";
	RN.harvesterType.GRASS					= "MOWERS";
	RN.isBaling.GRASS	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.GRASS						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.GRASS_FERMENTED  						= "GRASS_FERMENTED";
	RN.cropDensity.GRASS_FERMENTED 					= RN.forageDensity.GRASS_FERMENTED;	-- kg/L
	RN.cropYield.GRASS_FERMENTED  					= RN.growth.grassMassPerHa/100; 	-- GEO DE,100 kg/ha (165.8)
	RN.yieldRange.GRASS_FERMENTED  					= 0.153;	-- GEO DE
	RN.seedDensity.GRASS_FERMENTED  				= 0.31;	-- kg/L
	RN.TSM.GRASS_FERMENTED  						= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.GRASS_FERMENTED  				= 550;		-- number of plants per sqm
	RN.germination.GRASS_FERMENTED  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.GRASS_FERMENTED 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.GRASS_FERMENTED  			= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.GRASS_FERMENTED  			= RN.forageCost.grassSilagePricePer100kg; -- GEO DE, price / 100 kg (5.00)
	RN.seederCalibration.GRASS_FERMENTED  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.GRASS_FERMENTED						= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.GRASS_FERMENTED					= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.GRASS_FERMENTED					= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.GRASS_FERMENTED			= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.GRASS_FERMENTED					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.GRASS_FERMENTED				= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.GRASS_FERMENTED 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.GRASS_FERMENTED 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.GRASS_FERMENTED 			= 1/3;		-- Number of lime applications
	RN.isPlowing.GRASS_FERMENTED 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.GRASS_FERMENTED 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.GRASS_FERMENTED 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.GRASS_FERMENTED 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.GRASS_FERMENTED 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.GRASS_FERMENTED 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.GRASS_FERMENTED 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.GRASS_FERMENTED 				= RN.roundBale.volume;
	RN.squareBaleVolume.GRASS_FERMENTED 			= RN.squareBale.volume;
	RN.seederType.GRASS_FERMENTED					= "SEEDERS";
	RN.harvesterType.GRASS_FERMENTED				= "MOWERS";
	RN.isBaling.GRASS_FERMENTED	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.GRASS_FERMENTED						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.SILAGE  						= "SILAGE";
	RN.cropDensity.SILAGE 					= RN.forageDensity.SILAGE;	-- kg/L
	RN.cropYield.SILAGE  					= RN.growth.grassSilageMassPerHa/100; 	-- GEO DE,100 kg/ha (165.8)
	RN.yieldRange.SILAGE  					= 0.153;	-- GEO DE
	RN.seedDensity.SILAGE  					= 0.31;	-- kg/L
	RN.TSM.SILAGE  							= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.SILAGE  				= 550;		-- number of plants per sqm
	RN.germination.SILAGE  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SILAGE 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SILAGE  			= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.SILAGE  			= RN.forageCost.grassPricePer100kg; -- GEO DE, price / 100 kg (5.00)
	RN.seederCalibration.SILAGE  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SILAGE						= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SILAGE						= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SILAGE						= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.SILAGE			= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.SILAGE					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.SILAGE					= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.SILAGE 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.SILAGE 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.SILAGE 				= 1/3;		-- Number of lime applications
	RN.isPlowing.SILAGE 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.SILAGE 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.SILAGE 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.SILAGE 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.SILAGE	 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.SILAGE 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.SILAGE 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.SILAGE 				= RN.roundBale.volume;
	RN.squareBaleVolume.SILAGE 				= RN.squareBale.volume;
	RN.seederType.SILAGE					= "SEEDERS";
	RN.harvesterType.SILAGE					= "MOWERS";
	RN.isBaling.SILAGE	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.SILAGE						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.WETGRASS  					= "WETGRASS";
	RN.cropDensity.WETGRASS 				= RN.forageDensity.WETGRASS;		-- kg/L
	RN.cropYield.WETGRASS  					= RN.growth.grassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.WETGRASS  				= 0.153;	-- GEO DE
	RN.seedDensity.WETGRASS  				= 0.31;	-- kg/L
	RN.TSM.WETGRASS  						= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.WETGRASS  				= 550;		-- number of plants per sqm
	RN.germination.WETGRASS  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WETGRASS 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.WETGRASS  			= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.WETGRASS  			= RN.forageCost.grassPricePer100kg; -- GEO DE, price / 100 kg (5.00)
	RN.seederCalibration.WETGRASS  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WETGRASS					= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WETGRASS					= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WETGRASS					= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.WETGRASS			= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.WETGRASS					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.WETGRASS				= RN.fieldWorkCost.WETGRASS;	-- no harvest
	RN.manureApplications.WETGRASS 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.WETGRASS 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.WETGRASS 			= 1/3;		-- Number of lime applications
	RN.isPlowing.WETGRASS 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.WETGRASS 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.WETGRASS 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.WETGRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.WETGRASS 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.WETGRASS 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.WETGRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.WETGRASS 			= RN.roundBale.volume;
	RN.squareBaleVolume.WETGRASS 			= RN.squareBale.volume;
	RN.seederType.WETGRASS					= "SEEDERS";
	RN.harvesterType.WETGRASS				= "MOWERS";
	RN.isBaling.WETGRASS	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.WETGRASS					= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.WETGRASS_WINDROW  				= "WETGRASS_WINDROW";
	RN.cropDensity.WETGRASS_WINDROW 			= RN.forageDensity.WETGRASS_WINDROW;		-- kg/L
	RN.cropYield.WETGRASS_WINDROW  				= RN.growth.grassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.WETGRASS_WINDROW  			= 0.153;	-- GEO DE
	RN.seedDensity.WETGRASS_WINDROW  			= 0.31;	-- kg/L
	RN.TSM.WETGRASS_WINDROW  					= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.WETGRASS_WINDROW  			= 550;		-- number of plants per sqm
	RN.germination.WETGRASS_WINDROW  			= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WETGRASS_WINDROW 		= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.WETGRASS_WINDROW  		= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.WETGRASS_WINDROW  		= RN.forageCost.grassPricePer100kg; -- GEO DE, price / 100 kg (5.00)
	RN.seederCalibration.WETGRASS_WINDROW  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WETGRASS_WINDROW				= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WETGRASS_WINDROW				= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WETGRASS_WINDROW				= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.WETGRASS_WINDROW		= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.WETGRASS_WINDROW				= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.WETGRASS_WINDROW			= RN.fieldWorkCost.WETGRASS;	-- no harvest
	RN.manureApplications.WETGRASS_WINDROW 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.WETGRASS_WINDROW 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.WETGRASS_WINDROW 		= 1/3;		-- Number of lime applications
	RN.isPlowing.WETGRASS_WINDROW 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.WETGRASS_WINDROW 		= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.WETGRASS_WINDROW 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.WETGRASS_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.WETGRASS_WINDROW 	= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.WETGRASS_WINDROW	= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.WETGRASS_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.WETGRASS_WINDROW 		= RN.roundBale.volume;
	RN.squareBaleVolume.WETGRASS_WINDROW 		= RN.squareBale.volume;
	RN.seederType.WETGRASS_WINDROW				= "SEEDERS";
	RN.harvesterType.WETGRASS_WINDROW			= "MOWERS";
	RN.isBaling.WETGRASS_WINDROW	 			= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.WETGRASS_WINDROW				= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.GRASS_WINDROW  				= "GRASS_WINDROW";
	RN.cropDensity.GRASS_WINDROW 			= RN.forageDensity.GRASS_WINDROW;	-- kg/L
	RN.cropYield.GRASS_WINDROW  			= RN.growth.grassMassPerHa/100; 	-- GEO DE,100 kg/ha (165.8)
	RN.yieldRange.GRASS_WINDROW  			= 0.153;	-- GEO DE
	RN.seedDensity.GRASS_WINDROW  			= 0.31;	-- kg/L
	RN.TSM.GRASS_WINDROW  					= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.GRASS_WINDROW  			= 550;		-- number of plants per sqm
	RN.germination.GRASS_WINDROW  			= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.GRASS_WINDROW 		= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.GRASS_WINDROW  	= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.GRASS_WINDROW  	= RN.forageCost.grassPricePer100kg; -- GEO DE, price / 100 kg (5.00)
	RN.seederCalibration.GRASS_WINDROW  	= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.GRASS_WINDROW				= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.GRASS_WINDROW				= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.GRASS_WINDROW				= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.GRASS_WINDROW		= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.GRASS_WINDROW				= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.GRASS_WINDROW			= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.GRASS_WINDROW 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.GRASS_WINDROW 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.GRASS_WINDROW 			= 1/3;		-- Number of lime applications
	RN.isPlowing.GRASS_WINDROW 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.GRASS_WINDROW 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.GRASS_WINDROW 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.GRASS_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.GRASS_WINDROW 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.GRASS_WINDROW 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.GRASS_WINDROW 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.GRASS_WINDROW 			= RN.roundBale.volume;
	RN.squareBaleVolume.GRASS_WINDROW 			= RN.squareBale.volume;
	RN.seederType.GRASS_WINDROW					= "SEEDERS";
	RN.harvesterType.GRASS_WINDROW				= "MOWERS";
	RN.isBaling.GRASS_WINDROW	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.GRASS_WINDROW					= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.SEMIDRY_GRASS  					= "SEMIDRY_GRASS";
	RN.cropDensity.SEMIDRY_GRASS 				= RN.forageDensity.SEMIDRY_GRASS;		-- kg/L
	RN.cropYield.SEMIDRY_GRASS  				= RN.growth.drygrassMassPerHa/100; 	-- GEO DE,100 kg/ha
	RN.yieldRange.SEMIDRY_GRASS  				= 0.153;	-- GEO DE
	RN.seedDensity.SEMIDRY_GRASS  				= 0.31;	-- kg/L
	RN.TSM.SEMIDRY_GRASS  						= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.SEMIDRY_GRASS  				= 550;		-- number of plants per sqm
	RN.germination.SEMIDRY_GRASS  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SEMIDRY_GRASS 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SEMIDRY_GRASS  		= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.SEMIDRY_GRASS  		= RN.forageCost.drygrassPricePer100kg;		-- GEO DE, price / 100 kg
	RN.seederCalibration.SEMIDRY_GRASS  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SEMIDRY_GRASS					= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SEMIDRY_GRASS					= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SEMIDRY_GRASS					= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.SEMIDRY_GRASS			= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.SEMIDRY_GRASS					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.SEMIDRY_GRASS				= RN.fieldWorkCost.GRASS;
	RN.manureApplications.SEMIDRY_GRASS 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.SEMIDRY_GRASS 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.SEMIDRY_GRASS 			= 1/3;		-- Number of lime applications
	RN.isPlowing.SEMIDRY_GRASS 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.SEMIDRY_GRASS 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.SEMIDRY_GRASS 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.SEMIDRY_GRASS 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.SEMIDRY_GRASS 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.SEMIDRY_GRASS 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.SEMIDRY_GRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.SEMIDRY_GRASS 			= RN.roundBale.volume;
	RN.squareBaleVolume.SEMIDRY_GRASS 			= RN.squareBale.volume;
	RN.seederType.SEMIDRY_GRASS					= "SEEDERS";
	RN.harvesterType.SEMIDRY_GRASS				= "HAY";
	RN.isBaling.SEMIDRY_GRASS	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.SEMIDRY_GRASS					= "HAY"; -- Bale type for crop, if any

	RN.fruits.SEMIDRY_GRASS_WINDROW  				= "SEMIDRY_GRASS_WINDROW";
	RN.cropDensity.SEMIDRY_GRASS_WINDROW 			= RN.forageDensity.SEMIDRY_GRASS_WINDROW;		-- kg/L
	RN.cropYield.SEMIDRY_GRASS_WINDROW  			= RN.growth.drygrassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.SEMIDRY_GRASS_WINDROW  			= 0.153;	-- GEO DE
	RN.seedDensity.SEMIDRY_GRASS_WINDROW  			= 0.31;	-- kg/L
	RN.TSM.SEMIDRY_GRASS_WINDROW  					= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.SEMIDRY_GRASS_WINDROW  			= 550;		-- number of plants per sqm
	RN.germination.SEMIDRY_GRASS_WINDROW  			= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SEMIDRY_GRASS_WINDROW 		= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SEMIDRY_GRASS_WINDROW  	= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.SEMIDRY_GRASS_WINDROW  	= RN.forageCost.drygrassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.SEMIDRY_GRASS_WINDROW  	= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SEMIDRY_GRASS_WINDROW				= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SEMIDRY_GRASS_WINDROW				= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SEMIDRY_GRASS_WINDROW				= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.SEMIDRY_GRASS_WINDROW		= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.SEMIDRY_GRASS_WINDROW				= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.SEMIDRY_GRASS_WINDROW			= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.SEMIDRY_GRASS_WINDROW 	= 0;		-- Number of solid manure applications
	RN.slurryApplications.SEMIDRY_GRASS_WINDROW 	= 1;		-- Number of liquid manure applications
	RN.limeApplications.SEMIDRY_GRASS_WINDROW 		= 1/3;		-- Number of lime applications
	RN.isPlowing.SEMIDRY_GRASS_WINDROW 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.SEMIDRY_GRASS_WINDROW 		= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.SEMIDRY_GRASS_WINDROW 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.SEMIDRY_GRASS_WINDROW = 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.SEMIDRY_GRASS_WINDROW 	= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.SEMIDRY_GRASS_WINDROW	= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.SEMIDRY_GRASS_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.SEMIDRY_GRASS_WINDROW 		= RN.roundBale.volume;
	RN.squareBaleVolume.SEMIDRY_GRASS_WINDROW 		= RN.squareBale.volume;
	RN.seederType.SEMIDRY_GRASS_WINDROW				= "SEEDERS";
	RN.harvesterType.SEMIDRY_GRASS_WINDROW			= "HAY";
	RN.isBaling.SEMIDRY_GRASS_WINDROW	 			= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.SEMIDRY_GRASS_WINDROW				= "HAY"; -- Bale type for crop, if any

	RN.fruits.DRYGRASS  					= "DRYGRASS";
	RN.cropDensity.DRYGRASS 				= RN.forageDensity.DRYGRASS; -- kg/L
	RN.cropYield.DRYGRASS  					= RN.growth.drygrassMassPerHa/100; 	  -- GEO DE,100 kg/ha
	RN.yieldRange.DRYGRASS  				= 0.153;	-- GEO DE
	RN.seedDensity.DRYGRASS  				= 0.31;	-- kg/L
	RN.TSM.DRYGRASS  						= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.DRYGRASS  				= 550;		-- number of plants per sqm
	RN.germination.DRYGRASS  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYGRASS 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.DRYGRASS  			= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.DRYGRASS  			= RN.forageCost.drygrassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.DRYGRASS  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYGRASS					= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYGRASS					= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYGRASS					= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.DRYGRASS			= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.DRYGRASS					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.DRYGRASS				= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.DRYGRASS 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.DRYGRASS 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.DRYGRASS 			= 1/3;		-- Number of lime applications
	RN.isPlowing.DRYGRASS 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.DRYGRASS 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.DRYGRASS 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.DRYGRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.DRYGRASS 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.DRYGRASS 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.DRYGRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.DRYGRASS 			= RN.roundBale.volume;
	RN.squareBaleVolume.DRYGRASS 			= RN.squareBale.volume;
	RN.seederType.DRYGRASS					= "SEEDERS";
	RN.harvesterType.DRYGRASS				= "HAY";
	RN.isBaling.DRYGRASS	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.DRYGRASS					= "HAY"; -- Bale type for crop, if any

	RN.fruits.DRYGRASS_WINDROW  				= "DRYGRASS_WINDROW";
	RN.cropDensity.DRYGRASS_WINDROW 			= RN.forageDensity.DRYGRASS_WINDROW; -- kg/L
	RN.cropYield.DRYGRASS_WINDROW  				= RN.growth.drygrassMassPerHa/100; 	  -- GEO DE,100 kg/ha
	RN.yieldRange.DRYGRASS_WINDROW  			= 0.153;	-- GEO DE
	RN.seedDensity.DRYGRASS_WINDROW  			= 0.31;	-- kg/L
	RN.TSM.DRYGRASS_WINDROW  					= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.DRYGRASS_WINDROW  			= 550;		-- number of plants per sqm
	RN.germination.DRYGRASS_WINDROW  			= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYGRASS_WINDROW 		= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.DRYGRASS_WINDROW  		= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.DRYGRASS_WINDROW  		= RN.forageCost.drygrassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.DRYGRASS_WINDROW  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYGRASS_WINDROW				= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYGRASS_WINDROW				= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYGRASS_WINDROW				= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.DRYGRASS_WINDROW		= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.DRYGRASS_WINDROW				= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.DRYGRASS_WINDROW			= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.DRYGRASS_WINDROW 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.DRYGRASS_WINDROW 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.DRYGRASS_WINDROW 		= 1/3;		-- Number of lime applications
	RN.isPlowing.DRYGRASS_WINDROW 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.DRYGRASS_WINDROW 		= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.DRYGRASS_WINDROW 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.DRYGRASS_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.DRYGRASS_WINDROW 	= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.DRYGRASS_WINDROW	= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.DRYGRASS_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.DRYGRASS_WINDROW 		= RN.roundBale.volume;
	RN.squareBaleVolume.DRYGRASS_WINDROW 		= RN.squareBale.volume;
	RN.seederType.DRYGRASS_WINDROW				= "SEEDERS";
	RN.harvesterType.DRYGRASS_WINDROW			= "HAY";
	RN.isBaling.DRYGRASS_WINDROW	 			= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.DRYGRASS_WINDROW				= "HAY"; -- Bale type for crop, if any

	RN.fruits.GRASS_DECO  					= "GRASS_DECO";
	RN.cropDensity.GRASS_DECO 				= RN.forageDensity.GRASS;	-- kg/L
	RN.cropYield.GRASS_DECO  				= RN.growth.grassMassPerHa/100; 	-- GEO DE,100 kg/ha (165.8)
	RN.yieldRange.GRASS_DECO  				= 0.153;	-- GEO DE
	RN.seedDensity.GRASS_DECO  				= 0.31;	-- kg/L
	RN.TSM.GRASS_DECO  						= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.GRASS_DECO  			= 550;		-- number of plants per sqm
	RN.germination.GRASS_DECO  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.GRASS_DECO 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.GRASS_DECO  		= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.GRASS_DECO  		= RN.forageCost.grassPricePer100kg; -- GEO DE, price / 100 kg (5.00)
	RN.seederCalibration.GRASS_DECO  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.GRASS_DECO					= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.GRASS_DECO					= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.GRASS_DECO					= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.GRASS_DECO		= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.GRASS_DECO				= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.GRASS_DECO				= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.GRASS_DECO 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.GRASS_DECO 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.GRASS_DECO 			= 1/3;		-- Number of lime applications
	RN.isPlowing.GRASS_DECO 				= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.GRASS_DECO 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.GRASS_DECO 	= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.GRASS_DECO 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.GRASS_DECO 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.GRASS_DECO		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.GRASS_DECO 	= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.GRASS_DECO 			= RN.roundBale.volume;
	RN.squareBaleVolume.GRASS_DECO 			= RN.squareBale.volume;
	RN.seederType.GRASS_DECO				= "SEEDERS";
	RN.harvesterType.GRASS_DECO				= "MOWERS";
	RN.isBaling.GRASS_DECO	 				= 0;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.GRASS_DECO					= "noBale"; -- Bale type for crop, if any

	RN.fruits.HORSEGRASS  						= "HORSEGRASS";
	RN.cropDensity.HORSEGRASS 					= RN.forageDensity.HORSEGRASS;		-- kg/L
	RN.cropYield.HORSEGRASS  					= RN.growth.grassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.HORSEGRASS  					= 0.153;	-- GEO DE
	RN.seedDensity.HORSEGRASS  					= 0.31;	-- kg/L
	RN.TSM.HORSEGRASS  							= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.HORSEGRASS  				= 550;		-- number of plants per sqm
	RN.germination.HORSEGRASS  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.HORSEGRASS 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.HORSEGRASS  			= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.HORSEGRASS  			= RN.forageCost.grassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.HORSEGRASS  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.HORSEGRASS						= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.HORSEGRASS						= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.HORSEGRASS						= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.HORSEGRASS			= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.HORSEGRASS					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.HORSEGRASS					= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.HORSEGRASS 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.HORSEGRASS 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.HORSEGRASS 				= 1/3;		-- Number of lime applications
	RN.isPlowing.HORSEGRASS 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.HORSEGRASS 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.HORSEGRASS 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.HORSEGRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.HORSEGRASS	 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.HORSEGRASS 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.HORSEGRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.HORSEGRASS 				= RN.roundBale.volume;
	RN.squareBaleVolume.HORSEGRASS 				= RN.squareBale.volume;
	RN.seederType.HORSEGRASS					= "SEEDERS";
	RN.harvesterType.HORSEGRASS					= "MOWERS";
	RN.isBaling.HORSEGRASS	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.HORSEGRASS						= "HAY"; -- Bale type for crop, if any

	RN.fruits.WETHORSEGRASS  						= "WETHORSEGRASS";
	RN.cropDensity.WETHORSEGRASS 					= RN.forageDensity.WETHORSEGRASS;		-- kg/L
	RN.cropYield.WETHORSEGRASS  					= RN.growth.grassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.WETHORSEGRASS  					= 0.153;	-- GEO DE
	RN.seedDensity.WETHORSEGRASS  					= 0.31;	-- kg/L
	RN.TSM.WETHORSEGRASS  							= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.WETHORSEGRASS  					= 550;		-- number of plants per sqm
	RN.germination.WETHORSEGRASS  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WETHORSEGRASS 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.WETHORSEGRASS  			= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.WETHORSEGRASS  			= RN.forageCost.grassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.WETHORSEGRASS  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WETHORSEGRASS						= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WETHORSEGRASS						= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WETHORSEGRASS						= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.WETHORSEGRASS				= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.WETHORSEGRASS						= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.WETHORSEGRASS					= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.WETHORSEGRASS 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.WETHORSEGRASS 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.WETHORSEGRASS 				= 1/3;		-- Number of lime applications
	RN.isPlowing.WETHORSEGRASS 						= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.WETHORSEGRASS 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.WETHORSEGRASS 			= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.WETHORSEGRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.WETHORSEGRASS 			= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.WETHORSEGRASS	 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.WETHORSEGRASS 			= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.WETHORSEGRASS 				= RN.roundBale.volume;
	RN.squareBaleVolume.WETHORSEGRASS 				= RN.squareBale.volume;
	RN.seederType.WETHORSEGRASS						= "SEEDERS";
	RN.harvesterType.WETHORSEGRASS					= "MOWERS";
	RN.isBaling.WETHORSEGRASS	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.WETHORSEGRASS						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.WETHORSEGRASS_WINDROW  						= "WETHORSEGRASS_WINDROW";
	RN.cropDensity.WETHORSEGRASS_WINDROW 					= RN.forageDensity.WETHORSEGRASS_WINDROW;		-- kg/L
	RN.cropYield.WETHORSEGRASS_WINDROW  					= RN.growth.grassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.WETHORSEGRASS_WINDROW  					= 0.153;	-- GEO DE
	RN.seedDensity.WETHORSEGRASS_WINDROW  					= 0.31;	-- kg/L
	RN.TSM.WETHORSEGRASS_WINDROW  							= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.WETHORSEGRASS_WINDROW  					= 550;		-- number of plants per sqm
	RN.germination.WETHORSEGRASS_WINDROW  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WETHORSEGRASS_WINDROW 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.WETHORSEGRASS_WINDROW  			= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.WETHORSEGRASS_WINDROW  			= RN.forageCost.grassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.WETHORSEGRASS_WINDROW  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WETHORSEGRASS_WINDROW						= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WETHORSEGRASS_WINDROW						= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WETHORSEGRASS_WINDROW						= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.WETHORSEGRASS_WINDROW				= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.WETHORSEGRASS_WINDROW						= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.WETHORSEGRASS_WINDROW					= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.WETHORSEGRASS_WINDROW 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.WETHORSEGRASS_WINDROW 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.WETHORSEGRASS_WINDROW 				= 1/3;		-- Number of lime applications
	RN.isPlowing.WETHORSEGRASS_WINDROW 						= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.WETHORSEGRASS_WINDROW 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.WETHORSEGRASS_WINDROW 			= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.WETHORSEGRASS_WINDROW 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.WETHORSEGRASS_WINDROW 			= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.WETHORSEGRASS_WINDROW	 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.WETHORSEGRASS_WINDROW 			= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.WETHORSEGRASS_WINDROW 				= RN.roundBale.volume;
	RN.squareBaleVolume.WETHORSEGRASS_WINDROW 				= RN.squareBale.volume;
	RN.seederType.WETHORSEGRASS_WINDROW						= "SEEDERS";
	RN.harvesterType.WETHORSEGRASS_WINDROW					= "MOWERS";
	RN.isBaling.WETHORSEGRASS_WINDROW	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.WETHORSEGRASS_WINDROW						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.HORSEGRASS_WINDROW  							= "HORSEGRASS_WINDROW";
	RN.cropDensity.HORSEGRASS_WINDROW 						= RN.forageDensity.HORSEGRASS_WINDROW;		-- kg/L
	RN.cropYield.HORSEGRASS_WINDROW  						= RN.growth.grassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.HORSEGRASS_WINDROW  						= 0.153;	-- GEO DE
	RN.seedDensity.HORSEGRASS_WINDROW  						= 0.31;	-- kg/L
	RN.TSM.HORSEGRASS_WINDROW  								= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.HORSEGRASS_WINDROW  					= 550;		-- number of plants per sqm
	RN.germination.HORSEGRASS_WINDROW  						= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.HORSEGRASS_WINDROW 					= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.HORSEGRASS_WINDROW  				= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.HORSEGRASS_WINDROW  				= RN.forageCost.grassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.HORSEGRASS_WINDROW  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.HORSEGRASS_WINDROW							= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.HORSEGRASS_WINDROW							= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.HORSEGRASS_WINDROW							= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.HORSEGRASS_WINDROW				= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.HORSEGRASS_WINDROW						= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.HORSEGRASS_WINDROW						= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.HORSEGRASS_WINDROW 				= 0;		-- Number of solid manure applications
	RN.slurryApplications.HORSEGRASS_WINDROW 				= 1;		-- Number of liquid manure applications
	RN.limeApplications.HORSEGRASS_WINDROW 					= 1/3;		-- Number of lime applications
	RN.isPlowing.HORSEGRASS_WINDROW 						= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.HORSEGRASS_WINDROW 					= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.HORSEGRASS_WINDROW 			= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.HORSEGRASS_WINDROW 			= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.HORSEGRASS_WINDROW		 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.HORSEGRASS_WINDROW		 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.HORSEGRASS_WINDROW 			= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.HORSEGRASS_WINDROW 					= RN.roundBale.volume;
	RN.squareBaleVolume.HORSEGRASS_WINDROW 					= RN.squareBale.volume;
	RN.seederType.HORSEGRASS_WINDROW						= "SEEDERS";
	RN.harvesterType.HORSEGRASS_WINDROW						= "MOWERS";
	RN.isBaling.HORSEGRASS_WINDROW	 						= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.HORSEGRASS_WINDROW							= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.SEMIDRYHORSEGRASS  					= "SEMIDRYHORSEGRASS";
	RN.cropDensity.SEMIDRYHORSEGRASS 				= RN.forageDensity.SEMIDRYHORSEGRASS;		-- kg/L
	RN.cropYield.SEMIDRYHORSEGRASS  				= RN.growth.drygrassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.SEMIDRYHORSEGRASS  				= 0.153;	-- GEO DE
	RN.seedDensity.SEMIDRYHORSEGRASS  				= 0.31;	-- kg/L
	RN.TSM.SEMIDRYHORSEGRASS  						= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.SEMIDRYHORSEGRASS  				= 550;		-- number of plants per sqm
	RN.germination.SEMIDRYHORSEGRASS  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SEMIDRYHORSEGRASS 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SEMIDRYHORSEGRASS  		= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.SEMIDRYHORSEGRASS  		= RN.forageCost.drygrassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.SEMIDRYHORSEGRASS  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SEMIDRYHORSEGRASS					= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SEMIDRYHORSEGRASS					= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SEMIDRYHORSEGRASS					= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.SEMIDRYHORSEGRASS			= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.SEMIDRYHORSEGRASS					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.SEMIDRYHORSEGRASS				= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.SEMIDRYHORSEGRASS 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.SEMIDRYHORSEGRASS 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.SEMIDRYHORSEGRASS 			= 1/3;		-- Number of lime applications
	RN.isPlowing.SEMIDRYHORSEGRASS 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.SEMIDRYHORSEGRASS 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.SEMIDRYHORSEGRASS 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.SEMIDRYHORSEGRASS 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.SEMIDRYHORSEGRASS 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.SEMIDRYHORSEGRASS 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.SEMIDRYHORSEGRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.SEMIDRYHORSEGRASS 			= RN.roundBale.volume;
	RN.squareBaleVolume.SEMIDRYHORSEGRASS 			= RN.squareBale.volume;
	RN.seederType.SEMIDRYHORSEGRASS					= "SEEDERS";
	RN.harvesterType.SEMIDRYHORSEGRASS				= "HAY";
	RN.isBaling.SEMIDRYHORSEGRASS	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.SEMIDRYHORSEGRASS					= "HAY"; -- Bale type for crop, if any

	RN.fruits.SEMIDRYHORSEGRASS_WINDROW  					= "SEMIDRYHORSEGRASS_WINDROW";
	RN.cropDensity.SEMIDRYHORSEGRASS_WINDROW 				= RN.forageDensity.SEMIDRYHORSEGRASS_WINDROW;		-- kg/L
	RN.cropYield.SEMIDRYHORSEGRASS_WINDROW  				= RN.growth.drygrassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.SEMIDRYHORSEGRASS_WINDROW  				= 0.153;	-- GEO DE
	RN.seedDensity.SEMIDRYHORSEGRASS_WINDROW  				= 0.31;	-- kg/L
	RN.TSM.SEMIDRYHORSEGRASS_WINDROW  						= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.SEMIDRYHORSEGRASS_WINDROW  				= 550;		-- number of plants per sqm
	RN.germination.SEMIDRYHORSEGRASS_WINDROW  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SEMIDRYHORSEGRASS_WINDROW 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SEMIDRYHORSEGRASS_WINDROW  		= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.SEMIDRYHORSEGRASS_WINDROW  		= RN.forageCost.drygrassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.SEMIDRYHORSEGRASS_WINDROW  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SEMIDRYHORSEGRASS_WINDROW					= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SEMIDRYHORSEGRASS_WINDROW					= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SEMIDRYHORSEGRASS_WINDROW					= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.SEMIDRYHORSEGRASS_WINDROW			= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.SEMIDRYHORSEGRASS_WINDROW					= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.SEMIDRYHORSEGRASS_WINDROW				= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.SEMIDRYHORSEGRASS_WINDROW 		= 0;		-- Number of solid manure applications
	RN.slurryApplications.SEMIDRYHORSEGRASS_WINDROW 		= 1;		-- Number of liquid manure applications
	RN.limeApplications.SEMIDRYHORSEGRASS_WINDROW 			= 1/3;		-- Number of lime applications
	RN.isPlowing.SEMIDRYHORSEGRASS_WINDROW 					= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.SEMIDRYHORSEGRASS_WINDROW 			= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.SEMIDRYHORSEGRASS_WINDROW 		= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.SEMIDRYHORSEGRASS_WINDROW 	= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.SEMIDRYHORSEGRASS_WINDROW 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.SEMIDRYHORSEGRASS_WINDROW 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.SEMIDRYHORSEGRASS_WINDROW 		= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.SEMIDRYHORSEGRASS_WINDROW 			= RN.roundBale.volume;
	RN.squareBaleVolume.SEMIDRYHORSEGRASS_WINDROW 			= RN.squareBale.volume;
	RN.seederType.SEMIDRYHORSEGRASS_WINDROW					= "SEEDERS";
	RN.harvesterType.SEMIDRYHORSEGRASS_WINDROW				= "HAY";
	RN.isBaling.SEMIDRYHORSEGRASS_WINDROW	 				= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.SEMIDRYHORSEGRASS_WINDROW					= "HAY"; -- Bale type for crop, if any

	RN.fruits.DRYHORSEGRASS  						= "DRYHORSEGRASS";
	RN.cropDensity.DRYHORSEGRASS 					= RN.forageDensity.DRYHORSEGRASS;		-- kg/L
	RN.cropYield.DRYHORSEGRASS  					= RN.growth.drygrassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.DRYHORSEGRASS  					= 0.153;	-- GEO DE
	RN.seedDensity.DRYHORSEGRASS  					= 0.31;	-- kg/L
	RN.TSM.DRYHORSEGRASS  							= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.DRYHORSEGRASS  					= 550;		-- number of plants per sqm
	RN.germination.DRYHORSEGRASS  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYHORSEGRASS 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.DRYHORSEGRASS  			= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.DRYHORSEGRASS  			= RN.forageCost.drygrassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.DRYHORSEGRASS  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYHORSEGRASS						= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYHORSEGRASS						= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYHORSEGRASS						= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.DRYHORSEGRASS				= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.DRYHORSEGRASS						= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.DRYHORSEGRASS					= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.DRYHORSEGRASS 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.DRYHORSEGRASS 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.DRYHORSEGRASS 				= 1/3;		-- Number of lime applications
	RN.isPlowing.DRYHORSEGRASS 						= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.DRYHORSEGRASS 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.DRYHORSEGRASS 			= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.DRYHORSEGRASS 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.DRYHORSEGRASS 			= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.DRYHORSEGRASS	 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.DRYHORSEGRASS 			= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.DRYHORSEGRASS 				= RN.roundBale.volume;
	RN.squareBaleVolume.DRYHORSEGRASS 				= RN.squareBale.volume;
	RN.seederType.DRYHORSEGRASS						= "SEEDERS";
	RN.harvesterType.DRYHORSEGRASS					= "HAY";
	RN.isBaling.DRYHORSEGRASS	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.DRYHORSEGRASS						= "HAY"; -- Bale type for crop, if any

	RN.fruits.DRYHORSEGRASS_WINDROW  						= "DRYHORSEGRASS_WINDROW";
	RN.cropDensity.DRYHORSEGRASS_WINDROW 					= RN.forageDensity.DRYHORSEGRASS_WINDROW;		-- kg/L
	RN.cropYield.DRYHORSEGRASS_WINDROW  					= RN.growth.drygrassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.DRYHORSEGRASS_WINDROW  					= 0.153;	-- GEO DE
	RN.seedDensity.DRYHORSEGRASS_WINDROW  					= 0.31;	-- kg/L
	RN.TSM.DRYHORSEGRASS_WINDROW  							= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.DRYHORSEGRASS_WINDROW  					= 550;		-- number of plants per sqm
	RN.germination.DRYHORSEGRASS_WINDROW  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYHORSEGRASS_WINDROW 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.DRYHORSEGRASS_WINDROW  			= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.DRYHORSEGRASS_WINDROW  			= RN.forageCost.drygrassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.DRYHORSEGRASS_WINDROW  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYHORSEGRASS_WINDROW						= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYHORSEGRASS_WINDROW						= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYHORSEGRASS_WINDROW						= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.DRYHORSEGRASS_WINDROW				= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.DRYHORSEGRASS_WINDROW						= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.DRYHORSEGRASS_WINDROW					= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.DRYHORSEGRASS_WINDROW 			= 0;		-- Number of solid manure applications
	RN.slurryApplications.DRYHORSEGRASS_WINDROW 			= 1;		-- Number of liquid manure applications
	RN.limeApplications.DRYHORSEGRASS_WINDROW 				= 1/3;		-- Number of lime applications
	RN.isPlowing.DRYHORSEGRASS_WINDROW 						= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.DRYHORSEGRASS_WINDROW 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.DRYHORSEGRASS_WINDROW 			= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.DRYHORSEGRASS_WINDROW 		= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.DRYHORSEGRASS_WINDROW	 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.DRYHORSEGRASS_WINDROW	 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.DRYHORSEGRASS_WINDROW 			= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.DRYHORSEGRASS_WINDROW 				= RN.roundBale.volume;
	RN.squareBaleVolume.DRYHORSEGRASS_WINDROW 				= RN.squareBale.volume;
	RN.seederType.DRYHORSEGRASS_WINDROW						= "SEEDERS";
	RN.harvesterType.DRYHORSEGRASS_WINDROW					= "HAY";
	RN.isBaling.DRYHORSEGRASS_WINDROW	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.DRYHORSEGRASS_WINDROW						= "HAY"; -- Bale type for crop, if any

	RN.fruits.HORSEGRASS_FERMENTED  						= "HORSEGRASS_FERMENTED";
	RN.cropDensity.HORSEGRASS_FERMENTED 					= RN.forageDensity.HORSEGRASS_FERMENTED;		-- kg/L
	RN.cropYield.HORSEGRASS_FERMENTED  						= RN.growth.grassSilageMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.HORSEGRASS_FERMENTED  					= 0.153;	-- GEO DE
	RN.seedDensity.HORSEGRASS_FERMENTED  					= 0.31;	-- kg/L
	RN.TSM.HORSEGRASS_FERMENTED  							= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.HORSEGRASS_FERMENTED  					= 550;		-- number of plants per sqm
	RN.germination.HORSEGRASS_FERMENTED  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.HORSEGRASS_FERMENTED 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.HORSEGRASS_FERMENTED  				= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.HORSEGRASS_FERMENTED  				= RN.forageCost.grassSilagePricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.HORSEGRASS_FERMENTED  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.HORSEGRASS_FERMENTED						= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.HORSEGRASS_FERMENTED						= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.HORSEGRASS_FERMENTED						= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.HORSEGRASS_FERMENTED				= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.HORSEGRASS_FERMENTED						= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.HORSEGRASS_FERMENTED					= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.HORSEGRASS_FERMENTED 				= 0;		-- Number of solid manure applications
	RN.slurryApplications.HORSEGRASS_FERMENTED 				= 1;		-- Number of liquid manure applications
	RN.limeApplications.HORSEGRASS_FERMENTED 				= 1/3;		-- Number of lime applications
	RN.isPlowing.HORSEGRASS_FERMENTED 						= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.HORSEGRASS_FERMENTED 				= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.HORSEGRASS_FERMENTED 			= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.HORSEGRASS_FERMENTED 			= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.HORSEGRASS_FERMENTED	 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.HORSEGRASS_FERMENTED	 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.HORSEGRASS_FERMENTED 			= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.HORSEGRASS_FERMENTED 				= RN.roundBale.volume;
	RN.squareBaleVolume.HORSEGRASS_FERMENTED 				= RN.squareBale.volume;
	RN.seederType.HORSEGRASS_FERMENTED						= "SEEDERS";
	RN.harvesterType.HORSEGRASS_FERMENTED					= "MOWERS";
	RN.isBaling.HORSEGRASS_FERMENTED	 					= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.HORSEGRASS_FERMENTED						= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.FIELD_GRASS  									= "FIELD_GRASS";
	RN.cropDensity.FIELD_GRASS 								= RN.forageDensity.FIELD_GRASS;		-- kg/L
	RN.cropYield.FIELD_GRASS  								= RN.growth.grassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.FIELD_GRASS  								= 0.153;	-- GEO DE
	RN.seedDensity.FIELD_GRASS  							= 0.31;	-- kg/L
	RN.TSM.FIELD_GRASS  									= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.FIELD_GRASS  							= 550;		-- number of plants per sqm
	RN.germination.FIELD_GRASS  							= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.FIELD_GRASS 							= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.FIELD_GRASS  						= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.FIELD_GRASS  						= RN.forageCost.grassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.FIELD_GRASS  						= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.FIELD_GRASS									= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.FIELD_GRASS								= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.FIELD_GRASS								= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.FIELD_GRASS						= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.FIELD_GRASS								= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.FIELD_GRASS							= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.FIELD_GRASS 						= 0;		-- Number of solid manure applications
	RN.slurryApplications.FIELD_GRASS 						= 1;		-- Number of liquid manure applications
	RN.limeApplications.FIELD_GRASS 						= 1/3;		-- Number of lime applications
	RN.isPlowing.FIELD_GRASS 								= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.FIELD_GRASS 							= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.FIELD_GRASS 					= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.FIELD_GRASS 					= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.FIELD_GRASS				 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.FIELD_GRASS			 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.FIELD_GRASS 					= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.FIELD_GRASS 							= RN.roundBale.volume;
	RN.squareBaleVolume.FIELD_GRASS 						= RN.squareBale.volume;
	RN.seederType.FIELD_GRASS								= "SEEDERS";
	RN.harvesterType.FIELD_GRASS							= "MOWERS";
	RN.isBaling.FIELD_GRASS	 								= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.FIELD_GRASS									= "SILAGE"; -- Bale type for crop, if any

	RN.fruits.PASTUREGRASS  								= "PASTUREGRASS";
	RN.cropDensity.PASTUREGRASS 							= RN.forageDensity.PASTUREGRASS;		-- kg/L
	RN.cropYield.PASTUREGRASS  								= RN.growth.grassMassPerHa/100;  	-- 100 kg/ha,  165.8;
	RN.yieldRange.PASTUREGRASS  							= 0.153;	-- GEO DE
	RN.seedDensity.PASTUREGRASS  							= 0.31;	-- kg/L
	RN.TSM.PASTUREGRASS  									= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.PASTUREGRASS  							= 550;		-- number of plants per sqm
	RN.germination.PASTUREGRASS  							= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.PASTUREGRASS 						= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.PASTUREGRASS  						= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.PASTUREGRASS  						= RN.forageCost.grassPricePer100kg;	-- GEO DE, price / 100 kg
	RN.seederCalibration.PASTUREGRASS  						= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.PASTUREGRASS								= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.PASTUREGRASS								= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.PASTUREGRASS								= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.PASTUREGRASS						= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.PASTUREGRASS								= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.PASTUREGRASS							= RN.fieldWorkCost.GRASS;	-- no harvest
	RN.manureApplications.PASTUREGRASS 						= 0;		-- Number of solid manure applications
	RN.slurryApplications.PASTUREGRASS 						= 1;		-- Number of liquid manure applications
	RN.limeApplications.PASTUREGRASS 						= 1/3;		-- Number of lime applications
	RN.isPlowing.PASTUREGRASS 								= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.PASTUREGRASS 						= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.PASTUREGRASS 					= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.PASTUREGRASS 					= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.PASTUREGRASS			 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.PASTUREGRASS			 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.PASTUREGRASS 					= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.PASTUREGRASS 						= RN.roundBale.volume;
	RN.squareBaleVolume.PASTUREGRASS 						= RN.squareBale.volume;
	RN.seederType.PASTUREGRASS								= "SEEDERS";
	RN.harvesterType.PASTUREGRASS							= "MOWERS";
	RN.isBaling.PASTUREGRASS	 							= 3;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.PASTUREGRASS								= "HAY"; -- Bale type for crop, if any

	RN.fruits.CHAFF  							= "CHAFF";
	RN.cropDensity.CHAFF 						= 0.35;						-- kg/L
	RN.cropYield.CHAFF  						= RN.cropYield.MAIZE; 						-- GEO DE,100 kg/ha
	RN.yieldRange.CHAFF  						= RN.yieldRange.MAIZE;						-- GEO DE
	RN.seedDensity.CHAFF  						= RN.seedDensity.MAIZE;			-- kg/L
	RN.TSM.CHAFF  								= RN.TSM.MAIZE;					-- 1000 seed mass					Alberta: 380
	RN.plantsPerSqm.CHAFF  						= RN.plantsPerSqm.MAIZE;		-- number of plants per sqm			DK 6.5; ; Alberta: 6 (grain) 7.6 (silage)
	RN.germination.CHAFF  						= RN.germination.MAIZE;			-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.CHAFF 					= RN.seedUsagePerSqm.MAIZE;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.CHAFF  				= RN.seedPricePer100kg.MAIZE;	-- GEO DK, price / 100 kg
	RN.cropPricePer100kg.CHAFF  				= RN.forageCost.grassPricePer100kg;	-- GEO DE, price / 100 kg	
	RN.seederCalibration.CHAFF  				= RN.seederCalibration.MAIZE;	-- If seeder calibration is wanted.
	RN.Nitrogen.CHAFF							= RN.Nitrogen.MAIZE;			-- kg/ha Nitrogen  (N) fertilizer per year	DK: 138; Ontario: 157
	RN.Phosphate.CHAFF							= RN.Phosphate.MAIZE;			-- kg/ha Phosphate (P) fertilizer per year	DK:  35; Ontario:  56
	RN.Potassium.CHAFF							= RN.Potassium.MAIZE;			-- kg/ha Potassium (K) fertilizer per year	DK: 185; Ontario:  28
	RN.cropProtectionCost.CHAFF					= RN.cropProtectionCost.MAIZE;		-- DK: 70; Ontario: 42;
	RN.growthDays.CHAFF							= RN.growthDays.MAIZE;			-- Real-life days from seeding to harvest or between cuts
	RN.manureApplications.CHAFF 				= 0;		-- Number of solid manure applications
	RN.slurryApplications.CHAFF 				= 1;		-- Number of liquid manure applications
	RN.limeApplications.CHAFF 					= 1/3;		-- Number of lime applications
	RN.isPlowing.CHAFF 							= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.CHAFF 					= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.CHAFF 				= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.CHAFF 			= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.CHAFF		 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.CHAFF		 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.CHAFF 				= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.CHAFF 					= RN.roundBale.volume;
	RN.squareBaleVolume.CHAFF 					= RN.squareBale.volume;
	RN.seederType.CHAFF							= "SEEDERS";
	RN.harvesterType.CHAFF						= "MOWERS";
	RN.isBaling.CHAFF	 						= 0;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.CHAFF							= "noBale"; -- Bale type for crop, if any

	RN.fruits.FORAGE 							= "FORAGE";
	RN.cropDensity.FORAGE 						= RN.growth.grassBaleDensity;	-- kg/L
	RN.cropYield.FORAGE  						= RN.growth.grassMassPerHa/100; 	-- GEO DE,100 kg/ha (165.8)
	RN.yieldRange.FORAGE  						= 0.153;	-- GEO DE
	RN.seedDensity.FORAGE  						= 0.31;	-- kg/L
	RN.TSM.FORAGE  								= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.FORAGE  					= 550;		-- number of plants per sqm
	RN.germination.FORAGE  						= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.FORAGE 					= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.FORAGE  				= 350.00;	-- GEO DE, price / 100 kg	DK: 720; Manitoba: 200; US Rye grass 350
	RN.cropPricePer100kg.FORAGE  				= RN.forageCost.grassPricePer100kg; -- GEO DE, price / 100 kg (5.00)
	RN.seederCalibration.FORAGE  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.FORAGE							= 170;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.FORAGE							= 23;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.FORAGE							= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.cropProtectionCost.FORAGE				= 154;		-- €/ha DK: 154; Manitoba: 37;
	RN.growthDays.FORAGE						= 60;		-- Real-life days from seeding to harvest or between cuts
--	RN.fieldWorkCost.FORAGE						= RN.fieldWorkCost.FORAGE;	-- no harvest
	RN.manureApplications.FORAGE 				= 0;		-- Number of solid manure applications
	RN.slurryApplications.FORAGE 				= 1;		-- Number of liquid manure applications
	RN.limeApplications.FORAGE 					= 1/3;		-- Number of lime applications
	RN.isPlowing.FORAGE 						= 1;		-- If plowing set to 1 (one), if not plowing set to 0 (zero)
	RN.isDirectSeeding.FORAGE 					= 0;		-- If direct seeding with no cultivation and rolling, set to 1 (one); if cultivating before seeding, set to 0 (zero)
	RN.solidFertApplications.FORAGE 			= 0;		-- Number of solid fertilizer applications
	RN.liquidFertApplications.FORAGE 			= 1;		-- Number of liquid fertilizer applications
	RN.fertFirstApplication.FORAGE		 		= "cowLIQUIDMANURE";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.fertSecondApplication.FORAGE		 		= "LIQUIDFERTILIZER";	-- FERTILIZER, LIQUIDFERTILIZER, pigLIQUIDMANURE, cowLIQUIDMANURE, pigMANURE, cowMANURE, DIGESTATE, COMPOST
	RN.herbicideApplications.FORAGE 			= 1;		-- Number of liquid fertilizer applications
	RN.roundBaleVolume.FORAGE 					= RN.roundBale.volume;
	RN.squareBaleVolume.FORAGE 					= RN.squareBale.volume;
	RN.seederType.FORAGE						= "SEEDERS";
	RN.harvesterType.FORAGE						= "MOWERS";
	RN.isBaling.FORAGE	 						= 0;		-- If baling, set to number of cuttings, if not baling set to 0 (zero)
	RN.baleType.FORAGE							= "noBale"; -- Bale type for crop, if any



-- Forage commodities

-- ALFALFA / Lucerne / Luzerne

	RN.commodityName.ALFALFA 						= "ALFALFA";
	RN.commodityDensity.ALFALFA 					= RN.cropDensity.ALFALFA;		-- kg/L
	RN.commodityPricePer100kg.ALFALFA 				= RN.cropPricePer100kg.ALFALFA;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.ALFALFA_FERMENTED 				= "ALFALFA_FERMENTED";
	RN.commodityDensity.ALFALFA_FERMENTED 			= RN.forageDensity.SILAGE;	-- kg/L;	-- kg/L
	RN.commodityPricePer100kg.ALFALFA_FERMENTED 	= RN.forageCost.alfalfaSilagePricePer100kg;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.ALFALFA_WINDROW 				= "ALFALFA_WINDROW";
	RN.commodityDensity.ALFALFA_WINDROW 			= RN.cropDensity.ALFALFA;		-- kg/L
	RN.commodityPricePer100kg.ALFALFA_WINDROW 		= RN.cropPricePer100kg.ALFALFA;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.DRYALFALFA 					= "DRYALFALFA";
	RN.commodityDensity.DRYALFALFA 					= RN.cropDensity.DRYALFALFA;		-- kg/L
	RN.commodityPricePer100kg.DRYALFALFA 			= RN.cropPricePer100kg.DRYALFALFA;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.DRYALFALFA_WINDROW 			= "DRYALFALFA_WINDROW";
	RN.commodityDensity.DRYALFALFA_WINDROW 			= RN.cropDensity.DRYALFALFA;		-- kg/L
	RN.commodityPricePer100kg.DRYALFALFA_WINDROW 	= RN.cropPricePer100kg.DRYALFALFA;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SILOALFALFA 					= "SILOALFALFA";
	RN.commodityDensity.SILOALFALFA 				= RN.forageDensity.SILAGE;	-- kg/L;	-- kg/L
	RN.commodityPricePer100kg.SILOALFALFA 			= RN.forageCost.alfalfaSilagePricePer100kg;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.DRYLUCERNE 					= "DRYLUCERNE";
	RN.commodityDensity.DRYLUCERNE 					= RN.cropDensity.DRYALFALFA;		-- kg/L
	RN.commodityPricePer100kg.DRYLUCERNE 			= RN.cropPricePer100kg.DRYALFALFA;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.DRYLUCERNE_WINDROW 			= "DRYLUCERNE_WINDROW";
	RN.commodityDensity.DRYLUCERNE_WINDROW 			= RN.cropDensity.DRYALFALFA;		-- kg/L
	RN.commodityPricePer100kg.DRYLUCERNE_WINDROW 	= RN.cropPricePer100kg.DRYALFALFA;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.LUCERNE_WINDROW 				= "LUCERNE_WINDROW";
	RN.commodityDensity.LUCERNE_WINDROW 			= RN.cropDensity.ALFALFA;		-- kg/L
	RN.commodityPricePer100kg.LUCERNE_WINDROW 		= RN.cropPricePer100kg.ALFALFA;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.DRYLUZERNE 					= "DRYLUZERNE";
	RN.commodityDensity.DRYLUZERNE 					= RN.cropDensity.DRYALFALFA;		-- kg/L
	RN.commodityPricePer100kg.DRYLUZERNE 			= RN.cropPricePer100kg.DRYALFALFA;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.DRYLUZERNE_WINDROW 			= "DRYLUZERNE_WINDROW";
	RN.commodityDensity.DRYLUZERNE_WINDROW 			= RN.cropDensity.DRYALFALFA;		-- kg/L
	RN.commodityPricePer100kg.DRYLUZERNE_WINDROW 	= RN.cropPricePer100kg.DRYALFALFA;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.LUZERNE_WINDROW 				= "LUZERNE_WINDROW";
	RN.commodityDensity.LUZERNE_WINDROW 			= RN.cropDensity.ALFALFA;		-- kg/L
	RN.commodityPricePer100kg.LUZERNE_WINDROW 		= RN.cropPricePer100kg.ALFALFA;	-- GEO FS19_RDC, €-£-$/100 kg

--CLOVER

	RN.commodityName.CLOVER 						= "CLOVER";
	RN.commodityDensity.CLOVER 						= RN.cropDensity.CLOVER;		-- kg/L
	RN.commodityPricePer100kg.CLOVER 				= RN.cropPricePer100kg.CLOVER;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.CLOVER_FERMENTED 				= "CLOVER_FERMENTED";
	RN.commodityDensity.CLOVER_FERMENTED 			= RN.forageDensity.SILAGE;	-- kg/L;	-- kg/L
	RN.commodityPricePer100kg.CLOVER_FERMENTED 		= RN.forageCost.cloverSilagePricePer100kg;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.CLOVER_WINDROW 				= "CLOVER_WINDROW";
	RN.commodityDensity.CLOVER_WINDROW 				= RN.cropDensity.CLOVER;		-- kg/L
	RN.commodityPricePer100kg.CLOVER_WINDROW 		= RN.cropPricePer100kg.CLOVER;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.DRYCLOVER 						= "DRYCLOVER";
	RN.commodityDensity.DRYCLOVER 					= RN.cropDensity.DRYCLOVER;		-- kg/L
	RN.commodityPricePer100kg.DRYCLOVER 			= RN.cropPricePer100kg.DRYCLOVER;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.DRYCLOVER_WINDROW 				= "DRYCLOVER_WINDROW";
	RN.commodityDensity.DRYCLOVER_WINDROW 			= RN.cropDensity.DRYCLOVER;		-- kg/L
	RN.commodityPricePer100kg.DRYCLOVER_WINDROW 	= RN.cropPricePer100kg.DRYCLOVER;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SILOCLOVER 					= "SILOCLOVER";
	RN.commodityDensity.SILOCLOVER 					= RN.forageDensity.SILAGE;	-- kg/L;	-- kg/L
	RN.commodityPricePer100kg.SILOCLOVER 			= RN.forageCost.cloverSilagePricePer100kg;	-- GEO FS19_RDC, €-£-$/100 kg

-- GRASS

	RN.commodityName.GRASS 							= "GRASS";
	RN.commodityDensity.GRASS 						= RN.forageDensity.GRASS;	-- kg/L
	RN.commodityPricePer100kg.GRASS 				= RN.forageCost.grassPricePer100kg;	-- GEO HOF Bergmann, €-£-$/100 kg

	RN.commodityName.CHAFF_GRASS 					= "CHAFF_GRASS";
	RN.commodityDensity.CHAFF_GRASS 				= RN.forageDensity.GRASS;	-- kg/L
	RN.commodityPricePer100kg.CHAFF_GRASS 			= RN.forageCost.grassPricePer100kg;	-- GEO HOF Bergmann, €-£-$/100 kg
	
	RN.commodityName.SILAGE 						= "SILAGE";
	RN.commodityDensity.SILAGE 						= RN.forageDensity.SILAGE;	-- kg/L
	RN.commodityPricePer100kg.SILAGE 				= RN.forageCost.grassSilagePricePer100kg; -- GEO COM, €-£-$/100 kg
	
	RN.commodityName.GRASS_FERMENTED 				= "GRASS_FERMENTED";
	RN.commodityDensity.GRASS_FERMENTED 			= RN.forageDensity.SILAGE;	-- kg/L
	RN.commodityPricePer100kg.GRASS_FERMENTED 		= RN.forageCost.grassSilagePricePer100kg; -- GEO COM, €-£-$/100 kg	

	RN.commodityName.GRASS_WINDROW 					= "GRASS_WINDROW";
	RN.commodityDensity.GRASS_WINDROW 				= RN.forageDensity.GRASS;		-- kg/L
	RN.commodityPricePer100kg.GRASS_WINDROW 		= RN.forageCost.grassPricePer100kg;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.DRYGRASS 						= "DRYGRASS";
	RN.commodityDensity.DRYGRASS 					= RN.forageDensity.DRYGRASS;		-- kg/L
	RN.commodityPricePer100kg.DRYGRASS 				= RN.forageCost.drygrassPricePer100kg;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.DRYGRASS_WINDROW 				= "DRYGRASS_WINDROW";
	RN.commodityDensity.DRYGRASS_WINDROW 			= RN.forageDensity.DRYGRASS;		-- kg/L
	RN.commodityPricePer100kg.DRYGRASS_WINDROW 		= RN.forageCost.drygrassPricePer100kg;	-- GEO COM, €-£-$/100 kg
	
	RN.commodityName.SILOGRASS 						= "SILOGRASS";
	RN.commodityDensity.SILOGRASS 					= RN.forageDensity.SILAGE;	-- kg/L
	RN.commodityPricePer100kg.SILOGRASS 			= RN.forageCost.grassSilagePricePer100kg; -- GEO COM, €-£-$/100 kg	

-- MAIZE

	RN.commodityName.MAIZESILAGE 					= "MAIZESILAGE";
	RN.commodityDensity.MAIZESILAGE 				= RN.forageDensity.SILAGE;		-- kg/L HOF Bergman 1.0.0.6
	RN.commodityPricePer100kg.MAIZESILAGE 			= RN.forageCost.maizeSilagePricePer100kg;	-- GEO  HOF Bergman 1.0.0.6, €-£-$/100 kg

	RN.commodityName.CCM 							= "CCM";
	RN.commodityDensity.CCM 						= RN.forageDensity.SILAGE;		-- kg/L HOF Bergman 1.0.0.6
	RN.commodityPricePer100kg.CCM 					= RN.forageCost.maizeSilagePricePer100kg;	-- GEO  HOF Bergman 1.0.0.6, €-£-$/100 kg

	RN.commodityName.CHAFF 							= "CHAFF";
	RN.commodityDensity.CHAFF 						= RN.forageDensity.SILAGE;	-- kg/L
	RN.commodityPricePer100kg.CHAFF 				= RN.forageCost.maizeSilagePricePer100kg;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.CHOPPEDMAIZE 					= "CHOPPEDMAIZE";
	RN.commodityDensity.CHOPPEDMAIZE 				= RN.forageDensity.SILAGE;	-- kg/L
	RN.commodityPricePer100kg.CHOPPEDMAIZE 			= RN.forageCost.maizeSilagePricePer100kg;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.CHOPPEDMAIZE_FERMENTED 		= "CHOPPEDMAIZE_FERMENTED";
	RN.commodityDensity.CHOPPEDMAIZE_FERMENTED 		= RN.forageDensity.SILAGE;		-- kg/L HOF Bergman 1.0.0.6
	RN.commodityPricePer100kg.CHOPPEDMAIZE_FERMENTED= RN.forageCost.maizeSilagePricePer100kg;	-- GEO  HOF Bergman 1.0.0.6, €-£-$/100 kg

-- FORAGE

	RN.commodityName.FORAGE		 					= "FORAGE";	-- cow feed
	RN.commodityDensity.FORAGE 						= RN.forageDensity.GRASS;		-- kg/L
	RN.commodityPricePer100kg.FORAGE 				= RN.forageCost.grassPricePer100kg;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.FORAGE_MIXING 					= "FORAGE_MIXING";
	RN.commodityDensity.FORAGE_MIXING 				= RN.forageDensity.GRASS;		-- kg/L
	RN.commodityPricePer100kg.FORAGE_MIXING 		= RN.forageCost.grassPricePer100kg;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.FORAGE_WRAPPED 				= "FORAGE_WRAPPED";
	RN.commodityDensity.FORAGE_WRAPPED 				= RN.forageDensity.GRASS;		-- kg/L
	RN.commodityPricePer100kg.FORAGE_WRAPPED 		= RN.forageCost.grassPricePer100kg;	-- GEO HOF Bergmann, €-£-$/100 kg

--HEMP

	RN.commodityName.HEMP		 					= "HEMP";	-- cow feed
	RN.commodityDensity.HEMP 						= RN.cropDensity.HEMP;		-- kg/L
	RN.commodityPricePer100kg.HEMP 					= RN.cropPricePer100kg.HEMP;	-- GEO COM, €-£-$/100 kg


-- SEEDS


	RN.commodityName.SEED_ALFALFA 					= "SEED_ALFALFA";
	RN.commodityDensity.SEED_ALFALFA 				= RN.seedDensity.ALFALFA;		-- kg/L
	RN.commodityPricePer100kg.SEED_ALFALFA 			= RN.seedPricePer100kg.ALFALFA;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SEED_CLOVER 					= "SEED_CLOVER";
	RN.commodityDensity.SEED_CLOVER 				= RN.seedDensity.CLOVER;		-- kg/L
	RN.commodityPricePer100kg.SEED_CLOVER 			= RN.seedPricePer100kg.CLOVER;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SEED_GRASS 					= "SEED_GRASS";
	RN.commodityDensity.SEED_GRASS 					= RN.seedDensity.GRASS;		-- kg/L
	RN.commodityPricePer100kg.SEED_GRASS 			= RN.seedPricePer100kg.GRASS;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SEED_LUCERNE 					= "SEED_LUCERNE";
	RN.commodityDensity.SEED_LUCERNE 				= RN.seedDensity.LUCERNE;		-- kg/L
	RN.commodityPricePer100kg.SEED_LUCERNE 			= RN.seedPricePer100kg.LUCERNE;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SEED_LUZERNE 					= "SEED_LUZERNE";
	RN.commodityDensity.SEED_LUZERNE 				= RN.seedDensity.LUZERNE;		-- kg/L
	RN.commodityPricePer100kg.SEED_LUZERNE 			= RN.seedPricePer100kg.LUZERNE;	-- GEO COM, €-£-$/100 kg

--BALES

	RN.commodityName.ROUNDBALE 						= "ROUNDBALE"; 				-- assumed to be silage
	RN.commodityDensity.ROUNDBALE 					= RN.forageDensity.SILAGE;	-- kg/L
	RN.commodityVolume.ROUNDBALE					= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE 			= RN.forageCost.grassSilagePricePer100kg;	-- GEO COM, €-£-$/100 kg 12.00

	RN.commodityName.ROUNDBALE_ALFALFA  			= "ROUNDBALE_ALFALFA";
	RN.commodityDensity.ROUNDBALE_ALFALFA  			= RN.forageDensity.ALFALFA;	-- kg/L
	RN.commodityVolume.ROUNDBALE_ALFALFA 			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_ALFALFA  	= RN.forageCost.alfalfaPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.ROUNDBALE_DRYALFALFA 			= "ROUNDBALE_DRYALFALFA";
	RN.commodityDensity.ROUNDBALE_DRYALFALFA 		= RN.forageDensity.DRYALFALFA;-- kg/L
	RN.commodityVolume.ROUNDBALE_DRYALFALFA			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_DRYALFALFA 	= RN.forageCost.dryalfalfaPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.ROUNDBALE_CLOVER 				= "ROUNDBALE_CLOVER";
	RN.commodityDensity.ROUNDBALE_CLOVER 			= RN.forageDensity.CLOVER;	-- kg/L
	RN.commodityVolume.ROUNDBALE_CLOVER				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_CLOVER 		= RN.forageCost.cloverPricePer100kg;		-- GEO COM, €-£-$/100 kg 5.00

	RN.commodityName.ROUNDBALE_DRYCLOVER 			= "ROUNDBALE_DRYCLOVER";
	RN.commodityDensity.ROUNDBALE_DRYCLOVER 		= RN.forageDensity.DRYCLOVER;-- kg/L
	RN.commodityVolume.ROUNDBALE_DRYCLOVER			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_DRYCLOVER 	= RN.forageCost.drycloverPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.ROUNDBALE_GRASS 				= "ROUNDBALE_GRASS"; -- not silage
	RN.commodityDensity.ROUNDBALE_GRASS 			= RN.forageDensity.GRASS;	-- kg/L
	RN.commodityVolume.ROUNDBALE_GRASS				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_GRASS 		= RN.forageCost.grassPricePer100kg;		-- GEO COM, €-£-$/100 kg 5.00

	RN.commodityName.ROUNDBALE_DRYGRASS 			= "ROUNDBALE_DRYGRASS";
	RN.commodityDensity.ROUNDBALE_DRYGRASS 			= RN.forageDensity.DRYGRASS;-- kg/L
	RN.commodityVolume.ROUNDBALE_DRYGRASS			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_DRYGRASS 	= RN.forageCost.drygrassPricePer100kg;	-- GEO COM, €-£-$/100 kg 12.00

	RN.commodityName.ROUNDBALE_FORAGE 				= "ROUNDBALE_FORAGE"; -- not silage
	RN.commodityDensity.ROUNDBALE_FORAGE 			= RN.forageDensity.GRASS;	-- kg/L
	RN.commodityVolume.ROUNDBALE_FORAGE				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_FORAGE 		= RN.forageCost.grassPricePer100kg;		-- GEO COM, €-£-$/100 kg 5.00

	RN.commodityName.ROUNDBALE_LUCERNE 				= "ROUNDBALE_LUCERNE";
	RN.commodityDensity.ROUNDBALE_LUCERNE 			= RN.forageDensity.ALFALFA;	-- kg/L
	RN.commodityVolume.ROUNDBALE_LUCERNE			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_LUCERNE 	= RN.forageCost.alfalfaPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.ROUNDBALE_DRYLUCERNE 			= "ROUNDBALE_DRYLUCERNE";
	RN.commodityDensity.ROUNDBALE_DRYLUCERNE 		= RN.forageDensity.DRYALFALFA;-- kg/L
	RN.commodityVolume.ROUNDBALE_DRYLUCERNE			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_DRYLUCERNE 	= RN.forageCost.dryalfalfaPricePer100kg;	-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.ROUNDBALE_LUZERNE 				= "ROUNDBALE_LUZERNE";
	RN.commodityDensity.ROUNDBALE_LUZERNE 			= RN.forageDensity.ALFALFA;	-- kg/L
	RN.commodityVolume.ROUNDBALE_LUZERNE			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_LUZERNE 	= RN.forageCost.alfalfaPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.ROUNDBALE_DRYLUZERNE 			= "ROUNDBALE_DRYLUZERNE";
	RN.commodityDensity.ROUNDBALE_DRYLUZERNE 		= RN.forageDensity.DRYALFALFA;-- kg/L
	RN.commodityVolume.ROUNDBALE_DRYLUZERNE			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_DRYLUZERNE 	= RN.forageCost.dryalfalfaPricePer100kg;	-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.ROUNDBALE_RYE 					= "ROUNDBALE_RYE";
	RN.commodityDensity.ROUNDBALE_RYE 				= RN.forageDensity.STRAW;	-- kg/L
	RN.commodityVolume.ROUNDBALE_RYE				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_RYE 		= RN.forageCost.strawPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.ROUNDBALE_WHEAT 				= "ROUNDBALE_WHEAT";
	RN.commodityDensity.ROUNDBALE_WHEAT 			= RN.forageDensity.STRAW;	-- kg/L
	RN.commodityVolume.ROUNDBALE_WHEAT				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_WHEAT 		= RN.forageCost.strawPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.ROUNDBALE_BARLEY 				= "ROUNDBALE_BARLEY";
	RN.commodityDensity.ROUNDBALE_BARLEY 			= RN.forageDensity.STRAW;	-- kg/L
	RN.commodityVolume.ROUNDBALE_BARLEY				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_BARLEY 		= RN.forageCost.strawPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE 					= "SQUAREBALE";				-- Assumed silage
	RN.commodityDensity.SQUAREBALE 					= RN.forageDensity.SILAGE;-- kg/L
	RN.commodityVolume.SQUAREBALE					= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE 			= RN.forageCost.grassSilagePricePer100kg;	-- GEO COM, €-£-$/100 kg 12.00

	RN.commodityName.SQUAREBALE_ALFALFA 			= "SQUAREBALE_ALFALFA";
	RN.commodityDensity.SQUAREBALE_ALFALFA 			= RN.forageDensity.ALFALFA;	-- kg/L
	RN.commodityVolume.SQUAREBALE_ALFALFA			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_ALFALFA 	= RN.forageCost.alfalfaPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_DRYALFALFA 			= "SQUAREBALE_DRYALFALFA";
	RN.commodityDensity.SQUAREBALE_DRYALFALFA 		= RN.forageDensity.DRYALFALFA;-- kg/L
	RN.commodityVolume.SQUAREBALE_DRYALFALFA		= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_DRYALFALFA = RN.forageCost.dryalfalfaPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_BARLEY 				= "SQUAREBALE_BARLEY";
	RN.commodityDensity.SQUAREBALE_BARLEY 			= RN.forageDensity.STRAW;	-- kg/L
	RN.commodityVolume.SQUAREBALE_BARLEY			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_BARLEY 	= RN.forageCost.strawPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_CLOVER 				= "SQUAREBALE_CLOVER";
	RN.commodityDensity.SQUAREBALE_CLOVER 			= RN.forageDensity.CLOVER;	-- kg/L
	RN.commodityVolume.SQUAREBALE_CLOVER			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_CLOVER 	= RN.forageCost.cloverPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_DRYCLOVER 			= "SQUAREBALE_DRYCLOVER";
	RN.commodityDensity.SQUAREBALE_DRYCLOVER 		= RN.forageDensity.DRYCLOVER;-- kg/L
	RN.commodityVolume.SQUAREBALE_DRYCLOVER			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_DRYCLOVER 	= RN.forageCost.drycloverPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_GRASS 				= "SQUAREBALE_GRASS";
	RN.commodityDensity.SQUAREBALE_GRASS 			= RN.forageDensity.GRASS;	-- kg/L
	RN.commodityVolume.SQUAREBALE_GRASS				= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_GRASS 		= RN.forageCost.grassPricePer100kg;		-- GEO COM, €-£-$/100 kg 5.00

	RN.commodityName.SQUAREBALE_DRYGRASS 			= "squareBale_DRYGRASS";
	RN.commodityDensity.SQUAREBALE_DRYGRASS 		= RN.forageDensity.DRYGRASS;-- kg/L
	RN.commodityVolume.SQUAREBALE_DRYGRASS			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_DRYGRASS 	= RN.forageCost.drygrassPricePer100kg;	-- GEO COM, €-£-$/100 kg 12.00

	RN.commodityName.SQUAREBALE_LUCERNE 			= "SQUAREBALE_LUCERNE";
	RN.commodityDensity.SQUAREBALE_LUCERNE 			= RN.forageDensity.ALFALFA;	-- kg/L
	RN.commodityVolume.SQUAREBALE_LUCERNE			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_LUCERNE 	= RN.forageCost.alfalfaPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_DRYLUCERNE 			= "SQUAREBALE_DRYLUCERNE";
	RN.commodityDensity.SQUAREBALE_DRYLUCERNE 		= RN.forageDensity.DRYALFALFA;-- kg/L
	RN.commodityVolume.SQUAREBALE_DRYLUCERNE		= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_DRYLUCERNE = RN.forageCost.dryalfalfaPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_LUZERNE 			= "SQUAREBALE_LUZERNE";
	RN.commodityDensity.SQUAREBALE_LUZERNE 			= RN.forageDensity.ALFALFA;	-- kg/L
	RN.commodityVolume.SQUAREBALE_LUZERNE			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_LUZERNE 	= RN.forageCost.alfalfaPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_DRYLUZERNE 			= "SQUAREBALE_DRYLUZERNE";
	RN.commodityDensity.SQUAREBALE_DRYLUZERNE 		= RN.forageDensity.DRYALFALFA;-- kg/L
	RN.commodityVolume.SQUAREBALE_DRYLUZERNE		= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_DRYLUZERNE = RN.forageCost.dryalfalfaPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_RYE 				= "SQUAREBALE_RYE";
	RN.commodityDensity.SQUAREBALE_RYE 				= RN.forageDensity.STRAW;	-- kg/L
	RN.commodityVolume.SQUAREBALE_RYE				= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_RYE 		= RN.forageCost.strawPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_SILAGE 				= "SQUAREBALE_SILAGE";
	RN.commodityDensity.SQUAREBALE_SILAGE 			= RN.forageDensity.SILAGE;	-- kg/L
	RN.commodityVolume.SQUAREBALE_SILAGE			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_SILAGE 	= RN.forageCost.grassSilagePricePer100kg;		-- GEO COM, €-£-$/100 kg 12.0

	RN.commodityName.SQUAREBALE_WHEAT 				= "SQUAREBALE_WHEAT";
	RN.commodityDensity.SQUAREBALE_WHEAT 			= RN.forageDensity.STRAW;	-- kg/L
	RN.commodityVolume.SQUAREBALE_WHEAT				= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_WHEAT 		= RN.forageCost.strawPricePer100kg;		-- GEO COM, €-£-$/100 kg 7.80

	RN.commodityName.SQUAREBALE_COTTON 				= "SQUAREBALE_COTTON";
	RN.commodityDensity.SQUAREBALE_COTTON 			= 0.10;						-- kg/L
	RN.commodityVolume.SQUAREBALE_COTTON			= 20000;					-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_COTTON 	= 155;		-- GEO COM, €-£-$/100 kg 


-- Pellets

	RN.commodityName.STRAWPELLETS 					= "STRAWPELLETS";
	RN.commodityDensity.STRAWPELLETS 				= 0.75;	-- kg/L
	RN.commodityPricePer100kg.STRAWPELLETS 			= 10.00;		-- GEO COM, €-£-$/100 kg 12.0

	RN.commodityName.HAYPELLETS 					= "HAYPELLETS";
	RN.commodityDensity.HAYPELLETS 					= 0.80;	-- kg/L
	RN.commodityPricePer100kg.HAYPELLETS 			= 25.00;		-- GEO COM, €-£-$/100 kg


	iFillType = g_fillTypeManager:getFillTypeIndexByName("SILAGE");
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = RN.growth.grassSilageBaleDensity/massScale;
	g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = RN.forageCost.grassSilageRoundBalePrice/RN.growth.grassSilageRoundBaleVolume;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = RN.forageCost.grassSilageRoundBalePrice/RN.growth.grassSilageRoundBaleVolume;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = RN.forageCost.grassSilageRoundBalePrice/RN.growth.grassSilageRoundBaleVolume;		



end;

function RealNumbersForageCrops:keyEvent(unicode, sym, modifier, isDown)
end;

function RealNumbersForageCrops:update(dt)
end;
function RealNumbersForageCrops:draw()
end;
function RealNumbersForageCrops:deleteMap()
end;
function RealNumbersForageCrops:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersForageCrops);